'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index$1 = require('./index-e07e3a7e.js');
const abstractProvider = require('./abstract-provider-ca4f7e4f.js');
const utils = require('./utils-dd3b6f4c.js');
const feedbackSync = require('./feedbackSync-1c5ec9aa.js');
const index = require('./index-1efd27c0.js');
const index_es = require('./index.es-c563f3ba.js');
const constants = require('./constants-27331d2d.js');

class Errors {
    constructor() {
        this.component = (_title) => {
            const category = feedbackSync.ErrorCategory.Component;
            const title = `${_title} Error`;
            return {
                endtime_not_in_future: (message = '"endtime" can not be in the future') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                no_booking_info: (message = 'No booking info provided') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                no_timeslot_selected: (message = 'No timeslot selected') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                no_timezone_selected: (message = 'No timezone selected') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                no_booking_id: (message = 'No booking id provided') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                no_salt: (message = 'No salt provided') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                invalid_start_time: (message = 'Invalid start time') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                invalid_end_time: (message = 'Invalid end time') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                invalid_timezone: (message = 'Invalid timezone') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                no_config_id: (message = 'No configuration id provided') => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
            };
        };
        this.api = (_title) => {
            const category = feedbackSync.ErrorCategory.Api;
            const title = `${_title} Error`;
            return {
                invalid_session: (message) => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                general_error: (message) => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                internal_error: (message) => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                invalid_request_error: (message) => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                timeslot_not_available: (message) => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                provider_error: (message) => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
                not_found_error: (message) => {
                    return {
                        title,
                        message,
                        category,
                    };
                },
            };
        };
    }
}

class NylaSchedulerAPIConnector {
    constructor({ schedulerAPIURL, schedulerStore, sessionId, configId, slug, clientId }) {
        this.errors = new Errors();
        this.schedulerStore = schedulerStore;
        this.schedulerAPIURL = schedulerAPIURL;
        this.sessionId = sessionId;
        this.configId = configId;
        this.slug = slug;
        this.clientId = clientId;
    }
    getHeaders() {
        return this.sessionId
            ? {
                Authorization: `Bearer ${this.sessionId}`,
            }
            : {};
    }
    async makeAPIRequest(path, method, body, headers = {}) {
        try {
            const schedulerURL = new URL(this.schedulerAPIURL);
            const version = "2.0.1" ;
            schedulerURL.pathname = path;
            const response = await fetch(decodeURIComponent(schedulerURL.toString()), {
                method,
                headers: {
                    'Content-Type': 'application/json',
                    'Origin': window.location.origin,
                    'X-Source': 'nylas-scheduling',
                    'X-Nylas-Web-Elements-Version': version,
                    ...headers,
                },
                body,
            });
            const data = await response.json();
            return data;
        }
        catch (error) {
            return {
                error: {
                    message: error.message,
                    title: 'API request failed',
                    type: 'api',
                },
            };
        }
    }
    getErrorMessage(error) {
        let errorMessage = error?.message || error?.title || 'Something went wrong';
        if (error?.type === 'provider_error') {
            errorMessage = error?.provider_error?.error?.message || error?.provider_error?.error?.title || 'Something went wrong';
        }
        return errorMessage;
    }
    setConfigId(configId) {
        this.configId = configId;
    }
    selectDate(date) {
        this.schedulerStore.set('selectedDate', date);
        this.schedulerStore.set('selectedTimeslot', null);
    }
    selectTime(time) {
        this.schedulerStore.set('selectedTimeslot', time);
    }
    selectTimezone(timezone) {
        this.schedulerStore.set('selectedTimezone', timezone);
    }
    selectLanguage(language) {
        this.schedulerStore.set('selectedLanguage', language);
        utils.instance.changeLanguage(language);
    }
    async toggleAdditionalData(value) {
        if (!value) {
            await this.refetchAvailability();
        }
        this.schedulerStore.set('showBookingForm', value);
    }
    setParticipantName(name) {
        const { bookingInfo } = this.schedulerStore.state;
        this.schedulerStore.set('bookingInfo', {
            ...bookingInfo,
            primaryParticipant: {
                ...bookingInfo?.primaryParticipant,
                name,
            },
        });
    }
    setParticipantEmail(email) {
        const { bookingInfo } = this.schedulerStore.state;
        this.schedulerStore.set('bookingInfo', {
            ...bookingInfo,
            primaryParticipant: {
                ...bookingInfo?.primaryParticipant,
                email,
            },
        });
    }
    async refetchAvailability() {
        const today = new Date();
        const startTime = new Date(today.getFullYear(), today.getMonth(), 1).getTime() / 1000;
        const startTimeWithOffset = startTime < today.getTime() / 1000 ? Math.floor(today.getTime() / 1000) : startTime;
        const endTime = new Date(today.getFullYear(), today.getMonth() + 1, 1).getTime() / 1000;
        const result = await this.getAvailability(startTimeWithOffset, endTime);
        return result;
    }
    async resetStoreStateAndFetchAvailability() {
        const today = new Date();
        const result = await this.refetchAvailability();
        const firstAvailableDate = this.schedulerStore.get('availability').find((timeslot) => new Date(timeslot.start_time) > new Date());
        let _selectedDate = today;
        if (firstAvailableDate) {
            _selectedDate = firstAvailableDate.start_time;
        }
        this.schedulerStore.set('selectedDate', _selectedDate);
        this.schedulerStore.set('eventInfo', null);
        this.schedulerStore.set('showBookingForm', false);
        this.schedulerStore.set('selectedTimeslot', null);
        return result;
    }
    async setReschedule(bookingID) {
        this.schedulerStore.set('isLoading', true);
        const eventInfo = this.schedulerStore.state.eventInfo;
        if (eventInfo) {
            this.schedulerStore.set('reschedulingEventInfo', eventInfo);
        }
        this.schedulerStore.set('rescheduleBookingId', bookingID);
        await this.getUISettings();
        const result = await this.resetStoreStateAndFetchAvailability().finally(() => {
            this.schedulerStore.set('isLoading', false);
        });
        return result;
    }
    async setCancel(bookingID) {
        this.schedulerStore.set('cancelBookingId', bookingID);
    }
    async setReject(bookingID) {
        this.schedulerStore.set('rejectBookingId', bookingID);
    }
    async resetCancel() {
        const result = await this.resetStoreStateAndFetchAvailability();
        this.schedulerStore.set('cancelBookingId', '');
        this.schedulerStore.set('rejectBookingId', '');
        this.schedulerStore.set('cancelledEventInfo', null);
        return result;
    }
    async goBack() {
        this.schedulerStore.set('cancelBookingId', '');
        return;
    }
    async resetConfirm() {
        const result = await this.resetStoreStateAndFetchAvailability();
        this.schedulerStore.set('organizerConfirmationBookingId', '');
        this.schedulerStore.set('confirmedEventInfo', undefined);
        return result;
    }
    async bookTimeslot(data) {
        this.schedulerStore.set('isLoading', true);
        const { selectedTimeslot, selectedTimezone, bookingInfo, selectedLanguage } = this.schedulerStore.state;
        if (!data && !bookingInfo) {
            return { error: this.errors.component(utils.instance.t('createBookingErrorTitle')).no_booking_info() };
        }
        const timeslot = data?.timeslot || selectedTimeslot;
        if (!timeslot) {
            return { error: this.errors.component(utils.instance.t('createBookingErrorTitle')).no_timeslot_selected() };
        }
        const timezone = data && data?.timezone ? data?.timezone : selectedTimezone;
        const language = selectedLanguage || 'en-US';
        if (!timezone) {
            return { error: this.errors.component(utils.instance.t('createBookingErrorTitle')).no_timezone_selected() };
        }
        const order = [...this.schedulerStore.get('availabilityOrderEmails')];
        let participantToBookWith = '';
        const emails = timeslot?.emails || [];
        const addFields = {};
        Object.entries(bookingInfo?.additionalFields || {}).forEach(([key, entry]) => {
            addFields[key] = entry.value;
        });
        const primaryGuest = data ? data?.primaryParticipant : bookingInfo?.primaryParticipant;
        const guests = data ? data?.guests || [] : bookingInfo?.guests || [];
        const additional_fields = data ? data?.additionalFields : addFields;
        const headers = this.getHeaders();
        const configIdParam = !this.sessionId && this.configId
            ? `?configuration_id=${this.configId}`
            : !this.sessionId && this.slug && this.clientId
                ? `?slug=${this.slug}&client_id=${this.clientId}`
                : '';
        const url = `/v3/scheduling/bookings${configIdParam}`;
        if (order.length === 0) {
            const response = await this.makeAPIRequest(decodeURIComponent(url), 'POST', JSON.stringify({
                additional_fields,
                additional_guests: guests,
                guest: { ...primaryGuest },
                start_time: timeslot.start_time.getTime() / 1000,
                end_time: timeslot.end_time.getTime() / 1000,
                timezone,
                event_id: timeslot?.event_id || undefined,
                master_id: timeslot?.master_id || undefined,
                calendar_id: timeslot?.calendar_id || undefined,
                email_language: this.getTwoLetterLanguageCode(language),
            }), headers);
            this.schedulerStore.set('isLoading', false);
            if ('data' in response) {
                this.schedulerStore.set('eventInfo', response.data);
                return response;
            }
            return { error: response.error };
        }
        while (order.length > 0) {
            participantToBookWith = order.shift();
            if (!emails.includes(participantToBookWith)) {
                continue;
            }
            const response = await this.makeAPIRequest(decodeURIComponent(url), 'POST', JSON.stringify({
                participants: participantToBookWith ? [{ email: participantToBookWith }] : undefined,
                additional_fields,
                additional_guests: guests,
                guest: { ...primaryGuest },
                start_time: timeslot.start_time.getTime() / 1000,
                end_time: timeslot.end_time.getTime() / 1000,
                timezone: timezone,
                email_language: this.getTwoLetterLanguageCode(language),
            }), headers);
            if ('data' in response) {
                this.schedulerStore.set('isLoading', false);
                this.schedulerStore.set('eventInfo', response?.data);
                return response;
            }
            else if (response.error?.message?.startsWith('The selected timeslot is unavailable')) {
                continue;
            }
            else {
                this.schedulerStore.set('isLoading', false);
                const errorType = response.error?.type;
                let error = response.error;
                if (errorType && errorType in this.errors.api(utils.instance.t('createBookingErrorTitle'))) {
                    const errorMessage = this.getErrorMessage(error);
                    error = this.errors.api(utils.instance.t('createBookingErrorTitle'))[errorType](errorMessage);
                }
                return { error };
            }
        }
        this.schedulerStore.set('isLoading', false);
        return {
            error: this.errors.api(utils.instance.t('createBookingErrorTitle')).timeslot_not_available('The selected timeslot is unavailable'),
        };
    }
    async getUISettings() {
        this.schedulerStore.set('isLoading', true);
        const bookingId = this.schedulerStore.get('rescheduleBookingId');
        const headers = this.getHeaders();
        let configIdParam = !this.sessionId && this.configId
            ? `?configuration_id=${this.configId}`
            : !this.sessionId && this.slug && this.clientId
                ? `?slug=${this.slug}&client_id=${this.clientId}`
                : '';
        if (bookingId && !!configIdParam) {
            configIdParam += `&booking_id=${bookingId}`;
        }
        else if (bookingId) {
            configIdParam += `?booking_id=${bookingId}`;
        }
        const url = `/v3/scheduling/ui-settings${configIdParam}`;
        const response = await this.makeAPIRequest(url, 'GET', undefined, headers);
        if ('error' in response) {
            this.schedulerStore.set('isLoading', false);
            const errorType = response.error?.type;
            let error = response.error;
            if (errorType && errorType in this.errors.api(utils.instance.t('getUISettingErrorTitle'))) {
                error = this.errors.api(utils.instance.t('getUISettingErrorTitle'))[errorType](error?.message || error?.title || 'Something went wrong');
            }
            return { error };
        }
        if ('data' in response) {
            this.schedulerStore.set('configSettings', response.data);
        }
        this.schedulerStore.set('isLoading', false);
        return response;
    }
    getTwoLetterLanguageCode(language) {
        return language.split('-')[0];
    }
    getStartTimeWithMinBookingNotice(startTime) {
        const scheduler = this.schedulerStore.get('configSettings')?.scheduler;
        const min_booking_notice = scheduler?.min_booking_notice;
        if (!min_booking_notice) {
            return startTime;
        }
        const today = new Date().getTime();
        if (startTime < (today + min_booking_notice * 60 * 1000) / 1000) {
            return Math.floor((today + min_booking_notice * 60 * 1000) / 1000);
        }
        else {
            return startTime;
        }
    }
    getEndTimeForAvailableDaysInFuture(endTime) {
        const today = new Date();
        const availableDaysInFuture = this.schedulerStore.get('configSettings')?.scheduler?.available_days_in_future;
        const endTimeForAvailableDaysInFuture = Math.floor(utils.addDaysToCurrentDate(today, availableDaysInFuture).getTime() / 1000);
        const endTimeWithOffset = Math.min(endTimeForAvailableDaysInFuture, endTime);
        return endTimeWithOffset;
    }
    async getAvailability(startTime = 0, endTime = 0) {
        this.schedulerStore.set('isLoading', true);
        const params = new URLSearchParams();
        const now = new Date();
        const nowTime = now.getTime();
        if (endTime && endTime < nowTime / 1000) {
            this.schedulerStore.set('isLoading', false);
            const error = this.errors.component(utils.instance.t('getAvailabilityErrorTitle')).endtime_not_in_future();
            return { error };
        }
        if (!startTime) {
            const startOfMonth = new Date(now.getFullYear(), now.getMonth(), 1);
            startTime = Math.floor(startOfMonth.getTime() / 1000);
        }
        if (!endTime) {
            const endOfMonth = new Date(now.getFullYear(), now.getMonth() + 1, 0);
            endTime = Math.floor(endOfMonth.getTime() / 1000);
        }
        endTime = this.getEndTimeForAvailableDaysInFuture(endTime);
        const startTimeWithMinBooking = this.getStartTimeWithMinBookingNotice(startTime);
        startTime = startTimeWithMinBooking;
        endTime = startTimeWithMinBooking > endTime ? startTimeWithMinBooking + 1 : endTime;
        params.append('start_time', encodeURIComponent(startTime.toString()));
        params.append('end_time', encodeURIComponent(endTime.toString()));
        if (this.configId && !this.sessionId) {
            params.append('configuration_id', encodeURIComponent(this.configId));
        }
        else if (this.slug && this.clientId && !this.sessionId) {
            params.append('slug', encodeURIComponent(this.slug));
            params.append('client_id', encodeURIComponent(this.clientId));
        }
        const rescheduleBookingId = this.schedulerStore.get('rescheduleBookingId');
        if (rescheduleBookingId) {
            params.append('booking_id', encodeURIComponent(rescheduleBookingId));
        }
        const queryString = params.toString();
        const url = `/v3/scheduling/availability${queryString ? `?${queryString}` : ''}`;
        const headers = this.getHeaders();
        const response = await this.makeAPIRequest(decodeURIComponent(url), 'GET', undefined, headers);
        if ('error' in response) {
            this.schedulerStore.set('availability', []);
            this.schedulerStore.set('isLoading', false);
            const errorType = response.error?.type;
            let error = response.error;
            if (errorType && errorType in this.errors.api(utils.instance.t('getAvailabilityErrorTitle'))) {
                const errorMessage = this.getErrorMessage(error);
                error = this.errors.api(utils.instance.t('getAvailabilityErrorTitle'))[errorType](errorMessage);
            }
            return { error };
        }
        if ('data' in response) {
            const availability = response.data?.time_slots?.map(timeslot => {
                return {
                    ...timeslot,
                    start_time: new Date(timeslot.start_time * 1000),
                    end_time: new Date(timeslot.end_time * 1000),
                };
            }) || [];
            const availabilityTimeslotsFiltered = availability.filter(timeslot => timeslot.start_time.getTime() > nowTime);
            const availabilityTimeslotSorted = availabilityTimeslotsFiltered.sort((a, b) => a.start_time.getTime() - b.start_time.getTime());
            this.schedulerStore.set('availability', availabilityTimeslotSorted);
            const order = response.data?.order || [];
            this.schedulerStore.set('availabilityOrderEmails', order);
        }
        this.schedulerStore.set('isLoading', false);
        return response;
    }
    async cancelBooking(bookingId, reason) {
        this.schedulerStore.set('isLoading', true);
        if (!bookingId) {
            return { error: this.errors.component(utils.instance.t('cancelBookingErrorTitle')).no_booking_id() };
        }
        const configIdParam = !this.sessionId && this.configId
            ? `?configuration_id=${this.configId}`
            : !this.sessionId && this.slug && this.clientId
                ? `?slug=${this.slug}&client_id=${this.clientId}`
                : '';
        const url = `/v3/scheduling/bookings/${bookingId}${configIdParam}`;
        const headers = this.getHeaders();
        const response = await this.makeAPIRequest(decodeURIComponent(url), 'DELETE', JSON.stringify({
            action: 'cancel',
            cancellation_reason: reason,
        }), headers);
        if ('error' in response) {
            this.schedulerStore.set('isLoading', false);
            const errorType = response.error?.type;
            let error = response.error;
            if (errorType && errorType in this.errors.api(utils.instance.t('cancelBookingErrorTitle'))) {
                const errorMessage = this.getErrorMessage(error);
                error = this.errors.api(utils.instance.t('cancelBookingErrorTitle'))[errorType](errorMessage);
            }
            return { error };
        }
        this.schedulerStore.set('cancelledEventInfo', {
            booking_id: bookingId,
        });
        this.schedulerStore.set('rescheduleBookingId', '');
        this.schedulerStore.set('isLoading', false);
        return response;
    }
    async rescheduleBooking(bookingId, data) {
        this.schedulerStore.set('isLoading', true);
        if (!bookingId) {
            return { error: this.errors.component(utils.instance.t('rescheduleBookingErrorTitle')).no_booking_id() };
        }
        const apiErrors = this.errors.api(utils.instance.t('rescheduleBookingErrorTitle'));
        const componentErrors = this.errors.component(utils.instance.t('rescheduleBookingErrorTitle'));
        const { bookingInfo, selectedTimeslot, selectedTimezone, selectedLanguage } = this.schedulerStore.state;
        const { startTime, endTime, timezone } = data;
        const start_time = startTime || selectedTimeslot?.start_time;
        if (!start_time) {
            return { error: componentErrors.invalid_start_time('Please pass "startTime" in data or set "selectedTimeslot" in the defaultSchedulerState.') };
        }
        const end_time = endTime || selectedTimeslot?.end_time;
        if (!end_time) {
            return { error: componentErrors.invalid_end_time('Please pass "endTime" in data or set "selectedTimeslot" in the defaultSchedulerState.') };
        }
        const order = this.schedulerStore.get('availabilityOrderEmails');
        let participantToBookWith = '';
        if (order.length > 0) {
            const emails = selectedTimeslot?.emails || [];
            for (let i = 0; i < order.length; i++) {
                if (emails.includes(order[i])) {
                    participantToBookWith = order[i];
                    break;
                }
            }
        }
        const time_zone = timezone || selectedTimezone;
        if (!time_zone) {
            return { error: componentErrors.invalid_timezone('Please pass "timezone" in data or set "selectedTimezone" in the defaultSchedulerState.') };
        }
        const event_id = selectedTimeslot?.event_id || undefined;
        const master_id = selectedTimeslot?.master_id || undefined;
        const calendar_id = selectedTimeslot?.calendar_id || undefined;
        const addFields = {};
        Object.entries(bookingInfo?.additionalFields || {}).forEach(([key, entry]) => {
            addFields[key] = entry.value;
        });
        const primaryGuest = data ? data?.primaryParticipant : bookingInfo?.primaryParticipant;
        const guests = data ? data?.guests || [] : bookingInfo?.guests || [];
        const additional_fields = data ? data?.additionalFields : addFields;
        const configIdParam = !this.sessionId && this.configId
            ? `?configuration_id=${this.configId}`
            : !this.sessionId && this.slug && this.clientId
                ? `?slug=${this.slug}&client_id=${this.clientId}`
                : '';
        const url = `/v3/scheduling/bookings/${bookingId}${configIdParam}`;
        const headers = this.getHeaders();
        const response = await this.makeAPIRequest(decodeURIComponent(url), 'PATCH', JSON.stringify({
            start_time: start_time.getTime() / 1000,
            end_time: end_time.getTime() / 1000,
            timezone: time_zone,
            additional_fields,
            guest: { ...primaryGuest },
            additional_guests: guests,
            participants: participantToBookWith ? [{ email: participantToBookWith }] : undefined,
            email_language: this.getTwoLetterLanguageCode(selectedLanguage),
            event_id,
            master_id,
            calendar_id,
        }), headers);
        if ('error' in response) {
            this.schedulerStore.set('isLoading', false);
            const errorType = response.error?.type;
            let error = response.error;
            if (errorType && errorType in apiErrors) {
                const errorMessage = this.getErrorMessage(error);
                error = apiErrors[errorType](errorMessage);
            }
            return { error };
        }
        const eventInfo = this.schedulerStore.get('reschedulingEventInfo');
        if ('data' in response) {
            this.schedulerStore.set('eventInfo', response?.data);
        }
        else if (eventInfo) {
            this.schedulerStore.set('eventInfo', eventInfo);
        }
        else {
            const event = {
                booking_id: bookingId,
            };
            this.schedulerStore.set('eventInfo', event);
        }
        this.schedulerStore.set('isLoading', false);
        return response;
    }
    async updateBooking(payload) {
        this.schedulerStore.set('isLoading', true);
        const { bookingId, status, reason } = payload;
        const salt = this.schedulerStore.get('organizerConfirmationSalt');
        const errorTitle = status === 'confirmed' ? utils.instance.t('confirmBookingErrorTitle') : utils.instance.t('rejectBookingErrorTitle');
        if (!bookingId) {
            return { error: this.errors.component(errorTitle).no_booking_id() };
        }
        if (!salt) {
            return { error: this.errors.component(errorTitle).no_salt() };
        }
        const configIdParam = !this.sessionId && this.configId
            ? `?configuration_id=${this.configId}`
            : !this.sessionId && this.slug && this.clientId
                ? `?slug=${this.slug}&client_id=${this.clientId}`
                : '';
        const url = `/v3/scheduling/bookings/${bookingId}${configIdParam}`;
        const headers = this.getHeaders();
        const response = await this.makeAPIRequest(decodeURIComponent(url), 'PUT', JSON.stringify({
            status: status,
            cancellation_reason: reason,
            salt,
        }), headers);
        if ('error' in response) {
            this.schedulerStore.set('isLoading', false);
            const errorType = response.error?.type;
            let error = response.error;
            if (errorType && errorType in this.errors.api(errorTitle)) {
                const errorMessage = this.getErrorMessage(error);
                error = this.errors.api(errorTitle)[errorType](errorMessage);
            }
            return { error };
        }
        if ('data' in response && status === 'confirmed') {
            this.schedulerStore.set('confirmedEventInfo', response?.data);
        }
        else if ('request_id' in response && status === 'cancelled') {
            this.schedulerStore.set('cancelledEventInfo', {
                booking_id: bookingId,
            });
        }
        this.schedulerStore.set('organizerConfirmationBookingId', '');
        this.schedulerStore.set('isLoading', false);
        return response;
    }
    async validateGroupEventTimeslot(timeslot) {
        this.schedulerStore.set('isLoading', true);
        const configId = this.schedulerStore.get('configSettings')?.configuration_id;
        if (!configId) {
            return { error: this.errors.component(utils.instance.t('validateTimeslotErrorTitle')).no_config_id() };
        }
        const headers = this.getHeaders();
        const url = `/v3/scheduling/configurations/${configId}/group-events/validate-timeslot`;
        const response = await this.makeAPIRequest(decodeURIComponent(url), 'POST', JSON.stringify({
            ...timeslot,
            start_time: timeslot.start_time.getTime() / 1000,
            end_time: timeslot.end_time.getTime() / 1000,
        }), headers);
        if ('error' in response) {
            this.schedulerStore.set('isLoading', false);
            const errorType = response.error?.type;
            let error = response.error;
            if (errorType && errorType in this.errors.api(utils.instance.t('validateTimeslotErrorTitle'))) {
                const errorMessage = this.getErrorMessage(error);
                error = this.errors.api(utils.instance.t('validateTimeslotErrorTitle'))[errorType](errorMessage);
            }
            this.refetchAvailability();
            return { error };
        }
        this.schedulerStore.set('selectedTimeslot', timeslot);
        this.schedulerStore.set('showBookingForm', true);
        this.schedulerStore.set('isLoading', false);
        return response;
    }
}

class NylasSchedulerConnector {
    constructor({ schedulerAPIURL, nylasSchedulerStore, sessionId, configId, slug, clientId }) {
        if (!schedulerAPIURL) {
            throw new Error('schedulerAPIURL is required');
        }
        if (!nylasSchedulerStore) {
            throw new Error('nylasSchedulerStore is required');
        }
        if (!sessionId && !configId && !(slug || clientId)) {
            throw new Error('sessionId is required for private configs. If using public config either pass a configurationId or a combination of slug and clientId.');
        }
        if (schedulerAPIURL === '/') {
            const url = new URL(window.location.href);
            schedulerAPIURL = url.origin;
        }
        this.configId = configId;
        this.sessionId = sessionId;
        this.schedulerAPIURL = schedulerAPIURL;
        this.nylasSchedulerStore = nylasSchedulerStore;
        this.slug = slug;
        this.clientId = clientId;
    }
    init() {
        utils.debug('NylasConnector init');
    }
    get schedulerStore() {
        return this.nylasSchedulerStore;
    }
    get scheduler() {
        if (this._schedulerAPIConnector) {
            return this._schedulerAPIConnector;
        }
        this._schedulerAPIConnector = new NylaSchedulerAPIConnector({
            schedulerAPIURL: this.schedulerAPIURL,
            schedulerStore: this.schedulerStore,
            sessionId: this.sessionId,
            configId: this.configId,
            slug: this.slug,
            clientId: this.clientId,
        });
        return this._schedulerAPIConnector;
    }
    resetStores() {
        this.nylasSchedulerStore.reset();
    }
}

function CreateNylasSchedulerStore(defaultState = {}) {
    const defaultNylasStoreState = {
        selectedDate: null,
        selectedLanguage: navigator.language,
        selectedTimezone: Intl.DateTimeFormat().resolvedOptions().timeZone,
        selectedTimeslot: null,
        showBookingForm: false,
        availabilityOrderEmails: [],
        selectableDates: null,
        availability: [],
        eventDuration: 0,
        state: 'ready',
        eventInfo: null,
        cancelledEventInfo: null,
        isLoading: false,
        nylasBranding: true,
        ...defaultState,
    };
    utils.debug(`[defaultNylasStoreState]: `, defaultNylasStoreState);
    const store = index.createStore(defaultNylasStoreState);
    store.onChange('availability', availability => {
        utils.debug(`[availability]: `, availability);
        const selectableDates = availability.map(timeslot => timeslot.start_time);
        utils.debug(`[selectableDates]: `, selectableDates);
        store.set('selectableDates', selectableDates);
        const timeslot = availability[0];
        if (!timeslot)
            return;
        const durationMinutes = Math.floor((timeslot.end_time.getTime() - timeslot.start_time.getTime()) / 60000);
        utils.debug(`[durationMinutes]: `, durationMinutes);
        store.set('eventDuration', durationMinutes);
    });
    store.reset = () => {
        for (const key in defaultNylasStoreState) {
            const value = defaultNylasStoreState[key];
            store.set(key, value);
        }
    };
    return store;
}

const SchedulerView = (props, children) => {
    const isLoading = props.isLoading;
    const showNotification = props.showNotification;
    const nylasBranding = props.nylasBranding;
    const version = props.version;
    return (index$1.h(index$1.Fragment, null,
        showNotification && index$1.h("nylas-notification", null),
        isLoading && (index$1.h("div", { class: 'loading' },
            index$1.h("div", { class: 'left' },
                index$1.h("div", { class: 'skeleton' })),
            index$1.h("div", { class: 'right' },
                index$1.h("div", { class: 'skeleton' }),
                index$1.h("div", { class: 'skeleton' }),
                index$1.h("div", { class: 'skeleton' }),
                index$1.h("div", { class: 'skeleton' }),
                index$1.h("div", { class: 'skeleton' })))),
        !isLoading && children,
        index$1.h("div", { class: 'footer' },
            nylasBranding && (index$1.h("a", { href: "https://scheduler.nylas.com?utm_source=powered-by-nylas-logoutm_medium=link&utm_campaign=get-scheduler&utm_id=get-scheduler", class: "powered-by-nylas", target: "_blank", rel: "noreferrer noopener" },
                "Powered by\u00A0",
                index$1.h("span", { class: "sr-only" }, "Nylas"),
                index$1.h("nylas-logo", { "aria-hidden": true }))),
            index$1.h("tooltip-component", null,
                index$1.h("info-icon", { slot: "tooltip-icon" }),
                index$1.h("span", { slot: "tooltip-content" }, version)))));
};

const MessageBanner = (_props, children) => index$1.h("div", { class: "message-banner" }, children);

const nylasSchedulingCss = ":host{display:flex;flex-direction:column;overflow:visible;border-radius:var(--nylas-border-radius-2x);width:fit-content;background:var(--nylas-base-0);position:relative;box-shadow:0px 4px 8px 2px rgba(0, 0, 0, 0.05), 0px 8px 16px -2px rgba(0, 0, 0, 0.1);--nylas-primary:#2563eb;--nylas-error:#cc4841;--nylas-error-pressed:#992222;--nylas-wraning:#f06c00;--nylas-success:#16a392;--nylas-info:#2b8fc2;--nylas-base-0:#ffffff;--nylas-base-25:#fcfcfd;--nylas-base-50:#f8f9fc;--nylas-base-100:#eaecf5;--nylas-base-200:#d5d9eb;--nylas-base-300:#b3b8d8;--nylas-base-400:#717bbc;--nylas-base-500:#4e5ba6;--nylas-base-600:#3e4784;--nylas-base-700:#263f72;--nylas-base-800:#293056;--nylas-base-900:#101323;--nylas-base-950:#0e101b;--nylas-color-blue-100:#e0e6f9;--nylas-border-radius:0.25rem;--nylas-border-radius-2x:0.5rem;--nylas-border-radius-3x:0.75rem;--nylas-font-family:\"Inter\", sans-serif;--nylas-color-black:#000000;--nylas-color-grey-900:#2c2c2c;--nylas-color-grey-800:#4b4b4b;--nylas-color-grey-700:#6e6e6e;--nylas-color-grey-600:#8e8e8e;--nylas-color-grey-500:#b3b3b3;--nylas-color-grey-400:#cacaca;--nylas-color-grey-300:#e1e1e1;--nylas-color-grey-200:#eaeaea;--nylas-color-grey-100:#f5f5f5;--nylas-color-grey-50:#fbfcfe;--nylas-color-white:#ffffff;--nylas-color-red-900:#992222;--nylas-color-red-700:#cc4841;--nylas-color-red-500:#ff786a;--nylas-color-red-300:#ffa79e;--nylas-color-red-100:#ffc5bf;--nylas-color-red-50:#ffeae8;--nylas-color-blue-900:#213571;--nylas-color-blue-700:#314fa9;--nylas-color-blue-500:#4169e1;--nylas-color-blue-300:#bdccf9;--nylas-color-blue-100:#e0e6f9;--nylas-color-blue-50:#f6f8fd;--nylas-color-yellow-900:#7c6506;--nylas-color-yellow-700:#c29f09;--nylas-color-yellow-500:#f7c90b;--nylas-color-yellow-300:#f9de70;--nylas-color-yellow-100:#fceba9;--nylas-color-yellow-50:#fdf4ce;--nylas-color-green-900:#0e6b60;--nylas-color-green-700:#16a392;--nylas-color-green-500:#17c3b2;--nylas-color-green-300:#74dbd1;--nylas-color-green-100:#a2e7e0;--nylas-color-green-50:#d1f3f0;--nylas-color-purple-900:#643554;--nylas-color-purple-700:#954f7d;--nylas-color-purple-500:#c769a7;--nylas-color-purple-300:#dda5ca;--nylas-color-purple-100:#e0bdd6;--nylas-color-purple-50:#e9dde5;--nylas-color-sky-900:#20698f;--nylas-color-sky-700:#2b8fc2;--nylas-color-sky-500:#6dceff;--nylas-color-sky-300:#8fdaff;--nylas-color-sky-100:#b8e7ff;--nylas-color-sky-50:#d9f2ff;font-family:var(--nylas-font-family);font-optical-sizing:auto;font-style:normal;font-variation-settings:\"slnt\" 0}@media screen and (max-width: 768px){:host{width:auto;min-width:325px}}:root{font-family:inherit}.error{padding:8rem 12rem;color:var(--nylas-base-0);background-color:var(--nylas-error);margin:1.5rem;border-radius:var(--nylas-border-radius-2x)}.message-banner{text-align:right;color:var(--nylas-base-800);padding:1rem;border-bottom:1px solid var(--nylas-color-primary-200);margin:0}.loading{margin:1.5rem;display:flex;gap:1rem}.loading .skeleton{border-radius:var(--nylas-border-radius-2x);animation:pulsate 1.5s infinite}.loading .skeleton:nth-child(2){animation-delay:-100ms}.loading .skeleton:nth-child(3){animation-delay:-200ms}.loading .skeleton:nth-child(4){animation-delay:-300ms}.loading .skeleton:nth-child(5){animation-delay:-400ms}.loading .left .skeleton{height:100%;width:400px}.loading .right .skeleton{height:5rem;width:300px;margin-bottom:1rem}.loading .right .skeleton:last-child{margin-bottom:0}@keyframes pulsate{0%{background-color:var(--nylas-base-50)}50%{background-color:var(--nylas-base-100)}100%{background-color:var(--nylas-base-50)}}.select-date-page,.additional-data-page,.booked-event-page,.manual-confirmation-page,.cancelled-event-page,.cancel-flow-page{border-top-left-radius:var(--nylas-border-radius-2x);border-top-right-radius:var(--nylas-border-radius-2x)}.select-date-page,.additional-data-page{display:flex}@media screen and (max-width: 768px){.select-date-page,.additional-data-page{flex-direction:column}}.booked-event-page,.manual-confirmation-page{background-color:var(--nylas-base-50)}.cancelled-event-page,.manual-confirmation-page,.cancel-flow-page{padding:1rem;height:496px;display:flex;justify-content:center;align-items:center}.booked-event-page,.manual-confirmation-page,.cancelled-event-page,.cancel-flow-page{min-width:784px;background:var(--nylas-base-50)}@media screen and (max-width: 768px){.booked-event-page,.manual-confirmation-page,.cancelled-event-page,.cancel-flow-page{min-width:90%}}.left-panel{display:flex;flex-direction:column;min-width:424px;border-top-left-radius:inherit;background:var(--nylas-base-0);position:relative;padding:1rem 0 0 0;height:624px}@media screen and (max-width: 768px){.left-panel{border-top-right-radius:inherit;min-width:unset;height:auto}}@media screen and (max-width: 768px){.select-date-page .left-panel{height:624px}}.border{margin-left:-20px;margin-right:-20px;border-top-width:1px;height:0.5px;background-color:var(--nylas-base-200)}@media screen and (max-width: 768px){.border{display:none}}.right-panel{min-width:360px;width:360px;background-color:var(--nylas-base-50);height:624px;padding-top:16px;border-left:1px solid var(--nylas-base-200);border-top-right-radius:inherit}.right-panel.reschedule{border-top-right-radius:0px}@media screen and (max-width: 768px){.right-panel{border-top-right-radius:0px;width:inherit;min-width:unset;height:auto;border-left:none}}.right-panel h2{display:flex;margin:0;height:48px;gap:0.5rem;justify-content:center;align-items:center;width:auto;font-size:1.125rem;line-height:1.5rem;font-weight:500;text-align:center;color:var(--nylas-base-800)}.additional-data-page .left-panel{background-color:var(--nylas-base-50)}.additional-data-page .right-panel{background-color:var(--nylas-base-0)}nylas-selected-event-card{height:604px;padding:0 1rem}@media screen and (max-width: 768px){nylas-selected-event-card{height:250px}}.footer{display:flex;justify-content:flex-end;align-items:center;gap:8px;padding:16px;font-size:14px;font-weight:300;color:var(--nylas-base-500);border-top:1px solid var(--nylas-base-200);min-height:24px}.footer .powered-by-nylas{display:flex;align-items:center;text-decoration:none;color:var(--nylas-base-500)}.footer .powered-by-nylas:hover{color:var(--nylas-base-800)}.footer svg{fill:var(--nylas-base-500)}.sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0, 0, 0, 0);white-space:nowrap;border-width:0}.footer svg{margin-top:1px}nylas-selected-event-card::part(nsec__timezone){position:absolute;bottom:0}nylas-notification{margin:1.5rem;width:-webkit-fill-available;width:-moz-available;position:absolute}nylas-locale-switch{position:absolute;padding:18px 20px;bottom:0;width:-webkit-fill-available;width:-moz-available;border-top:1px solid var(--nylas-base-200)}@media screen and (max-width: 768px){nylas-locale-switch{height:auto}}nylas-date-picker{padding:0 20px}button-component#report-issue{width:auto;position:absolute;bottom:4px;left:16px}nylas-feedback-form{position:absolute;top:0;height:100%;width:100%;display:flex;flex-direction:column;justify-content:center;align-items:center;background:rgba(0, 0, 0, 0.6);z-index:2;border-radius:inherit}";
const NylasSchedulingStyle0 = nylasSchedulingCss;

const genericError = { title: utils.instance.t('genericErrorTitle'), type: index_es.nr.Error, category: feedbackSync.ErrorCategory.Component };
const NylasScheduling = class {
    constructor(hostRef) {
        index$1.registerInstance(this, hostRef);
        this.init = index$1.createEvent(this, "init", 7);
        this.schedulerWillLoad = index$1.createEvent(this, "schedulerWillLoad", 7);
        this.schedulerDidLoad = index$1.createEvent(this, "schedulerDidLoad", 7);
        this.nylasSchedulerError = index$1.createEvent(this, "nylasSchedulerError", 7);
        this.nylasSchedulerInfo = index$1.createEvent(this, "nylasSchedulerInfo", 7);
        this.configSettingsLoaded = index$1.createEvent(this, "configSettingsLoaded", 7);
        this.bookingRefExtracted = index$1.createEvent(this, "bookingRefExtracted", 7);
        this.bookedEventInfo = index$1.createEvent(this, "bookedEventInfo", 7);
        this.mode = 'app';
        this.defaultSchedulerState = undefined;
        this.sessionId = undefined;
        this.schedulerApiUrl = 'https://api.us.nylas.com';
        this.bookingInfo = undefined;
        this.rescheduleBookingRef = undefined;
        this.cancelBookingRef = undefined;
        this.organizerConfirmationBookingRef = undefined;
        this.configurationId = undefined;
        this.slug = undefined;
        this.clientId = undefined;
        this.nylasBranding = true;
        this.eventOverrides = {};
        this.isLoading = undefined;
        this.themeConfig = undefined;
        this.localization = undefined;
        this.showNotification = true;
        this.enableUserFeedback = true;
        this.hour12 = undefined;
        this.automaticComponentRegistration = true;
        this.selectedDateLabel = new Date().toLocaleDateString(navigator.language, { dateStyle: 'full' }) || `${utils.instance.t('noDateSelected')}`;
        this.refConfigId = undefined;
        this.language = navigator.language;
        this.showFeedbackModal = false;
        this.bookingInfoConfirmed = null;
        this.version = "2.0.1" ;
    }
    connectedCallback() {
        utils.debug(`[nylas-scheduler] connectedCallback`);
    }
    async componentWillLoad() {
        utils.debug(`[nylas-scheduler] Component will load`);
        this.version = "2.0.1" ;
        if (this.enableUserFeedback && !feedbackSync.isInitialized()) {
            feedbackSync.init({
                dsn: 'https://9d5731f1c77ca84c9ed3fb9b3ccf7ee1@o74852.ingest.us.sentry.io/4507889638178816',
                release: this.version,
                integrations: integrations => [
                    ...integrations.filter(_integration => false),
                    feedbackSync.feedbackSyncIntegration({
                        colorScheme: 'system',
                        autoInject: false,
                    }),
                ],
                autoSessionTracking: false,
                beforeSend: () => null,
            });
        }
        const schedulerWillLoadEvent = this.schedulerWillLoad.emit(this.host);
        if ('schedulerWillLoad' in this.eventOverrides) {
            await this.eventOverrides.schedulerWillLoad(schedulerWillLoadEvent, this.nylasSchedulerConnector);
            if (schedulerWillLoadEvent.defaultPrevented) {
                return;
            }
        }
        this.stores = {
            scheduler: CreateNylasSchedulerStore({
                bookingInfo: this.bookingInfo,
                nylasBranding: this.nylasBranding,
                themeConfig: this.themeConfig,
                hour12: this.hour12,
                ...this.defaultSchedulerState,
            }),
        };
        this.baseProvider = new abstractProvider.NylasBaseProvider(this.host, this.stores, this.automaticComponentRegistration, this.eventOverrides);
        this.refConfigId = this.configurationId;
        let bookingRefExtractedEvent;
        if (this.rescheduleBookingRef) {
            const [rescheduleConfigId, rescheduleBookingId, _] = utils.compactStringToUUIDs(this.rescheduleBookingRef);
            this.refConfigId = rescheduleConfigId;
            this.stores.scheduler.set('rescheduleBookingId', rescheduleBookingId);
            bookingRefExtractedEvent = this.bookingRefExtracted.emit({ configurationId: rescheduleConfigId, bookingId: rescheduleBookingId });
        }
        else if (this.cancelBookingRef) {
            const [cancelConfigId, cancelBookingId, _] = utils.compactStringToUUIDs(this.cancelBookingRef);
            this.refConfigId = cancelConfigId;
            this.stores.scheduler.set('cancelBookingId', cancelBookingId);
            bookingRefExtractedEvent = this.bookingRefExtracted.emit({ configurationId: cancelConfigId, bookingId: cancelBookingId });
        }
        else if (this.organizerConfirmationBookingRef) {
            const [organizerConfirmationConfigId, organizerConfirmationBookingId, salt] = utils.compactStringToUUIDs(this.organizerConfirmationBookingRef);
            this.refConfigId = organizerConfirmationConfigId;
            this.stores.scheduler.set('organizerConfirmationBookingId', organizerConfirmationBookingId);
            this.stores.scheduler.set('organizerConfirmationSalt', salt);
            bookingRefExtractedEvent = this.bookingRefExtracted.emit({ configurationId: organizerConfirmationConfigId, bookingId: organizerConfirmationBookingId, salt: salt });
        }
        if ('bookingRefExtracted' in this.eventOverrides) {
            await this.eventOverrides.bookingRefExtracted(bookingRefExtractedEvent, this.nylasSchedulerConnector);
            if (bookingRefExtractedEvent.defaultPrevented) {
                return;
            }
        }
        if (!this.checkIfSessionIdOrConfigIdExists()) {
            return;
        }
        const nylasSchedulerStore = this.baseProvider?.getStore('scheduler');
        this.nylasSchedulerConnector = new NylasSchedulerConnector({
            schedulerAPIURL: this.schedulerApiUrl,
            sessionId: this.sessionId,
            configId: this.refConfigId,
            slug: this.slug,
            clientId: this.clientId,
            nylasSchedulerStore,
        });
        const initEvent = this.init.emit(this.host);
        if ('init' in this.eventOverrides) {
            await this.eventOverrides.init(initEvent, this.nylasSchedulerConnector);
            if (initEvent.defaultPrevented) {
                return;
            }
        }
        this.baseProvider?.componentWillLoad(this.nylasSchedulerConnector);
        this.applyThemeConfig(this.themeConfig);
    }
    async componentDidLoad() {
        this.baseProvider?.componentDidLoad();
        const schedulerDidLoadEvent = this.schedulerDidLoad.emit(this.host);
        if ('schedulerDidLoad' in this.eventOverrides) {
            await this.eventOverrides.schedulerDidLoad(schedulerDidLoadEvent, this.nylasSchedulerConnector);
            if (schedulerDidLoadEvent.defaultPrevented) {
                return;
            }
        }
        if (!this.checkIfSessionIdOrConfigIdExists()) {
            return;
        }
        this.localizationChanged(this.localization);
        const settingsResponse = await this.nylasSchedulerConnector?.scheduler.getUISettings();
        if (!settingsResponse || 'error' in settingsResponse) {
            this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(settingsResponse?.error) }, host: this.host });
            return;
        }
        else {
            if ('data' in settingsResponse && settingsResponse.data?.appearance) {
                console.info('Appearance settings have been returned from the configuration used byt his scheduling page; please remember to grab them from the configSettingsLoaded event and apply them as desired.');
            }
            const configSettingsLoadedEvent = this.configSettingsLoaded.emit({ settings: settingsResponse });
            if ('configSettingsLoaded' in this.eventOverrides) {
                await this.eventOverrides.configSettingsLoaded(configSettingsLoadedEvent, this.nylasSchedulerConnector);
                if (configSettingsLoadedEvent.defaultPrevented) {
                    return;
                }
            }
        }
        const nylasSchedulerStore = this.baseProvider?.getStore('scheduler');
        const availableDaysInFuture = nylasSchedulerStore?.get('configSettings')?.scheduler?.available_days_in_future;
        const selectedTimeslot = nylasSchedulerStore?.get('selectedTimeslot');
        if (selectedTimeslot && selectedTimeslot?.start_time) {
            if (!this.isTimeslotValid(selectedTimeslot)) {
                return;
            }
            if (nylasSchedulerStore?.get('showBookingForm')) {
                nylasSchedulerStore?.set('selectedDate', selectedTimeslot.start_time);
                return;
            }
        }
        const selectedDate = nylasSchedulerStore?.get('selectedDate');
        const availability = nylasSchedulerStore?.get('availability');
        let result;
        if (availability && availability.length > 0) {
            return;
        }
        if (!selectedDate) {
            const today = new Date();
            const { startTime, endTime, endTimeForAvailableDaysInFuture } = this.validateAvailableDaysInFuture(today, availableDaysInFuture || 30);
            if (today.getTime() < endTimeForAvailableDaysInFuture * 1000) {
                result = await this.nylasSchedulerConnector?.scheduler.getAvailability(startTime, endTime);
            }
        }
        else {
            const { startTime, endTime, endTimeForAvailableDaysInFuture } = this.validateAvailableDaysInFuture(selectedDate, availableDaysInFuture || 30);
            if (selectedDate.getTime() < endTimeForAvailableDaysInFuture * 1000) {
                result = await this.nylasSchedulerConnector?.scheduler.getAvailability(startTime, endTime);
            }
        }
        if (!result || 'error' in result) {
            this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(result?.error) }, host: this.host });
        }
        if (!selectedDate) {
            let _selectedDate = new Date();
            const firstAvailableDate = nylasSchedulerStore?.get('availability').find((timeslot) => new Date(timeslot.start_time) > new Date());
            if (firstAvailableDate) {
                _selectedDate = firstAvailableDate.start_time;
            }
            nylasSchedulerStore?.set('selectedDate', _selectedDate);
        }
    }
    componentDisconnected() {
        this.baseProvider?.componentDisconnected();
    }
    bookingInfoChanged(newVal) {
        this.stores?.scheduler.set('bookingInfo', newVal);
    }
    rescheduleBookingRefChanged(newVal) {
        if (newVal) {
            const [configId, bookingId] = utils.compactStringToUUIDs(newVal);
            this.stores?.scheduler.set('rescheduleBookingId', bookingId);
            this.refConfigId = configId;
            this.nylasSchedulerConnector?.scheduler.setConfigId(configId);
        }
    }
    cancelBookingRefChanged(newVal) {
        if (newVal) {
            const [configId, bookingId] = utils.compactStringToUUIDs(newVal);
            this.stores?.scheduler.set('cancelBookingId', bookingId);
            this.refConfigId = configId;
            this.nylasSchedulerConnector?.scheduler.setConfigId(configId);
        }
    }
    organizerConfirmationBookingRefChanged(newVal) {
        if (newVal) {
            const [configId, bookingId] = utils.compactStringToUUIDs(newVal);
            this.stores?.scheduler.set('organizerConfirmationBookingId', bookingId);
            this.refConfigId = configId;
            this.nylasSchedulerConnector?.scheduler.setConfigId(configId);
        }
    }
    localizationChanged(newVal) {
        if (!newVal) {
            return;
        }
        Object.keys(newVal).forEach(lang => {
            if (!(lang in constants.LANGUAGE_CODE)) {
                return;
            }
            utils.instance.addResourceBundle(lang, 'translation', newVal[lang], false, true);
        });
    }
    themeConfigChanged(newVal) {
        this.baseProvider?.getStore('scheduler')?.set('themeConfig', newVal);
        this.applyThemeConfig(newVal);
    }
    languageChanged(event) {
        const newLanguage = event.detail;
        this.language = newLanguage;
        utils.instance.changeLanguage(newLanguage);
    }
    async registerComponentHandler(event) {
        this.baseProvider?.registerComponent(event.detail);
    }
    async unregisterComponentHandler(event) {
        this.baseProvider?.unregisterComponent(event.detail);
    }
    async monthChangedHandler(event) {
        const date = event.detail;
        const availableDaysInFuture = this.nylasSchedulerConnector?.schedulerStore?.get('configSettings')?.scheduler?.available_days_in_future;
        const { startTime, endTime, endTimeForAvailableDaysInFuture } = this.validateAvailableDaysInFuture(date, availableDaysInFuture || 30);
        if (event.defaultPrevented) {
            return;
        }
        if (startTime < endTimeForAvailableDaysInFuture && date.getTime() < endTimeForAvailableDaysInFuture * 1000) {
            const result = await this.nylasSchedulerConnector?.scheduler.getAvailability(startTime, endTime);
            if (!result || 'error' in result) {
                this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(result?.error) }, host: this.host });
            }
            const selectableDates = this.stores?.scheduler.get('selectableDates');
            if (selectableDates && selectableDates.length > 0) {
                this.stores?.scheduler.set('selectedDate', selectableDates[0]);
            }
        }
    }
    mapToBookingData(bookingInfo) {
        const timeslot = this.stores?.scheduler.get('selectedTimeslot');
        const language = this.stores?.scheduler.get('selectedLanguage');
        const timezone = this.stores?.scheduler.get('selectedTimezone');
        const startTime = timeslot?.start_time ? new Date(timeslot?.start_time).getTime() / 1000 : '';
        const endTime = timeslot?.end_time ? new Date(timeslot?.end_time).getTime() / 1000 : '';
        return {
            additional_guests: bookingInfo.guests,
            guest: { ...bookingInfo.primaryParticipant },
            additional_fields: { ...bookingInfo.additionalFields },
            start_time: startTime,
            end_time: endTime,
            email_language: language,
            timezone: timezone,
        };
    }
    async bookButtonClickedHandler(event) {
        if (event.defaultPrevented) {
            return;
        }
        const bookingData = event.detail;
        const mappedBookingData = this.mapToBookingData(bookingData);
        this.bookingInfoConfirmed = bookingData;
        const storeRescheduleId = this.nylasSchedulerConnector?.schedulerStore?.get('rescheduleBookingId');
        const rescheduleBookingId = storeRescheduleId;
        if (rescheduleBookingId) {
            const result = await this.nylasSchedulerConnector?.scheduler.rescheduleBooking(rescheduleBookingId, bookingData);
            if (!result || 'error' in result) {
                this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(result?.error) }, host: this.host });
            }
            const resultData = result?.data;
            const bookedEventInfoEvent = this.bookedEventInfo.emit({ ...result, data: { ...resultData, ...mappedBookingData } });
            this.bookingInfoConfirmed = { ...this.bookingInfoConfirmed, ...resultData };
            if ('bookedEventInfo' in this.eventOverrides) {
                await this.eventOverrides.bookedEventInfo(bookedEventInfoEvent, this.nylasSchedulerConnector);
            }
            return;
        }
        const result = await this.nylasSchedulerConnector?.scheduler.bookTimeslot(bookingData);
        if (!result || 'error' in result) {
            this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(result?.error) }, host: this.host });
        }
        const resultData = result?.data;
        const bookedEventInfoEvent = this.bookedEventInfo.emit({ ...result, data: { ...resultData, ...mappedBookingData } });
        this.bookingInfoConfirmed = { ...this.bookingInfoConfirmed, ...resultData };
        if ('bookedEventInfo' in this.eventOverrides) {
            await this.eventOverrides.bookedEventInfo(bookedEventInfoEvent, this.nylasSchedulerConnector);
        }
    }
    dateSelectedHandler(event) {
        const date = event.detail;
        this.selectedDateLabel = date ? date.toLocaleDateString(this.language, { dateStyle: 'full' }) : `${utils.instance.t('noDateSelected')}`;
    }
    cancelBookedEventErrorHandler(event) {
        this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(event.detail.error) }, host: this.host });
    }
    cancelBookedEventValidationErrorHandler(event) {
        this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(event.detail.error) }, host: this.host });
    }
    rescheduleBookedEventErrorHandler(event) {
        this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(event.detail.error) }, host: this.host });
    }
    confirmBookingErrorHandler(event) {
        this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject(event.detail.error) }, host: this.host });
    }
    feedbackModalClosedHandler() {
        this.showFeedbackModal = false;
    }
    eventIsFullHandler(_event) {
        const errorMessage = _event.detail.error;
        const type = _event.detail.type;
        if (type === 'error') {
            this.nylasSchedulerError.emit({ notification: { ...this.getErrorObject({ message: errorMessage }) }, host: this.host });
        }
        else {
            this.nylasSchedulerInfo.emit({
                notification: {
                    title: 'Event is full',
                    category: feedbackSync.ErrorCategory.Component,
                    type: index_es.nr.Info,
                    description: 'The event you selected is full. Please try a different time.',
                    id: new Date().getTime().toString(),
                    ttl: 3000,
                },
                host: this.host,
            });
        }
    }
    feedbackSubmittedHandler(event) {
        const eventId = feedbackSync.captureMessage('Scheduling Page User Feedback', {
            extra: {
                configId: this.configurationId,
                slug: this.slug,
            },
        });
        const feedback = {
            eventId: eventId,
            message: event.detail.feedback,
        };
        feedbackSync.captureFeedback(feedback, {
            includeReplay: true,
            captureContext: {
                tags: {
                    'nylas-web-element': 'nylas-scheduling',
                    'nylas-web-element-version': this.version,
                    'nylas-config-id': this.configurationId,
                    'nylas-slug': this.slug,
                    'host-url': window.location.href,
                },
                extra: {
                    configId: this.configurationId,
                    slug: this.slug,
                    version: this.version,
                },
            },
        });
        this.showFeedbackModal = false;
    }
    async getNylasSchedulerStore() {
        return this.baseProvider?.getStore('scheduler');
    }
    async getNylasSchedulerConnector() {
        return this.nylasSchedulerConnector;
    }
    async getRef() {
        return this.host;
    }
    getErrorObject(error) {
        return {
            title: error?.title || genericError.title,
            category: error?.category || genericError.category,
            type: index_es.nr.Error,
            description: error?.message || '',
            id: new Date().getTime().toString(),
            ttl: 'none',
        };
    }
    checkIfSessionIdOrConfigIdExists() {
        if (!this.sessionId && !this.refConfigId && !(this.slug && this.clientId)) {
            let description = '';
            if (!this.sessionId) {
                description += utils.instance.t('sessionIdRequiredErrorMessage');
            }
            if (!this.sessionId && !this.refConfigId && !(this.slug && this.clientId)) {
                description = utils.instance.t('sessionIdRequiredErrorMessage') + ' ' + utils.instance.t('publicConfigErrorMessage');
            }
            this.nylasSchedulerError.emit({
                notification: {
                    title: utils.instance.t('schedulingComponentErrorTitle'),
                    category: feedbackSync.ErrorCategory.Component,
                    type: index_es.nr.Error,
                    description: description,
                    id: new Date().getTime().toString(),
                    ttl: 'none',
                },
                host: this.host,
            });
            return false;
        }
        return true;
    }
    isTimeslotValid(timeslot) {
        const selectedDate = new Date(timeslot.start_time);
        if (selectedDate < new Date()) {
            this.nylasSchedulerError.emit({
                notification: {
                    title: utils.instance.t('invalidTimeslotErrorTitle'),
                    category: feedbackSync.ErrorCategory.Component,
                    type: index_es.nr.Error,
                    description: utils.instance.t('invalidTimeslotErrorMessage'),
                    id: new Date().getTime().toString(),
                    ttl: 'none',
                },
                host: this.host,
            });
            return false;
        }
        return true;
    }
    validateAvailableDaysInFuture(startDate, availableDaysInFuture) {
        const today = new Date();
        const startTime = new Date(startDate.getFullYear(), startDate.getMonth(), 1).getTime() / 1000;
        const endTimeForCurrentMonth = new Date(startDate.getFullYear(), startDate.getMonth() + 1, 1).getTime() / 1000;
        const endTimeForAvailableDaysInFuture = Math.floor(utils.addDaysToCurrentDate(today, availableDaysInFuture).getTime() / 1000);
        const endTime = Math.min(endTimeForAvailableDaysInFuture, endTimeForCurrentMonth);
        const startTimeWithOffset = startTime < today.getTime() / 1000 ? Math.floor(today.getTime() / 1000) : startTime;
        return { startTime: startTimeWithOffset, endTime, endTimeForAvailableDaysInFuture };
    }
    applyThemeConfig(themeConfig) {
        if (themeConfig) {
            for (const [key, value] of Object.entries(themeConfig)) {
                this.host.style.setProperty(`${key}`, value);
            }
        }
    }
    onFeedbackClick(e) {
        e.preventDefault();
        this.showFeedbackModal = true;
    }
    redirectToCustomUrl(url) {
        window.location.assign(url);
    }
    render() {
        const showDefaultScheduler = this.mode === 'app';
        const nylasSchedulerStore = this.baseProvider?.getStore('scheduler');
        const eventInfo = nylasSchedulerStore?.get('eventInfo');
        const showBookingForm = nylasSchedulerStore?.get('showBookingForm');
        const cancelledEventInfo = nylasSchedulerStore?.get('cancelledEventInfo');
        const cancelBookingId = nylasSchedulerStore?.get('cancelBookingId');
        const selectedTimeslot = nylasSchedulerStore?.get('selectedTimeslot');
        const rescheduleBookingId = nylasSchedulerStore?.get('rescheduleBookingId');
        const organizerConfirmationBookingId = nylasSchedulerStore?.get('organizerConfirmationBookingId');
        const rejectBookingId = nylasSchedulerStore?.get('rejectBookingId');
        const confirmedEventInfo = nylasSchedulerStore?.get('confirmedEventInfo');
        const nylasBranding = nylasSchedulerStore?.get('nylasBranding') || this.nylasBranding;
        const selectedDate = nylasSchedulerStore?.get('selectedDate');
        const redirectUrl = nylasSchedulerStore?.get('configSettings')?.scheduler?.confirmation_redirect_url;
        this.selectedDateLabel =
            selectedDate && this.language ? utils.capitalizeFirstLetter(selectedDate.toLocaleDateString(this.language, { dateStyle: 'full' })) : `${utils.instance.t('noDateSelected')}`;
        if (showDefaultScheduler && (cancelBookingId || rejectBookingId) && !cancelledEventInfo) {
            return (index$1.h(index$1.Host, null, index$1.h(SchedulerView, { version: this.version, nylasBranding: nylasBranding, isLoading: this.isLoading, showNotification: this.showNotification }, index$1.h("div", { class: "cancel-flow-page", part: "cancel-flow-page" }, index$1.h("nylas-cancel-booking-form", { selectedTimeslot: selectedTimeslot, cancelBookingId: cancelBookingId, rejectBookingId: rejectBookingId, exportparts: "ncbf, ncbf__icon, ncbf__title, ncbf__description, ncbf__reason-textarea, ncbf__button-cta, ncbf__button-outline, ncbf__card" }))), this.enableUserFeedback && (index$1.h("button-component", { id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, index$1.h("feedback-icon", null))), this.showFeedbackModal && index$1.h("nylas-feedback-form", null)));
        }
        if (showDefaultScheduler && organizerConfirmationBookingId) {
            return (index$1.h(index$1.Host, null, index$1.h(SchedulerView, null, index$1.h("div", { class: "manual-confirmation-page", part: "manual-confirmation-page" }, index$1.h("nylas-organizer-confirmation-card", { organizerConfirmationBookingId: organizerConfirmationBookingId, exportparts: "nmcc, nmcc__title, nmcc__description, nmcc__button-cta, nmcc__button-outline" }))), this.enableUserFeedback && (index$1.h("button-component", { id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, index$1.h("feedback-icon", null))), this.showFeedbackModal && index$1.h("nylas-feedback-form", null)));
        }
        if (showDefaultScheduler && cancelledEventInfo) {
            return (index$1.h(index$1.Host, null, index$1.h(SchedulerView, { version: this.version, nylasBranding: nylasBranding, isLoading: this.isLoading, showNotification: this.showNotification }, index$1.h("div", { class: "cancelled-event-page", part: "cancelled-event-page" }, index$1.h("nylas-cancelled-event-card", { cancelledEventInfo: cancelledEventInfo, exportparts: "ncec, ncec__icon, ncec__title, ncec__description, ncec__button-outline, ncec__card" }))), this.enableUserFeedback && (index$1.h("button-component", { id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, index$1.h("feedback-icon", null))), this.showFeedbackModal && index$1.h("nylas-feedback-form", null)));
        }
        if (showDefaultScheduler && confirmedEventInfo) {
            return (index$1.h(index$1.Host, null, index$1.h(SchedulerView, { version: this.version, nylasBranding: nylasBranding, isLoading: this.isLoading, showNotification: this.showNotification }, index$1.h("div", { class: "cancelled-event-page", part: "confirmed-event-page" }, index$1.h("nylas-confirmed-event-card", { confirmedEventInfo: confirmedEventInfo, exportparts: "ncec, ncec__icon, ncec__title, ncec__description, ncec__button-outline, ncec__card" }))), this.enableUserFeedback && (index$1.h("button-component", { id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, index$1.h("feedback-icon", null))), this.showFeedbackModal && index$1.h("nylas-feedback-form", null)));
        }
        if (showDefaultScheduler && eventInfo && redirectUrl) {
            const recipient = this.bookingInfoConfirmed?.primaryParticipant;
            const location = this.bookingInfoConfirmed?.location;
            const booking_ref = this.bookingInfoConfirmed?.booking_ref;
            const additionalFields = this.bookingInfoConfirmed?.additionalFields || {};
            if (this.bookingInfo && typeof this.bookingInfo?.additionalFields !== 'undefined') {
                const bookingInfoAdditionalFields = this.bookingInfo.additionalFields;
                Object.keys(bookingInfoAdditionalFields).forEach(key => {
                    if (!additionalFields[key] && bookingInfoAdditionalFields?.[key]) {
                        additionalFields[key] = bookingInfoAdditionalFields[key].value;
                    }
                });
            }
            const selectedTimeslot = this.stores?.scheduler.get('selectedTimeslot');
            const selectedTimezone = this.stores?.scheduler.get('selectedTimezone');
            const selectedLanguage = this.stores?.scheduler.get('selectedLanguage');
            const configSettings = this.stores?.scheduler.get('configSettings');
            const configurationId = this.configurationId ? this.configurationId : configSettings?.configuration_id;
            const queryString = window.location.search;
            const urlParams = new URLSearchParams(queryString);
            urlParams.set('booking_id', eventInfo.booking_id);
            recipient?.name && urlParams.set('name', recipient.name);
            recipient?.email && urlParams.set('email', recipient.email);
            selectedTimeslot?.start_time && urlParams.set('start_time', (new Date(selectedTimeslot.start_time).getTime() / 1000).toString());
            selectedTimeslot?.end_time && urlParams.set('end_time', (new Date(selectedTimeslot.end_time).getTime() / 1000).toString());
            selectedTimezone && urlParams.set('tz', selectedTimezone);
            selectedLanguage && urlParams.set('language', selectedLanguage);
            additionalFields && urlParams.set('additional_values', JSON.stringify(additionalFields));
            this.slug && urlParams.set('page_slug', this.slug);
            configurationId && urlParams.set('config_id', configurationId);
            location && urlParams.set('location', location);
            booking_ref && urlParams.set('booking_ref', booking_ref);
            this.redirectToCustomUrl(`${redirectUrl}?${urlParams.toString()}`);
            return;
        }
        if (showDefaultScheduler && eventInfo) {
            return (index$1.h(index$1.Host, null, index$1.h(SchedulerView, { version: this.version, nylasBranding: nylasBranding, isLoading: this.isLoading, showNotification: this.showNotification }, index$1.h("div", { class: "booked-event-page", part: "booked-event-page ns_booked-event-page" }, index$1.h("nylas-booked-event-card", { selectedTimeslot: selectedTimeslot, eventInfo: eventInfo, exportparts: "nbec, nbec__title, nbec__card, nbec__description, nbec__button-outline, nbec__cancel-cta, nbec__reschedule-cta" }))), this.enableUserFeedback && (index$1.h("button-component", { id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, index$1.h("feedback-icon", null))), this.showFeedbackModal && index$1.h("nylas-feedback-form", null)));
        }
        if (showDefaultScheduler && (!eventInfo || !!rescheduleBookingId) && !showBookingForm) {
            const timeslotPickerCTALabel = this.host.querySelector('[slot="timeslot-picker-cta-label"]');
            return (index$1.h(index$1.Host, null, index$1.h(SchedulerView, { version: this.version, nylasBranding: nylasBranding, isLoading: this.isLoading, showNotification: this.showNotification }, rescheduleBookingId && index$1.h(MessageBanner, null, `${utils.instance.t('rescheduleTitle')}`), index$1.h("div", { class: "select-date-page", part: "select-date-page ns_select-date-page" }, index$1.h("div", { class: "left-panel", part: "ns_left-panel" }, index$1.h("nylas-date-picker", { exportparts: "ndp, ndp__title, ndp__month-header, ndp__month-button, ndp__day, ndp__date, ndp__date--disabled, ndp__date--selected, ndp__date--current-day, ndp__date--current-month" }), index$1.h("nylas-locale-switch", { exportparts: "nls, nls__timezone, nls__timezone-dropdown, nls__timezone-drop-button, nls__timezone-drop-button-selected-label, nls__timezone-drop-content, nls__timezone-drop-label, nls__language, nls__language-dropdown, nls__language-drop-button, nls__language-drop-content, nls__language-drop-label" })), index$1.h("div", { class: `right-panel ${rescheduleBookingId ? 'reschedule' : ''}`, part: `ns_right-panel ${rescheduleBookingId ? 'ns_reschedule' : ''}` }, index$1.h("h2", { part: "ns_right-panel__title" }, index$1.h("calendar-icon", { part: "ns_right-panel__calendar-icon" }), index$1.h("span", { id: "selectedDate", part: "ns_right-panel__selected-date" }, this.selectedDateLabel)), index$1.h("nylas-timeslot-picker", { exportparts: "ntp, ntp__time-picker-wrapper, ntp__timeslots, ntp__timeslot, ntp__timeslot--selected, ntp__button-primary" }, timeslotPickerCTALabel && (index$1.h("span", { slot: "timeslot-picker-cta-label" }, index$1.h("slot", { name: "timeslot-picker-cta-label" }))))))), this.enableUserFeedback && (index$1.h("button-component", { id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, index$1.h("feedback-icon", null))), this.showFeedbackModal && index$1.h("nylas-feedback-form", null)));
        }
        if (showDefaultScheduler && !eventInfo && showBookingForm) {
            return (index$1.h(index$1.Host, null, index$1.h(SchedulerView, { version: this.version, nylasBranding: nylasBranding, isLoading: this.isLoading, showNotification: this.showNotification }, rescheduleBookingId && index$1.h(MessageBanner, null, `${utils.instance.t('rescheduleTitle')}`), index$1.h("div", { class: "additional-data-page", part: "additional-data-page ns_additional-data-page" }, index$1.h("div", { class: "left-panel ns_left-panel", part: "ns_left-panel" }, index$1.h("div", { class: "wrapper", part: "ns_left-panel__wrapper" }, index$1.h("nylas-selected-event-card", { exportparts: "nsec, nsec__card, nsec__icon, nsec__date, nsec__time, nsec__timezone" }))), index$1.h("div", { class: `right-panel ${rescheduleBookingId ? 'reschedule' : ''}`, part: `ns_right-panel ${rescheduleBookingId ? 'ns_reschedule' : ''}` }, index$1.h("nylas-booking-form", { exportparts: "nbf, nbf__input-textfield, nbf__button-ghost, nbf__button-outline, nbf__button-primary, nbf__input-wrapper, nbf__checkbox-component, nbf__radio-button-group, nbf__textarea-component, nbf__dropdown, nbf__dropdown-button, nbf__dropdown-content" })))), this.enableUserFeedback && (index$1.h("button-component", { id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, index$1.h("feedback-icon", null))), this.showFeedbackModal && index$1.h("nylas-feedback-form", null)));
        }
        return (index$1.h(index$1.Host, null, index$1.h("slot", null)));
    }
    get host() { return index$1.getElement(this); }
    static get watchers() { return {
        "bookingInfo": ["bookingInfoChanged"],
        "rescheduleBookingRef": ["rescheduleBookingRefChanged"],
        "cancelBookingRef": ["cancelBookingRefChanged"],
        "organizerConfirmationBookingRef": ["organizerConfirmationBookingRefChanged"],
        "localization": ["localizationChanged"],
        "themeConfig": ["themeConfigChanged"]
    }; }
};
NylasScheduling.style = NylasSchedulingStyle0;

exports.nylas_scheduling = NylasScheduling;

//# sourceMappingURL=nylas-scheduling.cjs.entry.js.map