import { h } from "@stencil/core";
export class CheckboxComponent {
    constructor() {
        this.componentType = 'checkbox';
        this.name = 'checkbox';
        this.checked = undefined;
        this.label = '';
        this.readOnly = false;
        this.required = false;
        this.isChecked = undefined;
        this.error = '';
    }
    checkedPropChangedHandler(newValue) {
        if (typeof newValue === 'boolean') {
            this.isChecked = newValue;
        }
    }
    componentWillLoad() {
        this.el.setAttribute('component-type', this.componentType);
    }
    componentDidLoad() {
        this.isChecked = this.checked || false;
    }
    handleBookingFormSubmitted(event) {
        if (this.required && !this.isChecked) {
            this.error = `${this.label} is required.`;
        }
        if (this.error) {
            event.preventDefault();
        }
    }
    toggleCheck() {
        this.error = '';
        this.isChecked = !this.isChecked;
        this.nylasFormCheckboxToggled.emit({
            checked: this.isChecked,
            name: this.name,
            label: this.label,
        });
    }
    render() {
        return (h("div", { key: '238fd5ba78b8e1fecd770c1c546b1dd331c8e9cd', class: "checkbox-container" }, h("label", { key: '55d41ec03a225841bea3efb427ba08acdad84d66', title: this.readOnly ? 'read-only field' : undefined, class: { readonly: this.readOnly } }, h("input", { key: '52658e7a95738612621527230ef2468edb317574', type: "checkbox", disabled: this.readOnly, readOnly: this.readOnly, name: this.name, title: this.readOnly ? 'read-only field' : undefined, checked: this.isChecked, onChange: () => this.toggleCheck() }), h("span", { key: '846d3c0112fba61630034f4b0863e9dbf9f9f71f', class: "checkmark" }), h("slot", { key: '54a380b1b4fa89b9ee63e561166c6929ddc94e98', name: "label" }, h("span", { key: 'b1a2ce0828e2aa069a99d1da62351c94ec62a638', class: "label", part: "checkbox-label-span" }, this.label, this.required && h("span", { class: "required" }, "*")))), this.error && h("p", { class: "error" }, this.error)));
    }
    static get is() { return "checkbox-component"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["checkbox-component.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["checkbox-component.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The name of the checkbox. This is used to identify the checkbox when submitting a form."
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'checkbox'"
            },
            "checked": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The default value of the checkbox. This is the value that is displayed when the checkbox is rendered."
                },
                "attribute": "checked",
                "reflect": false
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The label of the checkbox. This is displayed next to the checkbox."
                },
                "attribute": "label",
                "reflect": false,
                "defaultValue": "''"
            },
            "readOnly": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The property to make the checkbox read-only. If true, the checkbox cannot be edited."
                },
                "attribute": "read-only",
                "reflect": false,
                "defaultValue": "false"
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the checkbox is required. If true, the checkbox must be checked when submitting a form.\nDefault is false. If the checkbox is required and not checked, an error message is displayed."
                },
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "isChecked": {},
            "error": {}
        };
    }
    static get events() {
        return [{
                "method": "nylasFormCheckboxToggled",
                "name": "nylasFormCheckboxToggled",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the checkbox is toggled."
                },
                "complexType": {
                    "original": "{\n    checked: boolean;\n    name: string;\n    label: string;\n  }",
                    "resolved": "{ checked: boolean; name: string; label: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "checked",
                "methodName": "checkedPropChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "bookingFormSubmitted",
                "method": "handleBookingFormSubmitted",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=checkbox-component.js.map
