import { h } from "@stencil/core";
export class CheckboxGroup {
    constructor() {
        this.componentType = 'checkbox-group';
        this.name = 'checkbox-group';
        this.label = '';
        this.options = [];
        this.required = false;
        this.direction = 'vertical';
        this.error = '';
        this.selectedValues = [];
    }
    componentWillLoad() {
        this.el.setAttribute('component-type', this.componentType);
    }
    componentDidLoad() {
        this.selectedValues = this.options.filter(option => option.checked).map(option => option.value);
    }
    optionsChangedHandler(newValue, oldValue) {
        if (JSON.stringify(newValue) === JSON.stringify(oldValue))
            return;
        this.selectedValues = newValue.filter(option => option.checked).map(option => option.value);
    }
    handleBookingFormSubmitted(event) {
        if (this.required && !this.hasCheckedOptions()) {
            this.error = 'Please select at least one option.';
        }
        if (this.error) {
            event.preventDefault();
        }
    }
    hasCheckedOptions() {
        return this.options.some(option => option.checked);
    }
    handleCheckboxToggle(event) {
        const { checked, name: _checkboxName, label } = event.detail;
        const toggledOption = this.options.find(option => option.label === label);
        if (!toggledOption)
            return;
        let selected = [];
        if (checked) {
            if (toggledOption.selectAll) {
                selected = this.options.map(option => option.value);
            }
            else {
                selected = [...this.selectedValues, toggledOption.value];
            }
        }
        else {
            selected = this.selectedValues.filter(value => value !== toggledOption.value);
        }
        this.selectedValues = [...selected];
        this.nylasCheckboxGroupChanged.emit({
            selectedValues: this.selectedValues,
            name: this.name,
        });
    }
    handleCheckboxToggled(event) {
        this.handleCheckboxToggle(event);
    }
    render() {
        return (h("div", { key: '76ae2efb8faa2b161472a0330e398b1557e149a2', class: "checkbox-group-container" }, this.label && (h("div", { class: "group-label" }, this.label, this.required && h("span", { class: "required" }, "*"))), h("div", { key: 'fbc0e62c6ea9cd92bf1195721910f6a03b031900', class: `checkbox-list ${this.direction}` }, this.options.map(option => (h("checkbox-component", { name: `${this.name}-${option.value}`, label: option.label, checked: this.selectedValues.includes(option.value), readOnly: option.disabled, required: this.required })))), this.error && h("p", { class: "error" }, this.error)));
    }
    static get is() { return "checkbox-group"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["checkbox-group.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["checkbox-group.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The name of the checkbox group. This is used to identify the group when submitting a form."
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'checkbox-group'"
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The label for the checkbox group."
                },
                "attribute": "label",
                "reflect": false,
                "defaultValue": "''"
            },
            "options": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxOption[]",
                    "resolved": "CheckboxOption[]",
                    "references": {
                        "CheckboxOption": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::CheckboxOption"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Array of options to display as checkboxes.\nEach option should have a label and value."
                },
                "defaultValue": "[]"
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the checkbox group is required. If true, at least one checkbox must be checked when submitting a form."
                },
                "attribute": "required",
                "reflect": false,
                "defaultValue": "false"
            },
            "direction": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxGroupDirection",
                    "resolved": "\"horizontal\" | \"vertical\"",
                    "references": {
                        "CheckboxGroupDirection": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::CheckboxGroupDirection"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The layout direction of the checkboxes.\n'vertical' - checkboxes are stacked vertically (default)\n'horizontal' - checkboxes are arranged horizontally"
                },
                "attribute": "direction",
                "reflect": false,
                "defaultValue": "'vertical'"
            }
        };
    }
    static get states() {
        return {
            "error": {},
            "selectedValues": {}
        };
    }
    static get events() {
        return [{
                "method": "nylasCheckboxGroupChanged",
                "name": "nylasCheckboxGroupChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when any checkbox in the group is toggled."
                },
                "complexType": {
                    "original": "{\n    selectedValues: string[];\n    name: string;\n  }",
                    "resolved": "{ selectedValues: string[]; name: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "options",
                "methodName": "optionsChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "bookingFormSubmitted",
                "method": "handleBookingFormSubmitted",
                "target": "document",
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormCheckboxToggled",
                "method": "handleCheckboxToggled",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=checkbox-group.js.map
