var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import { DEFAULT_FORM_FIELD_TYPES, FIELD_TYPES } from "../../../common/constants";
import Sortable from "sortablejs";
import i18next from "../../../utils/i18n";
const fieldTypesWithOptions = ['dropdown', 'radio_button'];
const fieldTypesWithMultipleOptions = ['multi_select'];
export class NylasBookingFormConfig {
    constructor() {
        this.selectedConfiguration = undefined;
        this.name = 'additional-fields';
        this.additionalFields = undefined;
        this.selectedLanguage = undefined;
        this.staticFields = [
            {
                type: 'text',
                label: 'Your name',
                key: 'your_name',
                typeLabel: 'Short text',
                readonly: true,
                required: true,
                isOpen: false,
                fieldLabelKey: 'your_name',
                order: 0,
            },
            {
                type: 'email',
                label: 'Your Email',
                key: 'your_email',
                typeLabel: 'Email',
                readonly: true,
                isOpen: false,
                required: true,
                fieldLabelKey: 'your_email',
                order: 1,
            },
        ];
        this.formFields = undefined;
        this.formFieldsOrder = undefined;
        this.count = 0;
        this.watchFields = undefined;
        this.fieldTypes = DEFAULT_FORM_FIELD_TYPES.map(f => {
            return { label: i18next.t(`nylasBookingFormConfig.fieldType.${f.value}`), value: f.value };
        });
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-calendar-picker', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    selectedConfigurationChangedHandler(newValue) {
        this.updateFormFields(newValue, false);
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
        this.fieldTypes = DEFAULT_FORM_FIELD_TYPES.map(f => {
            return { label: i18next.t(`nylasBookingFormConfig.fieldType.${f.value}`), value: f.value };
        });
    }
    connectedCallback() {
        debug('nylas-booking-form-config', 'connectedCallback');
    }
    disconnectedCallback() {
        debug('nylas-booking-form-config', 'disconnectedCallback');
    }
    componentWillLoad() {
        debug('nylas-booking-form-config', 'componentWillLoad');
        this.host.setAttribute('name', this.name);
        this.formFields = [];
        this.formFieldsChangedHandler(this.formFields, false);
    }
    componentDidLoad() {
        debug('nylas-booking-form-config', 'componentDidLoad');
        if (this.selectedConfiguration) {
            this.updateFormFields(this.selectedConfiguration, false);
        }
    }
    get isInternalsAvailable() {
        return this.internals !== undefined && typeof this.internals.setFormValue === 'function';
    }
    updateFormFields(config, valueChanged = true) {
        this.watchFields = {
            title: config?.event_booking?.title || '',
            description: config?.event_booking?.description || '',
        };
        const additionalFields = Object.entries(config?.scheduler?.additional_fields || {}).map(([id, field]) => ({ ...field, key: id })) || this.additionalFields || [];
        this.formFields = [
            ...additionalFields
                .sort((a, b) => a.order - b.order)
                .map((f, _i) => {
                const fieldType = FIELD_TYPES.find(field => field.type === f.type);
                if (!fieldType) {
                    return { ...f, isOpen: false, typeLabel: 'Unknown' };
                }
                const typeLabel = fieldType.label;
                const order = f.order || 0;
                return { ...f, order: order - 1, isOpen: false, typeLabel, fieldLabelKey: f.type };
            }),
        ];
        this.formFields = [...this.formFields];
        this.formFieldsChangedHandler(this.formFields, valueChanged);
        const container = this.host.shadowRoot?.getElementById('fields');
        Sortable.create(container, {
            animation: 150,
            swap: true,
            swapClass: 'highlight',
            onEnd: this.swapFields.bind(this),
            handle: '.form-field_header',
            filter: '.fixed',
            fallbackTolerance: 3,
            onMove: evt => !evt.related.classList.contains('fixed'),
        });
    }
    formFieldsChangedHandler(newValue, valueChanged = true) {
        const additionalFields = newValue || [];
        const sortedFields = additionalFields
            .filter(f => !f.readonly)
            .sort((a, b) => a.order - b.order)
            .map((f, i) => {
            const field = {
                type: f.type,
                required: f.required,
                label: f.label,
                order: i + 1,
                options: f.options,
                key: f.key,
                default: f.default,
                fieldLabelKey: f.fieldLabelKey,
            };
            return { ...field };
        });
        const addFieldsMap = sortedFields.reduce((acc, field) => {
            if (field.key) {
                acc[field.key] = {
                    type: field.type,
                    required: field.required,
                    order: field.order,
                    options: field.options,
                    label: field.label,
                    default: field.default,
                };
            }
            return acc;
        }, {});
        this.isInternalsAvailable && this.internals.setFormValue(JSON.stringify(addFieldsMap), this.name);
        if (valueChanged) {
            this.valueChanged.emit({
                value: JSON.stringify(addFieldsMap),
                name: this.name,
            });
        }
        this.formFields = [...this.formFields];
    }
    findNextMissingNumber(arr) {
        if (arr.length === 0) {
            return 1;
        }
        const numbers = arr
            .map(item => {
            const parts = item.split('_');
            const lastPart = parts.pop();
            const parsedNumber = parseInt(lastPart || '', 10);
            return isNaN(parsedNumber) ? null : parsedNumber;
        })
            .filter((num) => num !== null)
            .sort((a, b) => a - b);
        for (let i = 0; i < numbers.length - 1; i++) {
            if (numbers[i + 1] !== numbers[i] + 1) {
                return numbers[i] + 1;
            }
        }
        return numbers.length > 0 ? numbers[numbers.length - 1] + 1 : 1;
    }
    nylasFormDropdownChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'add-field') {
            const field = FIELD_TYPES.find(f => f.type === value);
            const maxOrder = Math.max(...this.formFields.map(f => f.order));
            const existingFieldKeys = this.formFields.filter(f => f.type === field.type && f.key !== undefined).map(f => f.key);
            const next = this.findNextMissingNumber(existingFieldKeys);
            const newField = { ...field, label: field.label, key: `${field.type}_${field.label.split(' ').join('-')}_${next}`, order: maxOrder + 1 };
            this.formFields = [...this.formFields, newField];
            this.formFieldsChangedHandler(this.formFields);
        }
        else if (name.includes('-default-value')) {
            const fieldIndex = parseInt(name.split('-')[0] || '0');
            let defaultValue = value;
            if (value === 'null') {
                defaultValue = '';
            }
            this.fieldDefaultValueChanged(fieldIndex, { detail: { value: defaultValue } });
        }
    }
    selectedOptionsChangedHandler(event) {
        const { name, value } = event.detail;
        if (name.includes('-default-value')) {
            const fieldIndex = parseInt(name.split('-')[0] || '0');
            const defaultValue = value.join(', ');
            this.fieldDefaultValueChanged(fieldIndex, { detail: { value: defaultValue } });
        }
    }
    nylasFormInputChangedHandler(event) {
        const { name } = event.detail;
        if (name.startsWith('default-value-')) {
            const fieldIndex = parseInt(name.split('-').pop() || '0');
            this.fieldDefaultValueChanged(fieldIndex, event);
        }
        else {
            const [fieldIndex, optionIndex] = name.split('_');
            if (optionIndex) {
                this.fieldOptionChange(parseInt(fieldIndex), parseInt(optionIndex), event);
            }
            else {
                this.fieldLabelChange(parseInt(fieldIndex), event);
            }
        }
    }
    valueChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'title' || name === 'description') {
            this.watchFields = {
                ...this.watchFields,
                [name]: value,
            };
        }
    }
    swapFields(event) {
        const { oldIndex, newIndex } = event;
        if (oldIndex == null || newIndex == null || oldIndex === newIndex) {
            return;
        }
        const updatedFields = [...this.formFields];
        const [draggedItem] = updatedFields.splice(oldIndex, 1);
        updatedFields.splice(newIndex, 0, draggedItem);
        updatedFields.forEach((field, index) => {
            field.order = index + 1;
        });
        this.formFields = updatedFields;
        this.formFieldsChangedHandler(this.formFields);
    }
    fieldToggle(index) {
        this.formFields = this.formFields.map((f, i) => {
            if (index == i) {
                f.isOpen = !f.isOpen;
            }
            return f;
        });
        this.formFieldsChangedHandler(this.formFields);
    }
    staticFieldToggle(index) {
        this.staticFields = this.staticFields.map((f, i) => {
            if (index == i) {
                f.isOpen = !f.isOpen;
            }
            return f;
        });
        this.staticFields = [...this.staticFields];
    }
    fieldRemove(index) {
        this.formFields = this.formFields.filter((_, i) => i !== index);
        this.formFieldsChangedHandler(this.formFields);
    }
    fieldRequired(index) {
        this.formFields = this.formFields.map((field, i) => {
            if (i === index) {
                field.required = !field.required;
            }
            return field;
        });
        this.formFieldsChangedHandler(this.formFields);
    }
    fieldLabelChange(ind, event) {
        const target = event.detail;
        this.formFields = this.formFields.map((field, i) => {
            if (i === ind) {
                const label = target.value;
                return {
                    ...field,
                    label: label,
                };
            }
            return field;
        });
        this.formFieldsChangedHandler(this.formFields);
    }
    fieldOptionAdd(index) {
        this.formFields = this.formFields.map((field, i) => {
            if (i === index) {
                if (!field.options) {
                    field.options = [];
                }
                field.options = [...field.options, ''];
            }
            return field;
        });
        this.formFieldsChangedHandler(this.formFields);
    }
    fieldOptionRemove(fieldIndex, index) {
        this.formFields = this.formFields.map((field, i) => {
            if (i === fieldIndex) {
                if (!field.options) {
                    field.options = [];
                }
                field.options = field.options.filter((_, i) => i !== index);
            }
            return field;
        });
        this.formFieldsChangedHandler(this.formFields);
    }
    fieldOptionChange(fieldIndex, index, event) {
        this.formFields = this.formFields.map((field, i) => {
            if (i === fieldIndex) {
                if (!field.options) {
                    field.options = [];
                }
                field.options = field.options.map((o, i) => {
                    if (i === index) {
                        o = event.detail.value;
                    }
                    return o;
                });
            }
            return field;
        });
        this.formFieldsChangedHandler(this.formFields);
    }
    fieldDefaultValueChanged(index, event) {
        this.formFields = this.formFields.map((field, i) => {
            if (i === index) {
                field.default = event.detail.value;
            }
            return field;
        });
        this.formFieldsChangedHandler(this.formFields);
    }
    render() {
        return (h(Host, { key: '20f0aeab89c822407ffaf1f96edf15d49440a72f' }, h("div", { key: '79ed7c953897d5b319adbdd9f09f6da1851622c1', class: "nylas-booking-form-config", part: "nbfc" }, h("div", { key: '2805f58cd85ee3252037aa340ebf65185f2d8d9e', class: "header", part: "nbfc__header" }, h("div", { key: '2467bd598226df19e9eb00d7a7288c9492270599', class: "header_text" }, h("h3", { key: 'e5d7ede40d90f7e2c25c46fc192040a138e7f1fa' }, i18next.t('nylasBookingFormConfig.headerTitle')), h("p", { key: '6118c71c1e3c9fd531aca31b95ae764f186b98a8' }, i18next.t('nylasBookingFormConfig.headerSubTitle'))), h("div", { key: '84f7d998d1cc8918183406fe19da487356b5a0d5', class: "header_action" }, h("select-dropdown", { key: '35c60cb0e733b7602c01cfe16793faaa80d21629', name: "add-field", exportparts: "sd_dropdown: nbfc__add_field, sd_dropdown-button: nbfc__add_field-button, sd_dropdown-content: nbfc__add_field-dropdown-content", options: this.fieldTypes, withSearch: false, withChevron: false, dropdownButtonText: i18next.t('nylasBookingFormConfig.dropdownButtonText') }, h("span", { key: '81819f5ed73e5e826bb9374d382699c69a4852e8', slot: "select-icon" }, h("plus-icon", { key: '1c8df2d966e00e48338559e436eac3c59aa4054c', width: "15", height: "15" }))))), h("div", { key: '4bbff378cf59553922de4d8c2ad7fda4765889b9', class: "content" }, h("div", { key: 'c9679c35f96c072a558360dec003acefba62f7dc', class: "additional_fields static_fields", part: "nbfc__static_fields" }, this.staticFields.map((field, i) => {
            return (h("div", { class: `form-field draggable ${field.readonly && 'fixed'}`, part: "nbfc__form_field", key: i }, h("div", { class: "form-field_header", part: "nbfc__form_field-header" }, h("span", { class: "dragable" }, h("dragable-icon", { width: "24", height: "25" })), h("div", { class: "form-field_header_text" }, h("h4", null, i18next.t(`nylasBookingFormConfig.fieldLabel.${field.fieldLabelKey}`)), h("p", null, i18next.t(`nylasBookingFormConfig.fieldType.${field.type}`))), h("div", { class: "form-field_header_actions" }, h("span", { class: `is-required` }, field.required ? i18next.t('required') : i18next.t('optional')), h("span", { class: `chevron ${field.isOpen ? 'open' : 'closed'}`, onClick: () => {
                    this.staticFieldToggle(i);
                } }, h("chevron-icon", { width: "24", height: "24" })))), h("div", { class: `form-field_content ${!field.isOpen && 'hidden'}`, part: "nbfc__form_field-content" }, h("div", { class: "inputs" }, h("input-component", { class: 'label-input', name: `${i}`, key: i, label: i18next.t('nylasBookingFormConfig.label'), required: false, readOnly: field.readonly, defaultValue: field.label }, h("div", { class: "required-input", slot: "additional-input" }, h("input", { type: "checkbox", name: `required_${field.order}`, id: `required_${field.order}`, onClick: () => {
                    this.fieldRequired(i);
                }, checked: field.required, disabled: field.readonly }), h("label", { htmlFor: `required_${field.order}`, "aria-label": "Required" }, i18next.t('required'))))))));
        })), h("div", { key: '165f7e84613393e33a8216224e09ea35a5b2a13a', id: "fields", class: "additional_fields", part: "nbfc__additional_fields" }, this.formFields?.map((field, i) => {
            return (h("div", { class: `form-field draggable ${field?.readonly ? 'fixed' : ''}`, part: "nbfc__form_field", key: field.key }, h("div", { class: "form-field_header", part: "nbfc__form_field-header" }, h("span", { class: "dragable" }, h("dragable-icon", { width: "24", height: "25" })), h("div", { class: "form-field_header_text" }, h("h4", null, field.label || i18next.t(`nylasBookingFormConfig.fieldLabel.${field.fieldLabelKey}`)), h("p", null, i18next.t(`nylasBookingFormConfig.fieldType.${field.type}`))), h("div", { class: "form-field_header_actions" }, h("span", { class: `is-required` }, field.required ? i18next.t('required') : i18next.t('optional')), !field.readonly && (h("button", { onClick: () => {
                    const title = this.watchFields.title;
                    const description = this.watchFields.description;
                    if (title && field.key && title.includes(field.key)) {
                        field.error = i18next.t('nylasBookingFormConfig.fieldInTitleError');
                        this.formFields = [...this.formFields];
                        this.formFieldsChangedHandler(this.formFields);
                        setTimeout(() => {
                            field.error = '';
                            this.formFields = [...this.formFields];
                            this.formFieldsChangedHandler(this.formFields);
                        }, 3000);
                        return;
                    }
                    if (description && field.key && description.includes(field.key)) {
                        field.error = i18next.t('nylasBookingFormConfig.fieldInDescriptionError');
                        this.formFields = [...this.formFields];
                        this.formFieldsChangedHandler(this.formFields);
                        setTimeout(() => {
                            field.error = '';
                            this.formFields = [...this.formFields];
                            this.formFieldsChangedHandler(this.formFields);
                        }, 3000);
                        return;
                    }
                    this.fieldRemove(i);
                } }, h("close-icon", null))), h("span", { class: `chevron ${field.isOpen ? 'open' : 'closed'}`, onClick: () => {
                    this.fieldToggle(i);
                } }, h("chevron-icon", { width: "24", height: "24" })))), h("span", { class: {
                    'error': true,
                    'fade-out': !field?.error || field.error === '',
                } }, field.error), h("div", { class: `form-field_content ${!field.isOpen && 'hidden'}`, part: "nbfc__form_field-content" }, h("div", { class: "inputs" }, h("input-component", { class: 'label-input', name: `${i}`, key: `${i}-${field.key}-label`, label: i18next.t('nylasBookingFormConfig.label'), required: false, readOnly: field.readonly, defaultValue: field.label }, h("div", { class: "required-input", slot: "additional-input" }, h("input", { type: "checkbox", name: `required_${i}`, id: `required_${i}`, onClick: () => {
                    this.fieldRequired(i);
                }, checked: field.required, disabled: field.readonly }), h("label", { htmlFor: `required_${i}`, "aria-label": "Required" }, i18next.t('required')))), !field.readonly && fieldTypesWithOptions.includes(field.type) && (h("select-dropdown", { name: `${i}-${field.key}-default-value`, key: `${i}-${field.key}-default-value`, label: i18next.t('nylasBookingFormConfig.defaultValue'), required: false, readOnly: field.readonly, options: [
                    { value: 'null', label: i18next.t('nylasBookingCalendarPicker.selectOptionLabel') },
                    ...(field.options?.map(o => ({ value: o, label: o })) || []),
                ], emptyValue: i18next.t('nylasBookingCalendarPicker.selectOptionLabel'), withSearch: false })), !field.readonly && field.type === 'checkbox' && (h("select-dropdown", { name: `${i}-${field.key}-default-value`, key: `${i}-${field.key}-default-value`, label: i18next.t('nylasBookingFormConfig.defaultValue'), required: false, readOnly: field.readonly, options: [{ value: 'null', label: i18next.t('nylasBookingCalendarPicker.selectOptionLabel') }, ...['true', 'false'].map(o => ({ value: o, label: o }))], emptyValue: i18next.t('nylasBookingCalendarPicker.selectOptionLabel'), withSearch: false })), !field.readonly && fieldTypesWithMultipleOptions.includes(field.type) && (h("multi-select-dropdown", { name: `${i}-${field.key}-default-value`, key: `${i}-${field.key}-default-value`, label: i18next.t('nylasBookingFormConfig.defaultValue'), required: false, selectAtLeastOneOptionLabel: i18next.t('selectOneOrMoreOptions'), multipleOptionsSelectedLabel: i18next.t('multipleOptionsSelected'), readOnly: field.readonly, options: field.options?.filter(o => !!o && o !== null).map(o => ({ value: o, label: o })) || [] })), !field.readonly &&
                field.type !== 'date' &&
                field.type !== 'checkbox' &&
                !fieldTypesWithOptions.includes(field.type) &&
                !fieldTypesWithMultipleOptions.includes(field.type) && (h("input-component", { class: 'default-value', name: `default-value-${i}`, key: `${i}-${field.key}-default-value`, label: i18next.t('nylasBookingFormConfig.defaultValue'), required: false, readOnly: field.readonly, defaultValue: field.default })), !field.readonly && field.type === 'date' && (h("nylas-date-component", { class: 'default-value', name: `default-value-${i}`, key: `${i}-${field.key}-default-value`, label: i18next.t('nylasBookingFormConfig.defaultValue'), required: false, readOnly: field.readonly, defaultValue: field.default }))), field.options != undefined && (h("div", { class: "options-container" }, h("h4", null, i18next.t('nylasBookingFormConfig.allOptionsHeader')), h("div", { class: "options" }, field.options.map((o, j) => {
                return (h("div", { class: "option" }, h("input-component", { key: j, name: `${i}_${j}`, label: field.typeLabel + ' option ' + (j + 1), required: true, defaultValue: o }, j > 1 && (h("div", { class: "required-input", slot: "additional-input" }, h("button", { onClick: () => {
                        this.fieldOptionRemove(i, j);
                    } }, h("close-icon", null)))))));
            })), h("button", { onClick: () => {
                    this.fieldOptionAdd(i);
                }, part: "nap__add-time-range" }, h("add-circle-icon", null), " ", i18next.t('nylasBookingFormConfig.addOption')))))));
        }))))));
    }
    static get is() { return "nylas-booking-form-config"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-booking-form-config.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-booking-form-config.css"]
        };
    }
    static get properties() {
        return {
            "selectedConfiguration": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Configuration",
                    "resolved": "Configuration | undefined",
                    "references": {
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The selected configuration."
                        }],
                    "text": ""
                }
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The name of the booking form config."
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'additional-fields'"
            },
            "additionalFields": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "AdditionalFields[]",
                    "resolved": "AdditionalFields[] | undefined",
                    "references": {
                        "AdditionalFields": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::AdditionalFields"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The additional fields to be displayed on the booking form."
                }
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "staticFields": {},
            "formFields": {},
            "formFieldsOrder": {},
            "count": {},
            "watchFields": {},
            "fieldTypes": {}
        };
    }
    static get events() {
        return [{
                "method": "valueChanged",
                "name": "valueChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the selected availability / open hours change."
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n  }",
                    "resolved": "{ value: string; name: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedConfiguration",
                "methodName": "selectedConfigurationChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "nylasFormDropdownChanged",
                "method": "nylasFormDropdownChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "selectedOptionsChanged",
                "method": "selectedOptionsChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormInputChanged",
                "method": "nylasFormInputChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "valueChanged",
                "method": "valueChangedHandler",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    RegisterComponent({
        name: 'nylas-booking-form-config',
        stateToProps: new Map([
            ['schedulerConfig.selectedConfiguration', 'selectedConfiguration'],
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
        ]),
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasBookingFormConfig.prototype, "render", null);
//# sourceMappingURL=nylas-booking-form-config.js.map
