var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import i18next from "../../../utils/i18n";
import { LANGUAGE_CODE, LANGUAGE_MAP } from "../../../common/constants";
export class NylasDisableEmails {
    constructor() {
        this.selectedConfiguration = undefined;
        this.name = 'disable-emails';
        this.selectedLanguage = undefined;
        this.organizerLocale = this.selectedLanguage || 'en';
        this.disableEmails = false;
    }
    connectedCallback() {
        debug('nylas-disable-emails', 'connectedCallback');
    }
    disconnectedCallback() {
        debug('nylas-disable-emails', 'disconnectedCallback');
    }
    componentWillLoad() {
        debug('nylas-disable-emails', 'componentWillLoad');
        this.host.setAttribute('name', this.name);
    }
    componentDidLoad() {
        debug('nylas-disable-emails', 'componentDidLoad');
        const lang = this.selectedConfiguration?.scheduler?.email_template?.organizer_locale || this.selectedLanguage || 'en';
        this.organizerLocale = lang;
        const isGroupConfig = this.selectedConfiguration?.group_booking !== undefined;
        const disableEmails = isGroupConfig
            ? this.selectedConfiguration?.group_booking?.disable_emails
            : this.selectedConfiguration?.event_booking?.disable_emails;
        this.disableEmails = disableEmails || false;
        this.handleSettingValue(false);
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-disable-emails', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
    }
    selectedConfigurationChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        this.organizerLocale = newVal.scheduler?.email_template?.organizer_locale || this.selectedLanguage || 'en';
        this.handleSettingValue(false);
        const isGroupConfig = newVal?.group_booking !== undefined;
        const disableEmails = isGroupConfig ? newVal?.group_booking?.disable_emails : newVal?.event_booking?.disable_emails;
        this.disableEmails = disableEmails || false;
        this.handleSettingValue(false);
    }
    nyalsFormSwitchToggledHandler(event) {
        debug('nylas-confirmation-email', 'nyalsFormSwitchToggledHandler', event.detail);
        const { checked } = event.detail;
        if (event.detail.name === 'disable-emails') {
            this.disableEmails = !checked;
            this.handleSettingValue();
        }
    }
    nylasFormDropdownChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'organizer-locale') {
            const lang = LANGUAGE_CODE[value];
            this.organizerLocale = lang;
            this.handleSettingValue();
        }
    }
    handleSettingValue(valueChanged = true) {
        if (valueChanged) {
            this.valueChanged.emit({
                value: JSON.stringify({
                    disableEmails: this.disableEmails,
                    organizerLocale: this.organizerLocale,
                }),
                name: this.name,
            });
        }
        this.internals.setFormValue(JSON.stringify({
            disableEmails: this.disableEmails,
            organizerLocale: this.organizerLocale,
        }), this.name);
    }
    render() {
        const languageOptions = Object.keys(LANGUAGE_MAP).map(key => ({
            label: LANGUAGE_MAP[key],
            value: key,
        }));
        const isGroupConfig = this.selectedConfiguration?.group_booking !== undefined;
        const disableEmails = isGroupConfig
            ? this.selectedConfiguration?.group_booking?.disable_emails
            : this.selectedConfiguration?.event_booking?.disable_emails;
        return (h(Host, { key: '61c656e8493effefc64d68b07bf663350d854630' }, h("div", { key: 'e3e32aea50842e2e9c1426fd639eb0dab573a989', class: "nylas-disable-emails", part: "nde" }, h("div", { key: '621732af92baada7bc6c06408ff9a51674cc158c', class: "header", part: "nde__header" }, h("div", { key: '8f882d8b83994abc4c73219701979d2287411edb' }, h("h3", { key: 'a81f9e1b64dac3621ee45eb3d6dc1709f61c272b' }, i18next.t('eventCommunicationsTitle')), h("p", { key: 'c52741d9875a3f3c8df86e1a5d104783a7934c5e' }, i18next.t('eventCommunicationsDescription')))), h("div", { key: '5a08c4030ba531402a9a4bb42153eb8d4968dfd6', class: "toggle", part: "nde__toggle" }, h("label", { key: '9f2c2a5d4f07e2882d598d0f7f8a90d7f4ec5758' }, i18next.t('nylasConfirmationEmail.confirmationEmail.label'), h("span", { key: '8743fdc4d47c1ad833656629a7096610436ddccd', class: "label-icon" }, h("tooltip-component", { key: 'a92ff3a415b36a68fd94eff0a4b2f0d825fbfbb6' }, h("info-icon", { key: 'eb0806cdc0690f2d7f6e515a691569b683099c09', slot: "tooltip-icon" }), h("span", { key: '45f1a35f845617099c9b8d786dc5762a46ca374e', slot: "tooltip-content" }, " ", i18next.t('nylasConfirmationEmail.confirmationEmail.tooltip.desc'))))), h("toggle-switch", { key: '984d924370c58341ac73cce774c26b910d54a52b', exportparts: "ts_label: nde__toggle-label, ts_input: nde_toggle-input, ts_slider: nde_toggle-slider", name: `disable-emails`, checked: !disableEmails })), h("div", { key: '50524c61fa7d56e401a76b7f53a08e83b7498cc6', class: "toggle", part: "nde__toggle" }, h("label", { key: 'e72bac6b8d355a2d87cdb98e058e3564555c2783' }, i18next.t('nylasConfirmationEmail.confirmationEmail.language'), h("span", { key: 'ec813fa7ca1cb750b55c75f0954664dcb4625995', class: "label-icon" }, h("tooltip-component", { key: '5efbf9e93637e15b93e4baa786131534424d8896' }, h("info-icon", { key: '5e2e302326c873d637e7892d508d83636e81a20b', slot: "tooltip-icon" }), h("span", { key: 'b6a1e85100d303079c2efb4833d9b98fe74326c6', slot: "tooltip-content" }, " ", i18next.t('nylasConfirmationEmail.confirmationEmail.tooltip.language'))))), h("select-dropdown", { key: 'd1b12b65f4dcb88781400ec594611e6a41f86c0f', name: "organizer-locale", options: languageOptions, searchPlaceholder: i18next.t('search'), withChevron: false, defaultSelectedOption: languageOptions.find(lang => lang.value == this.organizerLocale), exportparts: "sd_dropdown: nse__language-dropdown, sd_dropdown-button: nse__language-drop-button, sd_dropdown-content: nse__language-drop-content, sd_dropdown_label: nse__language-drop-label" }, h("span", { key: '52a4959de14fb93cdcb0f624d0b86e768f302a5b', slot: "select-icon" }, h("translate-icon", { key: '5c0aa2784847c6b858b833606c661d593e7cd40c', width: "20", height: "20" })))))));
    }
    static get is() { return "nylas-disable-emails"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-disable-emails.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-disable-emails.css"]
        };
    }
    static get properties() {
        return {
            "selectedConfiguration": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Configuration | GroupConfiguration",
                    "resolved": "Configuration | GroupConfiguration | undefined",
                    "references": {
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        },
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The selected config"
                        }],
                    "text": ""
                }
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The name of the component"
                        }],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'disable-emails'"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "organizerLocale": {},
            "disableEmails": {}
        };
    }
    static get events() {
        return [{
                "method": "valueChanged",
                "name": "valueChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the toggle switch to disable emails is toggled."
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n    valueChanged?: (event: CustomEvent<{ value: string; name: string }>) => void;\n  }",
                    "resolved": "{ value: string; name: string; valueChanged?: ((event: CustomEvent<{ value: string; name: string; }>) => void) | undefined; }",
                    "references": {
                        "CustomEvent": {
                            "location": "global",
                            "id": "global::CustomEvent"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }, {
                "propName": "selectedConfiguration",
                "methodName": "selectedConfigurationChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "nylasFormSwitchToggled",
                "method": "nyalsFormSwitchToggledHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormDropdownChanged",
                "method": "nylasFormDropdownChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    RegisterComponent({
        name: 'nylas-disable-emails',
        stateToProps: new Map([
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
            ['schedulerConfig.selectedConfiguration', 'selectedConfiguration'],
        ]),
        eventToProps: {
            valueChanged: async (event, _nylasSchedulerConfigConnector) => {
                const { valueChanged } = event.detail;
                if (valueChanged) {
                    valueChanged(event);
                }
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasDisableEmails.prototype, "render", null);
//# sourceMappingURL=nylas-disable-emails.js.map
