var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { h, Host } from "@stencil/core";
import { Calendar } from "@fullcalendar/core";
import dayGridPlugin from "@fullcalendar/daygrid";
import timeGridPlugin from "@fullcalendar/timegrid";
import interactionPlugin from "@fullcalendar/interaction";
import { debug } from "../../../utils/utils";
import i18next from "../../../utils/i18n";
import dayjs from "dayjs";
import utc from "dayjs/plugin/utc";
import timezone from "dayjs/plugin/timezone";
dayjs.extend(utc);
dayjs.extend(timezone);
const typeToViewMapping = {
    day: 'timeGridDay',
    week: 'timeGridWeek',
    month: 'dayGridMonth',
};
const viewToTypeMapping = {
    timeGridDay: 'day',
    timeGridWeek: 'week',
    dayGridMonth: 'month',
};
const editChoices = [
    { label: i18next.t('nylasEventCalendar.editOptions.import') || 'Import', value: 'import', langKey: 'nylasEventCalendar.editOptions.import' },
    { label: i18next.t('nylasEventCalendar.editOptions.edit') || 'Edit', value: 'edit', langKey: 'nylasEventCalendar.editOptions.edit' },
    { label: i18next.t('nylasEventCalendar.editOptions.deleteThis') || 'Delete this event only', value: 'delete-this', langKey: 'nylasEventCalendar.editOptions.deleteThis' },
    { label: i18next.t('nylasEventCalendar.editOptions.deleteAll') || 'Delete all events', value: 'delete-all', langKey: 'nylasEventCalendar.editOptions.deleteAll' },
];
const updateChoices = [
    { label: i18next.t('nylasEventCalendar.updateOptions.updateThis') || 'Update this event', value: 'this', langKey: 'nylasEventCalendar.updateOptions.updateThis' },
    {
        label: i18next.t('nylasEventCalendar.updateOptions.updateFuture') || 'Update all future occurrences',
        value: 'future',
        langKey: 'nylasEventCalendar.updateOptions.updateFuture',
    },
    { label: i18next.t('nylasEventCalendar.updateOptions.updateAll') || 'Update all events', value: 'all', langKey: 'nylasEventCalendar.updateOptions.updateAll' },
];
const deleteChoices = [
    { label: i18next.t('nylasEventCalendar.deleteOptions.deleteThis') || 'Delete this event', value: 'this', langKey: 'nylasEventCalendar.deleteOptions.deleteThis' },
    {
        label: i18next.t('nylasEventCalendar.deleteOptions.deleteFuture') || 'Delete this and all future occurrences',
        value: 'future',
        langKey: 'nylasEventCalendar.deleteOptions.deleteFuture',
    },
    { label: i18next.t('nylasEventCalendar.deleteOptions.deleteAll') || 'Delete all events', value: 'all', langKey: 'nylasEventCalendar.deleteOptions.deleteAll' },
];
export class NylasEventCalendar {
    constructor() {
        this.selectedConfiguration = undefined;
        this.name = 'page-name';
        this.selectedLanguage = undefined;
        this.groupEvents = undefined;
        this.currentUser = undefined;
        this.calendars = undefined;
        this.masterGroupEvents = undefined;
        this.isLoading = undefined;
        this.selectedView = 'week';
        this.events = [];
        this.calendar = undefined;
        this.selectedEvent = null;
        this.selectedDateRangeString = '';
        this.showEditEventDetails = false;
        this.showCreateEventDetails = false;
        this.editOptionChoices = editChoices;
        this.updateOptionChoices = updateChoices;
        this.deleteOptionChoices = deleteChoices;
        this.editOptions = this.editOptionChoices;
        this.showEditOptions = false;
        this.updateOptions = this.updateOptionChoices;
        this.showUpdateOptions = false;
        this.deleteOptions = this.deleteOptionChoices;
        this.showDeleteOptions = false;
        this.unsavedChanges = false;
        this.showConfirmDiscardUnsavedChangesModal = false;
        this.createNewGroupEventTimeslot = null;
        this.formError = '';
        this.formErrors = {};
        this.loadingOptions = {
            update: '',
            delete: '',
            create: '',
        };
        this.showChooseParticipantsModal = false;
        this.importParticipants = [];
        this.selectedImportParticipants = [];
        this.showAllEvents = true;
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-page-name', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    createCustomLocaleConfig(lang) {
        return {
            code: lang,
            buttonText: {
                today: i18next.t('today') || 'today',
                month: i18next.t('timePeriod_month') || 'month',
                week: i18next.t('timePeriod_week') || 'week',
                day: i18next.t('timePeriod_day') || 'day',
            },
            allDayText: i18next.t('allDay') || 'all-day',
        };
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
        if (this.calendar) {
            const localeConfig = this.createCustomLocaleConfig(newVal);
            this.calendar.setOption('locale', localeConfig);
        }
        this.updateOptionTranslations();
    }
    updateOptionTranslations() {
        this.editOptionChoices = this.editOptionChoices.map(option => ({
            ...option,
            label: i18next.t(option.langKey) || option.label,
        }));
        this.updateOptionChoices = this.updateOptionChoices.map(option => ({
            ...option,
            label: i18next.t(option.langKey) || option.label,
        }));
        this.deleteOptionChoices = this.deleteOptionChoices.map(option => ({
            ...option,
            label: i18next.t(option.langKey) || option.label,
        }));
        this.editOptions = this.editOptions.map(option => ({
            ...option,
            label: this.editOptionChoices.find(o => o.value === option.value)?.label || option.label,
        }));
        this.updateOptions = this.updateOptions.map(option => ({
            ...option,
            label: this.updateOptionChoices.find(o => o.value === option.value)?.label || option.label,
        }));
        this.deleteOptions = this.deleteOptions.map(option => ({
            ...option,
            label: this.deleteOptionChoices.find(o => o.value === option.value)?.label || option.label,
        }));
    }
    groupEventsChangedHandler(newValue, oldValue) {
        if (newValue === oldValue)
            return;
        this.events = newValue
            .filter(event => event !== undefined)
            .map(eventData => {
            const event = eventData.event;
            if (event?.id) {
                const isGroupEvent = !!eventData.group_event_info && !!eventData.group_event_info?.event_id;
                const readOnly = event.read_only;
                const eventParticipants = event.participants || [];
                const groupEventParticipants = eventData.group_event_info?.participants || [];
                const noParticipants = eventParticipants.length <= 0 && groupEventParticipants.length <= 0;
                return {
                    title: event.title,
                    start: dayjs
                        .unix(event.when.start_time)
                        .locale(this.selectedLanguage || 'en')
                        .format('YYYY-MM-DDTHH:mm:ss'),
                    end: dayjs
                        .unix(event.when.end_time)
                        .locale(this.selectedLanguage || 'en')
                        .format('YYYY-MM-DDTHH:mm:ss'),
                    calendar_id: event.calendar_id,
                    id: event.id,
                    classNames: [isGroupEvent ? 'group-event' : 'regular-event', readOnly ? 'read-only' : '', noParticipants ? 'no-participants' : ''],
                    editable: false,
                };
            }
            return undefined;
        });
        let events = JSON.parse(JSON.stringify(this.events));
        if (!this.showAllEvents) {
            events = events.filter(event => event?.classNames.includes('group-event'));
        }
        this.calendar?.setOption('events', events);
    }
    connectedCallback() {
        debug('nylas-connected-calendars', 'connectedCallback');
    }
    disconnectedCallback() {
        debug('nylas-connected-calendars', 'disconnectedCallback');
    }
    componentWillLoad() {
        debug('nylas-connected-calendars', 'componentWillLoad');
    }
    componentDidLoad() {
        this.selectedView = 'week';
        const calendarOptions = {
            plugins: [dayGridPlugin, timeGridPlugin, interactionPlugin],
            headerToolbar: false,
            initialView: 'timeGridWeek',
            events: this.events,
            editable: true,
            selectable: true,
            nowIndicator: true,
            scrollTime: '05:00:00',
            dayHeaderFormat: { weekday: 'short', month: undefined, day: '2-digit', formatMatcher: 'basic' },
            dayHeaderContent: headerInfo => {
                if (headerInfo.view.type === 'dayGridMonth') {
                    return {
                        html: `<div class="custom-day-header">
              <span class="day-name">${dayjs(headerInfo.date)
                            .locale(this.selectedLanguage || 'en')
                            .format('ddd')}</span>
            </div>`,
                    };
                }
                return {
                    html: `<div class="custom-day-header">
              <span class="day-name">${dayjs(headerInfo.date)
                        .locale(this.selectedLanguage || 'en')
                        .format('ddd')}</span>
              <span class="day-number ${headerInfo.isToday ? 'today' : ''}">${dayjs(headerInfo.date)
                        .locale(this.selectedLanguage || 'en')
                        .format('D')}</span>
            </div>`,
                };
            },
            datesSet: info => {
                const startMonth = dayjs(info.start)
                    .locale(this.selectedLanguage || 'en')
                    .format('MMMM')
                    .substring(0, 3);
                const endMonth = dayjs(info.end)
                    .subtract(1, 'day')
                    .locale(this.selectedLanguage || 'en')
                    .format('MMMM')
                    .substring(0, 3);
                const startYear = dayjs(info.start).format('YYYY');
                const endYear = dayjs(info.end).subtract(1, 'day').format('YYYY');
                if (startMonth === endMonth && startYear === endYear) {
                    this.selectedDateRangeString = `${startMonth} ${startYear}`;
                }
                else if (startYear === endYear) {
                    this.selectedDateRangeString = `${startMonth} - ${endMonth} ${startYear}`;
                }
                else {
                    this.selectedDateRangeString = `${startMonth} ${startYear} - ${endMonth} ${endYear}`;
                }
                if (info.view.type.includes('timeGrid')) {
                    this.observeCalendarRendering();
                }
            },
            eventClick: info => {
                const event = this.groupEvents?.find(e => e.event.id === info.event._def.publicId);
                if (info.event.classNames.includes('read-only') || info.event.classNames.includes('no-participants')) {
                    return;
                }
                this.showEditEventDetails = false;
                this.unsavedChanges = false;
                this.showEditOptions = true;
                this.selectedEvent = event || null;
                if (event && event.group_event_info) {
                    const masterEventId = event.event.master_event_id;
                    this.groupEventSelected.emit(event);
                    this.editOptions = this.editOptionChoices.filter(option => option.value !== 'import');
                    this.deleteOptions = [...this.deleteOptionChoices];
                    this.updateOptions = [...this.updateOptionChoices];
                    if (!masterEventId) {
                        this.editOptions = this.editOptions.filter(option => option.value !== 'delete-all');
                        this.deleteOptions = this.deleteOptions.filter(option => option.value !== 'all' && option.value !== 'future');
                    }
                    if (masterEventId && !this.masterGroupEvents?.[masterEventId]) {
                        this.fetchMasterGroupEvent.emit(event.event.master_event_id);
                    }
                }
                else {
                    this.editOptions = this.editOptionChoices.filter(option => option.value === 'import');
                }
            },
            select: (info) => {
                if (new Date(info.start).getTime() < new Date().getTime()) {
                    return;
                }
                this.createNewGroupEventTimeslot = {
                    when: {
                        start_time: new Date(info.start).getTime() / 1000,
                        end_time: new Date(info.end).getTime() / 1000,
                        start_timezone: Intl.DateTimeFormat().resolvedOptions().timeZone,
                        end_timezone: Intl.DateTimeFormat().resolvedOptions().timeZone,
                    },
                    recurrence: [],
                };
                this.showCreateEventDetails = true;
            },
            eventDurationEditable: true,
            height: '100%',
            contentHeight: 'auto',
        };
        this.calendar = new Calendar(this.calendarEl, calendarOptions);
        this.calendar.render();
        if (this.selectedLanguage) {
            const localeConfig = this.createCustomLocaleConfig(this.selectedLanguage);
            this.calendar.setOption('locale', localeConfig);
            this.updateOptionTranslations();
        }
        this.observeCalendarRendering();
        this.setCalendarViewDateRange.emit({
            startTime: new Date(this.calendar.getCurrentData().viewApi.activeStart).getTime() / 1000,
            endTime: new Date(this.calendar.getCurrentData().viewApi.activeEnd).getTime() / 1000,
        });
    }
    observeCalendarRendering() {
        const observer = new MutationObserver(() => {
            const timeGridScrollers = this.calendarEl.querySelectorAll('.fc-timegrid-body .fc-scroller');
            if (timeGridScrollers.length > 0) {
                observer.disconnect();
                timeGridScrollers.forEach(scroller => {
                    const scrollElement = scroller;
                    scrollElement.style.overflowY = 'auto';
                    const scrollPosition = 8 * 48;
                    scrollElement.scrollTop = scrollPosition;
                    void scrollElement.offsetHeight;
                });
                this.injectScrollStyles();
            }
        });
        observer.observe(this.calendarEl, {
            childList: true,
            subtree: true,
        });
        setTimeout(() => {
            observer.disconnect();
            this.forceBrowserScrollToTime();
        }, 20);
    }
    injectScrollStyles() {
        const styleId = `nylas-calendar-scroll-${Math.random().toString(36).substring(2, 9)}`;
        const existingStyle = this.host.shadowRoot?.querySelector(`#${styleId}`);
        if (existingStyle) {
            existingStyle.remove();
        }
        const style = document.createElement('style');
        style.id = styleId;
        style.textContent = `
      .fc-timegrid-body .fc-scroller,
      .fc-scroller-liquid-absolute,
      .fc-scroller {
        overflow-y: auto;
        overflow-x: hidden;
        scroll-padding-top: 0;
        scroll-behavior: auto;
      }
      
      .fc-timegrid-body {
        overflow: visible;
      }
      
      .fc-timegrid-slots tr:nth-child(8) {
        scroll-margin-top: 0;
      }
    `;
        this.host.shadowRoot?.appendChild(style);
    }
    forceBrowserScrollToTime() {
        try {
            const hourSlots = this.calendarEl.querySelectorAll('.fc-timegrid-slot[data-time]');
            let fiveAmSlot = null;
            hourSlots.forEach(slot => {
                const dataTime = slot.getAttribute('data-time');
                if (dataTime && dataTime.startsWith('05:')) {
                    fiveAmSlot = slot;
                }
            });
            if (fiveAmSlot) {
                fiveAmSlot.scrollIntoView({ behavior: 'auto', block: 'start' });
            }
            else {
                const timeLabels = this.calendarEl.querySelectorAll('.fc-timegrid-axis-cushion');
                timeLabels.forEach(label => {
                    if (label.textContent?.includes('5') || label.textContent?.includes('05')) {
                        label.scrollIntoView({ behavior: 'auto', block: 'start' });
                    }
                });
            }
        }
        catch (error) {
            console.error('Error in direct time scroll:', error);
        }
    }
    setView(view) {
        this.selectedView = view;
        this.calendar.changeView(typeToViewMapping[view]);
        const startTime = new Date(this.calendar.getCurrentData().viewApi.activeStart).getTime() / 1000;
        const endTime = new Date(this.calendar.getCurrentData().viewApi.activeEnd).getTime() / 1000;
        this.calendarViewChanged.emit({ startTime, endTime });
        if (view === 'day' || view === 'week') {
            this.observeCalendarRendering();
        }
    }
    dayHeaderContent(headerInfo) {
        if (headerInfo.view.type === 'dayGridMonth') {
            return {
                html: `<div class="custom-day-header">
            <span class="day-name">${dayjs(headerInfo.date)
                    .locale(this.selectedLanguage || 'en')
                    .format('ddd')}</span>
          </div>`,
            };
        }
        return {
            html: `<div class="custom-day-header">
          <span class="day-name">${dayjs(headerInfo.date)
                .locale(this.selectedLanguage || 'en')
                .format('ddd')}</span>
          <span class="day-number ${headerInfo.isToday ? 'today' : ''}">${dayjs(headerInfo.date)
                .locale(this.selectedLanguage || 'en')
                .format('D')}</span>
        </div>`,
        };
    }
    handleEditOptionSelected(e, option) {
        e.preventDefault();
        e.stopPropagation();
        if (this.isLoading)
            return;
        if (option.value === 'edit') {
            this.showEditOptions = false;
            this.showEditEventDetails = true;
        }
        else if ((option.value === 'delete-this' || option.value === 'delete-all' || option.value === 'delete-future') && this.selectedEvent) {
            this.loadingOptions.delete = option.value;
            const action = option.value.split('-')[1];
            this.deleteGroupEvent.emit({ data: this.selectedEvent, action });
        }
        else if (option.value === 'import' && this.selectedEvent) {
            const participants = this.selectedEvent.event.participants || [];
            const organizer = this.selectedEvent.event.organizer;
            this.showEditOptions = false;
            this.showChooseParticipantsModal = true;
            this.importParticipants = participants.map(participant => ({
                label: participant?.email,
                value: participant?.email,
                disabled: participant?.email === organizer?.email,
                selected: participant?.email === organizer?.email,
            }));
        }
    }
    handleImportGroupEvent() {
        const masterEventId = this.selectedEvent?.event.master_event_id;
        const participantsList = this.selectedImportParticipants;
        const organizer = this.selectedEvent?.event.organizer;
        const groupEvent = {
            event_id: masterEventId ? masterEventId : this.selectedEvent?.event.id || '',
            calendar_id: this.selectedEvent?.event.calendar_id || '',
            capacity: 10,
            participants: participantsList.length > 0 ? participantsList : [{ ...organizer, is_organizer: true }],
            organizer: organizer,
        };
        this.showChooseParticipantsModal = false;
        if (!!groupEvent.event_id && !!groupEvent.calendar_id) {
            this.importGroupEvent.emit(groupEvent);
        }
    }
    handlePrevNextClick(direction) {
        const currentView = viewToTypeMapping[this.calendar.view.type];
        if (direction === 'prev') {
            this.calendar.prev();
        }
        else {
            this.calendar.next();
        }
        const startTime = new Date(this.calendar.getCurrentData().viewApi.activeStart).getTime() / 1000;
        const endTime = new Date(this.calendar.getCurrentData().viewApi.activeEnd).getTime() / 1000;
        this.previosNextClicked.emit({ direction, view: currentView, currentViewRange: { startTime, endTime } });
    }
    handleUpdateGroupEvent(e, option) {
        e.preventDefault();
        e.stopPropagation();
        if (this.isLoading)
            return;
        this.loadingOptions.update = option.value;
        if (this.selectedEvent && this.internals.checkValidity()) {
            this.saveGroupEventChanges.emit({ data: this.selectedEvent, action: option.value });
        }
    }
    handleDeleteGroupEvent(e, option) {
        e.preventDefault();
        e.stopPropagation();
        if (this.isLoading)
            return;
        this.loadingOptions.delete = option.value;
        if (this.selectedEvent) {
            this.deleteGroupEvent.emit({ data: this.selectedEvent, action: option.value });
        }
    }
    async handleCreateGroupEvent(e) {
        e.preventDefault();
        e.stopPropagation();
        const formData = new FormData(this.formRef);
        const valid = this.formRef.checkValidity();
        if (!valid) {
            this.formError = i18next.t('fixFormErrors');
            this.formErrors['form'] = i18next.t('fixFormErrors');
            return;
        }
        const formState = {};
        formData.forEach((value, key) => {
            formState[key] = value;
        });
        await this.createGroupEvent.emit({
            title: formState?.title,
            description: formState?.description,
            location: formState?.location,
            eventTimeslot: JSON.parse(formState?.['event-timeslot']),
            eventCapacity: parseInt(formState?.['event-capacity']),
            conferencing: formState?.conferencing ? JSON.parse(formState?.conferencing.toString()) : undefined,
            participants: formState?.participants ? JSON.parse(formState.participants) : [],
        });
    }
    isLoadingChangedHandler(newVal, _oldVal) {
        if (!newVal) {
            this.loadingOptions = {
                update: '',
                delete: '',
                create: '',
            };
            this.showCreateEventDetails = false;
            this.createNewGroupEventTimeslot = null;
            this.showEditOptions = false;
            this.showUpdateOptions = false;
            this.showDeleteOptions = false;
            this.showEditEventDetails = false;
            this.unsavedChanges = false;
            this.showConfirmDiscardUnsavedChangesModal = false;
            this.selectedEvent = null;
            this.selectedImportParticipants = [];
            this.importParticipants = [];
            this.showChooseParticipantsModal = false;
            this.formError = '';
            this.formErrors = {};
        }
    }
    valueChangedHandler(event) {
        const { value, name } = event.detail;
        const componentNames = ['title', 'description', 'location', 'event-timeslot', 'participants', 'event-capacity'];
        if ((this.showEditEventDetails || this.showCreateEventDetails) && componentNames.includes(name)) {
            this.unsavedChanges = true;
            if (this.formErrors[name]) {
                delete this.formErrors[name];
            }
            if (Object.keys(this.formErrors).length === 0) {
                this.formError = '';
                this.internals.setValidity({});
            }
            else {
                const firstErrorMessage = Object.values(this.formErrors)[0];
                this.formError = firstErrorMessage || '';
            }
        }
        if (name === 'event-timeslot') {
            const { recurrence } = JSON.parse(value);
            const currentRrule = this.selectedEvent?.group_event_info?.rrule?.[0];
            const updatedRrule = recurrence[0];
            if (currentRrule !== updatedRrule) {
                this.updateOptionTranslations();
                this.updateOptions = this.updateOptionChoices.filter(option => option.value !== 'this');
                return;
            }
            if (this.selectedEvent?.group_event_info) {
                this.selectedEvent.group_event_info.rrule = recurrence;
            }
        }
        if (name === 'event-capacity') {
            const parsedValue = parseInt(value);
            if (parsedValue < 1 || parsedValue > 500 || isNaN(parsedValue)) {
                this.formErrors['event-capacity'] = i18next.t('fixFormErrors');
                this.formError = i18next.t('fixFormErrors');
                this.internals.setValidity({ customError: true }, this.formError);
            }
            else {
                this.formError = '';
                this.internals.setValidity({ customError: false }, '');
            }
        }
    }
    timeWindowFormErrorHandler(event) {
        if (event.detail.key === 'event-timeslot') {
            const fieldIdentifier = event.detail?.uniqueIdentifier || event.detail.key;
            if (event.detail.message) {
                this.formErrors[fieldIdentifier] = event.detail.message;
                this.formError = event.detail.message;
                this.internals.setValidity({ customError: true }, event.detail.message);
            }
            else {
                if (this.formErrors[fieldIdentifier]) {
                    delete this.formErrors[fieldIdentifier];
                }
                if (Object.keys(this.formErrors).length === 0) {
                    this.formError = '';
                    this.internals.setValidity({});
                }
                else {
                    const firstErrorMessage = Object.values(this.formErrors)[0];
                    this.formError = firstErrorMessage || '';
                }
            }
        }
    }
    dateTimeInputErrorHandler(event) {
        if (event.detail.key === 'event-timeslot') {
            if (event.detail.message) {
                this.formErrors['date-time-input'] = event.detail.message;
                this.formError = event.detail.message;
            }
            else {
                delete this.formErrors['date-time-input'];
                this.formError = '';
            }
        }
    }
    saveGroupEventChangesErrorHandler(event) {
        this.loadingOptions.update = '';
        if (event.detail.error) {
            this.formError = event.detail.error;
        }
    }
    selectedOptionsChangedHandler(event) {
        const { value, name } = event.detail;
        if (name === 'participants') {
            this.selectedImportParticipants = this.selectedEvent?.event.participants?.filter(participant => value.includes(participant.email)) || [];
        }
    }
    nylasCheckboxGroupChangedHandler(event) {
        const { selectedValues, name } = event.detail;
        if (name === 'hide-non-group-events') {
            this.showAllEvents = !selectedValues.includes('group-only');
            let events = JSON.parse(JSON.stringify(this.events));
            if (!this.showAllEvents) {
                events = events.filter(event => event.classNames.includes('group-event'));
            }
            this.calendar?.setOption('events', events);
        }
    }
    render() {
        const calendarId = this.selectedConfiguration?.group_booking?.calendar_id;
        const currentCalendar = calendarId ? this.calendars?.find(c => c.id === calendarId) : null;
        const day = i18next.t('timePeriod_day') || 'day';
        const week = i18next.t('timePeriod_week') || 'week';
        const month = i18next.t('timePeriod_month') || 'month';
        const start = this.selectedEvent?.event?.when?.start_time;
        const timezone = this.selectedEvent?.event?.when?.start_timezone;
        const startDate = start ? dayjs(start * 1000).tz(timezone) : null;
        const eventInPast = startDate && startDate.isBefore(dayjs().tz(timezone));
        return (h(Host, null, h("div", { class: "nylas-event-calendar" }, h("div", { class: {
                'calendar-container': true,
                'show-event': this.showEditEventDetails || this.showCreateEventDetails,
            } }, h("div", { class: "calendar-header" }, h("div", { class: "calendar-header__row_one" }, h("div", { class: "calendar-header__title" }, h("div", { class: "calendar-header-prev-next" }, h("button", { onClick: () => this.handlePrevNextClick('prev'), class: { 'chevron-left': true, 'button': true } }, ' ', h("chevron-icon", null)), h("span", null, this.selectedDateRangeString), h("button", { onClick: () => this.handlePrevNextClick('next'), class: { 'chevron-right': true, 'button': true } }, ' ', h("chevron-icon", null)))), h("div", { class: "calendar-header__current-calendar" }, currentCalendar?.name || currentCalendar?.id, "'s calendar"), h("div", { class: "calendar-header__view-options" }, h("button", { class: { selected: this.calendar?.view.type === typeToViewMapping['day'] }, onClick: () => this.setView('day') }, day.charAt(0).toUpperCase() + day.slice(1)), h("button", { class: { selected: this.calendar?.view.type === typeToViewMapping['week'] }, onClick: () => this.setView('week') }, week.charAt(0).toUpperCase() + week.slice(1)), h("button", { class: { selected: this.calendar?.view.type === typeToViewMapping['month'] }, onClick: () => this.setView('month') }, month.charAt(0).toUpperCase() + month.slice(1)))), h("div", { class: "calendar-header__row_two" }, h("div", { class: "calendar-header__hide-non-group-events" }, h("label", null, i18next.t('nylasEventCalendar.hideNonGroupEvents.showLabel'), h("span", { class: "label-icon" }, h("tooltip-component", null, h("info-icon", { slot: "tooltip-icon" }), h("span", { slot: "tooltip-content" }, i18next.t('nylasEventCalendar.hideNonGroupEvents.tooltip.desc'))))), h("checkbox-group", { direction: "horizontal", name: "hide-non-group-events", options: [{ label: i18next.t('nylasEventCalendar.hideNonGroupEvents.options.group'), value: 'group-only', checked: false }] })))), h("div", { ref: el => (this.calendarEl = el) })), this.showEditEventDetails && this.selectedEvent?.group_event_info && (h("div", { class: "event-details-container" }, h("div", { class: "event-details-header" }, h("h3", null, i18next.t('nylasEventCalendar.editEventDetails.headerTitle')), h("div", { class: "event-details-header__actions" }, h("button-component", { tooltip: i18next.t('nylasEventCalendar.editEventDetails.closeButtonTooltip'), id: "close", disabled: this.isLoading, variant: 'invisible', onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                if (this.unsavedChanges) {
                    this.showConfirmDiscardUnsavedChangesModal = true;
                }
                else {
                    this.showEditEventDetails = false;
                    this.unsavedChanges = false;
                    this.selectedEvent = null;
                    this.formError = '';
                }
            } }, h("close-icon", null)))), h("div", { class: {
                'event-details': true,
                'edit-event-details': true,
            } }, h("nylas-event-title", { noTemplates: true, name: "title", eventTitle: this.selectedEvent.event.title, exportparts: "net, net__title, net__input_group, net__input_wrapper, net__input" }), h("nylas-event-description", { name: "description", noTemplates: true, eventDescription: this.selectedEvent.event.description, exportparts: "ned, ned__title, ned__input_group, ned__input_wrapper, ned__input" }), h("nylas-event-location", { name: "location", eventLocation: this.selectedEvent.event.location, eventConferencing: this.selectedEvent.event.conferencing, exportparts: "nel, nel__title, nel__input_group, nel__input_wrapper, nel__input, nel__conferencing" }), h("nylas-event-timeslot", { name: "event-timeslot", initialValue: {
                when: this.selectedEvent.event.when,
                recurrence: this.selectedEvent?.group_event_info?.rrule ? this.selectedEvent.group_event_info.rrule : [],
            }, exportparts: "nets, nets__title, nets__input_group, nets__input_wrapper, nets__input, nets__timezone, nets__recurrence" }), h("nylas-event-capacity", { name: "event-capacity", capacity: this.selectedEvent?.group_event_info?.capacity, exportparts: "nec, nec__title, nec__input_group, nec__input_wrapper, nec__input" }), h("nylas-additional-participants", { name: "participants", eventParticipants: this.selectedEvent.group_event_info.participants, exportparts: "nadtnlpart, nadtnlpart__title, nadtnlpart__subtitle, nadtnlpart__content, nadtnlpart__input_group, nadtnlpart__input_wrapper, nadtnlpart__input, nadtnlpart__remove-participant" })), h("div", { class: "event-details-footer" }, h("div", { class: "event-details-footer__error" }, h("p", null, this.formError)), h("div", { class: "event-details-footer__helper-text" }, h("p", null, this.unsavedChanges && !this.isLoading ? i18next.t('nylasEventCalendar.unsavedChanges') : '')), h("div", { class: "event-details-footer__actions" }, h("button-component", { variant: 'destructive', disabled: this.isLoading, onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                if (this.selectedEvent?.event?.master_event_id) {
                    this.showUpdateOptions = true;
                }
                else {
                    this.handleDeleteGroupEvent(e, { label: 'Delete this event', value: 'this' });
                }
            } }, i18next.t('nylasEventCalendar.editEventDetails.deleteButton')), h("button-component", { variant: 'basic', disabled: this.isLoading || this.formError !== '' || !!eventInPast, tooltip: eventInPast ? i18next.t('nylasEventCalendar.editEventDetails.pastEventTooltip') : '', onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                if (!this.unsavedChanges)
                    return;
                if (this.selectedEvent?.event?.master_event_id) {
                    this.showUpdateOptions = true;
                }
                else {
                    this.handleUpdateGroupEvent(e, { label: 'Update this event', value: 'this' });
                }
            } }, i18next.t('nylasEventCalendar.editEventDetails.saveButton')))))), this.showCreateEventDetails && this.createNewGroupEventTimeslot && (h("div", { class: "event-details-container" }, h("div", { class: "event-details-header" }, h("h3", null, i18next.t('nylasEventCalendar.createEventDetails.headerTitle')), h("div", { class: "event-details-header__actions" }, h("button-component", { tooltip: i18next.t('nylasEventCalendar.createEventDetails.closeButtonTooltip'), id: "close", variant: 'invisible', disabled: this.isLoading, onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                if (this.unsavedChanges) {
                    this.showConfirmDiscardUnsavedChangesModal = true;
                }
                else {
                    this.showCreateEventDetails = false;
                    this.createNewGroupEventTimeslot = null;
                    this.selectedEvent = null;
                    this.unsavedChanges = false;
                }
            } }, h("close-icon", null)))), h("form", { ref: el => (this.formRef = el) }, h("div", { class: {
                'event-details': true,
            } }, h("nylas-event-info", null, h("div", { slot: "inputs", class: "event-details-form-inputs" }, h("nylas-event-title", { noTemplates: true, eventTitle: 'New group event', exportparts: "net, net__title, net__input_group, net__input_wrapper, net__input" }), h("nylas-event-description", { noTemplates: true, hideAutoPopulateButton: true, exportparts: "ned, ned__title, ned__input_group, ned__input_wrapper, ned__input" }), h("nylas-event-location", { userProvider: this.currentUser?.provider, exportparts: "nel, nel__title, nel__input_group, nel__input_wrapper, nel__input, nel__conferencing" }), h("nylas-event-timeslot", { name: "event-timeslot", initialValue: this.createNewGroupEventTimeslot, exportparts: "nets, nets__title, nets__input_group, nets__input_wrapper, nets__input, nets__timezone, nets__recurrence" }), h("nylas-event-capacity", { name: "event-capacity", exportparts: "nec, nec__title, nec__input_group, nec__input_wrapper, nec__input" }))), h("nylas-additional-participants", { name: "participants", eventParticipants: [{ name: this.currentUser?.name || this.currentUser?.email, email: this.currentUser?.email || '', is_organizer: true }], exportparts: "nadtnlpart, nadtnlpart__title, nadtnlpart__subtitle, nadtnlpart__content, nadtnlpart__input_group, nadtnlpart__input_wrapper, nadtnlpart__input, nadtnlpart__remove-participant" })), h("div", { class: "event-details-footer" }, h("div", { class: "event-details-footer__error" }, h("p", null, this.formError)), h("div", { class: "event-details-footer__helper-text" }, h("p", null, this.unsavedChanges && !this.isLoading ? i18next.t('nylasEventCalendar.unsavedChanges') : '')), h("div", { class: "event-details-footer__actions" }, h("button-component", { variant: 'basic', disabled: this.isLoading, onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                if (this.unsavedChanges) {
                    this.showConfirmDiscardUnsavedChangesModal = true;
                }
                else {
                    this.showCreateEventDetails = false;
                    this.createNewGroupEventTimeslot = null;
                    this.selectedEvent = null;
                    this.unsavedChanges = false;
                }
            } }, i18next.t('nylasEventCalendar.createEventDetails.cancelButton')), h("button-component", { variant: 'primary', disabled: this.isLoading || this.formError !== '', isLoading: this.isLoading, onClick: e => {
                this.handleCreateGroupEvent(e);
            } }, i18next.t('nylasEventCalendar.createEventDetails.createButton'))))))), this.showConfirmDiscardUnsavedChangesModal && (h("div", { class: "discard-changes action-options", onClick: () => (this.showUpdateOptions = false) }, h("div", { class: "discard-changes__card action-options__card" }, h("button-component", { tooltip: "Close", id: "close-discard-changes", variant: 'invisible', disabled: this.isLoading, onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                this.showConfirmDiscardUnsavedChangesModal = false;
            } }, h("close-icon", null)), h("div", { class: "discard-changes__content action-options__content" }, h("h3", { slot: "card-title", part: "nfbf__title" }, i18next.t('nylasEventCalendar.discardChanges.headerTitle'))), h("div", { class: "discard-changes__footer action-options__footer" }, h("button-component", { variant: 'basic', onClick: _e => (this.showConfirmDiscardUnsavedChangesModal = false), part: "nfbf__button-outline nfbf__cancel-cta" }, i18next.t('nylasEventCalendar.discardChanges.cancelButton')), h("button-component", { variant: 'destructive', onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                this.showConfirmDiscardUnsavedChangesModal = false;
                this.unsavedChanges = false;
                this.showEditEventDetails = false;
                this.showCreateEventDetails = false;
                this.selectedEvent = null;
                this.createNewGroupEventTimeslot = null;
                this.formError = '';
            }, part: "nfbf__button-outline nfbf__reschedule-cta" }, i18next.t('nylasEventCalendar.discardChanges.discardButton')))))), this.showEditOptions && (h("div", { class: "edit-options action-options", onClick: () => (this.showEditOptions = false) }, h("div", { class: "edit-options__card action-options__card" }, h("div", { class: "edit-options__header action-options__header" }, h("h3", null, i18next.t('nylasEventCalendar.editOptions.headerTitle')), h("button-component", { tooltip: i18next.t('nylasEventCalendar.editOptions.closeButtonTooltip'), id: "close-edit-options", disabled: this.isLoading, variant: 'invisible', onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                this.showEditOptions = false;
            } }, h("close-icon", null))), h("div", { class: "edit-options__content action-options__content" }, h("ul", { tabindex: "-1", role: "listbox", "aria-label": this.name }, this.editOptions.map(option => option.value.toString() ? (h("li", { class: { disabled: !!this.isLoading }, tabindex: "0", key: option.value, id: option.value, onClick: e => this.handleEditOptionSelected(e, option), role: "option" }, this.isLoading && this.loadingOptions.delete === option.value ? i18next.t('nylasEventCalendar.editOptions.deleting') : option.label, option.value === 'import' && (h("tooltip-component", { id: "organizer_participant_tooltip" }, h("info-icon", { slot: "tooltip-icon" }), h("span", { slot: "tooltip-content" }, i18next.t('nylasEventCalendar.editOptions.importTooltip')))))) : null)))))), this.showUpdateOptions && (h("div", { class: "update-options action-options", onClick: () => (this.showUpdateOptions = false) }, h("div", { class: "update-options__card action-options__card" }, h("button-component", { tooltip: "Close", id: "close-update-options", variant: 'invisible', disabled: this.isLoading, onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                this.showUpdateOptions = false;
            } }, h("close-icon", null)), h("div", { class: "update-options__content action-options__content" }, h("ul", { tabindex: "-1", role: "listbox", "aria-label": this.name }, this.updateOptions.map(option => option.value.toString() ? (h("li", { class: { disabled: !!this.isLoading }, tabindex: "0", key: option.value, id: option.value, role: "option", onClick: e => this.handleUpdateGroupEvent(e, option) }, this.isLoading && this.loadingOptions.update === option.value ? `Updating...` : option.label)) : null)))))), this.showDeleteOptions && (h("div", { class: "delete-options action-options", onClick: () => (this.showDeleteOptions = false) }, h("div", { class: "delete-options__card action-options__card" }, h("button-component", { tooltip: i18next.t('nylasEventCalendar.deleteEvent.closeButtonTooltip'), id: "close-delete-options", variant: 'invisible', disabled: this.isLoading, onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                this.showDeleteOptions = false;
            } }, h("close-icon", null)), h("div", { class: "delete-options__content action-options__content" }, h("ul", { tabindex: "-1", role: "listbox", "aria-label": this.name }, this.deleteOptions.map(option => option.value.toString() ? (h("li", { class: { disabled: !!this.isLoading }, tabindex: "0", key: option.value, id: option.value, role: "option", onClick: e => this.handleDeleteGroupEvent(e, option) }, this.isLoading && this.loadingOptions.delete === option.value ? i18next.t('nylasEventCalendar.deleteEvent.deleting') : option.label)) : null)))))), this.showChooseParticipantsModal && (h("div", { class: "choose-participants-modal action-options" }, h("div", { class: "choose-participants-modal__card action-options__card" }, h("button-component", { tooltip: i18next.t('nylasEventCalendar.importEvent.closeButtonTooltip'), id: "close-choose-participants-modal", variant: 'invisible', disabled: this.isLoading, onClick: e => {
                e.preventDefault();
                e.stopImmediatePropagation();
                this.showChooseParticipantsModal = false;
            } }, h("close-icon", null)), h("div", { class: "choose-participants-modal__content action-options__content" }, h("multi-select-dropdown", { name: "participants", multipleOptionsSelectedLabel: i18next.t('multipleOptionsSelected'), selectAtLeastOneOptionLabel: i18next.t('selectOneOrMoreOptions'), label: i18next.t('nylasEventCalendar.importEvent.participantsLabel'), options: this.importParticipants }), h("button-component", { variant: 'basic', onClick: () => this.handleImportGroupEvent() }, i18next.t('nylasEventCalendar.importEvent.importButton')))))))));
    }
    static get is() { return "nylas-event-calendar"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-event-calendar.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-event-calendar.css"]
        };
    }
    static get properties() {
        return {
            "selectedConfiguration": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "GroupConfiguration",
                    "resolved": "GroupConfiguration | undefined",
                    "references": {
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The selected configuration"
                        }],
                    "text": ""
                }
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The name of the component"
                        }],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'page-name'"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            },
            "groupEvents": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "GroupEventAPIData[]",
                    "resolved": "GroupEventAPIData[] | undefined",
                    "references": {
                        "GroupEventAPIData": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEventAPIData"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The group events prop"
                }
            },
            "currentUser": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "User",
                    "resolved": "undefined | { id: string; email: string; name?: string | undefined; provider?: string | undefined; }",
                    "references": {
                        "User": {
                            "location": "import",
                            "path": "@/common/nylas-api-request",
                            "id": "src/common/nylas-api-request.ts::User"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The current user prop"
                }
            },
            "calendars": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "NylasCalendar[]",
                    "resolved": "NylasCalendar[] | undefined",
                    "references": {
                        "NylasCalendar": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::NylasCalendar"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The calendars prop"
                }
            },
            "masterGroupEvents": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Record<string, EventDetails>",
                    "resolved": "undefined | { [x: string]: EventDetails; }",
                    "references": {
                        "Record": {
                            "location": "global",
                            "id": "global::Record"
                        },
                        "EventDetails": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::EventDetails"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The master group events prop"
                }
            },
            "isLoading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The is loading prop"
                },
                "attribute": "is-loading",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "selectedView": {},
            "events": {},
            "calendar": {},
            "selectedEvent": {},
            "selectedDateRangeString": {},
            "showEditEventDetails": {},
            "showCreateEventDetails": {},
            "editOptionChoices": {},
            "updateOptionChoices": {},
            "deleteOptionChoices": {},
            "editOptions": {},
            "showEditOptions": {},
            "updateOptions": {},
            "showUpdateOptions": {},
            "deleteOptions": {},
            "showDeleteOptions": {},
            "unsavedChanges": {},
            "showConfirmDiscardUnsavedChangesModal": {},
            "createNewGroupEventTimeslot": {},
            "formError": {},
            "formErrors": {},
            "loadingOptions": {},
            "showChooseParticipantsModal": {},
            "importParticipants": {},
            "selectedImportParticipants": {},
            "showAllEvents": {}
        };
    }
    static get events() {
        return [{
                "method": "fetchMasterGroupEvent",
                "name": "fetchMasterGroupEvent",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }, {
                "method": "saveGroupEventChanges",
                "name": "saveGroupEventChanges",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ data: GroupEventAPIData; action: 'this' | 'future' | 'all' }",
                    "resolved": "{ data: GroupEventAPIData; action: \"this\" | \"future\" | \"all\"; }",
                    "references": {
                        "GroupEventAPIData": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEventAPIData"
                        }
                    }
                }
            }, {
                "method": "deleteGroupEvent",
                "name": "deleteGroupEvent",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ data: GroupEventAPIData; action: 'this' | 'future' | 'all' }",
                    "resolved": "{ data: GroupEventAPIData; action: \"this\" | \"future\" | \"all\"; }",
                    "references": {
                        "GroupEventAPIData": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEventAPIData"
                        }
                    }
                }
            }, {
                "method": "groupEventSelected",
                "name": "groupEventSelected",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "GroupEventAPIData",
                    "resolved": "GroupEventAPIData",
                    "references": {
                        "GroupEventAPIData": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEventAPIData"
                        }
                    }
                }
            }, {
                "method": "createGroupEvent",
                "name": "createGroupEvent",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "CreateGroupEventFormState",
                    "resolved": "{ title: string; description: string; location: string; eventTimeslot: { when: { start_time: number; end_time: number; start_timezone: string; end_timezone: string; }; recurrence: string[]; }; eventCapacity: number; conferencing?: Conference | undefined; participants: { name: string; email: string; is_organizer?: boolean | undefined; }[]; }",
                    "references": {
                        "CreateGroupEventFormState": {
                            "location": "local",
                            "path": "/home/runner/work/nylas/nylas/packages/nylas-web-elements/src/components/scheduler-editor/nylas-event-calendar/nylas-event-calendar.tsx",
                            "id": "src/components/scheduler-editor/nylas-event-calendar/nylas-event-calendar.tsx::CreateGroupEventFormState"
                        }
                    }
                }
            }, {
                "method": "calendarViewChanged",
                "name": "calendarViewChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ startTime: number; endTime: number }",
                    "resolved": "{ startTime: number; endTime: number; }",
                    "references": {}
                }
            }, {
                "method": "previosNextClicked",
                "name": "previosNextClicked",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ direction: 'prev' | 'next'; view: 'day' | 'week' | 'month'; currentViewRange: { startTime: number; endTime: number } }",
                    "resolved": "{ direction: \"next\" | \"prev\"; view: \"day\" | \"week\" | \"month\"; currentViewRange: { startTime: number; endTime: number; }; }",
                    "references": {}
                }
            }, {
                "method": "setCalendarViewDateRange",
                "name": "setCalendarViewDateRange",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ startTime: number; endTime: number }",
                    "resolved": "{ startTime: number; endTime: number; }",
                    "references": {}
                }
            }, {
                "method": "importGroupEvent",
                "name": "importGroupEvent",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{\n    event_id: string;\n    calendar_id: string;\n  }",
                    "resolved": "{ event_id: string; calendar_id: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }, {
                "propName": "groupEvents",
                "methodName": "groupEventsChangedHandler"
            }, {
                "propName": "isLoading",
                "methodName": "isLoadingChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "valueChanged",
                "method": "valueChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "timeWindowFormError",
                "method": "timeWindowFormErrorHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "dateTimeInputError",
                "method": "dateTimeInputErrorHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "saveGroupEventChangesError",
                "method": "saveGroupEventChangesErrorHandler",
                "target": "document",
                "capture": false,
                "passive": false
            }, {
                "name": "selectedOptionsChanged",
                "method": "selectedOptionsChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasCheckboxGroupChanged",
                "method": "nylasCheckboxGroupChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    RegisterComponent({
        name: 'nylas-event-calendar',
        stateToProps: new Map([
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
            ['schedulerConfig.groupEvents', 'groupEvents'],
            ['schedulerConfig.masterGroupEvents', 'masterGroupEvents'],
            ['schedulerConfig.currentUser', 'currentUser'],
            ['schedulerConfig.calendars', 'calendars'],
            ['schedulerConfig.isLoading', 'isLoading'],
            ['schedulerConfig.selectedConfiguration', 'selectedConfiguration'],
        ]),
        eventToProps: {
            groupEventSelected: async (event, connector) => {
                const { detail } = event;
                connector.schedulerConfigStore.state.selectedGroupEvent = detail;
            },
            calendarViewChanged: async (event, connector) => {
                const { detail } = event;
                connector.schedulerConfigStore.state.calendarViewDateRange = {
                    start_time: detail.startTime.toString(),
                    end_time: detail.endTime.toString(),
                };
                const configId = connector.schedulerConfigStore.state.selectedConfiguration?.id;
                if (configId) {
                    const [data, error] = await connector.schedulerConfig.getGroupEvents(configId, connector.schedulerConfigStore.state.selectedConfiguration);
                    if (!data && error && error.message) {
                        return;
                    }
                }
            },
            previosNextClicked: async (event, connector) => {
                const { detail } = event;
                connector.schedulerConfigStore.state.calendarViewDateRange = {
                    start_time: detail.currentViewRange.startTime.toString(),
                    end_time: detail.currentViewRange.endTime.toString(),
                };
                const configId = connector.schedulerConfigStore.state.selectedConfiguration?.id;
                if (configId) {
                    const [data, error] = await connector.schedulerConfig.getGroupEvents(configId, connector.schedulerConfigStore.state.selectedConfiguration);
                    if (!data && error && error.message) {
                        return;
                    }
                }
            },
            saveGroupEventChanges: async (event, _connector) => {
                debug('nylas-event-calendar', 'saveGroupEventChanges', event.detail);
            },
            setCalendarViewDateRange: async (event, connector) => {
                debug('nylas-event-calendar', 'setCalendarViewDateRange', event.detail);
                connector.schedulerConfigStore.state.calendarViewDateRange = {
                    start_time: event.detail.startTime.toString(),
                    end_time: event.detail.endTime.toString(),
                };
            },
            fetchMasterGroupEvent: async (event, connector) => {
                debug('nylas-event-calendar', 'fetchMasterGroupEvent', event.detail);
                const [data, error] = await connector.schedulerConfig.getMasterEventById(event.detail);
                if (!data && error && error.message) {
                    return;
                }
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasEventCalendar.prototype, "render", null);
//# sourceMappingURL=nylas-event-calendar.js.map
