import { newSpecPage } from "@stencil/core/testing";
import { NylasEventDescription } from "../nylas-event-description";
import { selectedConfiguration } from "../../../../utils/test-utils";
import { h } from "@stencil/core";
describe('nylas-event-description', () => {
    beforeEach(() => {
        jest.clearAllMocks();
    });
    it('should render', async () => {
        const page = await newSpecPage({ components: [NylasEventDescription], html: '<nylas-event-description></nylas-event-description>' });
        if (!page.root) {
            throw new Error('Component did not render.');
        }
        expect(page.root).toMatchSnapshot();
    });
    it('should apply additional fields to the description only once', async () => {
        const page = await newSpecPage({
            components: [NylasEventDescription],
            template: () => {
                return (h("nylas-event-description", { selectedConfiguration: {
                        ...selectedConfiguration,
                        scheduler: {
                            ...selectedConfiguration.scheduler,
                            additional_fields: {
                                'dropdown_Dropdown-Label_1': {
                                    label: 'Dropdown Label',
                                    type: 'dropdown',
                                    required: true,
                                    default: 'dgytg',
                                    order: 1,
                                    options: ['a', 'd'],
                                },
                            },
                        },
                    } }));
            },
        });
        if (!page.root) {
            throw new Error('Component did not render.');
        }
        const button = page.root?.shadowRoot?.querySelector('button-component');
        button.click();
        await page.waitForChanges();
        button.click();
        await page.waitForChanges();
        const description = page.root?.shadowRoot?.querySelector('div.event-description');
        expect(page.root).toMatchSnapshot();
        const text = '--- Additional Fields ---\nDropdown Label: ${dropdown_Dropdown-Label_1}\n--- End Additional Fields ---';
        expect(description.textContent).toBe(text);
    });
});
//# sourceMappingURL=nylas-event-description.spec.js.map
