var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import i18next from "../../../utils/i18n";
export class NylasEventDuration {
    constructor() {
        this.selectedConfiguration = undefined;
        this.name = 'duration';
        this.eventDurationMinutes = undefined;
        this.selectedLanguage = undefined;
        this.duration = this.eventDurationMinutes ? (this.eventDurationMinutes >= 60 ? this.eventDurationMinutes / 60 : this.eventDurationMinutes) : 30;
        this.durationMinutes = undefined;
        this.durationIncrement = undefined;
        this.error = '';
        this.durationMinutesOptions = [
            { value: (15).toString(), label: '15' },
            { value: (30).toString(), label: '30' },
            { value: (45).toString(), label: '45' },
            { value: (60).toString(), label: '60' },
        ];
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-event-duration', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    selectedConfigurationChangedHandler(newVal) {
        const configDuration = newVal?.availability?.duration_minutes;
        if (configDuration) {
            this.duration = configDuration >= 60 ? configDuration / 60 : configDuration;
            this.durationMinutes = configDuration ? configDuration : 30;
            this.durationIncrement = configDuration >= 60 ? 60 : 1;
            this.isInternalsAvailable && this.internals.setFormValue(this.durationMinutes.toString(), 'duration');
        }
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
        if (this.error) {
            this.validateDuration();
        }
    }
    connectedCallback() {
        debug('nylas-event-duration', 'connectedCallback');
    }
    componentWillLoad() {
        debug('nylas-event-duration', 'componentWillLoad');
        this.host.setAttribute('name', this.name);
    }
    componentDidLoad() {
        debug('nylas-event-duration', 'componentDidLoad');
        if (this.selectedConfiguration) {
            this.selectedConfigurationChangedHandler(this.selectedConfiguration);
        }
        this.duration = this.duration ? this.duration : this.eventDurationMinutes ? (this.eventDurationMinutes >= 60 ? this.eventDurationMinutes / 60 : this.eventDurationMinutes) : 30;
        this.durationMinutes = this.durationMinutes ? this.durationMinutes : this.duration ? this.duration : 30;
        this.durationIncrement = this.durationIncrement ? this.durationIncrement : this.duration >= 60 ? 60 : 1;
        this.setDurationMintueOptions();
        this.isInternalsAvailable && this.internals.setFormValue(this.durationMinutes.toString(), 'duration');
    }
    disconnectedCallback() {
        debug('nylas-event-duration', 'disconnectedCallback');
    }
    get isInternalsAvailable() {
        return typeof this.internals !== 'undefined' && typeof this.internals.setFormValue === 'function';
    }
    setDurationMintueOptions() {
        if (this.durationIncrement === 1) {
            this.durationMinutesOptions = [
                { value: (15).toString(), label: '15' },
                { value: (30).toString(), label: '30' },
                { value: (45).toString(), label: '45' },
                { value: (60).toString(), label: '60' },
            ];
        }
        else {
            this.durationMinutesOptions = Array.from({ length: 23 }, (_, i) => ({ value: (i + 1).toString(), label: (i + 1).toString() }));
        }
        return this.durationMinutesOptions;
    }
    validateDuration() {
        if (this.durationMinutes % 5 !== 0) {
            this.error = i18next.t('nylasEventDuration.error.durationMustBeMultipleOf5');
            this.isInternalsAvailable && this.internals.setValidity({ customError: true }, this.error);
        }
        else if (this.durationMinutes <= 0) {
            this.error = i18next.t('nylasEventDuration.error.durationMustBeGreaterThan0');
            this.isInternalsAvailable && this.internals.setValidity({ customError: true }, this.error);
        }
        else {
            this.error = '';
            this.isInternalsAvailable && this.internals.setValidity({});
        }
        return this.error;
    }
    nylasFormDropdownChangedHandler(event) {
        debug('nylas-calendar-picker', 'nylasFormDropdownChangedHandler', event.detail);
        const { value } = event.detail;
        this.durationIncrement = parseInt(value.toString());
        if (this.durationIncrement === 1) {
            this.duration = 60;
        }
        else {
            this.duration = 1;
        }
        this.setDurationMintueOptions();
        this.durationMinutes = this.duration * this.durationIncrement;
        if (this.validateDuration() !== '') {
            return;
        }
        this.isInternalsAvailable && this.internals.setFormValue(this.durationMinutes.toString(), this.name);
        this.valueChanged.emit({ value: this.durationMinutes.toString(), name: this.name });
    }
    inputOptionChangedHandler(event) {
        debug('nylas-calendar-picker', 'inputOptionChangedHandler', event.detail);
        const { value } = event.detail;
        this.duration = parseFloat(value.toString());
        this.durationMinutes = this.duration * this.durationIncrement;
        if (this.validateDuration() !== '') {
            return;
        }
        this.isInternalsAvailable && this.internals.setFormValue(this.durationMinutes.toString(), this.name);
        this.valueChanged.emit({ value: this.durationMinutes.toString(), name: this.name });
    }
    render() {
        const durationOptions = [
            { value: (1).toString(), label: i18next.t('timeDuration', { context: 'minute' }) },
            { value: (60).toString(), label: i18next.t('timeDuration', { context: 'hour' }) },
        ];
        return (h(Host, { key: 'bee74ed5eb48a1bc48dc362f078d7171e8a34257' }, h("div", { key: '5a04f4235b729b9ef3c8bdd85d154aff975736a2', class: "nylas-event-duration", part: "ned" }, h("label", { key: 'a66b0a5879cbdc7fdec1e1fe43385cea6a961a91', htmlFor: "duration" }, i18next.t('nylasEventDuration.headerTitle'), h("span", { key: '9c7b52f52a84a8ed7d956d7e3c3dd27386eacec4', class: "required" }, "*")), h("div", { key: '266a3ed77da606bfbed95157fa2ca4aaafe27a2b', class: "nylas-event-duration__wrapper" }, h("input-dropdown", { key: '7b3a65e9fb1d687b03cec7b0e9df10e8a873ebcf', class: this.error ? 'error' : '', name: 'event-duration', options: this.durationMinutesOptions, inputValue: this.duration.toString(), exportparts: "id_dropdown: ned__input_dropdown, id_dropdown-input: ned__input_dropdown-input, id_dropdown-content: ned__input_dropdown-content", defaultInputOption: this.durationMinutesOptions.find(i => i.value === this.duration.toString()) }), this.durationIncrement && (h("select-dropdown", { name: 'event-duration', options: durationOptions, pluralizedLabel: this.duration > 1
                ? i18next.t(`time.${this.durationIncrement === 60 ? 'hours' : 'minutes'}`)
                : i18next.t(`time.${this.durationIncrement === 60 ? 'hour' : 'minute'}`), exportparts: "sd_dropdown: ned__dropdown, sd_dropdown-button: ned__dropdown-button, sd_dropdown-content: ned__dropdown-content", defaultSelectedOption: durationOptions.find(i => i.value === this.durationIncrement.toString()), withSearch: false }))), h("div", { key: 'ab0e152a7d9858325b968ed4f01827c3b14cac3a', class: `nylas-event-duration__error-container ${this.error ? 'visible' : ''}`, part: "ned__error-container" }, h("div", { key: '1bfc3072b3e2b51d46247f3eebcbdf917df121e8', class: "nylas-event-duration__error", part: "ned__error" }, this.error)))));
    }
    static get is() { return "nylas-event-duration"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-event-duration.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-event-duration.css"]
        };
    }
    static get properties() {
        return {
            "selectedConfiguration": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Configuration",
                    "resolved": "Configuration | undefined",
                    "references": {
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The selected config"
                        }],
                    "text": ""
                }
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The name of the event duration. Default is 'duration'."
                        }],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'duration'"
            },
            "eventDurationMinutes": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The event duration in minutes as set in the configuration."
                        }],
                    "text": ""
                },
                "attribute": "event-duration-minutes",
                "reflect": false
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "duration": {},
            "durationMinutes": {},
            "durationIncrement": {},
            "error": {},
            "durationMinutesOptions": {}
        };
    }
    static get events() {
        return [{
                "method": "valueChanged",
                "name": "valueChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the event duration changes."
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n  }",
                    "resolved": "{ value: string; name: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedConfiguration",
                "methodName": "selectedConfigurationChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "nylasFormDropdownChanged",
                "method": "nylasFormDropdownChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "inputOptionChanged",
                "method": "inputOptionChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    RegisterComponent({
        name: 'nylas-event-duration',
        stateToProps: new Map([
            ['schedulerConfig.selectedConfiguration', 'selectedConfiguration'],
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
        ]),
        eventToProps: {},
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasEventDuration.prototype, "render", null);
//# sourceMappingURL=nylas-event-duration.js.map
