var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug, generateRRule, getTimezoneOffset } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import i18next from "../../../utils/i18n";
import { TIMEZONE_MAP } from "../../../common/constants";
import dayjs from "dayjs";
import customParseFormat from "dayjs/plugin/customParseFormat";
import utc from "dayjs/plugin/utc";
import timezone from "dayjs/plugin/timezone";
dayjs.extend(customParseFormat);
dayjs.extend(utc);
dayjs.extend(timezone);
const periodMap = {
    day: 'daily',
    week: 'weekly',
    month: 'monthly',
    year: 'yearly',
};
export class NylasEventTimeslot {
    constructor() {
        this.name = 'event-timeslot';
        this.initialValue = undefined;
        this.selectedLanguage = undefined;
        this.currentUser = undefined;
        this.selectedDate = undefined;
        this.selectedStartTime = undefined;
        this.selectedEndTime = undefined;
        this.selectedTimezone = undefined;
        this.selectedRecurrenceType = undefined;
        this.timeRangeError = false;
        this.selectedRrule = undefined;
        this.recurrenceOptions = [];
        this.repeatEveryInterval = 1;
        this.repeatEveryFrequency = 'week';
        this.repeatOnDays = [];
        this.repeatMonthlySameDate = true;
        this.repeatEndType = 'never';
        this.repeatEndAfter = 1;
        this.repeatEndOn = undefined;
        this.monthRecurrenceOptions = [];
        this.endDate = undefined;
        this.hasDateTimeInputError = false;
    }
    connectedCallback() {
        debug('nylas-event-timeslot', 'connectedCallback');
    }
    disconnectedCallback() {
        debug('nylas-event-timeslot', 'disconnectedCallback');
    }
    componentWillLoad() {
        debug('nylas-event-timeslot', 'componentWillLoad');
        this.host.setAttribute('name', this.name);
    }
    componentDidLoad() {
        debug('nylas-event-timeslot', 'componentDidLoad');
        if (this.initialValue) {
            const { when, recurrence } = this.initialValue;
            if (when) {
                this.selectedDate = dayjs.unix(when.start_time).tz(when.start_timezone).format('YYYY-MM-DD');
                this.selectedStartTime = dayjs.unix(when.start_time).tz(when.start_timezone).format('hh:mma');
                this.selectedEndTime = dayjs.unix(when.end_time).tz(when.end_timezone).format('hh:mma');
                this.selectedTimezone = when.start_timezone;
            }
            else {
                this.selectedDate = new Date().toISOString().split('T')[0];
                const defaultTimes = this.getSuggestedTime();
                this.selectedStartTime = defaultTimes.startTime;
                this.selectedEndTime = defaultTimes.endTime;
                this.selectedTimezone = Intl.DateTimeFormat().resolvedOptions().timeZone;
            }
            if (recurrence && recurrence.length > 0) {
                this.selectedRrule = recurrence[0];
                const repeatEndAfter = recurrence[0]?.split(';')?.find(s => s.includes('COUNT'));
                if (repeatEndAfter) {
                    this.repeatEndAfter = parseInt(repeatEndAfter.split('=')[1]);
                }
                const daysString = recurrence[0]?.split(';')?.find(s => s.includes('BYDAY'));
                if (daysString) {
                    this.repeatOnDays = daysString.split('=')[1].split(',');
                }
                const until = recurrence[0]?.split(';')?.find(s => s.includes('UNTIL'));
                if (until) {
                    const untilDate = dayjs(until.split('=')[1], 'YYYYMMDDTHHmmss').toDate();
                    this.repeatEndOn = dayjs(untilDate).toISOString().split('T')[0];
                    this.repeatEndType = 'on';
                }
                const recurrenceType = this.getRecurrenceTypeFromRrule(recurrence[0]);
                this.selectedRecurrenceType = recurrenceType || 'none';
            }
            else {
                this.selectedRecurrenceType = 'none';
                this.selectedRrule = generateRRule(this.selectedDate, this.selectedRecurrenceType, undefined, undefined, this.selectedTimezone);
            }
        }
        else {
            this.selectedDate = new Date().toISOString().split('T')[0];
            const defaultTimes = this.getSuggestedTime();
            this.selectedStartTime = defaultTimes.startTime;
            this.selectedEndTime = defaultTimes.endTime;
            this.selectedTimezone = Intl.DateTimeFormat().resolvedOptions().timeZone;
            this.selectedRecurrenceType = 'none';
            this.selectedRrule = generateRRule(this.selectedDate, this.selectedRecurrenceType, undefined, undefined, this.selectedTimezone);
        }
        this.recurrenceOptions = this.generateRecurrenceOptions(this.selectedDate, this.selectedTimezone);
        this.monthRecurrenceOptions = this.getMonthRecurrenceOptions(this.selectedDate, this.selectedTimezone);
        this.handleValueChanged(true);
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-event-timeslot', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
    }
    getOrdinalSuffix(n) {
        const s = ['th', 'st', 'nd', 'rd'];
        const v = n % 100;
        return n + (s[(v - 20) % 10] || s[v] || s[0]);
    }
    getRecurrenceTypeFromRrule(rrule) {
        if (rrule.includes('INTERVAL'))
            return 'custom';
        if (rrule.includes('FREQ=DAILY'))
            return 'daily';
        if (rrule.includes('FREQ=WEEKLY'))
            return 'weekly';
        if (rrule.includes('FREQ=MONTHLY'))
            return 'monthly';
        if (rrule.includes('FREQ=YEARLY'))
            return 'yearly';
        return undefined;
    }
    generateRecurrenceOptions(selectedDate, timezoneStr) {
        const daysOfWeek = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
        const selectedDay = dayjs.tz(selectedDate, timezoneStr);
        const dayOfWeek = daysOfWeek[selectedDay.day()];
        const date = selectedDay.date();
        const occurrenceInMonth = Math.ceil(date / 7);
        return [
            { label: i18next.t('nylasEventTimeslot.recurrenceOptions.none'), value: 'none' },
            { label: i18next.t('nylasEventTimeslot.recurrenceOptions.daily'), value: 'daily' },
            { label: i18next.t('nylasEventTimeslot.recurrenceOptions.weekly', { dayOfWeek: dayOfWeek }), value: 'weekly' },
            { label: i18next.t('nylasEventTimeslot.recurrenceOptions.monthly', { dayOfMonth: `${this.getOrdinalSuffix(occurrenceInMonth)} ${dayOfWeek}` }), value: 'monthly' },
            {
                label: i18next.t('nylasEventTimeslot.recurrenceOptions.yearly', { dateOfMonth: `${selectedDay.format('MMMM D')}` }),
                value: 'yearly',
            },
            { label: i18next.t('nylasEventTimeslot.recurrenceOptions.custom'), value: 'custom' },
        ];
    }
    getMonthRecurrenceOptions(selectedDate, timezoneStr) {
        const daysOfWeek = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
        const selectedDay = dayjs.tz(selectedDate, timezoneStr);
        const dayOfWeek = daysOfWeek[selectedDay.day()];
        const date = selectedDay.date();
        const occurrenceInMonth = Math.ceil(date / 7);
        return [
            { label: i18next.t('nylasEventTimeslot.recurrenceOptions.monthOnDay', { date: date }), value: 'monthly-same-date' },
            { label: i18next.t('nylasEventTimeslot.recurrenceOptions.monthly', { dayOfMonth: `${this.getOrdinalSuffix(occurrenceInMonth)} ${dayOfWeek}` }), value: 'monthly' },
        ];
    }
    getSuggestedTime() {
        const now = dayjs();
        const minutes = now.minute();
        const roundedMinutes = minutes <= 30 ? 30 : 60;
        const startTime = now.set('minute', roundedMinutes).set('second', 0);
        const endTime = startTime.add(30, 'minute');
        return {
            startTime: startTime.format('hh:mma'),
            endTime: endTime.format('hh:mma'),
        };
    }
    getTimezoneLabelHTML(timezone) {
        const offset = getTimezoneOffset(timezone);
        return (h("span", { class: "timezone-label", style: {
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'space-between',
                width: '-webkit-fill-available',
            } }, TIMEZONE_MAP[timezone], ' ', h("span", { class: "timezone-offset", style: {
                fontSize: '14px',
                fontWeight: '400',
                color: 'var(--nylas-base-500)',
            } }, offset)));
    }
    isStartTimeAfterEndTime(startTime, endTime) {
        const start = dayjs(startTime, 'hh:mma');
        const end = dayjs(endTime, 'hh:mma');
        return start.isAfter(end);
    }
    isStartTimeEqualToEndTime(startTime, endTime) {
        const start = dayjs(startTime, 'hh:mma');
        const end = dayjs(endTime, 'hh:mma');
        return start.isSame(end);
    }
    isStartTimeBeforeCurrentDate(date, startTime, timezone) {
        const dateTime = dayjs.tz(`${date} ${startTime}`, 'YYYY-MM-DD hh:mma', timezone);
        return dateTime.isBefore(dayjs());
    }
    validateDateTimeInput(date, startTime, timezone) {
        const dateTimeWithStartTime = dayjs.tz(`${date} ${startTime}`, 'YYYY-MM-DD hh:mma', timezone);
        const isInPast = dateTimeWithStartTime.isBefore(dayjs());
        return {
            isValid: !isInPast,
            errorMessage: isInPast ? i18next.t('nylasEventTimeslot.errors.startTimeBeforeCurrentDate') : '',
        };
    }
    getStartAndEndTimes() {
        const start_time = dayjs.tz(`${this.selectedDate} ${this.selectedStartTime}`, 'YYYY-MM-DD hh:mma', this.selectedTimezone).toDate();
        const end_time = dayjs.tz(`${this.selectedDate} ${this.selectedEndTime}`, 'YYYY-MM-DD hh:mma', this.selectedTimezone).toDate();
        return {
            start_time: Math.round(start_time.getTime() / 1000),
            end_time: Math.round(end_time.getTime() / 1000),
        };
    }
    getCustomOptions() {
        if (this.selectedRecurrenceType !== 'custom') {
            return undefined;
        }
        const repeatFreq = periodMap[this.repeatEveryFrequency];
        return {
            frequency: repeatFreq,
            interval: this.repeatEveryInterval,
            daysOfWeek: this.repeatEveryFrequency === 'week' ? this.repeatOnDays : undefined,
            monthlySameDate: this.repeatEveryFrequency === 'month' ? this.repeatMonthlySameDate : undefined,
            end: {
                type: this.repeatEndType,
                count: this.repeatEndType === 'after' ? this.repeatEndAfter : undefined,
                date: this.repeatEndType === 'on' ? this.repeatEndOn : undefined,
            },
        };
    }
    handleValueChanged(noValue = false) {
        const customOptions = this.getCustomOptions();
        this.selectedRrule = generateRRule(this.selectedDate, this.selectedRecurrenceType, this.repeatEndOn, customOptions, this.selectedTimezone);
        const { start_time, end_time } = this.getStartAndEndTimes();
        const internalsObj = {
            when: {
                start_time: start_time,
                end_time: end_time,
                start_timezone: this.selectedTimezone,
                end_timezone: this.selectedTimezone,
            },
            recurrence: this.selectedRrule ? [this.selectedRrule] : [],
        };
        this.internals.setFormValue(JSON.stringify(internalsObj), this.name);
        if (!noValue) {
            this.valueChanged.emit({
                value: JSON.stringify(internalsObj),
                name: this.name,
            });
        }
    }
    setTime(event) {
        const { key, value } = event.detail;
        if (key === 'event-timeslot-start-time') {
            this.selectedStartTime = value;
        }
        else if (key === 'event-timeslot-end-time') {
            this.selectedEndTime = value;
        }
        const validateStartTimeAfterEndTime = this.isStartTimeAfterEndTime(this.selectedStartTime, this.selectedEndTime);
        const validateStartTimeEqualToEndTime = this.isStartTimeEqualToEndTime(this.selectedStartTime, this.selectedEndTime);
        const validation = this.validateDateTimeInput(this.selectedDate, this.selectedStartTime, this.selectedTimezone);
        const validateStartTimeBeforeCurrentDate = !validation.isValid;
        this.timeRangeError = validateStartTimeAfterEndTime || validateStartTimeEqualToEndTime || validateStartTimeBeforeCurrentDate;
        let error = '';
        if (validateStartTimeAfterEndTime) {
            error = i18next.t('nylasEventTimeslot.errors.invalidTimeRange');
        }
        else if (validateStartTimeEqualToEndTime) {
            error = i18next.t('nylasEventTimeslot.errors.startTimeSameAsEndTime');
        }
        else if (validateStartTimeBeforeCurrentDate) {
            error = validation.errorMessage;
        }
        else {
            error = '';
        }
        this.timeWindowFormError.emit({
            key: this.name,
            message: error,
            uniqueIdentifier: 'time-range',
        });
        if (error) {
            return;
        }
        this.handleValueChanged();
    }
    nylasFormDropdownChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'timezone') {
            this.selectedTimezone = value;
            const date = dayjs(this.selectedDate);
            const validation = this.validateDateTimeInput(date.format('YYYY-MM-DD'), this.selectedStartTime, this.selectedTimezone);
            this.hasDateTimeInputError = !validation.isValid;
            this.dateTimeInputError.emit({
                key: this.name,
                message: validation.errorMessage,
            });
            if (!validation.isValid) {
                return;
            }
        }
        else if (name === 'recurrence-type') {
            this.selectedRecurrenceType = value;
        }
        else if (name === 'month-recurrence-type') {
            this.repeatMonthlySameDate = value === 'monthly-same-date';
        }
        else if (name === 'custom-recurrence-end-type') {
            this.repeatEndType = value;
        }
        this.handleValueChanged();
    }
    nylasFormInputChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'date-time-input') {
            const date = dayjs(value);
            const validation = this.validateDateTimeInput(date.format('YYYY-MM-DD'), this.selectedStartTime, this.selectedTimezone);
            this.hasDateTimeInputError = !validation.isValid;
            this.dateTimeInputError.emit({
                key: this.name,
                message: validation.errorMessage,
            });
            if (!validation.isValid) {
                return;
            }
            this.selectedDate = date.format('YYYY-MM-DD');
            this.recurrenceOptions = this.generateRecurrenceOptions(this.selectedDate, this.selectedTimezone);
            this.monthRecurrenceOptions = this.getMonthRecurrenceOptions(this.selectedDate, this.selectedTimezone);
        }
        else if (name === 'recurrence-end-date' || name === 'custom-recurrence-end-date') {
            const error = event.detail?.error || '';
            this.timeWindowFormError.emit({
                key: this.name,
                message: error,
                uniqueIdentifier: name,
            });
            this.repeatEndOn = value;
        }
        else if (name === 'recurrence-end-after') {
            const parsedValue = parseInt(value);
            if (parsedValue < 1 || isNaN(parsedValue)) {
                this.timeWindowFormError.emit({
                    key: this.name,
                    message: i18next.t('fixFormErrors'),
                });
                return;
            }
            this.repeatEndAfter = parsedValue;
        }
        this.handleValueChanged();
    }
    timePeriodChangedHandler(event) {
        const { number, period } = event.detail;
        this.repeatEveryInterval = number;
        this.repeatEveryFrequency = period;
        if (period === 'month') {
            this.monthRecurrenceOptions = this.getMonthRecurrenceOptions(this.selectedDate, this.selectedTimezone);
        }
        this.handleValueChanged();
    }
    render() {
        const icloudProvider = this.currentUser?.provider === 'icloud';
        const defaultRecurrenceOption = this.recurrenceOptions.find(option => option.value === this.selectedRecurrenceType);
        const timezoneOptions = Object.keys(TIMEZONE_MAP).map(key => ({
            labelHTML: this.getTimezoneLabelHTML(key),
            label: TIMEZONE_MAP[key],
            value: key,
        }));
        const selectedTimezoneOption = timezoneOptions.find(i => i.value === this.selectedTimezone);
        const endOptions = [
            { label: i18next.t('nylasEventTimeslot.customRecurrence.endsOptions.never'), value: 'never' },
            { label: i18next.t('nylasEventTimeslot.customRecurrence.endsOptions.on'), value: 'on' },
            { label: i18next.t('nylasEventTimeslot.customRecurrence.endsOptions.after'), value: 'after' },
        ];
        const defaultEndOnDate = dayjs(this.selectedDate).add(1, 'year').toISOString().split('T')[0];
        const defaultEndAfter = this.repeatEveryFrequency === 'week' ? 4 : this.repeatEveryFrequency === 'month' ? 12 : 5;
        this.repeatEndOn = this.repeatEndOn || defaultEndOnDate;
        this.repeatEndAfter = this.repeatEndAfter || defaultEndAfter;
        const today = dayjs().tz(this.selectedTimezone);
        return (h(Host, { key: '92581d88eaad6ec232d41d494635ce1cf922e310' }, h("div", { key: '2031b25539623b44c19924972fd768409ee524c7', class: "nylas-event-timeslot", part: "netimeslot" }, h("label", { key: 'aced1ba3abf182ee443917d347b8c7c6c4fc4478', htmlFor: "date-time-input" }, i18next.t('nylasEventTimeslot.dateTimeLabel')), h("div", { key: '25e8065e47d81b54f680edbdbd8aa7e2b744aa96', class: "date-time-input", part: "netimeslot__date-time-input" }, h("div", { key: 'bef56e130618fb6142e0aa604310ee083e3661bc', class: "date-time-picker", part: "netimeslot__date-time-picker" }, h("nylas-date-component", { key: '5f603058e7e5a67970f74108d93340cc6ed150e6', minDate: dayjs().tz(this.selectedTimezone).toISOString().split('T')[0], name: "date-time-input", defaultValue: this.selectedDate, id: 'date-time-input', class: { error: this.hasDateTimeInputError }, required: true, hasError: this.hasDateTimeInputError }), h("div", { key: '26ab20902a5d50be85b27c7634525f8e155bf4cc', class: "time-range", part: "netimeslot__time-range" }, h("nylas-time-window-picker", { id: 'event-timeslot-start-time', hasError: this.timeRangeError, time: this.selectedStartTime, language: this.selectedLanguage, name: 'event-timeslot-start-time', key: 'event-timeslot-start-time', exportparts: "time-picker: nap__time-picker-container, time-input: nap__time-picker-input, times: nap__time-picker-times" }), h("span", { key: '97433b9bef4f2d4f670f36fdb844518fcccd7dee' }, "\u2013"), h("nylas-time-window-picker", { id: 'event-timeslot-end-time', hasError: this.timeRangeError, time: this.selectedEndTime, language: this.selectedLanguage, name: 'event-timeslot-end-time', key: 'event-timeslot-end-time', minimumStartTime: this.selectedStartTime, exportparts: "time-picker: nap__time-picker-container, time-input: nap__time-picker-input, times: nap__time-picker-times" })), selectedTimezoneOption?.label && (h("select-dropdown", { searchPlaceholder: i18next.t('search'), name: "timezone", exportparts: "sd_dropdown: nap__timezone-container, sd_dropdown-button: nap__timezone-button, sd_dropdown-content: nap__timezone-dropdown-content", options: timezoneOptions, withChevron: false, defaultSelectedOption: selectedTimezoneOption }, h("span", { slot: "select-icon" }, h("globe-icon", { width: "20", height: "20" }))))), !icloudProvider && (h("div", { class: "recurrence-options", part: "netimeslot__recurrence-options" }, defaultRecurrenceOption && defaultRecurrenceOption?.label && (h("div", { class: "recurrence-type", part: "netimeslot__recurrence-type" }, h("label", { htmlFor: "recurrence-type" }, i18next.t('nylasEventTimeslot.recurrenceLabel')), h("select-dropdown", { withSearch: false, id: "recurrence-type", name: "recurrence-type", options: this.recurrenceOptions, defaultSelectedOption: defaultRecurrenceOption, exportparts: "sd_dropdown: netimeslot__dropdown, sd_dropdown-button: netimeslot__dropdown-button, sd_dropdown-content: netimeslot__dropdown-content" }))), this.selectedRecurrenceType !== 'custom' && this.selectedRecurrenceType !== 'none' && (h("div", { class: "recurrence-end", part: "netimeslot__recurrence-end" }, h("label", null, i18next.t('nylasEventTimeslot.endDate')), h("nylas-date-component", { name: "recurrence-end-date", minDate: today.toISOString().split('T')[0], defaultValue: this.repeatEndOn || defaultEndOnDate, id: 'recurrence-end-date', required: true }))), this.selectedRecurrenceType === 'custom' && (h("div", { class: "custom-recurrence-time-period", part: "netimeslot__custom-recurrence" }, h("label", { htmlFor: "" }, i18next.t('nylasEventTimeslot.customRecurrence.repeatEvery')), h("time-period-selector", { id: "custom-recurrence-time-period", exportparts: "tps__number-dropdown: netimeslot__number-dropdown, tps__number-dropdown-button: netimeslot__number-dropdown-button, tps__number-dropdown-content: netimeslot__number-dropdown-content, tps__period-dropdown: netimeslot__period-dropdown, tps__period-dropdown-button: netimeslot__period-dropdown-button, tps__period-dropdown-content: netimeslot__period-dropdown-content", timePeriods: [
                { value: 'day', label: i18next.t('timePeriod', { context: 'day' }) },
                { value: 'week', label: i18next.t('timePeriod', { context: 'week' }) },
                { value: 'month', label: i18next.t('timePeriod', { context: 'month' }) },
                { value: 'year', label: i18next.t('timePeriod', { context: 'year' }) },
            ], defaultSelectedNumber: this.repeatEveryInterval, defaultSelectedPeriod: this.repeatEveryFrequency }))), h("div", { class: "repeat-on" }, this.selectedRecurrenceType === 'custom' && this.repeatEveryFrequency === 'week' && (h("div", { class: "days" }, h("label", null, i18next.t('nylasEventTimeslot.customRecurrence.repeatOn')), h("div", { class: "buttons" }, [
            { label: 'S', value: 'SU', title: 'Sunday' },
            { label: 'M', value: 'MO', title: 'Monday' },
            { label: 'T', value: 'TU', title: 'Tuesday' },
            { label: 'W', value: 'WE', title: 'Wednesday' },
            { label: 'T', value: 'TH', title: 'Thursday' },
            { label: 'F', value: 'FR', title: 'Friday' },
            { label: 'S', value: 'SA', title: 'Saturday' },
        ].map(day => (h("button", { class: { selected: this.repeatOnDays.includes(day.value) }, title: day.title, onClick: () => {
                this.repeatOnDays = this.repeatOnDays.includes(day.value) ? this.repeatOnDays.filter(d => d !== day.value) : [...this.repeatOnDays, day.value];
                this.handleValueChanged();
            } }, day.label)))))), this.selectedRecurrenceType === 'custom' && this.repeatEveryFrequency === 'month' && (h("div", { class: "month-recurrence" }, h("span", null), h("select-dropdown", { withSearch: false, id: "month-recurrence-type", name: "month-recurrence-type", options: this.monthRecurrenceOptions, defaultSelectedOption: this.repeatMonthlySameDate ? this.monthRecurrenceOptions[0] : this.monthRecurrenceOptions[1], exportparts: "sd_dropdown: netimeslot__dropdown, sd_dropdown-button: netimeslot__dropdown-button, sd_dropdown-content: netimeslot__dropdown-content" }))), h("div", { class: "custom-recurrence" }, this.selectedRecurrenceType === 'custom' && (h("div", { class: "custom-recurrence-ends" }, h("label", { htmlFor: "recurrence-type" }, i18next.t('nylasEventTimeslot.customRecurrence.ends')), h("select-dropdown", { withSearch: false, id: "custom-recurrence-end-type", name: "custom-recurrence-end-type", options: endOptions, defaultSelectedOption: endOptions.find(option => option.value === this.repeatEndType), exportparts: "sd_dropdown: netimeslot__dropdown, sd_dropdown-button: netimeslot__dropdown-button, sd_dropdown-content: netimeslot__dropdown-content" }))), this.selectedRecurrenceType === 'custom' && this.repeatEndType === 'on' && (h("div", null, h("nylas-date-component", { name: "custom-recurrence-end-date", minDate: today.toISOString().split('T')[0], defaultValue: this.repeatEndOn || defaultEndOnDate, id: 'custom-recurrence-end-date', required: true }))), this.selectedRecurrenceType === 'custom' && this.repeatEndType === 'after' && (h("div", { class: "custom-recurrence-end-after" }, h("input-component", { name: "recurrence-end-after", id: "recurrence-end-after", type: "number", minValue: 1, defaultValue: defaultEndAfter.toString(), exportparts: "ic_input: netimeslot__input-textfield" }), h("span", null, i18next.t('nylasEventTimeslot.customRecurrence.occurrences'))))))))))));
    }
    static get is() { return "nylas-event-timeslot"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-event-timeslot.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-event-timeslot.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The name of the component"
                        }],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'event-timeslot'"
            },
            "initialValue": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "{\n    when: {\n      start_time: number;\n      end_time: number;\n      start_timezone: string;\n      end_timezone: string;\n    };\n    recurrence: string[];\n  }",
                    "resolved": "undefined | { when: { start_time: number; end_time: number; start_timezone: string; end_timezone: string; }; recurrence: string[]; }",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The initial value of the event timeslot."
                }
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            },
            "currentUser": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "User",
                    "resolved": "undefined | { id: string; email: string; name?: string | undefined; provider?: string | undefined; }",
                    "references": {
                        "User": {
                            "location": "import",
                            "path": "@/common/nylas-api-request",
                            "id": "src/common/nylas-api-request.ts::User"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The current user."
                }
            }
        };
    }
    static get states() {
        return {
            "selectedDate": {},
            "selectedStartTime": {},
            "selectedEndTime": {},
            "selectedTimezone": {},
            "selectedRecurrenceType": {},
            "timeRangeError": {},
            "selectedRrule": {},
            "recurrenceOptions": {},
            "repeatEveryInterval": {},
            "repeatEveryFrequency": {},
            "repeatOnDays": {},
            "repeatMonthlySameDate": {},
            "repeatEndType": {},
            "repeatEndAfter": {},
            "repeatEndOn": {},
            "monthRecurrenceOptions": {},
            "endDate": {},
            "hasDateTimeInputError": {}
        };
    }
    static get events() {
        return [{
                "method": "valueChanged",
                "name": "valueChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the value of the event location changes."
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n  }",
                    "resolved": "{ value: string; name: string; }",
                    "references": {}
                }
            }, {
                "method": "timeWindowFormError",
                "name": "timeWindowFormError",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the value of the event timeslot changes."
                },
                "complexType": {
                    "original": "{\n    key: string;\n    message: string;\n    uniqueIdentifier?: string;\n  }",
                    "resolved": "{ key: string; message: string; uniqueIdentifier?: string | undefined; }",
                    "references": {}
                }
            }, {
                "method": "dateTimeInputError",
                "name": "dateTimeInputError",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the value of the event timeslot changes."
                },
                "complexType": {
                    "original": "{\n    key: string;\n    message: string;\n  }",
                    "resolved": "{ key: string; message: string; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "timeChange",
                "method": "setTime",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormDropdownChanged",
                "method": "nylasFormDropdownChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormInputChanged",
                "method": "nylasFormInputChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "timePeriodChanged",
                "method": "timePeriodChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    RegisterComponent({
        name: 'nylas-event-timeslot',
        stateToProps: new Map([
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
            ['schedulerConfig.currentUser', 'currentUser'],
        ]),
        eventToProps: {
            valueChanged: async (event, _nylasConnector) => {
                debug('nylas-event-timeslot', 'valueChanged', event.detail);
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasEventTimeslot.prototype, "render", null);
//# sourceMappingURL=nylas-event-timeslot.js.map
