import { newSpecPage } from "@stencil/core/testing";
import { NylasLimitFutureBookings } from "../nylas-limit-future-bookings";
import { h } from "@stencil/core";
import { SelectDropdown } from "../../../design-system/select-dropdown/select-dropdown";
import { TimePeriodSelector } from "../../../design-system/time-period-selector/time-period-selector";
import { InputDropdown } from "../../../design-system/input-dropdown/input-dropdown";
import { selectedConfiguration } from "../../../../utils/test-utils";
describe('nylas-limit-future-bookings', () => {
    let nylasLimitFutureBookings;
    let page;
    const config = selectedConfiguration;
    beforeEach(async () => {
        page = await newSpecPage({
            components: [NylasLimitFutureBookings, TimePeriodSelector, SelectDropdown, InputDropdown],
            template: () => {
                return h("nylas-limit-future-bookings", { name: "limit-future-bookings", selectedConfiguration: config });
            },
        });
        nylasLimitFutureBookings = page.rootInstance;
    });
    it('renders', async () => {
        expect(page.root).toMatchSnapshot();
    });
    it('selects default available days', async () => {
        const availableDaysNumberInput = page.root.shadowRoot.querySelector('input-dropdown#time-number').shadowRoot.querySelector('input');
        expect(availableDaysNumberInput.value).toBe('1');
        const availableDaysPeriodButton = page.root.shadowRoot.querySelector('select-dropdown#time-period').shadowRoot.querySelector('button');
        expect(availableDaysPeriodButton.textContent).toBe('month');
    });
    it('selects available days in future', async () => {
        const spyEvent = jest.fn();
        nylasLimitFutureBookings.valueChanged = {
            emit: spyEvent,
        };
        const mockEvent = new CustomEvent('timePeriodChanged', {
            detail: { number: 2, period: 'week' },
            bubbles: true,
            composed: true,
        });
        nylasLimitFutureBookings.timePeriodChangedHandler(mockEvent);
        expect(spyEvent).toHaveBeenCalled();
    });
});
//# sourceMappingURL=nylas-limit-future-bookings.spec.js.map
