var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug, getCalendarRange, parsePreviewLink } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import { NotificationType } from "@nylas/core";
import i18next from "../../../utils/i18n";
import { CONFIGURATION_EVENT_TYPE } from "../../../common/constants";
import { ErrorCategory } from "../../../types/index";
export class NylasListConfigurations {
    constructor() {
        this.configurations = [];
        this.selectedLanguage = undefined;
        this.schedulerPreviewLink = '';
        this.listConfigurationsNextCursor = undefined;
        this.state = 'loading';
        this.error = {
            message: '',
            type: NotificationType.Error,
            category: ErrorCategory.Component,
            title: '',
        };
        this.currentCursor = null;
        this.previousCursors = [];
        this.disableNextPageButton = false;
        this.deleteConfigurationId = '';
        this.showDeleteButtonLoading = false;
        this.editButtonLoadingId = '';
    }
    listConfigurationsNextCursorChangedHandler(newVal, oldVal) {
        if (!newVal || newVal === oldVal) {
            if (newVal === null) {
                this.disableNextPageButton = true;
            }
            return;
        }
        this.disableNextPageButton = false;
        this.currentCursor = newVal;
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
    }
    connectedCallback() {
        debug('[nylas-list-configurations]', 'connectedCallback');
    }
    componentWillLoad() {
        debug('[nylas-list-configurations]', 'componentWillLoad');
        if (this.configurations && this.configurations.length > 0) {
            this.state = 'loaded';
        }
    }
    componentDidLoad() {
        debug('[nylas-list-configurations]', 'componentDidLoad');
        this.initListConfigurations.emit({
            host: this.host,
        });
    }
    disconnectedCallback() {
        debug('[nylas-list-configurations]', 'disconnectedCallback');
    }
    async handleNylasFormDropdownChanged(event) {
        debug('[nylas-list-configurations]', 'handleNylasFormDropdownChanged', event.detail);
        const { value } = event.detail;
        const [action, index] = value.split('-');
        event.preventDefault();
        switch (action) {
            case 'delete':
                this.deleteConfigurationId = this.configurations[index]?.id;
                break;
            case 'preview':
                window.open(parsePreviewLink(this.schedulerPreviewLink, this.configurations[index]), '_blank');
                break;
            case 'copy':
                await navigator.clipboard.writeText(parsePreviewLink(this.schedulerPreviewLink, this.configurations[index]));
                break;
            default:
                break;
        }
    }
    async registerCallback() {
        this.initListConfigurations.emit({
            host: this.host,
        });
    }
    async getState() {
        return this.state;
    }
    async setState(state) {
        this.state = state;
    }
    async setError(error) {
        this.error = {
            message: error.message,
            type: error.type,
            category: error.category,
            title: error.title || i18next.t('genericErrorTitle'),
        };
        if (this.error?.message) {
            this.showErrorNotification(this.error);
        }
    }
    async hideDeleteConfirmation() {
        this.deleteConfigurationId = '';
        this.showDeleteButtonLoading = false;
    }
    async hideEditButtonLoading() {
        this.editButtonLoadingId = '';
    }
    showErrorNotification(error) {
        this.nylasSchedulerError.emit({
            notification: {
                id: error.message.split(' ').join('-'),
                type: error.type || NotificationType.Error,
                title: error.title,
                category: error.category || ErrorCategory.Component,
                description: error.message,
                ttl: 'none',
            },
            host: this.host,
        });
    }
    closeModal(e) {
        e.preventDefault();
        this.deleteConfigurationId = '';
    }
    handleConfirmDeleteButtonClicked(e) {
        e.preventDefault();
        this.showDeleteButtonLoading = true;
        const config = this.configurations.find(config => config.id === this.deleteConfigurationId);
        if (config && config?.id) {
            this.deleteButtonClick.emit({ host: this.host, configuration: config });
        }
    }
    getDurationString(duration) {
        if (!duration)
            return '—';
        const hours = Math.floor(duration / 60);
        const minutes = duration % 60;
        return `${hours ? hours : ''} ${hours ? `${hours > 1 ? 'hours' : 'hour'}` : ''} ${minutes ? minutes : ''} ${minutes ? `${minutes > 1 ? 'mins' : 'min'}` : ''}`;
    }
    getActionLabelHTML(action) {
        const actionStyle = {
            display: 'inline-flex',
            alignItems: 'center',
            gap: '0.5rem',
        };
        const dangerStyle = {
            color: 'var(--nylas-error)',
        };
        switch (action) {
            case 'preview':
                return (h("span", { style: actionStyle }, h("eye-icon", { width: "16", height: "16" }), i18next.t('nylasListConfigurations.previewButtonText')));
            case 'copy':
                return (h("span", { style: actionStyle }, h("copy-icon", { width: "16", height: "16" }), i18next.t('nylasListConfigurations.copyLinkButtonText')));
            case 'delete':
                return (h("span", { style: { ...actionStyle, ...dangerStyle } }, h("delete-icon", { width: "15", height: "17" }), i18next.t('nylasListConfigurations.deleteButtonText')));
            default:
                return '';
        }
    }
    previousPageClickedHandler() {
        if (this.previousCursors.length === 0)
            return;
        this.currentCursor = this.previousCursors.pop() || null;
        const prevCursor = this.previousCursors[this.previousCursors.length - 1] || undefined;
        this.initListConfigurations.emit({
            host: this.host,
            cursor: prevCursor,
        });
    }
    nextPageClickedHandler() {
        if (!this.currentCursor)
            return;
        this.previousCursors = [...this.previousCursors, this.currentCursor];
        this.initListConfigurations.emit({
            host: this.host,
            cursor: this.currentCursor,
        });
    }
    render() {
        return (h(Host, null, h("nylas-notification", null), h("div", { class: "header" }, h("div", { class: "description" }, h("h2", null, i18next.t('allSchedulingPages')), h("p", null, i18next.t('createAndManageSchedulingPages'))), this.configurations && this.configurations.length > 0 && (h("div", { class: "actions" }, h("button-component", { part: "nlc__create-new-cta", clickHandler: () => {
                this.createButtonClick.emit(this.host);
            } }, i18next.t('createNewSchedulingPageButtonText'))))), h("div", { class: "configurations" }, h("div", { class: "table-container" }, h("table", { class: {
                'no-configurations': this.state !== 'loading' && (!this.configurations || this.configurations.length === 0),
            } }, h("tr", { class: {
                hide: this.state === 'loading' || (this.configurations && this.configurations.length === 0),
            } }, h("th", null, i18next.t('pageTitle')), h("th", null, i18next.t('durationTitle')), h("th", null)), this.state === 'loading' && (h("tr", { class: "no-configurations" }, h("td", { colSpan: 3 }, h("div", null, h("h3", null, i18next.t('loading'), "..."), h("p", null, i18next.t('loadingPagesDescription')))))), this.state !== 'loading' && (!this.configurations || this.configurations.length === 0) && (h("tr", { class: "no-configurations" }, h("td", { colSpan: 3 }, h("div", null, h("calendar-icon", { width: "48", height: "48" }), h("h3", null, i18next.t('noSchedulingPages')), h("p", null, i18next.t('createFirstSchedulingPage')), h("button-component", { part: "nlc__create-new-cta", clickHandler: () => {
                this.createButtonClick.emit(this.host);
            } }, i18next.t('createNewSchedulingPageButtonText')))))), this.state !== 'loading' &&
            this.configurations?.map((config, i) => {
                const lastTwo = (i === this.configurations.length - 1 || i === this.configurations.length - 2) && this.configurations.length > 3;
                const groupConfig = config;
                const regularConfig = config;
                return (h("tr", { key: config?.id }, h("td", null, h("div", { class: "title" }, h("div", { class: "config-event-title", title: regularConfig?.event_booking?.title }, regularConfig?.event_booking?.title || groupConfig?.name), h("div", { class: 'config-event-description' }, regularConfig?.event_booking?.description))), h("td", null, h("div", { class: "duration" }, this.getDurationString(regularConfig?.availability?.duration_minutes))), h("td", null, h("div", { class: "actions" }, h("button-component", { class: "edit-button", variant: 'basic', key: `edit-${i}`, disabled: this.editButtonLoadingId === `edit-${i}`, isLoading: this.editButtonLoadingId === `edit-${i}`, clickHandler: event => {
                        event.preventDefault();
                        this.editButtonLoadingId = `edit-${i}`;
                        this.editButtonClick.emit({ host: this.host, configuration: config });
                    } }, this.editButtonLoadingId === `edit-${i}` ? null : h("edit-icon", { width: "16", height: "16" }), i18next.t('editSchedulingPageButtonText')), h("select-dropdown", { class: {
                        last: lastTwo,
                    }, name: "actions", options: [
                        { value: `preview-${i}`, label: 'Preview', labelHTML: this.getActionLabelHTML('preview') },
                        { value: `copy-${i}`, label: 'Copy link', labelHTML: this.getActionLabelHTML('copy') },
                        { value: `delete-${i}`, label: 'Delete', labelHTML: this.getActionLabelHTML('delete') },
                    ], defaultSelectedOption: { value: '', label: '' }, dropdownButtonText: "...", withSearch: false, withChevron: false, exportparts: "sd_dropdown: actions__dropdown, sd_dropdown-button: actions__dropdown-button, sd_dropdown-content: actions__dropdown-content, actions-Copy, actions-Preview, actions-Delete" })))));
            }))), h("div", { class: "pagination" }, h("button", { class: "arrow left", onClick: () => this.previousPageClickedHandler(), disabled: this.previousCursors.length <= 0 }, h("chevron-icon", null)), h("button", { class: "arrow right", onClick: () => this.nextPageClickedHandler(), disabled: this.disableNextPageButton }, h("chevron-icon", null)))), !!this.deleteConfigurationId && (h("div", { class: "card-wrapper" }, h("div", { class: "card-modal" }, h("div", { class: "close-button" }, h("button-component", { tooltip: "Close", id: "close", variant: 'invisible', onClick: e => this.closeModal(e), part: "nfbf__close-button" }, h("close-icon", null))), h("div", { class: "header" }, h("h2", { slot: "card-title", part: "nfbf__title" }, i18next.t('deleteSchedulingPageTitle'))), h("div", { class: "description title-desc" }, h("p", null, i18next.t('deleteSchedulingPageDescription'))), h("div", { class: {
                footer: true,
            } }, h("button-component", { variant: 'basic', onClick: e => this.closeModal(e), part: "nfbf__button-outline nfbf__cancel-cta" }, `${i18next.t('deleteSchedulingPageCancelButton')}`), h("button-component", { variant: 'destructive', onClick: e => this.handleConfirmDeleteButtonClicked(e), disabled: this.showDeleteButtonLoading, isLoading: this.showDeleteButtonLoading, part: "nfbf__button-outline nfbf__reschedule-cta" }, `${i18next.t('deleteSchedulingPageConfirmButton')}`)))))));
    }
    static get is() { return "nylas-list-configurations"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-list-configurations.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-list-configurations.css"]
        };
    }
    static get properties() {
        return {
            "configurations": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(Configuration | GroupConfiguration)[]",
                    "resolved": "(Configuration | GroupConfiguration)[]",
                    "references": {
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        },
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The list of configurations to display."
                },
                "defaultValue": "[]"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            },
            "schedulerPreviewLink": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The scheduler preview link to use when the user clicks on the preview button.\nYou can use a placeholder `{config.id}` to replace the configuration id anywhere in the link."
                },
                "attribute": "scheduler-preview-link",
                "reflect": false,
                "defaultValue": "''"
            },
            "listConfigurationsNextCursor": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string | null",
                    "resolved": "null | string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The next cursor for list configurations, if any."
                },
                "attribute": "list-configurations-next-cursor",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "state": {},
            "error": {},
            "currentCursor": {},
            "previousCursors": {},
            "disableNextPageButton": {},
            "deleteConfigurationId": {},
            "showDeleteButtonLoading": {},
            "editButtonLoadingId": {}
        };
    }
    static get events() {
        return [{
                "method": "initListConfigurations",
                "name": "initListConfigurations",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the component is initialized."
                },
                "complexType": {
                    "original": "{\n    host: HTMLNylasListConfigurationsElement;\n    cursor?: string;\n  }",
                    "resolved": "{ host: HTMLNylasListConfigurationsElement; cursor?: string | undefined; }",
                    "references": {
                        "HTMLNylasListConfigurationsElement": {
                            "location": "global",
                            "id": "global::HTMLNylasListConfigurationsElement"
                        }
                    }
                }
            }, {
                "method": "createButtonClick",
                "name": "createButtonClick",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the create event button."
                },
                "complexType": {
                    "original": "HTMLNylasListConfigurationsElement",
                    "resolved": "HTMLNylasListConfigurationsElement",
                    "references": {
                        "HTMLNylasListConfigurationsElement": {
                            "location": "global",
                            "id": "global::HTMLNylasListConfigurationsElement"
                        }
                    }
                }
            }, {
                "method": "editButtonClick",
                "name": "editButtonClick",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the edit event button."
                },
                "complexType": {
                    "original": "{\n    host: HTMLNylasListConfigurationsElement;\n    configuration: Configuration | GroupConfiguration;\n  }",
                    "resolved": "{ host: HTMLNylasListConfigurationsElement; configuration: Configuration | GroupConfiguration; }",
                    "references": {
                        "HTMLNylasListConfigurationsElement": {
                            "location": "global",
                            "id": "global::HTMLNylasListConfigurationsElement"
                        },
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        },
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                }
            }, {
                "method": "deleteButtonClick",
                "name": "deleteButtonClick",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the delete event button."
                },
                "complexType": {
                    "original": "{\n    host: HTMLNylasListConfigurationsElement;\n    configuration: Configuration | GroupConfiguration;\n  }",
                    "resolved": "{ host: HTMLNylasListConfigurationsElement; configuration: Configuration | GroupConfiguration; }",
                    "references": {
                        "HTMLNylasListConfigurationsElement": {
                            "location": "global",
                            "id": "global::HTMLNylasListConfigurationsElement"
                        },
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        },
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                }
            }, {
                "method": "nylasSchedulerError",
                "name": "nylasSchedulerError",
                "bubbles": true,
                "cancelable": false,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when there is an error in the component."
                },
                "complexType": {
                    "original": "{ notification: Notification; host: HTMLElement }",
                    "resolved": "{ notification: Notification; host: HTMLElement; }",
                    "references": {
                        "Notification": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Notification"
                        },
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }, {
                "method": "dismissNotification",
                "name": "dismissNotification",
                "bubbles": true,
                "cancelable": false,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user dismisses the error notification."
                },
                "complexType": {
                    "original": "{ id: string; host: HTMLNylasListConfigurationsElement }",
                    "resolved": "{ id: string; host: HTMLNylasListConfigurationsElement; }",
                    "references": {
                        "HTMLNylasListConfigurationsElement": {
                            "location": "global",
                            "id": "global::HTMLNylasListConfigurationsElement"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "registerCallback": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "getState": {
                "complexType": {
                    "signature": "() => Promise<\"loading\" | \"error\" | \"loaded\">",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<\"loading\" | \"error\" | \"loaded\">"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setState": {
                "complexType": {
                    "signature": "(state: 'loading' | 'loaded' | 'error') => Promise<void>",
                    "parameters": [{
                            "name": "state",
                            "type": "\"loading\" | \"error\" | \"loaded\"",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setError": {
                "complexType": {
                    "signature": "(error: { message: string; type: NotificationType; category: ErrorCategory; title: string; }) => Promise<void>",
                    "parameters": [{
                            "name": "error",
                            "type": "{ message: string; type: NotificationType; category: ErrorCategory; title: string; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "NotificationType": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::NotificationType"
                        },
                        "ErrorCategory": {
                            "location": "import",
                            "path": "@/types/index",
                            "id": "src/types/index.ts::ErrorCategory"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "hideDeleteConfirmation": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "hideEditButtonLoading": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "listConfigurationsNextCursor",
                "methodName": "listConfigurationsNextCursorChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "nylasFormDropdownChanged",
                "method": "handleNylasFormDropdownChanged",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
__decorate([
    RegisterComponent({
        name: 'nylas-list-configurations',
        stateToProps: new Map([
            ['schedulerConfig.configurations', 'configurations'],
            ['schedulerConfig.listConfigurationsNextCursor', 'listConfigurationsNextCursor'],
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
        ]),
        localPropsToProp: new Map([['schedulerPreviewLink', 'schedulerPreviewLink']]),
        eventToProps: {
            initListConfigurations: async (event, connector) => {
                const { host, cursor } = event.detail;
                await host.setState('loading');
                const [data, error] = await connector.schedulerConfig.getConfigurations(cursor);
                if (!data && error && error.message) {
                    await host.setState('error');
                    await host.setError({
                        message: error.message,
                        type: NotificationType.Error,
                        category: ErrorCategory.Component,
                        title: i18next.t('nylasEditorTabs.getConfigsError'),
                    });
                    return;
                }
                await host.setState('loaded');
            },
            createButtonClick: async (_, connector) => {
                connector.schedulerConfigStore.resetSelectedConfiguration();
                const enabledEventTypes = Object.entries(connector.schedulerConfigStore.state.enableEventTypes || {}).filter(([_key, value]) => value);
                if (enabledEventTypes.length === 1) {
                    connector.schedulerConfigStore.state.action = 'create';
                    connector.schedulerConfigStore.state.selectedEventType = CONFIGURATION_EVENT_TYPE[enabledEventTypes[0][0]];
                }
                else {
                    connector.schedulerConfigStore.state.action = 'create-select';
                }
            },
            deleteButtonClick: async (event, connector) => {
                const { host, configuration } = event.detail;
                const [data, error] = await connector.schedulerConfig.deleteConfiguration(configuration.id);
                if (!data && error && error.message) {
                    await host.setState('error');
                    await host.setError({
                        message: error.message,
                        type: NotificationType.Error,
                        category: ErrorCategory.Component,
                        title: i18next.t('nylasEditorTabs.deleteConfigError'),
                    });
                }
                await host.hideDeleteConfirmation();
            },
            editButtonClick: async (event, connector) => {
                const { host, configuration } = event.detail;
                if (configuration.type === 'group') {
                    const { startTime, endTime } = getCalendarRange(new Date().toISOString(), 'week');
                    connector.schedulerConfigStore.state.calendarViewDateRange = {
                        start_time: startTime.toString(),
                        end_time: endTime.toString(),
                    };
                    const [data, error] = await connector.schedulerConfig.getGroupEvents(configuration.id, configuration);
                    if (!data && error && error.message) {
                        await host.setError({
                            message: error.message,
                            type: NotificationType.Error,
                            category: ErrorCategory.Component,
                            title: i18next.t('nylasEditorTabsGroup.getGroupEventsError'),
                        });
                        host.hideEditButtonLoading();
                        return;
                    }
                }
                connector.schedulerConfigStore.state.action = 'edit';
                connector.schedulerConfigStore.state.selectedConfiguration = configuration;
                host.hideEditButtonLoading();
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasListConfigurations.prototype, "render", null);
//# sourceMappingURL=nylas-list-configurations.js.map
