import { newSpecPage } from "@stencil/core/testing";
import { NylasMinCancellationNotice } from "../nylas-min-cancellation-notice";
import { h } from "@stencil/core";
import { SelectDropdown } from "../../../design-system/select-dropdown/select-dropdown";
import { TimePeriodSelector } from "../../../design-system/time-period-selector/time-period-selector";
import { InputDropdown } from "../../../design-system/input-dropdown/input-dropdown";
import { selectedConfiguration } from "../../../../utils/test-utils";
describe('nylas-min-cancellation-notice', () => {
    let nylasMinCancellationNotice;
    let page;
    const config = selectedConfiguration;
    beforeEach(async () => {
        page = await newSpecPage({
            components: [NylasMinCancellationNotice, TimePeriodSelector, SelectDropdown, InputDropdown],
            template: () => {
                return h("nylas-min-cancellation-notice", { name: "min-cancellation-notice", selectedConfiguration: config });
            },
        });
        nylasMinCancellationNotice = page.rootInstance;
    });
    it('renders', async () => {
        expect(page.root).toMatchSnapshot();
    });
    it('selects default min cancellation notice', async () => {
        const minCancellationInput = page.root.shadowRoot.querySelector('input-dropdown#time-number').shadowRoot.querySelector('input');
        expect(minCancellationInput.value).toBe('1');
        const minCancellationInputPeriodButton = page.root.shadowRoot.querySelector('select-dropdown#time-period').shadowRoot.querySelector('button');
        expect(minCancellationInputPeriodButton.textContent).toBe('hour');
    });
    it('selects min cancellation notice', async () => {
        const spyEvent = jest.fn();
        nylasMinCancellationNotice.valueChanged = {
            emit: spyEvent,
        };
        const mockEvent = new CustomEvent('timePeriodChanged', {
            detail: { number: 2, period: 'week' },
            bubbles: true,
            composed: true,
        });
        nylasMinCancellationNotice.timePeriodChangedHandler(mockEvent);
        expect(spyEvent).toHaveBeenCalled();
    });
});
//# sourceMappingURL=nylas-min-cancellation-notice.spec.js.map
