import { newSpecPage } from "@stencil/core/testing";
import { NylasPageName } from "../nylas-page-name";
import { InputComponent } from "../../../design-system/input-component/input-component";
import { h } from "@stencil/core";
describe('nylas-page-name', () => {
    it('renders', async () => {
        const page = await newSpecPage({
            components: [NylasPageName],
            html: '<nylas-page-name></nylas-page-name>',
        });
        await page.waitForChanges();
        expect(page.root).toMatchSnapshot();
    });
    it('should allow typing "&" in the input', async () => {
        const page = await newSpecPage({
            components: [NylasPageName, InputComponent],
            template: () => {
                return (h("nylas-page-name", null, h("input-component", { name: "page-name" })));
            },
        });
        await page.waitForChanges();
        expect(page.root).toMatchSnapshot();
        const inputComponent = page?.root?.shadowRoot?.querySelector('input-component');
        const input = inputComponent?.shadowRoot?.querySelector('input');
        expect(input).not.toBeNull();
        const dispatchEvent = (element, eventType, value) => {
            const event = new Event(eventType, {
                bubbles: true,
                cancelable: true,
            });
            Object.defineProperty(event, 'target', { value: element, enumerable: true });
            element.value = value;
            element.dispatchEvent(event);
        };
        dispatchEvent(input, 'input', 'Test & Test');
        expect(input.value).toBe('Test & Test');
    });
    it('should show error message when required page name is not entered', async () => {
        const page = await newSpecPage({
            components: [NylasPageName],
            template: () => {
                return h("nylas-page-name", { pageName: "Test Page", isOpen: true, requirePageName: true });
            },
        });
        await page.waitForChanges();
        const errorMessage = page?.root?.shadowRoot?.querySelector('.error-message');
        expect(errorMessage).toBeNull();
        const event = new CustomEvent('nylasFormInputChanged', {
            bubbles: true,
            cancelable: true,
            detail: {
                name: 'page-name',
                value: '',
            },
        });
        page.root?.dispatchEvent(event);
        await page.waitForChanges();
        expect(page.root).toMatchSnapshot();
        const errorMessage1 = page?.root?.shadowRoot?.querySelector('.error-message');
        expect(errorMessage1).not.toBeNull();
        expect(errorMessage1?.textContent).toBe('Please enter a page name');
    });
});
//# sourceMappingURL=nylas-page-name.spec.js.map
