var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import i18next from "../../../utils/i18n";
export class NylasReminderEmails {
    constructor() {
        this.selectedConfiguration = undefined;
        this.eventReminders = undefined;
        this.name = 'reminder-overrides';
        this.selectedLanguage = undefined;
        this.reminders = this.selectedConfiguration?.event_booking?.reminders ??
            this.selectedConfiguration?.group_booking?.reminders ??
            this.eventReminders ??
            [];
        this.reminderErrors = {};
        this.participants = this.selectedConfiguration?.participants ?? [];
        this.clearError = false;
    }
    connectedCallback() {
        debug('nylas-reminder-emails', 'connectedCallback');
    }
    disconnectedCallback() {
        debug('nylas-reminder-emails', 'disconnectedCallback');
    }
    componentWillLoad() {
        debug('nylas-reminder-emails', 'componentWillLoad');
        this.host.setAttribute('name', this.name);
    }
    componentDidLoad() {
        debug('nylas-reminder-emails', 'componentDidLoad');
        if (this.selectedConfiguration) {
            this.selectedConfigurationChangedHandler(this.selectedConfiguration);
        }
        else {
            this.reminders = this.eventReminders ?? [];
            this.updateRemindersFormValue(false);
        }
    }
    componentWillUpdate() {
        debug('nylas-reminder-emails', 'componentWillUpdate');
    }
    componentDidUpdate() {
        debug('nylas-reminder-emails', 'componentDidUpdate');
    }
    componentWillRender() {
        debug('nylas-reminder-emails', 'componentWillRender');
    }
    componentDidRender() {
        debug('nylas-reminder-emails', 'componentDidRender');
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-reminder-emails', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    selectedConfigurationChangedHandler(newVal) {
        debug('nylas-reminder-emails', 'selectedConfigurationChangedHandler', newVal);
        const configuration = newVal;
        const groupConfiguration = newVal;
        this.reminders = configuration?.event_booking?.reminders ?? groupConfiguration?.group_booking?.reminders ?? [];
        this.participants = configuration?.participants ?? [];
        this.updateRemindersFormValue(false);
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
    }
    handleValueChanged(event) {
        debug('nylas-reminder-emails', 'handleValueChanged', event);
        const { name, value } = event.detail;
        if (name.startsWith('reminder-time-')) {
            const remainder = parseInt(value) % 5;
            if (remainder !== 0) {
                this.reminderErrors[name] = {
                    error: i18next.t('nylasReminderEmails.reminderMinutesValidationError'),
                    suggestion: parseInt(value) + (5 - remainder),
                };
                this.reminderErrors = { ...this.reminderErrors };
                this.internals.setValidity({ customError: true }, 'Reminder time must be a multiple of 5');
                return;
            }
            else {
                delete this.reminderErrors[name];
                this.reminderErrors = { ...this.reminderErrors };
                this.internals.setValidity({ customError: false });
            }
            const [_, reminderIndex] = name.split(/(\d+)/);
            const updatedReminders = [...this.reminders];
            updatedReminders[reminderIndex].minutes_before_event = parseInt(value);
            this.reminders = [...updatedReminders];
            this.updateRemindersFormValue();
        }
    }
    handleNylasFormDropdownChanged(event) {
        debug('nylas-reminder-emails', 'handleNylasFormDropdownChanged', event);
        const { name, value } = event.detail;
        if (!name.startsWith('recipient-')) {
            return;
        }
        const [_, reminderIndex] = name.split(/(\d+)/);
        const updatedReminders = [...this.reminders];
        updatedReminders[reminderIndex].recipient = value;
        this.reminders = [...updatedReminders];
        this.updateRemindersFormValue();
    }
    handleNylasFormInputChanged(event) {
        debug('nylas-reminder-emails', 'handleNylasFormInputChanged', event);
        const { name, value } = event.detail;
        if (!name.startsWith('reminder-subject-')) {
            return;
        }
        const [_, reminderIndex] = name.split(/(\d+)/);
        const updatedReminders = [...this.reminders];
        updatedReminders[reminderIndex].email_subject = value;
        this.reminders = [...updatedReminders];
        this.updateRemindersFormValue();
    }
    addReminder() {
        debug('nylas-reminder-emails', 'addReminder');
        const recipient = this.selectedConfiguration?.type === 'group' ? 'guest' : 'all';
        this.reminders = [
            ...this.reminders,
            {
                type: 'email',
                minutes_before_event: 30,
                editing: true,
                recipient: recipient,
            },
        ];
        this.updateRemindersFormValue();
    }
    deleteReminder(index) {
        this.reminders = this.reminders.filter((_, i) => i !== index).map(p => ({ ...p }));
        this.updateRemindersFormValue();
    }
    get isInternalsAvailable() {
        return this.internals !== undefined && typeof this.internals.setFormValue === 'function';
    }
    updateRemindersFormValue(valueChanged = true) {
        debug('nylas-reminder-emails', 'updateRemindersFormValue');
        const eventReminders = this.reminders.map(reminder => {
            const rem = { ...reminder };
            rem?.editing && delete rem.editing;
            return rem;
        });
        if (valueChanged) {
            this.valueChanged.emit({
                value: JSON.stringify(eventReminders),
                name: this.name,
            });
        }
        this.isInternalsAvailable && this.internals.setFormValue(JSON.stringify(eventReminders), this.name);
    }
    formatReminderTime(reminderTime) {
        switch (true) {
            case reminderTime > 24 * 60:
                return `${(reminderTime / 60 / 24).toFixed(2)} ${i18next.t('time.days')}`;
            case reminderTime === 24 * 60:
                return `1 ${i18next.t('time.days')}`;
            case reminderTime > 90 || reminderTime === 60:
                return `${(reminderTime / 60).toFixed(2)} ${i18next.t('time.hours')}`;
            default:
                return `${reminderTime} ${reminderTime > 1 ? i18next.t('time.minutes') : i18next.t('time.minute')} `;
        }
    }
    render() {
        const organizerName = this.participants.find(p => p.is_organizer)?.name;
        let recipientOptions = [
            {
                label: i18next.t('nylasReminderEmails.recipientOptions', { context: 'all' }),
                value: 'all',
            },
            {
                label: i18next.t('nylasReminderEmails.recipientOptions', { context: 'guest' }),
                value: 'guest',
            },
            {
                label: i18next.t('nylasReminderEmails.recipientOptions', { context: 'host' }),
                value: 'host',
            },
        ];
        if (this.selectedConfiguration?.type === 'group') {
            recipientOptions = recipientOptions.filter(option => option.value !== 'all');
        }
        return (h(Host, { key: 'a14f383c9531076b75a3c8848b1a866199675f95' }, h("div", { key: 'bfa9969c2318b4f3c23bc159524da0f05b571b51', class: "cards-container" }, this.reminders.map((reminder, index) => {
            return reminder.type !== 'webhook' ? (h("div", { class: "nylas-reminder-email", part: "nre" }, h("div", { class: "header", part: "nre__header" }, h("div", null, h("h3", null, i18next.t('nylasReminderEmails.headerTitle', { organizerName: organizerName ? ` with ${organizerName} ` : '' })), h("p", null, i18next.t('nylasReminderEmails.headerSubTitle'))), !reminder.editing ? (h("button-component", { variant: 'basic', key: `edit-${index} `, clickHandler: event => {
                    event.preventDefault();
                    reminder.editing = true;
                    this.reminders = [...this.reminders];
                } }, h("edit-icon", { width: "16", height: "16" }), i18next.t('nylasReminderEmails.editButtonText'))) : (h("div", { class: "reminder-open-close-toggle" }, h("button-component", { variant: 'basic', class: "delete-btn", tooltip: "Delete reminder", key: `delete -${index} `, clickHandler: event => {
                    event.preventDefault();
                    this.deleteReminder(index);
                } }, h("trash-icon", { width: "16", height: "16" })), h("span", { class: `chevron ${reminder.editing ? 'open' : 'closed'}`, onClick: () => {
                    reminder.editing = !reminder.editing;
                    this.reminders = [...this.reminders];
                } }, h("chevron-icon", { width: "24", height: "24" }))))), reminder.editing ? (h("div", { class: "nylas-reminder-email__body", part: "nre__body" }, h("div", { class: "nylas-reminder-email__section" }, h("div", { class: "nylas-reminder-email__row" }, h("label", null, i18next.t('nylasReminderEmails.emailRecipients.label')), h("select-dropdown", { name: `recipient-${index}`, options: recipientOptions, defaultSelectedOption: recipientOptions.find(i => i.value === reminder.recipient) ?? recipientOptions[0], withSearch: false })), h("div", { class: "nylas-reminder-email__row" }, h("label", null, i18next.t('nylasReminderEmails.sendConfirmation.label'), h("span", { class: "label-icon" }, h("tooltip-component", null, h("info-icon", { slot: "tooltip-icon" }), h("span", { slot: "tooltip-content" }, i18next.t('nylasReminderEmails.sendConfirmation.tooltip.desc'))))), h("div", null, h("nylas-reminder-time", { name: `reminder-time-${index}`, eventReminderTimeMinutes: reminder.minutes_before_event, exportparts: "nrt, nrt__number-dropdown, nrt__number-dropdown-button, nrt__number-dropdown-content, nrt__period-dropdown, nrt__period-dropdown-button, nrt__period-dropdown-content, nrt__time-period-selector" }), this.reminderErrors[`reminder-time-${index}`]?.error && (h("p", { class: "error-message" }, this.reminderErrors[`reminder-time-${index}`]?.error, ' ', h("button-component", { variant: "invisible", onClick: _e => {
                    this.nylasSuggestReminderMinutes.emit({ minutes: this.reminderErrors[`reminder-time-${index}`]?.suggestion });
                } }, this.reminderErrors[`reminder-time-${index}`]?.suggestion))))), h("div", { class: "nylas-reminder-email__block" }, h("label", null, i18next.t('nylasReminderEmails.emailSubject.label')), h("input-component", { name: `reminder-subject-${index}`, maxLength: 60, placeholder: i18next.t('nylasReminderEmails.emailSubject.placeholder', { organizerName: organizerName ? ` with ${organizerName}` : '' }), defaultValue: reminder?.email_subject || '' }))))) : (h("div", { class: "nylas-reminder-email__summary", part: "nre__summary" }, h("p", null, h("span", { class: "summary-icon" }, h("person-clipboard-icon", null)), recipientOptions.find(i => i.value === reminder.recipient)?.label), h("p", null, h("span", { class: "summary-icon" }, h("clock-icon", null)), this.formatReminderTime(reminder.minutes_before_event), " ", i18next.t('nylasReminderEmails.beforeTheEvent')))))) : null;
        })), h("button-component", { key: '7ce94e57ade399ef39bb69df3bef3c0eec4c94ce', class: "create-reminder", variant: 'basic', clickHandler: event => {
                event.preventDefault();
                this.addReminder();
            } }, h("plus-icon", { key: '9c40a99b724f31d196f81640c882d2c673f31f43', width: "16", height: "16" }), i18next.t('nylasReminderEmails.newReminderButtonText'))));
    }
    static get is() { return "nylas-reminder-emails"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-reminder-emails.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-reminder-emails.css"]
        };
    }
    static get properties() {
        return {
            "selectedConfiguration": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Configuration | GroupConfiguration",
                    "resolved": "Configuration | GroupConfiguration | undefined",
                    "references": {
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        },
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected configuration."
                }
            },
            "eventReminders": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(EventReminder & { editing?: boolean })[]",
                    "resolved": "(EventReminder & { editing?: boolean | undefined; })[] | undefined",
                    "references": {
                        "EventReminder": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::EventReminder"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The event reminders prop."
                }
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The name of the component"
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'reminder-overrides'"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "reminders": {},
            "reminderErrors": {},
            "participants": {},
            "clearError": {}
        };
    }
    static get events() {
        return [{
                "method": "valueChanged",
                "name": "valueChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the email reminders change."
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n    valueChanged?: (event: CustomEvent<{ value: string; name: string }>) => void;\n  }",
                    "resolved": "{ value: string; name: string; valueChanged?: ((event: CustomEvent<{ value: string; name: string; }>) => void) | undefined; }",
                    "references": {
                        "CustomEvent": {
                            "location": "global",
                            "id": "global::CustomEvent"
                        }
                    }
                }
            }, {
                "method": "nylasSuggestReminderMinutes",
                "name": "nylasSuggestReminderMinutes",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ minutes: number }",
                    "resolved": "{ minutes: number; }",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedConfiguration",
                "methodName": "selectedConfigurationChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "valueChanged",
                "method": "handleValueChanged",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormDropdownChanged",
                "method": "handleNylasFormDropdownChanged",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormInputChanged",
                "method": "handleNylasFormInputChanged",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    RegisterComponent({
        name: 'nylas-reminder-emails',
        stateToProps: new Map([
            ['schedulerConfig.selectedConfiguration', 'selectedConfiguration'],
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
        ]),
        eventToProps: {
            valueChanged: async (event, _nylasSchedulerConfigConnector) => {
                const { valueChanged } = event.detail;
                if (valueChanged) {
                    valueChanged(event);
                }
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasReminderEmails.prototype, "render", null);
//# sourceMappingURL=nylas-reminder-emails.js.map
