import { newSpecPage } from "@stencil/core/testing";
import { NylasReminderEmails } from "../nylas-reminder-emails";
import { InputComponent } from "../../../design-system/input-component/input-component";
import { h } from "@stencil/core";
describe('nylas-reminder-emails', () => {
    let page;
    beforeEach(async () => {
        page = await newSpecPage({
            components: [InputComponent, NylasReminderEmails],
            template: () => {
                return (h("nylas-reminder-emails", { eventReminders: [
                        {
                            type: 'webhook',
                            minutes_before_event: 50,
                            email_subject: 'Webhook Reminder',
                            recipient: 'all',
                        },
                        {
                            type: 'email',
                            minutes_before_event: 30,
                            editing: true,
                            email_subject: 'Email Reminder for guest',
                            recipient: 'guest',
                        },
                        {
                            type: 'email',
                            minutes_before_event: 80,
                            editing: true,
                            email_subject: 'Email Reminder for host',
                            recipient: 'host',
                        },
                    ] }));
            },
        });
        await page.waitForChanges();
    });
    it('renders', async () => {
        expect(page.root).toMatchSnapshot();
    });
    it('should not render webhook reminder', async () => {
        const reminders = page.root.shadowRoot.querySelectorAll('.nylas-reminder-email');
        expect(reminders).not.toBeNull();
        expect(reminders.length).toBe(2);
        const reminder = reminders[0];
        const inputComponent = reminder.querySelector('input-component');
        const input = inputComponent.shadowRoot.querySelector('input');
        expect(input.value).toBe('Email Reminder for guest');
    });
});
//# sourceMappingURL=new-reminder-emails.spec.js.map
