var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import i18next from "../../../utils/i18n";
import { CONFIGURATION_EVENT_TYPE } from "../../../common/constants";
export class NylasSelectEventType {
    constructor() {
        this.participantOptions = undefined;
        this.name = 'select-event-type';
        this.selectedLanguage = undefined;
        this.enableEventTypes = {
            one_on_one: true,
            collective: true,
            max_fairness: true,
            max_availability: true,
            group: true,
        };
    }
    connectedCallback() {
        debug('nylas-select-event-type', 'connectedCallback');
    }
    disconnectedCallback() {
        debug('nylas-select-event-type', 'disconnectedCallback');
    }
    componentWillLoad() {
        debug('nylas-select-event-type', 'componentWillLoad');
        this.host.setAttribute('name', this.name);
    }
    componentDidLoad() {
        debug('nylas-select-event-type', 'componentDidLoad');
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-select-event-type', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
    }
    render() {
        const eventTypeKey = {
            'one-on-one': 'one_on_one',
            'collective': 'collective',
            'max-fairness': 'max_fairness',
            'max-availability': 'max_availability',
            'group': 'group',
        };
        const allEventTypes = [
            {
                label: i18next.t('nylasSelectEventType.eventTypeOptions.oneOnOne.label'),
                value: CONFIGURATION_EVENT_TYPE.one_on_one,
                description: i18next.t('nylasSelectEventType.eventTypeOptions.oneOnOne.desc'),
            },
            {
                label: i18next.t('nylasSelectEventType.eventTypeOptions.collective.label'),
                value: CONFIGURATION_EVENT_TYPE.collective,
                description: i18next.t('nylasSelectEventType.eventTypeOptions.collective.desc'),
            },
            {
                label: i18next.t('nylasSelectEventType.eventTypeOptions.maxFairness.label'),
                value: CONFIGURATION_EVENT_TYPE.max_fairness,
                description: i18next.t('nylasSelectEventType.eventTypeOptions.maxFairness.desc'),
            },
            {
                label: i18next.t('nylasSelectEventType.eventTypeOptions.maxAvailability.label'),
                value: CONFIGURATION_EVENT_TYPE.max_availability,
                description: i18next.t('nylasSelectEventType.eventTypeOptions.maxAvailability.desc'),
            },
            {
                label: i18next.t('nylasSelectEventType.eventTypeOptions.group.label'),
                value: CONFIGURATION_EVENT_TYPE.group,
                description: i18next.t('nylasSelectEventType.eventTypeOptions.group.desc'),
            },
        ];
        const conditionalEventTypes = [CONFIGURATION_EVENT_TYPE.collective, CONFIGURATION_EVENT_TYPE.max_availability, CONFIGURATION_EVENT_TYPE.max_fairness];
        const hasAdditionalParticipants = this.participantOptions &&
            this.participantOptions?.length > 0 &&
            !!this.participantOptions[0].email &&
            !!this.participantOptions[0].name &&
            !!this.participantOptions[0].calendars &&
            this.participantOptions[0].calendars.length > 0;
        const eventTypes = this.enableEventTypes
            ? allEventTypes.filter(eventType => {
                const key = eventType.value;
                const keyType = eventTypeKey[key];
                console.log('key', key, this.enableEventTypes ? this.enableEventTypes[keyType] : 'no enableEventTypes');
                if (conditionalEventTypes.includes(key) && !hasAdditionalParticipants) {
                    return false;
                }
                return this.enableEventTypes && this.enableEventTypes[keyType];
            })
            : allEventTypes;
        return (h(Host, null, h("div", { class: "nylas-select-event-type", part: "nset" }, h("div", { class: "header", part: "nset__header" }, h("h2", null, i18next.t('nylasSelectEventType.createEventHeaderTitle')), h("button-component", { variant: "invisible", part: "nset__header__back-button", onClick: _event => {
                this.returnToAllSchedulingPagesEvent.emit();
            } }, h("chevron-icon", { width: "16", height: "16" }), h("span", null, i18next.t('nylasSelectEventType.returnToAllSchedulingPages')))), h("div", { class: "content", part: "nset__content" }, h("h3", null, i18next.t('nylasSelectEventType.eventTypeHeaderTitle')), h("div", { class: "event-type", part: "nset__content__event-type" }, eventTypes.length === 0 && h("p", null, i18next.t('nylasSelectEventType.noEventTypesEnabled')), eventTypes.map(eventType => (h("div", { class: "event-type-option", onClick: _event => {
                this.createEventTypeSelected.emit({ eventType: eventType.value });
            }, part: `nset__content__event-type-option-${eventType.value}` }, h("h4", null, eventType.label), h("p", null, eventType.description)))))))));
    }
    static get is() { return "nylas-select-event-type"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-select-event-type.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-select-event-type.css"]
        };
    }
    static get properties() {
        return {
            "participantOptions": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "AdditionalParticipant[]",
                    "resolved": "AdditionalParticipant[] | undefined",
                    "references": {
                        "AdditionalParticipant": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::AdditionalParticipant"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The participant options passed in the additionalParticipants prop\nfrom the nylas-scheduler-editor component."
                        }],
                    "text": ""
                }
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The name of the component"
                        }],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'select-event-type'"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            },
            "enableEventTypes": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "EnableEventTypes",
                    "resolved": "undefined | { one_on_one: boolean; collective: boolean; max_fairness: boolean; max_availability: boolean; group: boolean; }",
                    "references": {
                        "EnableEventTypes": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::EnableEventTypes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The enable event types."
                },
                "defaultValue": "{\n    one_on_one: true,\n    collective: true,\n    max_fairness: true,\n    max_availability: true,\n    group: true,\n  }"
            }
        };
    }
    static get events() {
        return [{
                "method": "returnToAllSchedulingPagesEvent",
                "name": "returnToAllSchedulingPagesEvent",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the return to all scheduling pages button is clicked."
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }, {
                "method": "createEventTypeSelected",
                "name": "createEventTypeSelected",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the event type is selected."
                },
                "complexType": {
                    "original": "{ eventType: CONFIGURATION_EVENT_TYPE }",
                    "resolved": "{ eventType: CONFIGURATION_EVENT_TYPE; }",
                    "references": {
                        "CONFIGURATION_EVENT_TYPE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::CONFIGURATION_EVENT_TYPE"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }];
    }
}
__decorate([
    RegisterComponent({
        name: 'nylas-select-event-type',
        stateToProps: new Map([
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
            ['schedulerConfig.additionalParticipants', 'participantOptions'],
            ['schedulerConfig.enableEventTypes', 'enableEventTypes'],
        ]),
        eventToProps: {
            returnToAllSchedulingPagesEvent: async (_event, connector) => {
                connector.schedulerConfigStore.state.action = null;
                connector.schedulerConfigStore.set('selectedEventType', undefined);
            },
            createEventTypeSelected: async (event, connector) => {
                const { eventType } = event.detail;
                connector.schedulerConfigStore.state.action = 'create';
                connector.schedulerConfigStore.state.selectedEventType = eventType;
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasSelectEventType.prototype, "render", null);
//# sourceMappingURL=nylas-select-event-type.js.map
