import { newSpecPage } from "@stencil/core/testing";
import { NylasSelectedEventCard } from "../nylas-selected-event-card";
import { h } from "@stencil/core";
import { formatTime } from "../../../../utils/test-utils";
describe('nylas-selected-event-card', () => {
    beforeEach(() => {
        jest.clearAllMocks();
        const originalIntl = Intl;
        global.Intl = {
            ...originalIntl,
            DateTimeFormat: jest.fn().mockImplementation(() => ({
                resolvedOptions: () => ({
                    timeZone: 'America/New_York',
                }),
                format: jest.fn(x => formatTime(x)),
                supportedLocalesOf: jest.fn(),
            })),
        };
    });
    it('renders correctly with initial props', async () => {
        const page = await newSpecPage({
            components: [NylasSelectedEventCard],
            html: `<nylas-selected-event-card></nylas-selected-event-card>`,
        });
        expect(page.root).toMatchSnapshot();
    });
    it('updates time display when selectedTimeslot changes', async () => {
        const selectedTimeslot = { start_time: new Date('2021-01-01T09:00:00Z'), end_time: new Date('2021-01-01T10:00:00Z'), emails: [] };
        const selectedDate = new Date('2021-01-01T00:00:00Z');
        const page = await newSpecPage({
            components: [NylasSelectedEventCard],
            template: () => {
                return h("nylas-selected-event-card", { selectedTimeslot: selectedTimeslot, selectedDate: selectedDate });
            },
        });
        if (!page.root) {
            throw new Error('Component did not render.');
        }
        await page.waitForChanges();
        const dateDisplay = page?.root?.shadowRoot?.querySelector('[part="nsec__date"]');
        expect(dateDisplay.textContent).toContain('Friday, January 1, 2021');
        const timeDisplay = page?.root?.shadowRoot?.querySelector('[part="nsec__time"]');
        expect(timeDisplay.textContent).toContain('9:00 AM - 10:00 AM');
    });
});
//# sourceMappingURL=nylas-selected-event-card.spec.js.map
