var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug, isSameDayTimezone } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import i18next from "../../../utils/i18n";
import { LANGUAGE_CODE_TO_LOCALE_MAP } from "../../../common/constants";
export class NylasTimeslotPicker {
    constructor() {
        this.handleConfirmedTimeslot = async (event, timeslot) => {
            event.preventDefault();
            debug(`[nylas-timeslot-picker] Confirm timeslot`, timeslot);
            if (timeslot) {
                this.timeslotConfirmed.emit({ timeslot, host: this.host });
            }
        };
        this.handleMouseEnter = (index) => {
            this.hoveredTimeslotIndex = index;
        };
        this.handleMouseLeave = () => {
            this.hoveredTimeslotIndex = -1;
        };
        this.availability = undefined;
        this.isLoading = undefined;
        this.themeConfig = undefined;
        this.selectedTimeslot = undefined;
        this.selectedTimezone = Intl.DateTimeFormat().resolvedOptions().timeZone;
        this.selectedDate = new Date();
        this.selectedLanguage = undefined;
        this.hour12 = undefined;
        this.times = [];
        this.hoveredTimeslotIndex = undefined;
        this.selectedTimeslotIndex = undefined;
    }
    selectedLanguageChanged(newLanguage) {
        i18next.changeLanguage(newLanguage);
    }
    selectedDateChanged(newVal) {
        debug(`[nylas-timeslot-picker] Selected date changed`, { newVal });
        if (newVal) {
            this.selectedTimeslotIndex = '';
            if (typeof newVal !== 'undefined') {
                const availableTimes = this.availability?.filter(timeslot => isSameDayTimezone(timeslot.start_time, newVal, this.selectedTimezone)).map(timeslot => timeslot);
                this.times = availableTimes || [];
            }
        }
    }
    availabilityChanged(newVal) {
        debug(`[nylas-timeslot-picker] Available times changed`, { newVal, selectedDate: this.selectedDate });
        if (typeof newVal !== 'undefined') {
            const availableTimes = newVal
                ?.filter(timeslot => this.selectedDate && isSameDayTimezone(timeslot.start_time, this.selectedDate, this.selectedTimezone))
                .map(timeslot => timeslot);
            this.times = availableTimes || [];
        }
    }
    themeConfigChanged(newThemeConfig) {
        this.applyThemeConfig(newThemeConfig);
    }
    connectedCallback() { }
    disconnectedCallback() { }
    async componentWillLoad() {
        debug(`[nylas-timeslot-picker] Component will load`, { selectedDate: this.selectedDate, availability: this.availability, times: this.times });
    }
    async componentDidLoad() {
        debug(`[nylas-timeslot-picker] Component did load`);
        const availableTimes = this.availability
            ?.filter(timeslot => this.selectedDate && isSameDayTimezone(timeslot.start_time, this.selectedDate, this.selectedTimezone))
            .map(timeslot => timeslot);
        this.times = availableTimes || [];
        this.applyThemeConfig(this.themeConfig);
    }
    applyThemeConfig(themeConfig) {
        if (themeConfig) {
            for (const [key, value] of Object.entries(themeConfig)) {
                this.host.style.setProperty(`${key}`, value);
            }
        }
    }
    getTimeslotId(timeslot, index) {
        const date = new Date(timeslot.start_time);
        const eventId = timeslot.event_id;
        return `${date.toLocaleDateString()}-${index}${eventId ? `-${eventId}` : ''}`;
    }
    onClickSelectTime(timeslot, index) {
        debug(`[nylas-timeslot-picker] Time selected`, timeslot, index);
        this.selectedTimeslotIndex = this.getTimeslotId(timeslot, index);
        this.timeslotSelected.emit({
            start_time: timeslot.start_time,
            end_time: timeslot.end_time,
            emails: timeslot.emails,
            capacity: timeslot?.capacity,
            event_id: timeslot?.event_id,
            master_id: timeslot?.master_id,
            calendar_id: timeslot?.calendar_id,
        });
    }
    async emitValidateTimeslotError(error, type) {
        this.validateTimeslotError.emit({ error, type });
    }
    getTimeSlotLabel(timeslot) {
        const locale = LANGUAGE_CODE_TO_LOCALE_MAP[this.selectedLanguage || 'en'];
        const timeFormat = new Intl.DateTimeFormat(locale, {
            hour: '2-digit',
            minute: '2-digit',
            timeZone: this.selectedTimezone,
            hour12: this.hour12,
        });
        return `${timeFormat.format(timeslot.start_time)} - ${timeFormat.format(timeslot.end_time)}`;
    }
    render() {
        const locale = LANGUAGE_CODE_TO_LOCALE_MAP[this.selectedLanguage || 'en'];
        if (this.isLoading) {
            return (h(Host, null, h("div", { class: 'loading' }, new Array(6).fill(0).map((_, i) => (h("div", { class: 'timeslot-skeleton', style: { animationDelay: `${i * 20}ms` } }))))));
        }
        if (this.availability && this.availability.length === 0) {
            return (h(Host, null, h("div", { class: 'empty' }, h("span", null, "No dates available"))));
        }
        const filteredTimes = this.times.filter(timeslot => {
            const groupEvent = timeslot?.event_id || timeslot?.master_id;
            const showCapacity = typeof timeslot?.capacity === 'number' && timeslot?.capacity > 0;
            return !(groupEvent && !showCapacity);
        });
        if ((!this.times || this.times.length === 0 || filteredTimes.length === 0) && !!this.selectedDate) {
            return (h(Host, null, h("div", { class: 'empty' }, h("span", null, "No time slots available for selected date"))));
        }
        if (!this.selectedDate)
            return h(Host, null);
        return (h(Host, { part: "ntp" }, h("div", { class: 'time-picker-wrapper', part: "ntp__time-picker-wrapper" }, h("div", { class: 'timeslots', part: "ntp__timeslots" }, filteredTimes.map((timeslot, index) => {
            const showCapacity = typeof timeslot?.capacity === 'number' && timeslot?.capacity > 0;
            const isSelected = this.selectedTimeslotIndex == this.getTimeslotId(timeslot, index);
            return (h("button", { part: `ntp__timeslot ${this.selectedTimeslot?.start_time?.getTime() === timeslot.start_time.getTime() ? 'ntp__timeslot--selected' : ''}`, class: {
                    time: true,
                    selected: typeof this.selectedTimeslot !== 'undefined' && isSelected,
                }, onClick: () => this.onClickSelectTime(timeslot, index), onMouseEnter: () => this.handleMouseEnter(index), onMouseLeave: () => this.handleMouseLeave() }, h("div", { class: "time-label", part: "ntp__time-label" }, this.hoveredTimeslotIndex == index || isSelected
                ? this.getTimeSlotLabel(timeslot)
                : timeslot.start_time.toLocaleTimeString(locale, { hour: '2-digit', minute: '2-digit', timeZone: this.selectedTimezone, hour12: this.hour12 }), h("span", { class: "spots" }, showCapacity ? i18next.t('spotsLeft', { count: timeslot?.capacity }) : null))));
        })), this.selectedTimeslot && (h("div", { class: 'footer' }, h("button-component", { variant: 'primary', onClick: (event) => this.handleConfirmedTimeslot(event, this.selectedTimeslot), part: "ntp__button-primary" }, h("slot", { name: "timeslot-picker-cta-label" }, i18next.t('nextButton'))))))));
    }
    static get is() { return "nylas-timeslot-picker"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-timeslot-picker.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-timeslot-picker.css"]
        };
    }
    static get properties() {
        return {
            "availability": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "AvailabilityTimeslot[]",
                    "resolved": "AvailabilityTimeslot[] | undefined",
                    "references": {
                        "AvailabilityTimeslot": {
                            "location": "import",
                            "path": "@/stores/scheduler-store",
                            "id": "src/stores/scheduler-store.ts::AvailabilityTimeslot"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The available timeslots."
                        }],
                    "text": ""
                }
            },
            "isLoading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The loading state prop. Used to display loading state when fetching availability."
                        }],
                    "text": ""
                },
                "attribute": "loading-state",
                "reflect": false
            },
            "themeConfig": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The theme configuration."
                        }],
                    "text": ""
                },
                "attribute": "theme-config",
                "reflect": false
            },
            "selectedTimeslot": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Timeslot",
                    "resolved": "undefined | { start_time: Date; end_time: Date; emails?: string[] | undefined; capacity?: number | undefined; event_id?: string | undefined; master_id?: string | undefined; calendar_id?: string | undefined; }",
                    "references": {
                        "Timeslot": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Timeslot"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected timeslot."
                }
            },
            "selectedTimezone": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The selected timezone."
                },
                "attribute": "selected-timezone",
                "reflect": false,
                "defaultValue": "Intl.DateTimeFormat().resolvedOptions().timeZone"
            },
            "selectedDate": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Date",
                    "resolved": "Date | undefined",
                    "references": {
                        "Date": {
                            "location": "global",
                            "id": "global::Date"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected date."
                },
                "defaultValue": "new Date()"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            },
            "hour12": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The 12-hour time format."
                },
                "attribute": "hour-1-2",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "times": {},
            "hoveredTimeslotIndex": {},
            "selectedTimeslotIndex": {}
        };
    }
    static get events() {
        return [{
                "method": "timeslotSelected",
                "name": "timeslotSelected",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when a timeslot is selected."
                },
                "complexType": {
                    "original": "Timeslot",
                    "resolved": "{ start_time: Date; end_time: Date; emails?: string[] | undefined; capacity?: number | undefined; event_id?: string | undefined; master_id?: string | undefined; calendar_id?: string | undefined; }",
                    "references": {
                        "Timeslot": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Timeslot"
                        }
                    }
                }
            }, {
                "method": "timeslotConfirmed",
                "name": "timeslotConfirmed",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when a timeslot is confirmed. By default, this will proceed to the booking form page."
                },
                "complexType": {
                    "original": "{ timeslot: Timeslot; host: HTMLNylasTimeslotPickerElement }",
                    "resolved": "{ timeslot: Timeslot; host: HTMLNylasTimeslotPickerElement; }",
                    "references": {
                        "Timeslot": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Timeslot"
                        },
                        "HTMLNylasTimeslotPickerElement": {
                            "location": "global",
                            "id": "global::HTMLNylasTimeslotPickerElement"
                        }
                    }
                }
            }, {
                "method": "validateTimeslotError",
                "name": "validateTimeslotError",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ error: string; type: 'error' | 'info' }",
                    "resolved": "{ error: string; type: \"error\" | \"info\"; }",
                    "references": {}
                }
            }];
    }
    static get methods() {
        return {
            "emitValidateTimeslotError": {
                "complexType": {
                    "signature": "(error: string, type: 'error' | 'info') => Promise<void>",
                    "parameters": [{
                            "name": "error",
                            "type": "string",
                            "docs": ""
                        }, {
                            "name": "type",
                            "type": "\"error\" | \"info\"",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChanged"
            }, {
                "propName": "selectedDate",
                "methodName": "selectedDateChanged"
            }, {
                "propName": "availability",
                "methodName": "availabilityChanged"
            }, {
                "propName": "themeConfig",
                "methodName": "themeConfigChanged"
            }];
    }
}
__decorate([
    RegisterComponent({
        name: 'nylas-timeslot-picker',
        stateToProps: new Map([
            ['scheduler.selectedDate', 'selectedDate'],
            ['scheduler.availability', 'availability'],
            ['scheduler.selectedTimeslot', 'selectedTimeslot'],
            ['scheduler.selectedTimezone', 'selectedTimezone'],
            ['scheduler.selectedLanguage', 'selectedLanguage'],
            ['scheduler.isLoading', 'isLoading'],
            ['scheduler.themeConfig', 'themeConfig'],
            ['scheduler.hour12', 'hour12'],
        ]),
        eventToProps: {
            timeslotSelected: async (event, nylasSchedulerConnector) => {
                debug('nylas-timeslot-picker', 'timeslotSelected', event.detail);
                nylasSchedulerConnector.scheduler.selectTime(event.detail);
            },
            timeslotConfirmed: async (event, nylasSchedulerConnector) => {
                debug('nylas-timeslot-picker', 'timeslotConfirmed', event.detail);
                const { timeslot, host } = event.detail;
                if (timeslot && timeslot?.event_id && timeslot?.capacity) {
                    const result = await nylasSchedulerConnector.scheduler.validateGroupEventTimeslot(timeslot);
                    if (result && 'error' in result) {
                        const errorMessage = result.error?.message || 'An error occurred while validating the timeslot';
                        if (errorMessage === 'Event is full') {
                            host.emitValidateTimeslotError(errorMessage, 'info');
                        }
                        else {
                            host.emitValidateTimeslotError(errorMessage, 'error');
                        }
                    }
                }
                else {
                    nylasSchedulerConnector.scheduler.toggleAdditionalData(true);
                }
            },
            validateTimeslotError: async (event, _nylasSchedulerConnector) => {
                debug('nylas-timeslot-picker', 'validateTimeslotError', event.detail);
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasTimeslotPicker.prototype, "render", null);
//# sourceMappingURL=nylas-timeslot-picker.js.map
