import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { d as defineCustomElement$1 } from './checkbox-component2.js';

const checkboxGroupCss = ":host{display:block}.checkbox-group-container{display:flex;flex-direction:column;gap:0.5rem}.group-label{font-weight:500;margin-bottom:0.25rem}.group-label .required{color:var(--nylas-error);margin-left:0.25rem}.checkbox-list{display:flex;gap:16px}.checkbox-list.vertical{flex-direction:column}.checkbox-list.horizontal{flex-direction:row;align-items:center}.checkbox-list checkbox-component{width:max-content}.checkbox-list checkbox-component::part(checkbox-label-span){width:inherit;margin-left:24px}.error{color:var(--nylas-error);font-size:0.875rem;margin-top:0.25rem}";
const CheckboxGroupStyle0 = checkboxGroupCss;

const CheckboxGroup = proxyCustomElement(class CheckboxGroup extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.nylasCheckboxGroupChanged = createEvent(this, "nylasCheckboxGroupChanged", 7);
        this.componentType = 'checkbox-group';
        this.name = 'checkbox-group';
        this.label = '';
        this.options = [];
        this.required = false;
        this.direction = 'vertical';
        this.error = '';
        this.selectedValues = [];
    }
    componentWillLoad() {
        this.el.setAttribute('component-type', this.componentType);
    }
    componentDidLoad() {
        this.selectedValues = this.options.filter(option => option.checked).map(option => option.value);
    }
    optionsChangedHandler(newValue, oldValue) {
        if (JSON.stringify(newValue) === JSON.stringify(oldValue))
            return;
        this.selectedValues = newValue.filter(option => option.checked).map(option => option.value);
    }
    handleBookingFormSubmitted(event) {
        if (this.required && !this.hasCheckedOptions()) {
            this.error = 'Please select at least one option.';
        }
        if (this.error) {
            event.preventDefault();
        }
    }
    hasCheckedOptions() {
        return this.options.some(option => option.checked);
    }
    handleCheckboxToggle(event) {
        const { checked, name: _checkboxName, label } = event.detail;
        const toggledOption = this.options.find(option => option.label === label);
        if (!toggledOption)
            return;
        let selected = [];
        if (checked) {
            if (toggledOption.selectAll) {
                selected = this.options.map(option => option.value);
            }
            else {
                selected = [...this.selectedValues, toggledOption.value];
            }
        }
        else {
            selected = this.selectedValues.filter(value => value !== toggledOption.value);
        }
        this.selectedValues = [...selected];
        this.nylasCheckboxGroupChanged.emit({
            selectedValues: this.selectedValues,
            name: this.name,
        });
    }
    handleCheckboxToggled(event) {
        this.handleCheckboxToggle(event);
    }
    render() {
        return (h("div", { key: '76ae2efb8faa2b161472a0330e398b1557e149a2', class: "checkbox-group-container" }, this.label && (h("div", { class: "group-label" }, this.label, this.required && h("span", { class: "required" }, "*"))), h("div", { key: 'fbc0e62c6ea9cd92bf1195721910f6a03b031900', class: `checkbox-list ${this.direction}` }, this.options.map(option => (h("checkbox-component", { name: `${this.name}-${option.value}`, label: option.label, checked: this.selectedValues.includes(option.value), readOnly: option.disabled, required: this.required })))), this.error && h("p", { class: "error" }, this.error)));
    }
    get el() { return this; }
    static get watchers() { return {
        "options": ["optionsChangedHandler"]
    }; }
    static get style() { return CheckboxGroupStyle0; }
}, [1, "checkbox-group", {
        "name": [1],
        "label": [1],
        "options": [16],
        "required": [4],
        "direction": [1],
        "error": [32],
        "selectedValues": [32]
    }, [[4, "bookingFormSubmitted", "handleBookingFormSubmitted"], [4, "nylasFormCheckboxToggled", "handleCheckboxToggled"]], {
        "options": ["optionsChangedHandler"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["checkbox-group", "checkbox-component"];
    components.forEach(tagName => { switch (tagName) {
        case "checkbox-group":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, CheckboxGroup);
            }
            break;
        case "checkbox-component":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { CheckboxGroup as C, defineCustomElement as d };

//# sourceMappingURL=checkbox-group2.js.map