import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { s as sanitize } from './utils.js';

const nylasDateComponentCss = ":host{display:block;height:auto;--nylas-primary:#2563eb;--nylas-error:#cc4841;--nylas-error-pressed:#992222;--nylas-wraning:#f06c00;--nylas-success:#16a392;--nylas-info:#2b8fc2;--nylas-base-0:#ffffff;--nylas-base-25:#fcfcfd;--nylas-base-50:#f8f9fc;--nylas-base-100:#eaecf5;--nylas-base-200:#d5d9eb;--nylas-base-300:#b3b8d8;--nylas-base-400:#717bbc;--nylas-base-500:#4e5ba6;--nylas-base-600:#3e4784;--nylas-base-700:#263f72;--nylas-base-800:#293056;--nylas-base-900:#101323;--nylas-base-950:#0e101b;--nylas-color-blue-100:#e0e6f9;--nylas-border-radius:0.25rem;--nylas-border-radius-2x:0.5rem;--nylas-border-radius-3x:0.75rem;--nylas-font-family:\"Inter\", sans-serif;--nylas-color-black:#000000;--nylas-color-grey-900:#2c2c2c;--nylas-color-grey-800:#4b4b4b;--nylas-color-grey-700:#6e6e6e;--nylas-color-grey-600:#8e8e8e;--nylas-color-grey-500:#b3b3b3;--nylas-color-grey-400:#cacaca;--nylas-color-grey-300:#e1e1e1;--nylas-color-grey-200:#eaeaea;--nylas-color-grey-100:#f5f5f5;--nylas-color-grey-50:#fbfcfe;--nylas-color-white:#ffffff;--nylas-color-red-900:#992222;--nylas-color-red-700:#cc4841;--nylas-color-red-500:#ff786a;--nylas-color-red-300:#ffa79e;--nylas-color-red-100:#ffc5bf;--nylas-color-red-50:#ffeae8;--nylas-color-blue-900:#213571;--nylas-color-blue-700:#314fa9;--nylas-color-blue-500:#4169e1;--nylas-color-blue-300:#bdccf9;--nylas-color-blue-100:#e0e6f9;--nylas-color-blue-50:#f6f8fd;--nylas-color-yellow-900:#7c6506;--nylas-color-yellow-700:#c29f09;--nylas-color-yellow-500:#f7c90b;--nylas-color-yellow-300:#f9de70;--nylas-color-yellow-100:#fceba9;--nylas-color-yellow-50:#fdf4ce;--nylas-color-green-900:#0e6b60;--nylas-color-green-700:#16a392;--nylas-color-green-500:#17c3b2;--nylas-color-green-300:#74dbd1;--nylas-color-green-100:#a2e7e0;--nylas-color-green-50:#d1f3f0;--nylas-color-purple-900:#643554;--nylas-color-purple-700:#954f7d;--nylas-color-purple-500:#c769a7;--nylas-color-purple-300:#dda5ca;--nylas-color-purple-100:#e0bdd6;--nylas-color-purple-50:#e9dde5;--nylas-color-sky-900:#20698f;--nylas-color-sky-700:#2b8fc2;--nylas-color-sky-500:#6dceff;--nylas-color-sky-300:#8fdaff;--nylas-color-sky-100:#b8e7ff;--nylas-color-sky-50:#d9f2ff;width:100%}label{display:flex;color:var(--nylas-base-800, #293056);font-size:14px;font-style:normal;font-weight:400;line-height:150%;flex-direction:column;gap:4px;font-family:var(--nylas-font-family);font-size:16px;color:var(--nylas-base-800)}label.error{color:var(--nylas-error)}label span.required{color:var(--nylas-error);padding:0 0.25rem}label p{margin:0}label .error{color:var(--nylas-error);border-color:var(--nylas-error)}.input_wrapper{display:flex;align-items:center;gap:1rem}input[type=date]{display:flex;height:48px;padding-left:16px;align-items:center;gap:8px;align-self:stretch;border-radius:var(--nylas-border-radius-2x);border:1px solid var(--nylas-base-300);background:var(--nylas-base-0);width:-webkit-fill-available;color:var(--nylas-base-900);font-size:16px;font-style:normal;font-weight:400;line-height:150%;width:100%;width:-moz-available;width:-webkit-fill-available;font-family:var(--nylas-font-family);cursor:pointer}input[type=date]:focus{outline-color:var(--nylas-primary)}input[type=date].error{border-radius:var(--nylas-border-radius-2x);font-weight:600;border-color:var(--nylas-error);border-width:2px}input[type=date].error::placeholder{font-weight:400}input[type=date]::placeholder{color:var(--nylas-base-300)}input:read-only{background-color:var(--nylas-base-100);cursor:not-allowed}";
const NylasDateComponentStyle0 = nylasDateComponentCss;

const DefaultPlaceholder = {
    date: 'YYYY-MM-DD',
};
const NylasDateComponent = proxyCustomElement(class NylasDateComponent extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.nylasFormInputChanged = createEvent(this, "nylasFormInputChanged", 7);
        this.nylasFormInputFocused = createEvent(this, "nylasFormInputFocused", 7);
        this.nylasFormInputBlurred = createEvent(this, "nylasFormInputBlurred", 7);
        this.name = 'input';
        this.defaultValue = undefined;
        this.label = '';
        this.placeholder = DefaultPlaceholder['date'];
        this.required = false;
        this.readOnly = false;
        this.autoFocus = false;
        this.pattern = undefined;
        this.maxLength = 255;
        this.patternError = '';
        this.requiredError = '';
        this.minDate = undefined;
        this.hasError = false;
        this.value = undefined;
        this.error = '';
        this.isDateValid = true;
    }
    handleDefaultValueChange(newValue) {
        this.value = sanitize(newValue);
        if (this.value) {
            this.validatePattern(this.value, true);
        }
    }
    componentDidLoad() {
        this.value = sanitize(this.defaultValue || '');
        if (this.value) {
            this.validatePattern(this.value, true);
        }
    }
    handleBookingFormSubmitted(event) {
        this.validatePattern(this.value);
        if (this.error) {
            event.preventDefault();
        }
    }
    async handleFormSubmitted(event) {
        this.validatePattern(this.value);
        if (this.error) {
            event.preventDefault();
        }
    }
    handleInput(e) {
        this.error = '';
        const target = e.target;
        this.value = sanitize(target.value);
        this.isDateValid = target.validity.valid;
        this.nylasFormInputChanged.emit({
            value: this.value,
            name: this.name,
            label: this.label,
            error: this.error,
            type: 'date',
        });
    }
    handleBlur() {
        this.nylasFormInputBlurred.emit({
            value: this.value,
            name: this.name,
        });
    }
    handleFocus() {
        this.nylasFormInputFocused.emit({
            value: this.value,
            name: this.name,
        });
    }
    validatePattern(value, onLoad = false) {
        this.error = '';
        if (!onLoad && ((this.required && !this.isDateValid) || (this.minDate && new Date(this.minDate) > new Date(value)))) {
            this.error = 'Please enter a valid date';
            this.nylasFormInputChanged.emit({
                value: this.value,
                name: this.name,
                label: this.label,
                error: this.error,
                type: 'date',
            });
            return;
        }
        if (this.required && !value) {
            this.error = this.requiredError || 'This field is required.';
            return;
        }
        if (!this.pattern || (!value && !this.required))
            return;
        if (this.pattern.test(value)) {
            this.error = '';
        }
        else {
            this.error = this.patternError || 'Invalid format.';
        }
    }
    render() {
        return (h("label", { key: '5b1b9d5bd627971fab0ae9450dfffbc4b4d7c5e0', part: "ic__label", class: { error: !!this.error || this.hasError } }, this.label && (h("p", null, h("span", { class: "label" }, this.label), this.required && h("span", { class: "required" }, "*"))), h("div", { key: '62a760f2aaf894ecd7701d2f9d7318d3ed81ddd3', part: "ic__input_wrapper", class: "input_wrapper" }, h("input", { key: 'b34364549bdb557423a5bcae0f6958c797d2e265', type: "date", name: this.name, part: "ic__date", title: this.readOnly ? 'read-only field' : undefined, readOnly: this.readOnly, autoFocus: this.autoFocus, value: this.value, min: this.minDate, maxLength: this.maxLength, placeholder: this.placeholder, class: { error: !!this.error || this.hasError }, onInput: e => this.handleInput(e), onFocus: () => this.handleFocus(), onBlur: () => this.handleBlur() }), h("slot", { key: 'e1af09a4f2e6557b3b5b42c08d4ac54478981c9f', name: "additional-input" })), this.error && h("span", { class: "error help-text" }, this.error)));
    }
    get el() { return this; }
    static get watchers() { return {
        "defaultValue": ["handleDefaultValueChange"]
    }; }
    static get style() { return NylasDateComponentStyle0; }
}, [1, "nylas-date-component", {
        "name": [1],
        "defaultValue": [1, "default-value"],
        "label": [1],
        "placeholder": [1],
        "required": [4],
        "readOnly": [4, "read-only"],
        "autoFocus": [4, "auto-focus"],
        "pattern": [16],
        "maxLength": [2, "max-length"],
        "patternError": [1, "pattern-error"],
        "requiredError": [1, "required-error"],
        "minDate": [1, "min-date"],
        "hasError": [4, "has-error"],
        "value": [32],
        "error": [32],
        "isDateValid": [32]
    }, [[4, "bookingFormSubmitted", "handleBookingFormSubmitted"], [4, "formSubmitted", "handleFormSubmitted"]], {
        "defaultValue": ["handleDefaultValueChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["nylas-date-component"];
    components.forEach(tagName => { switch (tagName) {
        case "nylas-date-component":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, NylasDateComponent);
            }
            break;
    } });
}

export { NylasDateComponent as N, defineCustomElement as d };

//# sourceMappingURL=nylas-date-component2.js.map