import { AdditionalFields, Appearance, BookingType, Calendar, Conference, Configuration, EmailTemplate, EventReminder, GroupConfiguration, GroupEvent, GroupEventAPIData, ImportGroupEventDetails, NotificationType, RecurrenceDeleteOption, RecurrenceUpdateOption } from '@nylas/core';
import { Event, EventEmitter } from '../../../stencil-public-runtime';
import { TabGroup } from './tab-contents-group';
import { User } from "../../../common/nylas-api-request";
import { CONFIGURATION_EVENT_TYPE } from "../../../common/constants";
import { LANGUAGE_CODE } from "../../../common/constants";
import { CreateGroupEventFormState } from '../../..';
import { SchedulerGroupEventDetail } from '@nylas/core';
import { ErrorCategory, Notification } from "../../../types/index";
export declare class NylasEditorTabsGroup {
    private formRef;
    host: HTMLNylasEditorTabsGroupElement;
    calendars?: Calendar[];
    selectedConfiguration?: GroupConfiguration;
    configurations?: (Configuration | GroupConfiguration)[];
    currentUser?: User;
    schedulerPreviewLink: string;
    mode?: 'app' | 'composable';
    hideEditorTabs?: TabGroup[];
    enableUserFeedback?: boolean;
    selectedLanguage?: LANGUAGE_CODE;
    selectedEventType?: CONFIGURATION_EVENT_TYPE;
    selectedGroupEvent?: GroupEventAPIData;
    action: 'create' | 'edit';
    showFeedbackModal: boolean;
    activeTab: TabGroup;
    isLoading: boolean;
    componentLoaded: boolean;
    hasUnsavedChanges: boolean;
    changesSaved: boolean;
    formState: Partial<{
        title: string;
        description: string;
        participants: {
            name: string;
            email: string;
            is_organizer?: boolean;
        }[];
        additionalFields?: Record<string, AdditionalFields>;
        bookingCalendar?: string;
        location?: string;
        conferencing?: Conference;
        bookingType?: string;
        cancellationPolicy?: string;
        minCancellationNotice?: number;
        minBookingNotice?: number;
        hideCancellationOptions?: boolean;
        hideReschedulingOptions?: boolean;
        reminders?: EventReminder[];
        emailTemplate?: EmailTemplate;
        redirectUrl?: string;
        slug: string;
        appearance: Appearance;
        name: string;
        eventCapacity: number;
        eventTimeslot: {
            when: {
                start_time: number;
                end_time: number;
                start_timezone: string;
                end_timezone: string;
            };
            recurrence: string[];
        };
        disableEmails?: boolean;
        organizerLocale?: string;
    }>;
    error?: {
        message: string;
        type: NotificationType | undefined;
        category: ErrorCategory | undefined;
        title: string;
    };
    schedulerConfigChanged: EventEmitter<SchedulerGroupEventDetail & {
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    schedulerConfigCreated: EventEmitter<SchedulerGroupEventDetail & {
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    cancelButtonClick: EventEmitter<void>;
    formSubmitted: EventEmitter<void>;
    previewButtonClicked: EventEmitter<HTMLNylasEditorTabsGroupElement>;
    schedulerEditorFormUpdated: EventEmitter<{
        value: string;
        name: string;
    }>;
    groupEventCreateTriggered: EventEmitter<{
        groupEvent: Partial<GroupEvent>;
        configId: string;
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    groupEventUpdateTriggered: EventEmitter<{
        groupEvent: GroupEvent;
        chosenOption: RecurrenceUpdateOption;
        configId: string;
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    groupEventDeleteTriggered: EventEmitter<{
        groupEvent: GroupEvent;
        chosenOption: RecurrenceDeleteOption;
        configId: string;
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    groupEventImportTriggered: EventEmitter<{
        groupEvent: ImportGroupEventDetails;
        configId: string;
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    saveGroupEventChangesError: EventEmitter<{
        error: string;
        configId: string;
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    readonly nylasSchedulerError: EventEmitter<{
        notification: Notification;
        host: HTMLElement;
    }>;
    dismissNotification: EventEmitter<{
        id: string;
        host: HTMLNylasEditorTabsGroupElement;
    }>;
    configChangedHandler(newConfig: GroupConfiguration): void;
    selectedGroupEventChangedHandler(newConfig: GroupEventAPIData): void;
    userChangedHandler(newUser: User): void;
    selectedLanguageChangedHandler(newVal: LANGUAGE_CODE, oldVal: LANGUAGE_CODE): void;
    schedulerConfigCreatedEventHandler(data: SchedulerGroupEventDetail & {
        host: HTMLNylasEditorTabsGroupElement;
    }): Promise<CustomEvent<SchedulerGroupEventDetail & {
        host: HTMLNylasEditorTabsGroupElement;
    }>>;
    setError(error: {
        message: string;
        type: NotificationType;
        category: ErrorCategory;
        title: string;
    }): Promise<void>;
    resetError(): Promise<void>;
    connectedCallback(): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    disconnectedCallback(): void;
    handleValueChanged(event: CustomEvent): void;
    feedbackModalClosedHandler(): void;
    feedbackSubmittedHandler(event: CustomEvent<{
        feedback: string;
    }>): void;
    importGroupEventHandler(event: CustomEvent<ImportGroupEventDetails>): void;
    saveGroupEventChangesHandler(event: CustomEvent<{
        data: GroupEventAPIData;
        action: RecurrenceUpdateOption;
    }>): void;
    deleteGroupEventHandler(event: CustomEvent<{
        data: GroupEventAPIData;
        action: RecurrenceDeleteOption;
    }>): void;
    createGroupEventHandler(event: CustomEvent<CreateGroupEventFormState>): void;
    showErrorNotification(error: {
        message: string;
        type: NotificationType | undefined;
        category: ErrorCategory | undefined;
        title: string;
    }): void;
    getGroupEventDetailsFromFormState(): any;
    getFormStateFromConfig(config?: GroupConfiguration): {
        additionalFields: Record<string, AdditionalFields>;
        bookingType: BookingType;
        cancellationPolicy: string;
        minCancellationNotice: number;
        minBookingNotice: number;
        hideCancellationOptions: boolean;
        hideReschedulingOptions: boolean;
        reminders: EventReminder[] | undefined;
        emailTemplate: EmailTemplate | undefined;
        redirectUrl: string | undefined;
        slug: string | undefined;
        appearance: Appearance | undefined;
        name: string | undefined;
        bookingCalendar: string | undefined;
        disableEmails: boolean | undefined;
        organizerLocale: string | undefined;
    };
    setFormState(value: any, key: any): void;
    updateFormState(): Partial<{
        title: string;
        description: string;
        participants: {
            name: string;
            email: string;
            is_organizer?: boolean | undefined;
        }[];
        additionalFields?: Record<string, AdditionalFields> | undefined;
        bookingCalendar?: string | undefined;
        location?: string | undefined;
        conferencing?: Conference | undefined;
        bookingType?: string | undefined;
        cancellationPolicy?: string | undefined;
        minCancellationNotice?: number | undefined;
        minBookingNotice?: number | undefined;
        hideCancellationOptions?: boolean | undefined;
        hideReschedulingOptions?: boolean | undefined;
        reminders?: EventReminder[] | undefined;
        emailTemplate?: EmailTemplate | undefined;
        redirectUrl?: string | undefined;
        slug: string;
        appearance: Appearance;
        name: string;
        eventCapacity: number;
        eventTimeslot: {
            when: {
                start_time: number;
                end_time: number;
                start_timezone: string;
                end_timezone: string;
            };
            recurrence: string[];
        };
        disableEmails?: boolean | undefined;
        organizerLocale?: string | undefined;
    }>;
    setActiveTab(e: Event, tabName: TabGroup): void;
    formSubmissionHandler: (event: Event) => Promise<void>;
    checkForBookingFormErrors: (config: any) => boolean;
    hideTab(tab: TabGroup): boolean;
    onFeedbackClick(e: Event): void;
    render(): any;
}
