import { EventEmitter } from '../../../stencil-public-runtime';
import { Calendar } from '@fullcalendar/core';
import { LANGUAGE_CODE } from "../../../common/constants";
import { Conference, EventDetails, GroupConfiguration, GroupEventAPIData, NylasCalendar } from '@nylas/core';
import { User } from "../../../common/nylas-api-request";
export type CreateGroupEventFormState = {
    title: string;
    description: string;
    location: string;
    eventTimeslot: {
        when: {
            start_time: number;
            end_time: number;
            start_timezone: string;
            end_timezone: string;
        };
        recurrence: string[];
    };
    eventCapacity: number;
    conferencing?: Conference;
    participants: {
        name: string;
        email: string;
        is_organizer?: boolean;
    }[];
};
export declare class NylasEventCalendar {
    host: HTMLNylasEventCalendarElement;
    private calendarEl;
    private formRef;
    selectedConfiguration?: GroupConfiguration;
    name: string;
    selectedLanguage?: LANGUAGE_CODE;
    groupEvents?: GroupEventAPIData[];
    currentUser?: User;
    calendars?: NylasCalendar[];
    masterGroupEvents?: Record<string, EventDetails>;
    isLoading?: boolean;
    internals: ElementInternals;
    selectedView: 'day' | 'week' | 'month';
    events: {
        title: string;
        start: string;
        end: string;
        calendar_id: string;
        id: string;
        classNames: string[];
    }[];
    calendar: Calendar;
    selectedEvent: GroupEventAPIData | null;
    selectedDateRangeString: string;
    showEditEventDetails: boolean;
    showCreateEventDetails: boolean;
    editOptionChoices: {
        label: string;
        value: string;
        langKey: string;
    }[];
    updateOptionChoices: {
        label: string;
        value: 'this' | 'future' | 'all';
        langKey: string;
    }[];
    deleteOptionChoices: {
        label: string;
        value: string;
        langKey: string;
    }[];
    editOptions: {
        label: string;
        value: string;
    }[];
    showEditOptions: boolean;
    updateOptions: {
        label: string;
        value: 'this' | 'future' | 'all';
    }[];
    showUpdateOptions: boolean;
    deleteOptions: {
        label: string;
        value: string;
    }[];
    showDeleteOptions: boolean;
    unsavedChanges: boolean;
    showConfirmDiscardUnsavedChangesModal: boolean;
    createNewGroupEventTimeslot: {
        when: {
            start_time: number;
            end_time: number;
            start_timezone: string;
            end_timezone: string;
        };
        recurrence: string[];
    } | null;
    formError: string;
    formErrors: Record<string, string>;
    loadingOptions: {
        update: string;
        delete: string;
        create: string;
    };
    showChooseParticipantsModal: boolean;
    importParticipants: {
        label: string;
        value: string;
        disabled?: boolean;
    }[];
    selectedImportParticipants: {
        email: string;
        status: string;
    }[];
    showAllEvents: boolean;
    fetchMasterGroupEvent: EventEmitter<string>;
    saveGroupEventChanges: EventEmitter<{
        data: GroupEventAPIData;
        action: 'this' | 'future' | 'all';
    }>;
    deleteGroupEvent: EventEmitter<{
        data: GroupEventAPIData;
        action: 'this' | 'future' | 'all';
    }>;
    groupEventSelected: EventEmitter<GroupEventAPIData>;
    createGroupEvent: EventEmitter<CreateGroupEventFormState>;
    calendarViewChanged: EventEmitter<{
        startTime: number;
        endTime: number;
    }>;
    previosNextClicked: EventEmitter<{
        direction: 'prev' | 'next';
        view: 'day' | 'week' | 'month';
        currentViewRange: {
            startTime: number;
            endTime: number;
        };
    }>;
    setCalendarViewDateRange: EventEmitter<{
        startTime: number;
        endTime: number;
    }>;
    importGroupEvent: EventEmitter<{
        event_id: string;
        calendar_id: string;
    }>;
    elementNameChangedHandler(newValue: string): void;
    createCustomLocaleConfig(lang: LANGUAGE_CODE): {
        code: LANGUAGE_CODE;
        buttonText: {
            today: string;
            month: string;
            week: string;
            day: string;
        };
        allDayText: string;
    };
    selectedLanguageChangedHandler(newVal: LANGUAGE_CODE, oldVal: LANGUAGE_CODE): void;
    private updateOptionTranslations;
    groupEventsChangedHandler(newValue: GroupEventAPIData[], oldValue: GroupEventAPIData[]): void;
    connectedCallback(): void;
    disconnectedCallback(): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    private observeCalendarRendering;
    private injectScrollStyles;
    private forceBrowserScrollToTime;
    setView(view: 'day' | 'week' | 'month'): void;
    dayHeaderContent(headerInfo: any): {
        html: string;
    };
    handleEditOptionSelected(e: Event, option: {
        label: string;
        value: string;
    }): void;
    handleImportGroupEvent(): void;
    handlePrevNextClick(direction: 'prev' | 'next'): void;
    handleUpdateGroupEvent(e: Event, option: {
        label: string;
        value: 'this' | 'future' | 'all';
    }): void;
    handleDeleteGroupEvent(e: Event, option: {
        label: string;
        value: string;
    }): void;
    handleCreateGroupEvent(e: Event): Promise<void>;
    isLoadingChangedHandler(newVal: boolean, _oldVal: boolean): void;
    valueChangedHandler(event: CustomEvent<{
        value: string;
        name: string;
    }>): void;
    timeWindowFormErrorHandler(event: CustomEvent<{
        key: string;
        message: string;
        uniqueIdentifier?: string;
    }>): void;
    dateTimeInputErrorHandler(event: CustomEvent<{
        key: string;
        message: string;
    }>): void;
    saveGroupEventChangesErrorHandler(event: CustomEvent<{
        error: string;
    }>): void;
    selectedOptionsChangedHandler(event: CustomEvent<{
        value: string[];
        name: string;
    }>): void;
    nylasCheckboxGroupChangedHandler(event: CustomEvent<{
        selectedValues: string[];
        name: string;
    }>): void;
    render(): any;
}
