import { EventEmitter } from '../../../stencil-public-runtime';
import { LANGUAGE_CODE } from "../../../common/constants";
import { User } from "../../../common/nylas-api-request";
type RepeatEndType = 'never' | 'on' | 'after';
type RecurrenceType = 'none' | 'daily' | 'weekly' | 'monthly' | 'yearly' | 'custom';
export declare class NylasEventTimeslot {
    host: HTMLNylasEventTimeslotElement;
    name: string;
    initialValue?: {
        when: {
            start_time: number;
            end_time: number;
            start_timezone: string;
            end_timezone: string;
        };
        recurrence: string[];
    };
    selectedLanguage?: LANGUAGE_CODE;
    currentUser?: User;
    selectedDate: string;
    selectedStartTime: string;
    selectedEndTime: string;
    selectedTimezone: string;
    selectedRecurrenceType: RecurrenceType;
    timeRangeError: boolean;
    selectedRrule: string | null;
    recurrenceOptions: {
        label: string;
        value: string;
    }[];
    repeatEveryInterval: number;
    repeatEveryFrequency: string;
    repeatOnDays: string[];
    repeatMonthlySameDate: boolean;
    repeatEndType: RepeatEndType;
    repeatEndAfter: number;
    repeatEndOn: string | undefined;
    monthRecurrenceOptions: {
        label: string;
        value: string;
    }[];
    endDate: string | undefined;
    hasDateTimeInputError: boolean;
    internals: ElementInternals;
    valueChanged: EventEmitter<{
        value: string;
        name: string;
    }>;
    timeWindowFormError: EventEmitter<{
        key: string;
        message: string;
        uniqueIdentifier?: string;
    }>;
    dateTimeInputError: EventEmitter<{
        key: string;
        message: string;
    }>;
    connectedCallback(): void;
    disconnectedCallback(): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    elementNameChangedHandler(newValue: string): void;
    selectedLanguageChangedHandler(newVal: LANGUAGE_CODE, oldVal: LANGUAGE_CODE): void;
    getOrdinalSuffix(n: any): string;
    getRecurrenceTypeFromRrule(rrule: string): RecurrenceType | undefined;
    generateRecurrenceOptions(selectedDate: string, timezoneStr: string): {
        label: string;
        value: string;
    }[];
    getMonthRecurrenceOptions(selectedDate: string, timezoneStr: string): {
        label: string;
        value: string;
    }[];
    getSuggestedTime(): {
        startTime: string;
        endTime: string;
    };
    getTimezoneLabelHTML(timezone: string): any;
    isStartTimeAfterEndTime(startTime: string, endTime: string): boolean;
    isStartTimeEqualToEndTime(startTime: string, endTime: string): boolean;
    isStartTimeBeforeCurrentDate(date: string, startTime: string, timezone: string): boolean;
    validateDateTimeInput(date: string, startTime: string, timezone: string): {
        isValid: boolean;
        errorMessage: string;
    };
    getStartAndEndTimes(): {
        start_time: number;
        end_time: number;
    };
    getCustomOptions(): {
        frequency: any;
        interval: number;
        daysOfWeek: string[] | undefined;
        monthlySameDate: boolean | undefined;
        end: {
            type: RepeatEndType;
            count: number | undefined;
            date: string | undefined;
        };
    } | undefined;
    handleValueChanged(noValue?: boolean): void;
    setTime(event: CustomEvent<{
        key: string;
        value: string;
    }>): void;
    nylasFormDropdownChangedHandler(event: CustomEvent<{
        value: RecurrenceType | RepeatEndType | string;
        name: string;
    }>): void;
    nylasFormInputChangedHandler(event: CustomEvent<{
        value: string;
        name: string;
        error?: string;
    }>): void;
    timePeriodChangedHandler(event: CustomEvent<{
        number: number;
        period: 'day' | 'week' | 'month' | 'year';
    }>): void;
    render(): any;
}
export {};
