import { NylasApiRequest } from '../../../common/nylas-api-request';
import { NylasSchedulerConfigStoreType } from "../../../stores/scheduler-config-store";
import { Calendar, Configuration, EventDetails, GroupConfiguration, GroupEvent, GroupEventAPIData, ImportGroupEventDetails, ImportGroupEventResponse, RecurrenceDeleteOption, RecurrenceUpdateOption } from '@nylas/core';
type NylasSchedulerConfigAPIConnectorOptions = {
    nylasApiRequest?: NylasApiRequest;
    nylasSchedulerConfigStore: NylasSchedulerConfigStoreType;
};
export declare class NylasSchedulerConfigAPIConnector {
    private nylasApiRequest?;
    private nylasSchedulerConfigStore;
    private groupEventsCache;
    private readonly CACHE_DURATION;
    constructor({ nylasApiRequest, nylasSchedulerConfigStore }: NylasSchedulerConfigAPIConnectorOptions);
    currentUser(): Promise<import("../../../common/nylas-api-request").User | null>;
    getCalendars(): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [Calendar[], null]>;
    getConfigurationById(configurationId: string, forceFetch?: boolean): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [Configuration, null]>;
    getConfigurations(cursor?: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [Configuration[], null]>;
    getMasterEventById(masterEventId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [EventDetails, null]>;
    createConfiguration(configuration: Omit<Partial<Configuration>, 'id'>): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [Configuration, null]>;
    updateConfiguration(configuration: Partial<Configuration>): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [Configuration, null]>;
    deleteConfiguration(configurationId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [Configuration, null]>;
    createGroupEvent(eventDetails: Omit<Partial<GroupEvent>, 'id'>, configurationId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [GroupEventAPIData, null]>;
    getGroupEvents(configurationId: string, selectedConfiguration: Configuration | GroupConfiguration): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [GroupEventAPIData[], null]>;
    private cleanupExpiredCache;
    updateGroupEventById(groupEventDetails: Partial<GroupEvent>, configurationId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [GroupEventAPIData, null]>;
    updateGroupEvent(groupEventDetails: GroupEvent, chosenOption: RecurrenceUpdateOption, configurationId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [GroupEventAPIData, null] | ([null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [GroupEventAPIData, null] | {
        location: string | undefined;
        conferencing: {
            provider: import("@nylas/core").ConferenceProvider;
            details: {
                meeting_code: string;
                url: string;
                pin: string;
                phone: string[];
            };
        };
        title: string;
        description: string | undefined;
        capacity: number | undefined;
        calendar_id: string;
        recurrence: string[];
    })[]>;
    deleteGroupEvent(_groupEventDetails: GroupEvent, chosenOption: RecurrenceDeleteOption, configurationId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [GroupEventAPIData, null]>;
    deleteGroupEventById(groupEventId: string, configurationId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [GroupEventAPIData, null]>;
    importGroupEvent(groupEventDetails: ImportGroupEventDetails[], configurationId: string): Promise<[null, {
        type?: string | undefined;
        code?: string | number | undefined;
        title?: string | undefined;
        message?: string | undefined;
        provider_error?: {
            error: Record<string, any>;
        } | undefined;
    }] | [null, null] | [ImportGroupEventResponse, null]>;
}
export {};
