import { AdditionalParticipant, Calendar, Configuration, EventDetails, GroupConfiguration, GroupEventAPIData, EnableEventTypes } from '@nylas/core';
import { ObservableMap } from '@stencil/store';
import { User } from '../common/nylas-api-request';
import { CONFIGURATION_EVENT_TYPE, EXPERIMENTAL_FEATURES } from "../common/constants";
type RecursivePartial<T> = {
    [P in keyof T]?: T[P] extends (infer U)[] ? RecursivePartial<U>[] : T[P] extends object | undefined ? RecursivePartial<T[P]> : T[P];
};
export interface NylasSchedulerConfigStoreState {
    selectedConfiguration: RecursivePartial<Configuration> | RecursivePartial<GroupConfiguration>;
    configurations: Configuration[];
    calendars: Calendar[];
    currentUser: User | null;
    action: 'create' | 'create-select' | 'edit' | null;
    additionalParticipants: AdditionalParticipant[];
    listConfigurationsNextCursor: string | null;
    conferenceProviders?: Record<'microsoft' | 'zoom' | 'google', string>;
    requiresSlug: boolean;
    selectedLanguage?: string;
    nylasBranding?: boolean;
    experimentalFeatures?: Record<EXPERIMENTAL_FEATURES, boolean>;
    enableEventTypes?: EnableEventTypes;
    selectedEventType?: CONFIGURATION_EVENT_TYPE;
    groupEvents: GroupEventAPIData[];
    selectedGroupEvent?: GroupEventAPIData;
    calendarViewDateRange?: {
        start_time: string;
        end_time: string;
    };
    masterGroupEvents: Record<string, EventDetails>;
    isLoading: boolean;
}
export type NylasSchedulerConfigStoreType = ReturnType<typeof CreateNylasSchedulerConfigStore>;
export type CreateNylasSchedulerConfigStoreReturnType = ObservableMap<NylasSchedulerConfigStoreState> & {
    resetSelectedConfiguration: () => void;
};
export declare function CreateNylasSchedulerConfigStore(defaultState?: Partial<NylasSchedulerConfigStoreState>): CreateNylasSchedulerConfigStoreReturnType;
export {};
