const global$1 = (typeof global !== "undefined" ? global :
  typeof self !== "undefined" ? self :
  typeof window !== "undefined" ? window : {});

var lookup = [];
var revLookup = [];
var Arr = typeof Uint8Array !== 'undefined' ? Uint8Array : Array;
var inited = false;
function init () {
  inited = true;
  var code = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
  for (var i = 0, len = code.length; i < len; ++i) {
    lookup[i] = code[i];
    revLookup[code.charCodeAt(i)] = i;
  }

  revLookup['-'.charCodeAt(0)] = 62;
  revLookup['_'.charCodeAt(0)] = 63;
}

function toByteArray (b64) {
  if (!inited) {
    init();
  }
  var i, j, l, tmp, placeHolders, arr;
  var len = b64.length;

  if (len % 4 > 0) {
    throw new Error('Invalid string. Length must be a multiple of 4')
  }

  // the number of equal signs (place holders)
  // if there are two placeholders, than the two characters before it
  // represent one byte
  // if there is only one, then the three characters before it represent 2 bytes
  // this is just a cheap hack to not do indexOf twice
  placeHolders = b64[len - 2] === '=' ? 2 : b64[len - 1] === '=' ? 1 : 0;

  // base64 is 4/3 + up to two characters of the original data
  arr = new Arr(len * 3 / 4 - placeHolders);

  // if there are placeholders, only get up to the last complete 4 chars
  l = placeHolders > 0 ? len - 4 : len;

  var L = 0;

  for (i = 0, j = 0; i < l; i += 4, j += 3) {
    tmp = (revLookup[b64.charCodeAt(i)] << 18) | (revLookup[b64.charCodeAt(i + 1)] << 12) | (revLookup[b64.charCodeAt(i + 2)] << 6) | revLookup[b64.charCodeAt(i + 3)];
    arr[L++] = (tmp >> 16) & 0xFF;
    arr[L++] = (tmp >> 8) & 0xFF;
    arr[L++] = tmp & 0xFF;
  }

  if (placeHolders === 2) {
    tmp = (revLookup[b64.charCodeAt(i)] << 2) | (revLookup[b64.charCodeAt(i + 1)] >> 4);
    arr[L++] = tmp & 0xFF;
  } else if (placeHolders === 1) {
    tmp = (revLookup[b64.charCodeAt(i)] << 10) | (revLookup[b64.charCodeAt(i + 1)] << 4) | (revLookup[b64.charCodeAt(i + 2)] >> 2);
    arr[L++] = (tmp >> 8) & 0xFF;
    arr[L++] = tmp & 0xFF;
  }

  return arr
}

function tripletToBase64 (num) {
  return lookup[num >> 18 & 0x3F] + lookup[num >> 12 & 0x3F] + lookup[num >> 6 & 0x3F] + lookup[num & 0x3F]
}

function encodeChunk (uint8, start, end) {
  var tmp;
  var output = [];
  for (var i = start; i < end; i += 3) {
    tmp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2]);
    output.push(tripletToBase64(tmp));
  }
  return output.join('')
}

function fromByteArray (uint8) {
  if (!inited) {
    init();
  }
  var tmp;
  var len = uint8.length;
  var extraBytes = len % 3; // if we have 1 byte left, pad 2 bytes
  var output = '';
  var parts = [];
  var maxChunkLength = 16383; // must be multiple of 3

  // go through the array every three bytes, we'll deal with trailing stuff later
  for (var i = 0, len2 = len - extraBytes; i < len2; i += maxChunkLength) {
    parts.push(encodeChunk(uint8, i, (i + maxChunkLength) > len2 ? len2 : (i + maxChunkLength)));
  }

  // pad the end with zeros, but make sure to not forget the extra bytes
  if (extraBytes === 1) {
    tmp = uint8[len - 1];
    output += lookup[tmp >> 2];
    output += lookup[(tmp << 4) & 0x3F];
    output += '==';
  } else if (extraBytes === 2) {
    tmp = (uint8[len - 2] << 8) + (uint8[len - 1]);
    output += lookup[tmp >> 10];
    output += lookup[(tmp >> 4) & 0x3F];
    output += lookup[(tmp << 2) & 0x3F];
    output += '=';
  }

  parts.push(output);

  return parts.join('')
}

function read (buffer, offset, isLE, mLen, nBytes) {
  var e, m;
  var eLen = nBytes * 8 - mLen - 1;
  var eMax = (1 << eLen) - 1;
  var eBias = eMax >> 1;
  var nBits = -7;
  var i = isLE ? (nBytes - 1) : 0;
  var d = isLE ? -1 : 1;
  var s = buffer[offset + i];

  i += d;

  e = s & ((1 << (-nBits)) - 1);
  s >>= (-nBits);
  nBits += eLen;
  for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8) {}

  m = e & ((1 << (-nBits)) - 1);
  e >>= (-nBits);
  nBits += mLen;
  for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8) {}

  if (e === 0) {
    e = 1 - eBias;
  } else if (e === eMax) {
    return m ? NaN : ((s ? -1 : 1) * Infinity)
  } else {
    m = m + Math.pow(2, mLen);
    e = e - eBias;
  }
  return (s ? -1 : 1) * m * Math.pow(2, e - mLen)
}

function write (buffer, value, offset, isLE, mLen, nBytes) {
  var e, m, c;
  var eLen = nBytes * 8 - mLen - 1;
  var eMax = (1 << eLen) - 1;
  var eBias = eMax >> 1;
  var rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0);
  var i = isLE ? 0 : (nBytes - 1);
  var d = isLE ? 1 : -1;
  var s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0;

  value = Math.abs(value);

  if (isNaN(value) || value === Infinity) {
    m = isNaN(value) ? 1 : 0;
    e = eMax;
  } else {
    e = Math.floor(Math.log(value) / Math.LN2);
    if (value * (c = Math.pow(2, -e)) < 1) {
      e--;
      c *= 2;
    }
    if (e + eBias >= 1) {
      value += rt / c;
    } else {
      value += rt * Math.pow(2, 1 - eBias);
    }
    if (value * c >= 2) {
      e++;
      c /= 2;
    }

    if (e + eBias >= eMax) {
      m = 0;
      e = eMax;
    } else if (e + eBias >= 1) {
      m = (value * c - 1) * Math.pow(2, mLen);
      e = e + eBias;
    } else {
      m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen);
      e = 0;
    }
  }

  for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8) {}

  e = (e << mLen) | m;
  eLen += mLen;
  for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8) {}

  buffer[offset + i - d] |= s * 128;
}

var toString = {}.toString;

var isArray$1 = Array.isArray || function (arr) {
  return toString.call(arr) == '[object Array]';
};

/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * @license  MIT
 */

var INSPECT_MAX_BYTES = 50;

/**
 * If `Buffer.TYPED_ARRAY_SUPPORT`:
 *   === true    Use Uint8Array implementation (fastest)
 *   === false   Use Object implementation (most compatible, even IE6)
 *
 * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
 * Opera 11.6+, iOS 4.2+.
 *
 * Due to various browser bugs, sometimes the Object implementation will be used even
 * when the browser supports typed arrays.
 *
 * Note:
 *
 *   - Firefox 4-29 lacks support for adding new properties to `Uint8Array` instances,
 *     See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
 *
 *   - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
 *
 *   - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
 *     incorrect length in some situations.

 * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they
 * get the Object implementation, which is slower but behaves correctly.
 */
Buffer.TYPED_ARRAY_SUPPORT = global$1.TYPED_ARRAY_SUPPORT !== undefined
  ? global$1.TYPED_ARRAY_SUPPORT
  : true;

function kMaxLength () {
  return Buffer.TYPED_ARRAY_SUPPORT
    ? 0x7fffffff
    : 0x3fffffff
}

function createBuffer (that, length) {
  if (kMaxLength() < length) {
    throw new RangeError('Invalid typed array length')
  }
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Return an augmented `Uint8Array` instance, for best performance
    that = new Uint8Array(length);
    that.__proto__ = Buffer.prototype;
  } else {
    // Fallback: Return an object instance of the Buffer class
    if (that === null) {
      that = new Buffer(length);
    }
    that.length = length;
  }

  return that
}

/**
 * The Buffer constructor returns instances of `Uint8Array` that have their
 * prototype changed to `Buffer.prototype`. Furthermore, `Buffer` is a subclass of
 * `Uint8Array`, so the returned instances will have all the node `Buffer` methods
 * and the `Uint8Array` methods. Square bracket notation works as expected -- it
 * returns a single octet.
 *
 * The `Uint8Array` prototype remains unmodified.
 */

function Buffer (arg, encodingOrOffset, length) {
  if (!Buffer.TYPED_ARRAY_SUPPORT && !(this instanceof Buffer)) {
    return new Buffer(arg, encodingOrOffset, length)
  }

  // Common case.
  if (typeof arg === 'number') {
    if (typeof encodingOrOffset === 'string') {
      throw new Error(
        'If encoding is specified then the first argument must be a string'
      )
    }
    return allocUnsafe(this, arg)
  }
  return from(this, arg, encodingOrOffset, length)
}

Buffer.poolSize = 8192; // not used by this implementation

// TODO: Legacy, not needed anymore. Remove in next major version.
Buffer._augment = function (arr) {
  arr.__proto__ = Buffer.prototype;
  return arr
};

function from (that, value, encodingOrOffset, length) {
  if (typeof value === 'number') {
    throw new TypeError('"value" argument must not be a number')
  }

  if (typeof ArrayBuffer !== 'undefined' && value instanceof ArrayBuffer) {
    return fromArrayBuffer(that, value, encodingOrOffset, length)
  }

  if (typeof value === 'string') {
    return fromString(that, value, encodingOrOffset)
  }

  return fromObject(that, value)
}

/**
 * Functionally equivalent to Buffer(arg, encoding) but throws a TypeError
 * if value is a number.
 * Buffer.from(str[, encoding])
 * Buffer.from(array)
 * Buffer.from(buffer)
 * Buffer.from(arrayBuffer[, byteOffset[, length]])
 **/
Buffer.from = function (value, encodingOrOffset, length) {
  return from(null, value, encodingOrOffset, length)
};

if (Buffer.TYPED_ARRAY_SUPPORT) {
  Buffer.prototype.__proto__ = Uint8Array.prototype;
  Buffer.__proto__ = Uint8Array;
}

function assertSize (size) {
  if (typeof size !== 'number') {
    throw new TypeError('"size" argument must be a number')
  } else if (size < 0) {
    throw new RangeError('"size" argument must not be negative')
  }
}

function alloc (that, size, fill, encoding) {
  assertSize(size);
  if (size <= 0) {
    return createBuffer(that, size)
  }
  if (fill !== undefined) {
    // Only pay attention to encoding if it's a string. This
    // prevents accidentally sending in a number that would
    // be interpretted as a start offset.
    return typeof encoding === 'string'
      ? createBuffer(that, size).fill(fill, encoding)
      : createBuffer(that, size).fill(fill)
  }
  return createBuffer(that, size)
}

/**
 * Creates a new filled Buffer instance.
 * alloc(size[, fill[, encoding]])
 **/
Buffer.alloc = function (size, fill, encoding) {
  return alloc(null, size, fill, encoding)
};

function allocUnsafe (that, size) {
  assertSize(size);
  that = createBuffer(that, size < 0 ? 0 : checked(size) | 0);
  if (!Buffer.TYPED_ARRAY_SUPPORT) {
    for (var i = 0; i < size; ++i) {
      that[i] = 0;
    }
  }
  return that
}

/**
 * Equivalent to Buffer(num), by default creates a non-zero-filled Buffer instance.
 * */
Buffer.allocUnsafe = function (size) {
  return allocUnsafe(null, size)
};
/**
 * Equivalent to SlowBuffer(num), by default creates a non-zero-filled Buffer instance.
 */
Buffer.allocUnsafeSlow = function (size) {
  return allocUnsafe(null, size)
};

function fromString (that, string, encoding) {
  if (typeof encoding !== 'string' || encoding === '') {
    encoding = 'utf8';
  }

  if (!Buffer.isEncoding(encoding)) {
    throw new TypeError('"encoding" must be a valid string encoding')
  }

  var length = byteLength(string, encoding) | 0;
  that = createBuffer(that, length);

  var actual = that.write(string, encoding);

  if (actual !== length) {
    // Writing a hex string, for example, that contains invalid characters will
    // cause everything after the first invalid character to be ignored. (e.g.
    // 'abxxcd' will be treated as 'ab')
    that = that.slice(0, actual);
  }

  return that
}

function fromArrayLike (that, array) {
  var length = array.length < 0 ? 0 : checked(array.length) | 0;
  that = createBuffer(that, length);
  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255;
  }
  return that
}

function fromArrayBuffer (that, array, byteOffset, length) {

  if (byteOffset < 0 || array.byteLength < byteOffset) {
    throw new RangeError('\'offset\' is out of bounds')
  }

  if (array.byteLength < byteOffset + (length || 0)) {
    throw new RangeError('\'length\' is out of bounds')
  }

  if (byteOffset === undefined && length === undefined) {
    array = new Uint8Array(array);
  } else if (length === undefined) {
    array = new Uint8Array(array, byteOffset);
  } else {
    array = new Uint8Array(array, byteOffset, length);
  }

  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Return an augmented `Uint8Array` instance, for best performance
    that = array;
    that.__proto__ = Buffer.prototype;
  } else {
    // Fallback: Return an object instance of the Buffer class
    that = fromArrayLike(that, array);
  }
  return that
}

function fromObject (that, obj) {
  if (internalIsBuffer(obj)) {
    var len = checked(obj.length) | 0;
    that = createBuffer(that, len);

    if (that.length === 0) {
      return that
    }

    obj.copy(that, 0, 0, len);
    return that
  }

  if (obj) {
    if ((typeof ArrayBuffer !== 'undefined' &&
        obj.buffer instanceof ArrayBuffer) || 'length' in obj) {
      if (typeof obj.length !== 'number' || isnan(obj.length)) {
        return createBuffer(that, 0)
      }
      return fromArrayLike(that, obj)
    }

    if (obj.type === 'Buffer' && isArray$1(obj.data)) {
      return fromArrayLike(that, obj.data)
    }
  }

  throw new TypeError('First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.')
}

function checked (length) {
  // Note: cannot use `length < kMaxLength()` here because that fails when
  // length is NaN (which is otherwise coerced to zero.)
  if (length >= kMaxLength()) {
    throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
                         'size: 0x' + kMaxLength().toString(16) + ' bytes')
  }
  return length | 0
}
Buffer.isBuffer = isBuffer;
function internalIsBuffer (b) {
  return !!(b != null && b._isBuffer)
}

Buffer.compare = function compare (a, b) {
  if (!internalIsBuffer(a) || !internalIsBuffer(b)) {
    throw new TypeError('Arguments must be Buffers')
  }

  if (a === b) return 0

  var x = a.length;
  var y = b.length;

  for (var i = 0, len = Math.min(x, y); i < len; ++i) {
    if (a[i] !== b[i]) {
      x = a[i];
      y = b[i];
      break
    }
  }

  if (x < y) return -1
  if (y < x) return 1
  return 0
};

Buffer.isEncoding = function isEncoding (encoding) {
  switch (String(encoding).toLowerCase()) {
    case 'hex':
    case 'utf8':
    case 'utf-8':
    case 'ascii':
    case 'latin1':
    case 'binary':
    case 'base64':
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      return true
    default:
      return false
  }
};

Buffer.concat = function concat (list, length) {
  if (!isArray$1(list)) {
    throw new TypeError('"list" argument must be an Array of Buffers')
  }

  if (list.length === 0) {
    return Buffer.alloc(0)
  }

  var i;
  if (length === undefined) {
    length = 0;
    for (i = 0; i < list.length; ++i) {
      length += list[i].length;
    }
  }

  var buffer = Buffer.allocUnsafe(length);
  var pos = 0;
  for (i = 0; i < list.length; ++i) {
    var buf = list[i];
    if (!internalIsBuffer(buf)) {
      throw new TypeError('"list" argument must be an Array of Buffers')
    }
    buf.copy(buffer, pos);
    pos += buf.length;
  }
  return buffer
};

function byteLength (string, encoding) {
  if (internalIsBuffer(string)) {
    return string.length
  }
  if (typeof ArrayBuffer !== 'undefined' && typeof ArrayBuffer.isView === 'function' &&
      (ArrayBuffer.isView(string) || string instanceof ArrayBuffer)) {
    return string.byteLength
  }
  if (typeof string !== 'string') {
    string = '' + string;
  }

  var len = string.length;
  if (len === 0) return 0

  // Use a for loop to avoid recursion
  var loweredCase = false;
  for (;;) {
    switch (encoding) {
      case 'ascii':
      case 'latin1':
      case 'binary':
        return len
      case 'utf8':
      case 'utf-8':
      case undefined:
        return utf8ToBytes(string).length
      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return len * 2
      case 'hex':
        return len >>> 1
      case 'base64':
        return base64ToBytes(string).length
      default:
        if (loweredCase) return utf8ToBytes(string).length // assume utf8
        encoding = ('' + encoding).toLowerCase();
        loweredCase = true;
    }
  }
}
Buffer.byteLength = byteLength;

function slowToString (encoding, start, end) {
  var loweredCase = false;

  // No need to verify that "this.length <= MAX_UINT32" since it's a read-only
  // property of a typed array.

  // This behaves neither like String nor Uint8Array in that we set start/end
  // to their upper/lower bounds if the value passed is out of range.
  // undefined is handled specially as per ECMA-262 6th Edition,
  // Section 13.3.3.7 Runtime Semantics: KeyedBindingInitialization.
  if (start === undefined || start < 0) {
    start = 0;
  }
  // Return early if start > this.length. Done here to prevent potential uint32
  // coercion fail below.
  if (start > this.length) {
    return ''
  }

  if (end === undefined || end > this.length) {
    end = this.length;
  }

  if (end <= 0) {
    return ''
  }

  // Force coersion to uint32. This will also coerce falsey/NaN values to 0.
  end >>>= 0;
  start >>>= 0;

  if (end <= start) {
    return ''
  }

  if (!encoding) encoding = 'utf8';

  while (true) {
    switch (encoding) {
      case 'hex':
        return hexSlice(this, start, end)

      case 'utf8':
      case 'utf-8':
        return utf8Slice(this, start, end)

      case 'ascii':
        return asciiSlice(this, start, end)

      case 'latin1':
      case 'binary':
        return latin1Slice(this, start, end)

      case 'base64':
        return base64Slice(this, start, end)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return utf16leSlice(this, start, end)

      default:
        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
        encoding = (encoding + '').toLowerCase();
        loweredCase = true;
    }
  }
}

// The property is used by `Buffer.isBuffer` and `is-buffer` (in Safari 5-7) to detect
// Buffer instances.
Buffer.prototype._isBuffer = true;

function swap (b, n, m) {
  var i = b[n];
  b[n] = b[m];
  b[m] = i;
}

Buffer.prototype.swap16 = function swap16 () {
  var len = this.length;
  if (len % 2 !== 0) {
    throw new RangeError('Buffer size must be a multiple of 16-bits')
  }
  for (var i = 0; i < len; i += 2) {
    swap(this, i, i + 1);
  }
  return this
};

Buffer.prototype.swap32 = function swap32 () {
  var len = this.length;
  if (len % 4 !== 0) {
    throw new RangeError('Buffer size must be a multiple of 32-bits')
  }
  for (var i = 0; i < len; i += 4) {
    swap(this, i, i + 3);
    swap(this, i + 1, i + 2);
  }
  return this
};

Buffer.prototype.swap64 = function swap64 () {
  var len = this.length;
  if (len % 8 !== 0) {
    throw new RangeError('Buffer size must be a multiple of 64-bits')
  }
  for (var i = 0; i < len; i += 8) {
    swap(this, i, i + 7);
    swap(this, i + 1, i + 6);
    swap(this, i + 2, i + 5);
    swap(this, i + 3, i + 4);
  }
  return this
};

Buffer.prototype.toString = function toString () {
  var length = this.length | 0;
  if (length === 0) return ''
  if (arguments.length === 0) return utf8Slice(this, 0, length)
  return slowToString.apply(this, arguments)
};

Buffer.prototype.equals = function equals (b) {
  if (!internalIsBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return true
  return Buffer.compare(this, b) === 0
};

Buffer.prototype.inspect = function inspect () {
  var str = '';
  var max = INSPECT_MAX_BYTES;
  if (this.length > 0) {
    str = this.toString('hex', 0, max).match(/.{2}/g).join(' ');
    if (this.length > max) str += ' ... ';
  }
  return '<Buffer ' + str + '>'
};

Buffer.prototype.compare = function compare (target, start, end, thisStart, thisEnd) {
  if (!internalIsBuffer(target)) {
    throw new TypeError('Argument must be a Buffer')
  }

  if (start === undefined) {
    start = 0;
  }
  if (end === undefined) {
    end = target ? target.length : 0;
  }
  if (thisStart === undefined) {
    thisStart = 0;
  }
  if (thisEnd === undefined) {
    thisEnd = this.length;
  }

  if (start < 0 || end > target.length || thisStart < 0 || thisEnd > this.length) {
    throw new RangeError('out of range index')
  }

  if (thisStart >= thisEnd && start >= end) {
    return 0
  }
  if (thisStart >= thisEnd) {
    return -1
  }
  if (start >= end) {
    return 1
  }

  start >>>= 0;
  end >>>= 0;
  thisStart >>>= 0;
  thisEnd >>>= 0;

  if (this === target) return 0

  var x = thisEnd - thisStart;
  var y = end - start;
  var len = Math.min(x, y);

  var thisCopy = this.slice(thisStart, thisEnd);
  var targetCopy = target.slice(start, end);

  for (var i = 0; i < len; ++i) {
    if (thisCopy[i] !== targetCopy[i]) {
      x = thisCopy[i];
      y = targetCopy[i];
      break
    }
  }

  if (x < y) return -1
  if (y < x) return 1
  return 0
};

// Finds either the first index of `val` in `buffer` at offset >= `byteOffset`,
// OR the last index of `val` in `buffer` at offset <= `byteOffset`.
//
// Arguments:
// - buffer - a Buffer to search
// - val - a string, Buffer, or number
// - byteOffset - an index into `buffer`; will be clamped to an int32
// - encoding - an optional encoding, relevant is val is a string
// - dir - true for indexOf, false for lastIndexOf
function bidirectionalIndexOf (buffer, val, byteOffset, encoding, dir) {
  // Empty buffer means no match
  if (buffer.length === 0) return -1

  // Normalize byteOffset
  if (typeof byteOffset === 'string') {
    encoding = byteOffset;
    byteOffset = 0;
  } else if (byteOffset > 0x7fffffff) {
    byteOffset = 0x7fffffff;
  } else if (byteOffset < -0x80000000) {
    byteOffset = -0x80000000;
  }
  byteOffset = +byteOffset;  // Coerce to Number.
  if (isNaN(byteOffset)) {
    // byteOffset: it it's undefined, null, NaN, "foo", etc, search whole buffer
    byteOffset = dir ? 0 : (buffer.length - 1);
  }

  // Normalize byteOffset: negative offsets start from the end of the buffer
  if (byteOffset < 0) byteOffset = buffer.length + byteOffset;
  if (byteOffset >= buffer.length) {
    if (dir) return -1
    else byteOffset = buffer.length - 1;
  } else if (byteOffset < 0) {
    if (dir) byteOffset = 0;
    else return -1
  }

  // Normalize val
  if (typeof val === 'string') {
    val = Buffer.from(val, encoding);
  }

  // Finally, search either indexOf (if dir is true) or lastIndexOf
  if (internalIsBuffer(val)) {
    // Special case: looking for empty string/buffer always fails
    if (val.length === 0) {
      return -1
    }
    return arrayIndexOf(buffer, val, byteOffset, encoding, dir)
  } else if (typeof val === 'number') {
    val = val & 0xFF; // Search for a byte value [0-255]
    if (Buffer.TYPED_ARRAY_SUPPORT &&
        typeof Uint8Array.prototype.indexOf === 'function') {
      if (dir) {
        return Uint8Array.prototype.indexOf.call(buffer, val, byteOffset)
      } else {
        return Uint8Array.prototype.lastIndexOf.call(buffer, val, byteOffset)
      }
    }
    return arrayIndexOf(buffer, [ val ], byteOffset, encoding, dir)
  }

  throw new TypeError('val must be string, number or Buffer')
}

function arrayIndexOf (arr, val, byteOffset, encoding, dir) {
  var indexSize = 1;
  var arrLength = arr.length;
  var valLength = val.length;

  if (encoding !== undefined) {
    encoding = String(encoding).toLowerCase();
    if (encoding === 'ucs2' || encoding === 'ucs-2' ||
        encoding === 'utf16le' || encoding === 'utf-16le') {
      if (arr.length < 2 || val.length < 2) {
        return -1
      }
      indexSize = 2;
      arrLength /= 2;
      valLength /= 2;
      byteOffset /= 2;
    }
  }

  function read (buf, i) {
    if (indexSize === 1) {
      return buf[i]
    } else {
      return buf.readUInt16BE(i * indexSize)
    }
  }

  var i;
  if (dir) {
    var foundIndex = -1;
    for (i = byteOffset; i < arrLength; i++) {
      if (read(arr, i) === read(val, foundIndex === -1 ? 0 : i - foundIndex)) {
        if (foundIndex === -1) foundIndex = i;
        if (i - foundIndex + 1 === valLength) return foundIndex * indexSize
      } else {
        if (foundIndex !== -1) i -= i - foundIndex;
        foundIndex = -1;
      }
    }
  } else {
    if (byteOffset + valLength > arrLength) byteOffset = arrLength - valLength;
    for (i = byteOffset; i >= 0; i--) {
      var found = true;
      for (var j = 0; j < valLength; j++) {
        if (read(arr, i + j) !== read(val, j)) {
          found = false;
          break
        }
      }
      if (found) return i
    }
  }

  return -1
}

Buffer.prototype.includes = function includes (val, byteOffset, encoding) {
  return this.indexOf(val, byteOffset, encoding) !== -1
};

Buffer.prototype.indexOf = function indexOf (val, byteOffset, encoding) {
  return bidirectionalIndexOf(this, val, byteOffset, encoding, true)
};

Buffer.prototype.lastIndexOf = function lastIndexOf (val, byteOffset, encoding) {
  return bidirectionalIndexOf(this, val, byteOffset, encoding, false)
};

function hexWrite (buf, string, offset, length) {
  offset = Number(offset) || 0;
  var remaining = buf.length - offset;
  if (!length) {
    length = remaining;
  } else {
    length = Number(length);
    if (length > remaining) {
      length = remaining;
    }
  }

  // must be an even number of digits
  var strLen = string.length;
  if (strLen % 2 !== 0) throw new TypeError('Invalid hex string')

  if (length > strLen / 2) {
    length = strLen / 2;
  }
  for (var i = 0; i < length; ++i) {
    var parsed = parseInt(string.substr(i * 2, 2), 16);
    if (isNaN(parsed)) return i
    buf[offset + i] = parsed;
  }
  return i
}

function utf8Write (buf, string, offset, length) {
  return blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
}

function asciiWrite (buf, string, offset, length) {
  return blitBuffer(asciiToBytes(string), buf, offset, length)
}

function latin1Write (buf, string, offset, length) {
  return asciiWrite(buf, string, offset, length)
}

function base64Write (buf, string, offset, length) {
  return blitBuffer(base64ToBytes(string), buf, offset, length)
}

function ucs2Write (buf, string, offset, length) {
  return blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
}

Buffer.prototype.write = function write (string, offset, length, encoding) {
  // Buffer#write(string)
  if (offset === undefined) {
    encoding = 'utf8';
    length = this.length;
    offset = 0;
  // Buffer#write(string, encoding)
  } else if (length === undefined && typeof offset === 'string') {
    encoding = offset;
    length = this.length;
    offset = 0;
  // Buffer#write(string, offset[, length][, encoding])
  } else if (isFinite(offset)) {
    offset = offset | 0;
    if (isFinite(length)) {
      length = length | 0;
      if (encoding === undefined) encoding = 'utf8';
    } else {
      encoding = length;
      length = undefined;
    }
  // legacy write(string, encoding, offset, length) - remove in v0.13
  } else {
    throw new Error(
      'Buffer.write(string, encoding, offset[, length]) is no longer supported'
    )
  }

  var remaining = this.length - offset;
  if (length === undefined || length > remaining) length = remaining;

  if ((string.length > 0 && (length < 0 || offset < 0)) || offset > this.length) {
    throw new RangeError('Attempt to write outside buffer bounds')
  }

  if (!encoding) encoding = 'utf8';

  var loweredCase = false;
  for (;;) {
    switch (encoding) {
      case 'hex':
        return hexWrite(this, string, offset, length)

      case 'utf8':
      case 'utf-8':
        return utf8Write(this, string, offset, length)

      case 'ascii':
        return asciiWrite(this, string, offset, length)

      case 'latin1':
      case 'binary':
        return latin1Write(this, string, offset, length)

      case 'base64':
        // Warning: maxLength not taken into account in base64Write
        return base64Write(this, string, offset, length)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return ucs2Write(this, string, offset, length)

      default:
        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
        encoding = ('' + encoding).toLowerCase();
        loweredCase = true;
    }
  }
};

Buffer.prototype.toJSON = function toJSON () {
  return {
    type: 'Buffer',
    data: Array.prototype.slice.call(this._arr || this, 0)
  }
};

function base64Slice (buf, start, end) {
  if (start === 0 && end === buf.length) {
    return fromByteArray(buf)
  } else {
    return fromByteArray(buf.slice(start, end))
  }
}

function utf8Slice (buf, start, end) {
  end = Math.min(buf.length, end);
  var res = [];

  var i = start;
  while (i < end) {
    var firstByte = buf[i];
    var codePoint = null;
    var bytesPerSequence = (firstByte > 0xEF) ? 4
      : (firstByte > 0xDF) ? 3
      : (firstByte > 0xBF) ? 2
      : 1;

    if (i + bytesPerSequence <= end) {
      var secondByte, thirdByte, fourthByte, tempCodePoint;

      switch (bytesPerSequence) {
        case 1:
          if (firstByte < 0x80) {
            codePoint = firstByte;
          }
          break
        case 2:
          secondByte = buf[i + 1];
          if ((secondByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0x1F) << 0x6 | (secondByte & 0x3F);
            if (tempCodePoint > 0x7F) {
              codePoint = tempCodePoint;
            }
          }
          break
        case 3:
          secondByte = buf[i + 1];
          thirdByte = buf[i + 2];
          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0xF) << 0xC | (secondByte & 0x3F) << 0x6 | (thirdByte & 0x3F);
            if (tempCodePoint > 0x7FF && (tempCodePoint < 0xD800 || tempCodePoint > 0xDFFF)) {
              codePoint = tempCodePoint;
            }
          }
          break
        case 4:
          secondByte = buf[i + 1];
          thirdByte = buf[i + 2];
          fourthByte = buf[i + 3];
          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80 && (fourthByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0xF) << 0x12 | (secondByte & 0x3F) << 0xC | (thirdByte & 0x3F) << 0x6 | (fourthByte & 0x3F);
            if (tempCodePoint > 0xFFFF && tempCodePoint < 0x110000) {
              codePoint = tempCodePoint;
            }
          }
      }
    }

    if (codePoint === null) {
      // we did not generate a valid codePoint so insert a
      // replacement char (U+FFFD) and advance only 1 byte
      codePoint = 0xFFFD;
      bytesPerSequence = 1;
    } else if (codePoint > 0xFFFF) {
      // encode to utf16 (surrogate pair dance)
      codePoint -= 0x10000;
      res.push(codePoint >>> 10 & 0x3FF | 0xD800);
      codePoint = 0xDC00 | codePoint & 0x3FF;
    }

    res.push(codePoint);
    i += bytesPerSequence;
  }

  return decodeCodePointsArray(res)
}

// Based on http://stackoverflow.com/a/22747272/680742, the browser with
// the lowest limit is Chrome, with 0x10000 args.
// We go 1 magnitude less, for safety
var MAX_ARGUMENTS_LENGTH = 0x1000;

function decodeCodePointsArray (codePoints) {
  var len = codePoints.length;
  if (len <= MAX_ARGUMENTS_LENGTH) {
    return String.fromCharCode.apply(String, codePoints) // avoid extra slice()
  }

  // Decode in chunks to avoid "call stack size exceeded".
  var res = '';
  var i = 0;
  while (i < len) {
    res += String.fromCharCode.apply(
      String,
      codePoints.slice(i, i += MAX_ARGUMENTS_LENGTH)
    );
  }
  return res
}

function asciiSlice (buf, start, end) {
  var ret = '';
  end = Math.min(buf.length, end);

  for (var i = start; i < end; ++i) {
    ret += String.fromCharCode(buf[i] & 0x7F);
  }
  return ret
}

function latin1Slice (buf, start, end) {
  var ret = '';
  end = Math.min(buf.length, end);

  for (var i = start; i < end; ++i) {
    ret += String.fromCharCode(buf[i]);
  }
  return ret
}

function hexSlice (buf, start, end) {
  var len = buf.length;

  if (!start || start < 0) start = 0;
  if (!end || end < 0 || end > len) end = len;

  var out = '';
  for (var i = start; i < end; ++i) {
    out += toHex(buf[i]);
  }
  return out
}

function utf16leSlice (buf, start, end) {
  var bytes = buf.slice(start, end);
  var res = '';
  for (var i = 0; i < bytes.length; i += 2) {
    res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256);
  }
  return res
}

Buffer.prototype.slice = function slice (start, end) {
  var len = this.length;
  start = ~~start;
  end = end === undefined ? len : ~~end;

  if (start < 0) {
    start += len;
    if (start < 0) start = 0;
  } else if (start > len) {
    start = len;
  }

  if (end < 0) {
    end += len;
    if (end < 0) end = 0;
  } else if (end > len) {
    end = len;
  }

  if (end < start) end = start;

  var newBuf;
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    newBuf = this.subarray(start, end);
    newBuf.__proto__ = Buffer.prototype;
  } else {
    var sliceLen = end - start;
    newBuf = new Buffer(sliceLen, undefined);
    for (var i = 0; i < sliceLen; ++i) {
      newBuf[i] = this[i + start];
    }
  }

  return newBuf
};

/*
 * Need to make sure that buffer isn't trying to write out of bounds.
 */
function checkOffset (offset, ext, length) {
  if ((offset % 1) !== 0 || offset < 0) throw new RangeError('offset is not uint')
  if (offset + ext > length) throw new RangeError('Trying to access beyond buffer length')
}

Buffer.prototype.readUIntLE = function readUIntLE (offset, byteLength, noAssert) {
  offset = offset | 0;
  byteLength = byteLength | 0;
  if (!noAssert) checkOffset(offset, byteLength, this.length);

  var val = this[offset];
  var mul = 1;
  var i = 0;
  while (++i < byteLength && (mul *= 0x100)) {
    val += this[offset + i] * mul;
  }

  return val
};

Buffer.prototype.readUIntBE = function readUIntBE (offset, byteLength, noAssert) {
  offset = offset | 0;
  byteLength = byteLength | 0;
  if (!noAssert) {
    checkOffset(offset, byteLength, this.length);
  }

  var val = this[offset + --byteLength];
  var mul = 1;
  while (byteLength > 0 && (mul *= 0x100)) {
    val += this[offset + --byteLength] * mul;
  }

  return val
};

Buffer.prototype.readUInt8 = function readUInt8 (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 1, this.length);
  return this[offset]
};

Buffer.prototype.readUInt16LE = function readUInt16LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length);
  return this[offset] | (this[offset + 1] << 8)
};

Buffer.prototype.readUInt16BE = function readUInt16BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length);
  return (this[offset] << 8) | this[offset + 1]
};

Buffer.prototype.readUInt32LE = function readUInt32LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length);

  return ((this[offset]) |
      (this[offset + 1] << 8) |
      (this[offset + 2] << 16)) +
      (this[offset + 3] * 0x1000000)
};

Buffer.prototype.readUInt32BE = function readUInt32BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length);

  return (this[offset] * 0x1000000) +
    ((this[offset + 1] << 16) |
    (this[offset + 2] << 8) |
    this[offset + 3])
};

Buffer.prototype.readIntLE = function readIntLE (offset, byteLength, noAssert) {
  offset = offset | 0;
  byteLength = byteLength | 0;
  if (!noAssert) checkOffset(offset, byteLength, this.length);

  var val = this[offset];
  var mul = 1;
  var i = 0;
  while (++i < byteLength && (mul *= 0x100)) {
    val += this[offset + i] * mul;
  }
  mul *= 0x80;

  if (val >= mul) val -= Math.pow(2, 8 * byteLength);

  return val
};

Buffer.prototype.readIntBE = function readIntBE (offset, byteLength, noAssert) {
  offset = offset | 0;
  byteLength = byteLength | 0;
  if (!noAssert) checkOffset(offset, byteLength, this.length);

  var i = byteLength;
  var mul = 1;
  var val = this[offset + --i];
  while (i > 0 && (mul *= 0x100)) {
    val += this[offset + --i] * mul;
  }
  mul *= 0x80;

  if (val >= mul) val -= Math.pow(2, 8 * byteLength);

  return val
};

Buffer.prototype.readInt8 = function readInt8 (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 1, this.length);
  if (!(this[offset] & 0x80)) return (this[offset])
  return ((0xff - this[offset] + 1) * -1)
};

Buffer.prototype.readInt16LE = function readInt16LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length);
  var val = this[offset] | (this[offset + 1] << 8);
  return (val & 0x8000) ? val | 0xFFFF0000 : val
};

Buffer.prototype.readInt16BE = function readInt16BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length);
  var val = this[offset + 1] | (this[offset] << 8);
  return (val & 0x8000) ? val | 0xFFFF0000 : val
};

Buffer.prototype.readInt32LE = function readInt32LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length);

  return (this[offset]) |
    (this[offset + 1] << 8) |
    (this[offset + 2] << 16) |
    (this[offset + 3] << 24)
};

Buffer.prototype.readInt32BE = function readInt32BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length);

  return (this[offset] << 24) |
    (this[offset + 1] << 16) |
    (this[offset + 2] << 8) |
    (this[offset + 3])
};

Buffer.prototype.readFloatLE = function readFloatLE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length);
  return read(this, offset, true, 23, 4)
};

Buffer.prototype.readFloatBE = function readFloatBE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length);
  return read(this, offset, false, 23, 4)
};

Buffer.prototype.readDoubleLE = function readDoubleLE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 8, this.length);
  return read(this, offset, true, 52, 8)
};

Buffer.prototype.readDoubleBE = function readDoubleBE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 8, this.length);
  return read(this, offset, false, 52, 8)
};

function checkInt (buf, value, offset, ext, max, min) {
  if (!internalIsBuffer(buf)) throw new TypeError('"buffer" argument must be a Buffer instance')
  if (value > max || value < min) throw new RangeError('"value" argument is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('Index out of range')
}

Buffer.prototype.writeUIntLE = function writeUIntLE (value, offset, byteLength, noAssert) {
  value = +value;
  offset = offset | 0;
  byteLength = byteLength | 0;
  if (!noAssert) {
    var maxBytes = Math.pow(2, 8 * byteLength) - 1;
    checkInt(this, value, offset, byteLength, maxBytes, 0);
  }

  var mul = 1;
  var i = 0;
  this[offset] = value & 0xFF;
  while (++i < byteLength && (mul *= 0x100)) {
    this[offset + i] = (value / mul) & 0xFF;
  }

  return offset + byteLength
};

Buffer.prototype.writeUIntBE = function writeUIntBE (value, offset, byteLength, noAssert) {
  value = +value;
  offset = offset | 0;
  byteLength = byteLength | 0;
  if (!noAssert) {
    var maxBytes = Math.pow(2, 8 * byteLength) - 1;
    checkInt(this, value, offset, byteLength, maxBytes, 0);
  }

  var i = byteLength - 1;
  var mul = 1;
  this[offset + i] = value & 0xFF;
  while (--i >= 0 && (mul *= 0x100)) {
    this[offset + i] = (value / mul) & 0xFF;
  }

  return offset + byteLength
};

Buffer.prototype.writeUInt8 = function writeUInt8 (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 1, 0xff, 0);
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value);
  this[offset] = (value & 0xff);
  return offset + 1
};

function objectWriteUInt16 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffff + value + 1;
  for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; ++i) {
    buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
      (littleEndian ? i : 1 - i) * 8;
  }
}

Buffer.prototype.writeUInt16LE = function writeUInt16LE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0);
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff);
    this[offset + 1] = (value >>> 8);
  } else {
    objectWriteUInt16(this, value, offset, true);
  }
  return offset + 2
};

Buffer.prototype.writeUInt16BE = function writeUInt16BE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0);
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8);
    this[offset + 1] = (value & 0xff);
  } else {
    objectWriteUInt16(this, value, offset, false);
  }
  return offset + 2
};

function objectWriteUInt32 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffffffff + value + 1;
  for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; ++i) {
    buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff;
  }
}

Buffer.prototype.writeUInt32LE = function writeUInt32LE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0);
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset + 3] = (value >>> 24);
    this[offset + 2] = (value >>> 16);
    this[offset + 1] = (value >>> 8);
    this[offset] = (value & 0xff);
  } else {
    objectWriteUInt32(this, value, offset, true);
  }
  return offset + 4
};

Buffer.prototype.writeUInt32BE = function writeUInt32BE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0);
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24);
    this[offset + 1] = (value >>> 16);
    this[offset + 2] = (value >>> 8);
    this[offset + 3] = (value & 0xff);
  } else {
    objectWriteUInt32(this, value, offset, false);
  }
  return offset + 4
};

Buffer.prototype.writeIntLE = function writeIntLE (value, offset, byteLength, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) {
    var limit = Math.pow(2, 8 * byteLength - 1);

    checkInt(this, value, offset, byteLength, limit - 1, -limit);
  }

  var i = 0;
  var mul = 1;
  var sub = 0;
  this[offset] = value & 0xFF;
  while (++i < byteLength && (mul *= 0x100)) {
    if (value < 0 && sub === 0 && this[offset + i - 1] !== 0) {
      sub = 1;
    }
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF;
  }

  return offset + byteLength
};

Buffer.prototype.writeIntBE = function writeIntBE (value, offset, byteLength, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) {
    var limit = Math.pow(2, 8 * byteLength - 1);

    checkInt(this, value, offset, byteLength, limit - 1, -limit);
  }

  var i = byteLength - 1;
  var mul = 1;
  var sub = 0;
  this[offset + i] = value & 0xFF;
  while (--i >= 0 && (mul *= 0x100)) {
    if (value < 0 && sub === 0 && this[offset + i + 1] !== 0) {
      sub = 1;
    }
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF;
  }

  return offset + byteLength
};

Buffer.prototype.writeInt8 = function writeInt8 (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 1, 0x7f, -0x80);
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value);
  if (value < 0) value = 0xff + value + 1;
  this[offset] = (value & 0xff);
  return offset + 1
};

Buffer.prototype.writeInt16LE = function writeInt16LE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000);
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff);
    this[offset + 1] = (value >>> 8);
  } else {
    objectWriteUInt16(this, value, offset, true);
  }
  return offset + 2
};

Buffer.prototype.writeInt16BE = function writeInt16BE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000);
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8);
    this[offset + 1] = (value & 0xff);
  } else {
    objectWriteUInt16(this, value, offset, false);
  }
  return offset + 2
};

Buffer.prototype.writeInt32LE = function writeInt32LE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000);
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff);
    this[offset + 1] = (value >>> 8);
    this[offset + 2] = (value >>> 16);
    this[offset + 3] = (value >>> 24);
  } else {
    objectWriteUInt32(this, value, offset, true);
  }
  return offset + 4
};

Buffer.prototype.writeInt32BE = function writeInt32BE (value, offset, noAssert) {
  value = +value;
  offset = offset | 0;
  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000);
  if (value < 0) value = 0xffffffff + value + 1;
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24);
    this[offset + 1] = (value >>> 16);
    this[offset + 2] = (value >>> 8);
    this[offset + 3] = (value & 0xff);
  } else {
    objectWriteUInt32(this, value, offset, false);
  }
  return offset + 4
};

function checkIEEE754 (buf, value, offset, ext, max, min) {
  if (offset + ext > buf.length) throw new RangeError('Index out of range')
  if (offset < 0) throw new RangeError('Index out of range')
}

function writeFloat (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert) {
    checkIEEE754(buf, value, offset, 4);
  }
  write(buf, value, offset, littleEndian, 23, 4);
  return offset + 4
}

Buffer.prototype.writeFloatLE = function writeFloatLE (value, offset, noAssert) {
  return writeFloat(this, value, offset, true, noAssert)
};

Buffer.prototype.writeFloatBE = function writeFloatBE (value, offset, noAssert) {
  return writeFloat(this, value, offset, false, noAssert)
};

function writeDouble (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert) {
    checkIEEE754(buf, value, offset, 8);
  }
  write(buf, value, offset, littleEndian, 52, 8);
  return offset + 8
}

Buffer.prototype.writeDoubleLE = function writeDoubleLE (value, offset, noAssert) {
  return writeDouble(this, value, offset, true, noAssert)
};

Buffer.prototype.writeDoubleBE = function writeDoubleBE (value, offset, noAssert) {
  return writeDouble(this, value, offset, false, noAssert)
};

// copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
Buffer.prototype.copy = function copy (target, targetStart, start, end) {
  if (!start) start = 0;
  if (!end && end !== 0) end = this.length;
  if (targetStart >= target.length) targetStart = target.length;
  if (!targetStart) targetStart = 0;
  if (end > 0 && end < start) end = start;

  // Copy 0 bytes; we're done
  if (end === start) return 0
  if (target.length === 0 || this.length === 0) return 0

  // Fatal error conditions
  if (targetStart < 0) {
    throw new RangeError('targetStart out of bounds')
  }
  if (start < 0 || start >= this.length) throw new RangeError('sourceStart out of bounds')
  if (end < 0) throw new RangeError('sourceEnd out of bounds')

  // Are we oob?
  if (end > this.length) end = this.length;
  if (target.length - targetStart < end - start) {
    end = target.length - targetStart + start;
  }

  var len = end - start;
  var i;

  if (this === target && start < targetStart && targetStart < end) {
    // descending copy from end
    for (i = len - 1; i >= 0; --i) {
      target[i + targetStart] = this[i + start];
    }
  } else if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
    // ascending copy from start
    for (i = 0; i < len; ++i) {
      target[i + targetStart] = this[i + start];
    }
  } else {
    Uint8Array.prototype.set.call(
      target,
      this.subarray(start, start + len),
      targetStart
    );
  }

  return len
};

// Usage:
//    buffer.fill(number[, offset[, end]])
//    buffer.fill(buffer[, offset[, end]])
//    buffer.fill(string[, offset[, end]][, encoding])
Buffer.prototype.fill = function fill (val, start, end, encoding) {
  // Handle string cases:
  if (typeof val === 'string') {
    if (typeof start === 'string') {
      encoding = start;
      start = 0;
      end = this.length;
    } else if (typeof end === 'string') {
      encoding = end;
      end = this.length;
    }
    if (val.length === 1) {
      var code = val.charCodeAt(0);
      if (code < 256) {
        val = code;
      }
    }
    if (encoding !== undefined && typeof encoding !== 'string') {
      throw new TypeError('encoding must be a string')
    }
    if (typeof encoding === 'string' && !Buffer.isEncoding(encoding)) {
      throw new TypeError('Unknown encoding: ' + encoding)
    }
  } else if (typeof val === 'number') {
    val = val & 255;
  }

  // Invalid ranges are not set to a default, so can range check early.
  if (start < 0 || this.length < start || this.length < end) {
    throw new RangeError('Out of range index')
  }

  if (end <= start) {
    return this
  }

  start = start >>> 0;
  end = end === undefined ? this.length : end >>> 0;

  if (!val) val = 0;

  var i;
  if (typeof val === 'number') {
    for (i = start; i < end; ++i) {
      this[i] = val;
    }
  } else {
    var bytes = internalIsBuffer(val)
      ? val
      : utf8ToBytes(new Buffer(val, encoding).toString());
    var len = bytes.length;
    for (i = 0; i < end - start; ++i) {
      this[i + start] = bytes[i % len];
    }
  }

  return this
};

// HELPER FUNCTIONS
// ================

var INVALID_BASE64_RE = /[^+\/0-9A-Za-z-_]/g;

function base64clean (str) {
  // Node strips out invalid characters like \n and \t from the string, base64-js does not
  str = stringtrim(str).replace(INVALID_BASE64_RE, '');
  // Node converts strings with length < 2 to ''
  if (str.length < 2) return ''
  // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
  while (str.length % 4 !== 0) {
    str = str + '=';
  }
  return str
}

function stringtrim (str) {
  if (str.trim) return str.trim()
  return str.replace(/^\s+|\s+$/g, '')
}

function toHex (n) {
  if (n < 16) return '0' + n.toString(16)
  return n.toString(16)
}

function utf8ToBytes (string, units) {
  units = units || Infinity;
  var codePoint;
  var length = string.length;
  var leadSurrogate = null;
  var bytes = [];

  for (var i = 0; i < length; ++i) {
    codePoint = string.charCodeAt(i);

    // is surrogate component
    if (codePoint > 0xD7FF && codePoint < 0xE000) {
      // last char was a lead
      if (!leadSurrogate) {
        // no lead yet
        if (codePoint > 0xDBFF) {
          // unexpected trail
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
          continue
        } else if (i + 1 === length) {
          // unpaired lead
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
          continue
        }

        // valid lead
        leadSurrogate = codePoint;

        continue
      }

      // 2 leads in a row
      if (codePoint < 0xDC00) {
        if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
        leadSurrogate = codePoint;
        continue
      }

      // valid surrogate pair
      codePoint = (leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00) + 0x10000;
    } else if (leadSurrogate) {
      // valid bmp char, but last char was a lead
      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
    }

    leadSurrogate = null;

    // encode utf8
    if (codePoint < 0x80) {
      if ((units -= 1) < 0) break
      bytes.push(codePoint);
    } else if (codePoint < 0x800) {
      if ((units -= 2) < 0) break
      bytes.push(
        codePoint >> 0x6 | 0xC0,
        codePoint & 0x3F | 0x80
      );
    } else if (codePoint < 0x10000) {
      if ((units -= 3) < 0) break
      bytes.push(
        codePoint >> 0xC | 0xE0,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      );
    } else if (codePoint < 0x110000) {
      if ((units -= 4) < 0) break
      bytes.push(
        codePoint >> 0x12 | 0xF0,
        codePoint >> 0xC & 0x3F | 0x80,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      );
    } else {
      throw new Error('Invalid code point')
    }
  }

  return bytes
}

function asciiToBytes (str) {
  var byteArray = [];
  for (var i = 0; i < str.length; ++i) {
    // Node's code seems to be doing this and not & 0x7F..
    byteArray.push(str.charCodeAt(i) & 0xFF);
  }
  return byteArray
}

function utf16leToBytes (str, units) {
  var c, hi, lo;
  var byteArray = [];
  for (var i = 0; i < str.length; ++i) {
    if ((units -= 2) < 0) break

    c = str.charCodeAt(i);
    hi = c >> 8;
    lo = c % 256;
    byteArray.push(lo);
    byteArray.push(hi);
  }

  return byteArray
}


function base64ToBytes (str) {
  return toByteArray(base64clean(str))
}

function blitBuffer (src, dst, offset, length) {
  for (var i = 0; i < length; ++i) {
    if ((i + offset >= dst.length) || (i >= src.length)) break
    dst[i + offset] = src[i];
  }
  return i
}

function isnan (val) {
  return val !== val // eslint-disable-line no-self-compare
}


// the following is from is-buffer, also by Feross Aboukhadijeh and with same lisence
// The _isBuffer check is for Safari 5-7 support, because it's missing
// Object.prototype.constructor. Remove this eventually
function isBuffer(obj) {
  return obj != null && (!!obj._isBuffer || isFastBuffer(obj) || isSlowBuffer(obj))
}

function isFastBuffer (obj) {
  return !!obj.constructor && typeof obj.constructor.isBuffer === 'function' && obj.constructor.isBuffer(obj)
}

// For Node v0.10 support. Remove this eventually.
function isSlowBuffer (obj) {
  return typeof obj.readFloatLE === 'function' && typeof obj.slice === 'function' && isFastBuffer(obj.slice(0, 0))
}

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function getAugmentedNamespace(n) {
	if (n.__esModule) return n;
	var a = Object.defineProperty({}, '__esModule', {value: true});
	Object.keys(n).forEach(function (k) {
		var d = Object.getOwnPropertyDescriptor(n, k);
		Object.defineProperty(a, k, d.get ? d : {
			enumerable: true,
			get: function () {
				return n[k];
			}
		});
	});
	return a;
}

var dayjs_min = {exports: {}};

(function (module, exports) {
!function(t,e){module.exports=e();}(commonjsGlobal,(function(){var t=1e3,e=6e4,n=36e5,r="millisecond",i="second",s="minute",u="hour",a="day",o="week",f="month",h="quarter",c="year",d="date",l="Invalid Date",$=/^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[Tt\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/,y=/\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g,M={name:"en",weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),ordinal:function(t){var e=["th","st","nd","rd"],n=t%100;return "["+t+(e[(n-20)%10]||e[n]||e[0])+"]"}},m=function(t,e,n){var r=String(t);return !r||r.length>=e?t:""+Array(e+1-r.length).join(n)+t},v={s:m,z:function(t){var e=-t.utcOffset(),n=Math.abs(e),r=Math.floor(n/60),i=n%60;return (e<=0?"+":"-")+m(r,2,"0")+":"+m(i,2,"0")},m:function t(e,n){if(e.date()<n.date())return -t(n,e);var r=12*(n.year()-e.year())+(n.month()-e.month()),i=e.clone().add(r,f),s=n-i<0,u=e.clone().add(r+(s?-1:1),f);return +(-(r+(n-i)/(s?i-u:u-i))||0)},a:function(t){return t<0?Math.ceil(t)||0:Math.floor(t)},p:function(t){return {M:f,y:c,w:o,d:a,D:d,h:u,m:s,s:i,ms:r,Q:h}[t]||String(t||"").toLowerCase().replace(/s$/,"")},u:function(t){return void 0===t}},g="en",D={};D[g]=M;var p=function(t){return t instanceof _},S=function t(e,n,r){var i;if(!e)return g;if("string"==typeof e){var s=e.toLowerCase();D[s]&&(i=s),n&&(D[s]=n,i=s);var u=e.split("-");if(!i&&u.length>1)return t(u[0])}else {var a=e.name;D[a]=e,i=a;}return !r&&i&&(g=i),i||!r&&g},w=function(t,e){if(p(t))return t.clone();var n="object"==typeof e?e:{};return n.date=t,n.args=arguments,new _(n)},O=v;O.l=S,O.i=p,O.w=function(t,e){return w(t,{locale:e.$L,utc:e.$u,x:e.$x,$offset:e.$offset})};var _=function(){function M(t){this.$L=S(t.locale,null,!0),this.parse(t);}var m=M.prototype;return m.parse=function(t){this.$d=function(t){var e=t.date,n=t.utc;if(null===e)return new Date(NaN);if(O.u(e))return new Date;if(e instanceof Date)return new Date(e);if("string"==typeof e&&!/Z$/i.test(e)){var r=e.match($);if(r){var i=r[2]-1||0,s=(r[7]||"0").substring(0,3);return n?new Date(Date.UTC(r[1],i,r[3]||1,r[4]||0,r[5]||0,r[6]||0,s)):new Date(r[1],i,r[3]||1,r[4]||0,r[5]||0,r[6]||0,s)}}return new Date(e)}(t),this.$x=t.x||{},this.init();},m.init=function(){var t=this.$d;this.$y=t.getFullYear(),this.$M=t.getMonth(),this.$D=t.getDate(),this.$W=t.getDay(),this.$H=t.getHours(),this.$m=t.getMinutes(),this.$s=t.getSeconds(),this.$ms=t.getMilliseconds();},m.$utils=function(){return O},m.isValid=function(){return !(this.$d.toString()===l)},m.isSame=function(t,e){var n=w(t);return this.startOf(e)<=n&&n<=this.endOf(e)},m.isAfter=function(t,e){return w(t)<this.startOf(e)},m.isBefore=function(t,e){return this.endOf(e)<w(t)},m.$g=function(t,e,n){return O.u(t)?this[e]:this.set(n,t)},m.unix=function(){return Math.floor(this.valueOf()/1e3)},m.valueOf=function(){return this.$d.getTime()},m.startOf=function(t,e){var n=this,r=!!O.u(e)||e,h=O.p(t),l=function(t,e){var i=O.w(n.$u?Date.UTC(n.$y,e,t):new Date(n.$y,e,t),n);return r?i:i.endOf(a)},$=function(t,e){return O.w(n.toDate()[t].apply(n.toDate("s"),(r?[0,0,0,0]:[23,59,59,999]).slice(e)),n)},y=this.$W,M=this.$M,m=this.$D,v="set"+(this.$u?"UTC":"");switch(h){case c:return r?l(1,0):l(31,11);case f:return r?l(1,M):l(0,M+1);case o:var g=this.$locale().weekStart||0,D=(y<g?y+7:y)-g;return l(r?m-D:m+(6-D),M);case a:case d:return $(v+"Hours",0);case u:return $(v+"Minutes",1);case s:return $(v+"Seconds",2);case i:return $(v+"Milliseconds",3);default:return this.clone()}},m.endOf=function(t){return this.startOf(t,!1)},m.$set=function(t,e){var n,o=O.p(t),h="set"+(this.$u?"UTC":""),l=(n={},n[a]=h+"Date",n[d]=h+"Date",n[f]=h+"Month",n[c]=h+"FullYear",n[u]=h+"Hours",n[s]=h+"Minutes",n[i]=h+"Seconds",n[r]=h+"Milliseconds",n)[o],$=o===a?this.$D+(e-this.$W):e;if(o===f||o===c){var y=this.clone().set(d,1);y.$d[l]($),y.init(),this.$d=y.set(d,Math.min(this.$D,y.daysInMonth())).$d;}else l&&this.$d[l]($);return this.init(),this},m.set=function(t,e){return this.clone().$set(t,e)},m.get=function(t){return this[O.p(t)]()},m.add=function(r,h){var d,l=this;r=Number(r);var $=O.p(h),y=function(t){var e=w(l);return O.w(e.date(e.date()+Math.round(t*r)),l)};if($===f)return this.set(f,this.$M+r);if($===c)return this.set(c,this.$y+r);if($===a)return y(1);if($===o)return y(7);var M=(d={},d[s]=e,d[u]=n,d[i]=t,d)[$]||1,m=this.$d.getTime()+r*M;return O.w(m,this)},m.subtract=function(t,e){return this.add(-1*t,e)},m.format=function(t){var e=this,n=this.$locale();if(!this.isValid())return n.invalidDate||l;var r=t||"YYYY-MM-DDTHH:mm:ssZ",i=O.z(this),s=this.$H,u=this.$m,a=this.$M,o=n.weekdays,f=n.months,h=function(t,n,i,s){return t&&(t[n]||t(e,r))||i[n].slice(0,s)},c=function(t){return O.s(s%12||12,t,"0")},d=n.meridiem||function(t,e,n){var r=t<12?"AM":"PM";return n?r.toLowerCase():r},$={YY:String(this.$y).slice(-2),YYYY:this.$y,M:a+1,MM:O.s(a+1,2,"0"),MMM:h(n.monthsShort,a,f,3),MMMM:h(f,a),D:this.$D,DD:O.s(this.$D,2,"0"),d:String(this.$W),dd:h(n.weekdaysMin,this.$W,o,2),ddd:h(n.weekdaysShort,this.$W,o,3),dddd:o[this.$W],H:String(s),HH:O.s(s,2,"0"),h:c(1),hh:c(2),a:d(s,u,!0),A:d(s,u,!1),m:String(u),mm:O.s(u,2,"0"),s:String(this.$s),ss:O.s(this.$s,2,"0"),SSS:O.s(this.$ms,3,"0"),Z:i};return r.replace(y,(function(t,e){return e||$[t]||i.replace(":","")}))},m.utcOffset=function(){return 15*-Math.round(this.$d.getTimezoneOffset()/15)},m.diff=function(r,d,l){var $,y=O.p(d),M=w(r),m=(M.utcOffset()-this.utcOffset())*e,v=this-M,g=O.m(this,M);return g=($={},$[c]=g/12,$[f]=g,$[h]=g/3,$[o]=(v-m)/6048e5,$[a]=(v-m)/864e5,$[u]=v/n,$[s]=v/e,$[i]=v/t,$)[y]||v,l?g:O.a(g)},m.daysInMonth=function(){return this.endOf(f).$D},m.$locale=function(){return D[this.$L]},m.locale=function(t,e){if(!t)return this.$L;var n=this.clone(),r=S(t,e,!0);return r&&(n.$L=r),n},m.clone=function(){return O.w(this.$d,this)},m.toDate=function(){return new Date(this.valueOf())},m.toJSON=function(){return this.isValid()?this.toISOString():null},m.toISOString=function(){return this.$d.toISOString()},m.toString=function(){return this.$d.toUTCString()},M}(),T=_.prototype;return w.prototype=T,[["$ms",r],["$s",i],["$m",s],["$H",u],["$W",a],["$M",f],["$y",c],["$D",d]].forEach((function(t){T[t[1]]=function(e){return this.$g(e,t[0],t[1])};})),w.extend=function(t,e){return t.$i||(t(e,_,w),t.$i=!0),w},w.locale=S,w.isDayjs=p,w.unix=function(t){return w(1e3*t)},w.en=D[g],w.Ls=D,w.p={},w}));
}(dayjs_min));

const dayjs = dayjs_min.exports;

// =============================================================================
// Weekday
// =============================================================================
var ALL_WEEKDAYS = [
    'MO',
    'TU',
    'WE',
    'TH',
    'FR',
    'SA',
    'SU',
];
var Weekday = /** @class */ (function () {
    function Weekday(weekday, n) {
        if (n === 0)
            throw new Error("Can't create weekday with n == 0");
        this.weekday = weekday;
        this.n = n;
    }
    Weekday.fromStr = function (str) {
        return new Weekday(ALL_WEEKDAYS.indexOf(str));
    };
    // __call__ - Cannot call the object directly, do it through
    // e.g. RRule.TH.nth(-1) instead,
    Weekday.prototype.nth = function (n) {
        return this.n === n ? this : new Weekday(this.weekday, n);
    };
    // __eq__
    Weekday.prototype.equals = function (other) {
        return this.weekday === other.weekday && this.n === other.n;
    };
    // __repr__
    Weekday.prototype.toString = function () {
        var s = ALL_WEEKDAYS[this.weekday];
        if (this.n)
            s = (this.n > 0 ? '+' : '') + String(this.n) + s;
        return s;
    };
    Weekday.prototype.getJsWeekday = function () {
        return this.weekday === 6 ? 0 : this.weekday + 1;
    };
    return Weekday;
}());

// =============================================================================
var isPresent = function (value) {
    return value !== null && value !== undefined;
};
var isNumber$1 = function (value) {
    return typeof value === 'number';
};
var isWeekdayStr = function (value) {
    return typeof value === 'string' && ALL_WEEKDAYS.includes(value);
};
var isArray = Array.isArray;
/**
 * Simplified version of python's range()
 */
var range = function (start, end) {
    if (end === void 0) { end = start; }
    if (arguments.length === 1) {
        end = start;
        start = 0;
    }
    var rang = [];
    for (var i = start; i < end; i++)
        rang.push(i);
    return rang;
};
var repeat = function (value, times) {
    var i = 0;
    var array = [];
    if (isArray(value)) {
        for (; i < times; i++)
            array[i] = [].concat(value);
    }
    else {
        for (; i < times; i++)
            array[i] = value;
    }
    return array;
};
var toArray = function (item) {
    if (isArray(item)) {
        return item;
    }
    return [item];
};
function padStart(item, targetLength, padString) {
    if (padString === void 0) { padString = ' '; }
    var str = String(item);
    targetLength = targetLength >> 0;
    if (str.length > targetLength) {
        return String(str);
    }
    targetLength = targetLength - str.length;
    if (targetLength > padString.length) {
        padString += repeat(padString, targetLength / padString.length);
    }
    return padString.slice(0, targetLength) + String(str);
}
/**
 * Python like split
 */
var split = function (str, sep, num) {
    var splits = str.split(sep);
    return num
        ? splits.slice(0, num).concat([splits.slice(num).join(sep)])
        : splits;
};
/**
 * closure/goog/math/math.js:modulo
 * Copyright 2006 The Closure Library Authors.
 * The % operator in JavaScript returns the remainder of a / b, but differs from
 * some other languages in that the result will have the same sign as the
 * dividend. For example, -1 % 8 == -1, whereas in some other languages
 * (such as Python) the result would be 7. This function emulates the more
 * correct modulo behavior, which is useful for certain applications such as
 * calculating an offset index in a circular list.
 *
 * @param {number} a The dividend.
 * @param {number} b The divisor.
 * @return {number} a % b where the result is between 0 and b (either 0 <= x < b
 * or b < x <= 0, depending on the sign of b).
 */
var pymod = function (a, b) {
    var r = a % b;
    // If r and b differ in sign, add b to wrap the result to the correct sign.
    return r * b < 0 ? r + b : r;
};
/**
 * @see: <http://docs.python.org/library/functions.html#divmod>
 */
var divmod = function (a, b) {
    return { div: Math.floor(a / b), mod: pymod(a, b) };
};
var empty = function (obj) {
    return !isPresent(obj) || obj.length === 0;
};
/**
 * Python-like boolean
 *
 * @return {Boolean} value of an object/primitive, taking into account
 * the fact that in Python an empty list's/tuple's
 * boolean value is False, whereas in JS it's true
 */
var notEmpty = function (obj) {
    return !empty(obj);
};
/**
 * Return true if a value is in an array
 */
var includes = function (arr, val) {
    return notEmpty(arr) && arr.indexOf(val) !== -1;
};

var datetime = function (y, m, d, h, i, s) {
    if (h === void 0) { h = 0; }
    if (i === void 0) { i = 0; }
    if (s === void 0) { s = 0; }
    return new Date(Date.UTC(y, m - 1, d, h, i, s));
};
/**
 * General date-related utilities.
 * Also handles several incompatibilities between JavaScript and Python
 *
 */
var MONTH_DAYS = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
/**
 * Number of milliseconds of one day
 */
var ONE_DAY = 1000 * 60 * 60 * 24;
/**
 * @see: <http://docs.python.org/library/datetime.html#datetime.MAXYEAR>
 */
var MAXYEAR = 9999;
/**
 * Python uses 1-Jan-1 as the base for calculating ordinals but we don't
 * want to confuse the JS engine with milliseconds > Number.MAX_NUMBER,
 * therefore we use 1-Jan-1970 instead
 */
var ORDINAL_BASE = datetime(1970, 1, 1);
/**
 * Python: MO-SU: 0 - 6
 * JS: SU-SAT 0 - 6
 */
var PY_WEEKDAYS = [6, 0, 1, 2, 3, 4, 5];
var isLeapYear = function (year) {
    return (year % 4 === 0 && year % 100 !== 0) || year % 400 === 0;
};
var isDate = function (value) {
    return value instanceof Date;
};
var isValidDate = function (value) {
    return isDate(value) && !isNaN(value.getTime());
};
/**
 * @see: <http://www.mcfedries.com/JavaScript/DaysBetween.asp>
 */
var daysBetween = function (date1, date2) {
    // The number of milliseconds in one day
    // Convert both dates to milliseconds
    var date1ms = date1.getTime();
    var date2ms = date2.getTime();
    // Calculate the difference in milliseconds
    var differencems = date1ms - date2ms;
    // Convert back to days and return
    return Math.round(differencems / ONE_DAY);
};
/**
 * @see: <http://docs.python.org/library/datetime.html#datetime.date.toordinal>
 */
var toOrdinal = function (date) {
    return daysBetween(date, ORDINAL_BASE);
};
/**
 * @see - <http://docs.python.org/library/datetime.html#datetime.date.fromordinal>
 */
var fromOrdinal = function (ordinal) {
    return new Date(ORDINAL_BASE.getTime() + ordinal * ONE_DAY);
};
var getMonthDays = function (date) {
    var month = date.getUTCMonth();
    return month === 1 && isLeapYear(date.getUTCFullYear())
        ? 29
        : MONTH_DAYS[month];
};
/**
 * @return {Number} python-like weekday
 */
var getWeekday = function (date) {
    return PY_WEEKDAYS[date.getUTCDay()];
};
/**
 * @see: <http://docs.python.org/library/calendar.html#calendar.monthrange>
 */
var monthRange = function (year, month) {
    var date = datetime(year, month + 1, 1);
    return [getWeekday(date), getMonthDays(date)];
};
/**
 * @see: <http://docs.python.org/library/datetime.html#datetime.datetime.combine>
 */
var combine = function (date, time) {
    time = time || date;
    return new Date(Date.UTC(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate(), time.getHours(), time.getMinutes(), time.getSeconds(), time.getMilliseconds()));
};
var clone = function (date) {
    var dolly = new Date(date.getTime());
    return dolly;
};
var cloneDates = function (dates) {
    var clones = [];
    for (var i = 0; i < dates.length; i++) {
        clones.push(clone(dates[i]));
    }
    return clones;
};
/**
 * Sorts an array of Date or Time objects
 */
var sort = function (dates) {
    dates.sort(function (a, b) {
        return a.getTime() - b.getTime();
    });
};
var timeToUntilString = function (time, utc) {
    if (utc === void 0) { utc = true; }
    var date = new Date(time);
    return [
        padStart(date.getUTCFullYear().toString(), 4, '0'),
        padStart(date.getUTCMonth() + 1, 2, '0'),
        padStart(date.getUTCDate(), 2, '0'),
        'T',
        padStart(date.getUTCHours(), 2, '0'),
        padStart(date.getUTCMinutes(), 2, '0'),
        padStart(date.getUTCSeconds(), 2, '0'),
        utc ? 'Z' : '',
    ].join('');
};
var untilStringToDate = function (until) {
    var re = /^(\d{4})(\d{2})(\d{2})(T(\d{2})(\d{2})(\d{2})Z?)?$/;
    var bits = re.exec(until);
    if (!bits)
        throw new Error("Invalid UNTIL value: ".concat(until));
    return new Date(Date.UTC(parseInt(bits[1], 10), parseInt(bits[2], 10) - 1, parseInt(bits[3], 10), parseInt(bits[5], 10) || 0, parseInt(bits[6], 10) || 0, parseInt(bits[7], 10) || 0));
};
var dateTZtoISO8601 = function (date, timeZone) {
    // date format for sv-SE is almost ISO8601
    var dateStr = date.toLocaleString('sv-SE', { timeZone: timeZone });
    // '2023-02-07 10:41:36'
    return dateStr.replace(' ', 'T') + 'Z';
};
var dateInTimeZone = function (date, timeZone) {
    var localTimeZone = Intl.DateTimeFormat().resolvedOptions().timeZone;
    // Date constructor can only reliably parse dates in ISO8601 format
    var dateInLocalTZ = new Date(dateTZtoISO8601(date, localTimeZone));
    var dateInTargetTZ = new Date(dateTZtoISO8601(date, timeZone !== null && timeZone !== void 0 ? timeZone : 'UTC'));
    var tzOffset = dateInTargetTZ.getTime() - dateInLocalTZ.getTime();
    return new Date(date.getTime() - tzOffset);
};

/**
 * This class helps us to emulate python's generators, sorta.
 */
var IterResult = /** @class */ (function () {
    function IterResult(method, args) {
        this.minDate = null;
        this.maxDate = null;
        this._result = [];
        this.total = 0;
        this.method = method;
        this.args = args;
        if (method === 'between') {
            this.maxDate = args.inc
                ? args.before
                : new Date(args.before.getTime() - 1);
            this.minDate = args.inc ? args.after : new Date(args.after.getTime() + 1);
        }
        else if (method === 'before') {
            this.maxDate = args.inc ? args.dt : new Date(args.dt.getTime() - 1);
        }
        else if (method === 'after') {
            this.minDate = args.inc ? args.dt : new Date(args.dt.getTime() + 1);
        }
    }
    /**
     * Possibly adds a date into the result.
     *
     * @param {Date} date - the date isn't necessarly added to the result
     * list (if it is too late/too early)
     * @return {Boolean} true if it makes sense to continue the iteration
     * false if we're done.
     */
    IterResult.prototype.accept = function (date) {
        ++this.total;
        var tooEarly = this.minDate && date < this.minDate;
        var tooLate = this.maxDate && date > this.maxDate;
        if (this.method === 'between') {
            if (tooEarly)
                return true;
            if (tooLate)
                return false;
        }
        else if (this.method === 'before') {
            if (tooLate)
                return false;
        }
        else if (this.method === 'after') {
            if (tooEarly)
                return true;
            this.add(date);
            return false;
        }
        return this.add(date);
    };
    /**
     *
     * @param {Date} date that is part of the result.
     * @return {Boolean} whether we are interested in more values.
     */
    IterResult.prototype.add = function (date) {
        this._result.push(date);
        return true;
    };
    /**
     * 'before' and 'after' return only one date, whereas 'all'
     * and 'between' an array.
     *
     * @return {Date,Array?}
     */
    IterResult.prototype.getValue = function () {
        var res = this._result;
        switch (this.method) {
            case 'all':
            case 'between':
                return res;
            case 'before':
            case 'after':
            default:
                return (res.length ? res[res.length - 1] : null);
        }
    };
    IterResult.prototype.clone = function () {
        return new IterResult(this.method, this.args);
    };
    return IterResult;
}());

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    if (typeof b !== "function" && b !== null)
        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

/**
 * IterResult subclass that calls a callback function on each add,
 * and stops iterating when the callback returns false.
 */
var CallbackIterResult = /** @class */ (function (_super) {
    __extends(CallbackIterResult, _super);
    function CallbackIterResult(method, args, iterator) {
        var _this = _super.call(this, method, args) || this;
        _this.iterator = iterator;
        return _this;
    }
    CallbackIterResult.prototype.add = function (date) {
        if (this.iterator(date, this._result.length)) {
            this._result.push(date);
            return true;
        }
        return false;
    };
    return CallbackIterResult;
}(IterResult));

// =============================================================================
// i18n
// =============================================================================
var ENGLISH = {
    dayNames: [
        'Sunday',
        'Monday',
        'Tuesday',
        'Wednesday',
        'Thursday',
        'Friday',
        'Saturday',
    ],
    monthNames: [
        'January',
        'February',
        'March',
        'April',
        'May',
        'June',
        'July',
        'August',
        'September',
        'October',
        'November',
        'December',
    ],
    tokens: {
        SKIP: /^[ \r\n\t]+|^\.$/,
        number: /^[1-9][0-9]*/,
        numberAsText: /^(one|two|three)/i,
        every: /^every/i,
        'day(s)': /^days?/i,
        'weekday(s)': /^weekdays?/i,
        'week(s)': /^weeks?/i,
        'hour(s)': /^hours?/i,
        'minute(s)': /^minutes?/i,
        'month(s)': /^months?/i,
        'year(s)': /^years?/i,
        on: /^(on|in)/i,
        at: /^(at)/i,
        the: /^the/i,
        first: /^first/i,
        second: /^second/i,
        third: /^third/i,
        nth: /^([1-9][0-9]*)(\.|th|nd|rd|st)/i,
        last: /^last/i,
        for: /^for/i,
        'time(s)': /^times?/i,
        until: /^(un)?til/i,
        monday: /^mo(n(day)?)?/i,
        tuesday: /^tu(e(s(day)?)?)?/i,
        wednesday: /^we(d(n(esday)?)?)?/i,
        thursday: /^th(u(r(sday)?)?)?/i,
        friday: /^fr(i(day)?)?/i,
        saturday: /^sa(t(urday)?)?/i,
        sunday: /^su(n(day)?)?/i,
        january: /^jan(uary)?/i,
        february: /^feb(ruary)?/i,
        march: /^mar(ch)?/i,
        april: /^apr(il)?/i,
        may: /^may/i,
        june: /^june?/i,
        july: /^july?/i,
        august: /^aug(ust)?/i,
        september: /^sep(t(ember)?)?/i,
        october: /^oct(ober)?/i,
        november: /^nov(ember)?/i,
        december: /^dec(ember)?/i,
        comma: /^(,\s*|(and|or)\s*)+/i,
    },
};

// =============================================================================
// Helper functions
// =============================================================================
/**
 * Return true if a value is in an array
 */
var contains = function (arr, val) {
    return arr.indexOf(val) !== -1;
};
var defaultGetText = function (id) { return id.toString(); };
var defaultDateFormatter = function (year, month, day) { return "".concat(month, " ").concat(day, ", ").concat(year); };
/**
 *
 * @param {RRule} rrule
 * Optional:
 * @param {Function} gettext function
 * @param {Object} language definition
 * @constructor
 */
var ToText = /** @class */ (function () {
    function ToText(rrule, gettext, language, dateFormatter) {
        if (gettext === void 0) { gettext = defaultGetText; }
        if (language === void 0) { language = ENGLISH; }
        if (dateFormatter === void 0) { dateFormatter = defaultDateFormatter; }
        this.text = [];
        this.language = language || ENGLISH;
        this.gettext = gettext;
        this.dateFormatter = dateFormatter;
        this.rrule = rrule;
        this.options = rrule.options;
        this.origOptions = rrule.origOptions;
        if (this.origOptions.bymonthday) {
            var bymonthday = [].concat(this.options.bymonthday);
            var bynmonthday = [].concat(this.options.bynmonthday);
            bymonthday.sort(function (a, b) { return a - b; });
            bynmonthday.sort(function (a, b) { return b - a; });
            // 1, 2, 3, .., -5, -4, -3, ..
            this.bymonthday = bymonthday.concat(bynmonthday);
            if (!this.bymonthday.length)
                this.bymonthday = null;
        }
        if (isPresent(this.origOptions.byweekday)) {
            var byweekday = !isArray(this.origOptions.byweekday)
                ? [this.origOptions.byweekday]
                : this.origOptions.byweekday;
            var days = String(byweekday);
            this.byweekday = {
                allWeeks: byweekday.filter(function (weekday) {
                    return !weekday.n;
                }),
                someWeeks: byweekday.filter(function (weekday) {
                    return Boolean(weekday.n);
                }),
                isWeekdays: days.indexOf('MO') !== -1 &&
                    days.indexOf('TU') !== -1 &&
                    days.indexOf('WE') !== -1 &&
                    days.indexOf('TH') !== -1 &&
                    days.indexOf('FR') !== -1 &&
                    days.indexOf('SA') === -1 &&
                    days.indexOf('SU') === -1,
                isEveryDay: days.indexOf('MO') !== -1 &&
                    days.indexOf('TU') !== -1 &&
                    days.indexOf('WE') !== -1 &&
                    days.indexOf('TH') !== -1 &&
                    days.indexOf('FR') !== -1 &&
                    days.indexOf('SA') !== -1 &&
                    days.indexOf('SU') !== -1,
            };
            var sortWeekDays = function (a, b) {
                return a.weekday - b.weekday;
            };
            this.byweekday.allWeeks.sort(sortWeekDays);
            this.byweekday.someWeeks.sort(sortWeekDays);
            if (!this.byweekday.allWeeks.length)
                this.byweekday.allWeeks = null;
            if (!this.byweekday.someWeeks.length)
                this.byweekday.someWeeks = null;
        }
        else {
            this.byweekday = null;
        }
    }
    /**
     * Test whether the rrule can be fully converted to text.
     *
     * @param {RRule} rrule
     * @return {Boolean}
     */
    ToText.isFullyConvertible = function (rrule) {
        var canConvert = true;
        if (!(rrule.options.freq in ToText.IMPLEMENTED))
            return false;
        if (rrule.origOptions.until && rrule.origOptions.count)
            return false;
        for (var key in rrule.origOptions) {
            if (contains(['dtstart', 'tzid', 'wkst', 'freq'], key))
                return true;
            if (!contains(ToText.IMPLEMENTED[rrule.options.freq], key))
                return false;
        }
        return canConvert;
    };
    ToText.prototype.isFullyConvertible = function () {
        return ToText.isFullyConvertible(this.rrule);
    };
    /**
     * Perform the conversion. Only some of the frequencies are supported.
     * If some of the rrule's options aren't supported, they'll
     * be omitted from the output an "(~ approximate)" will be appended.
     *
     * @return {*}
     */
    ToText.prototype.toString = function () {
        var gettext = this.gettext;
        if (!(this.options.freq in ToText.IMPLEMENTED)) {
            return gettext('RRule error: Unable to fully convert this rrule to text');
        }
        this.text = [gettext('every')];
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        this[RRule.FREQUENCIES[this.options.freq]]();
        if (this.options.until) {
            this.add(gettext('until'));
            var until = this.options.until;
            this.add(this.dateFormatter(until.getUTCFullYear(), this.language.monthNames[until.getUTCMonth()], until.getUTCDate()));
        }
        else if (this.options.count) {
            this.add(gettext('for'))
                .add(this.options.count.toString())
                .add(this.plural(this.options.count) ? gettext('times') : gettext('time'));
        }
        if (!this.isFullyConvertible())
            this.add(gettext('(~ approximate)'));
        return this.text.join('');
    };
    ToText.prototype.HOURLY = function () {
        var gettext = this.gettext;
        if (this.options.interval !== 1)
            this.add(this.options.interval.toString());
        this.add(this.plural(this.options.interval) ? gettext('hours') : gettext('hour'));
    };
    ToText.prototype.MINUTELY = function () {
        var gettext = this.gettext;
        if (this.options.interval !== 1)
            this.add(this.options.interval.toString());
        this.add(this.plural(this.options.interval)
            ? gettext('minutes')
            : gettext('minute'));
    };
    ToText.prototype.DAILY = function () {
        var gettext = this.gettext;
        if (this.options.interval !== 1)
            this.add(this.options.interval.toString());
        if (this.byweekday && this.byweekday.isWeekdays) {
            this.add(this.plural(this.options.interval)
                ? gettext('weekdays')
                : gettext('weekday'));
        }
        else {
            this.add(this.plural(this.options.interval) ? gettext('days') : gettext('day'));
        }
        if (this.origOptions.bymonth) {
            this.add(gettext('in'));
            this._bymonth();
        }
        if (this.bymonthday) {
            this._bymonthday();
        }
        else if (this.byweekday) {
            this._byweekday();
        }
        else if (this.origOptions.byhour) {
            this._byhour();
        }
    };
    ToText.prototype.WEEKLY = function () {
        var gettext = this.gettext;
        if (this.options.interval !== 1) {
            this.add(this.options.interval.toString()).add(this.plural(this.options.interval) ? gettext('weeks') : gettext('week'));
        }
        if (this.byweekday && this.byweekday.isWeekdays) {
            if (this.options.interval === 1) {
                this.add(this.plural(this.options.interval)
                    ? gettext('weekdays')
                    : gettext('weekday'));
            }
            else {
                this.add(gettext('on')).add(gettext('weekdays'));
            }
        }
        else if (this.byweekday && this.byweekday.isEveryDay) {
            this.add(this.plural(this.options.interval) ? gettext('days') : gettext('day'));
        }
        else {
            if (this.options.interval === 1)
                this.add(gettext('week'));
            if (this.origOptions.bymonth) {
                this.add(gettext('in'));
                this._bymonth();
            }
            if (this.bymonthday) {
                this._bymonthday();
            }
            else if (this.byweekday) {
                this._byweekday();
            }
            if (this.origOptions.byhour) {
                this._byhour();
            }
        }
    };
    ToText.prototype.MONTHLY = function () {
        var gettext = this.gettext;
        if (this.origOptions.bymonth) {
            if (this.options.interval !== 1) {
                this.add(this.options.interval.toString()).add(gettext('months'));
                if (this.plural(this.options.interval))
                    this.add(gettext('in'));
            }
            this._bymonth();
        }
        else {
            if (this.options.interval !== 1) {
                this.add(this.options.interval.toString());
            }
            this.add(this.plural(this.options.interval)
                ? gettext('months')
                : gettext('month'));
        }
        if (this.bymonthday) {
            this._bymonthday();
        }
        else if (this.byweekday && this.byweekday.isWeekdays) {
            this.add(gettext('on')).add(gettext('weekdays'));
        }
        else if (this.byweekday) {
            this._byweekday();
        }
    };
    ToText.prototype.YEARLY = function () {
        var gettext = this.gettext;
        if (this.origOptions.bymonth) {
            if (this.options.interval !== 1) {
                this.add(this.options.interval.toString());
                this.add(gettext('years'));
            }
            this._bymonth();
        }
        else {
            if (this.options.interval !== 1) {
                this.add(this.options.interval.toString());
            }
            this.add(this.plural(this.options.interval) ? gettext('years') : gettext('year'));
        }
        if (this.bymonthday) {
            this._bymonthday();
        }
        else if (this.byweekday) {
            this._byweekday();
        }
        if (this.options.byyearday) {
            this.add(gettext('on the'))
                .add(this.list(this.options.byyearday, this.nth, gettext('and')))
                .add(gettext('day'));
        }
        if (this.options.byweekno) {
            this.add(gettext('in'))
                .add(this.plural(this.options.byweekno.length)
                ? gettext('weeks')
                : gettext('week'))
                .add(this.list(this.options.byweekno, undefined, gettext('and')));
        }
    };
    ToText.prototype._bymonthday = function () {
        var gettext = this.gettext;
        if (this.byweekday && this.byweekday.allWeeks) {
            this.add(gettext('on'))
                .add(this.list(this.byweekday.allWeeks, this.weekdaytext, gettext('or')))
                .add(gettext('the'))
                .add(this.list(this.bymonthday, this.nth, gettext('or')));
        }
        else {
            this.add(gettext('on the')).add(this.list(this.bymonthday, this.nth, gettext('and')));
        }
        // this.add(gettext('DAY'))
    };
    ToText.prototype._byweekday = function () {
        var gettext = this.gettext;
        if (this.byweekday.allWeeks && !this.byweekday.isWeekdays) {
            this.add(gettext('on')).add(this.list(this.byweekday.allWeeks, this.weekdaytext));
        }
        if (this.byweekday.someWeeks) {
            if (this.byweekday.allWeeks)
                this.add(gettext('and'));
            this.add(gettext('on the')).add(this.list(this.byweekday.someWeeks, this.weekdaytext, gettext('and')));
        }
    };
    ToText.prototype._byhour = function () {
        var gettext = this.gettext;
        this.add(gettext('at')).add(this.list(this.origOptions.byhour, undefined, gettext('and')));
    };
    ToText.prototype._bymonth = function () {
        this.add(this.list(this.options.bymonth, this.monthtext, this.gettext('and')));
    };
    ToText.prototype.nth = function (n) {
        n = parseInt(n.toString(), 10);
        var nth;
        var gettext = this.gettext;
        if (n === -1)
            return gettext('last');
        var npos = Math.abs(n);
        switch (npos) {
            case 1:
            case 21:
            case 31:
                nth = npos + gettext('st');
                break;
            case 2:
            case 22:
                nth = npos + gettext('nd');
                break;
            case 3:
            case 23:
                nth = npos + gettext('rd');
                break;
            default:
                nth = npos + gettext('th');
        }
        return n < 0 ? nth + ' ' + gettext('last') : nth;
    };
    ToText.prototype.monthtext = function (m) {
        return this.language.monthNames[m - 1];
    };
    ToText.prototype.weekdaytext = function (wday) {
        var weekday = isNumber$1(wday) ? (wday + 1) % 7 : wday.getJsWeekday();
        return ((wday.n ? this.nth(wday.n) + ' ' : '') +
            this.language.dayNames[weekday]);
    };
    ToText.prototype.plural = function (n) {
        return n % 100 !== 1;
    };
    ToText.prototype.add = function (s) {
        this.text.push(' ');
        this.text.push(s);
        return this;
    };
    ToText.prototype.list = function (arr, callback, finalDelim, delim) {
        var _this = this;
        if (delim === void 0) { delim = ','; }
        if (!isArray(arr)) {
            arr = [arr];
        }
        var delimJoin = function (array, delimiter, finalDelimiter) {
            var list = '';
            for (var i = 0; i < array.length; i++) {
                if (i !== 0) {
                    if (i === array.length - 1) {
                        list += ' ' + finalDelimiter + ' ';
                    }
                    else {
                        list += delimiter + ' ';
                    }
                }
                list += array[i];
            }
            return list;
        };
        callback =
            callback ||
                function (o) {
                    return o.toString();
                };
        var realCallback = function (arg) {
            return callback && callback.call(_this, arg);
        };
        if (finalDelim) {
            return delimJoin(arr.map(realCallback), delim, finalDelim);
        }
        else {
            return arr.map(realCallback).join(delim + ' ');
        }
    };
    return ToText;
}());

// =============================================================================
// Parser
// =============================================================================
var Parser$3 = /** @class */ (function () {
    function Parser(rules) {
        this.done = true;
        this.rules = rules;
    }
    Parser.prototype.start = function (text) {
        this.text = text;
        this.done = false;
        return this.nextSymbol();
    };
    Parser.prototype.isDone = function () {
        return this.done && this.symbol === null;
    };
    Parser.prototype.nextSymbol = function () {
        var best;
        var bestSymbol;
        this.symbol = null;
        this.value = null;
        do {
            if (this.done)
                return false;
            var rule = void 0;
            best = null;
            for (var name_1 in this.rules) {
                rule = this.rules[name_1];
                var match = rule.exec(this.text);
                if (match) {
                    if (best === null || match[0].length > best[0].length) {
                        best = match;
                        bestSymbol = name_1;
                    }
                }
            }
            if (best != null) {
                this.text = this.text.substr(best[0].length);
                if (this.text === '')
                    this.done = true;
            }
            if (best == null) {
                this.done = true;
                this.symbol = null;
                this.value = null;
                return;
            }
        } while (bestSymbol === 'SKIP');
        this.symbol = bestSymbol;
        this.value = best;
        return true;
    };
    Parser.prototype.accept = function (name) {
        if (this.symbol === name) {
            if (this.value) {
                var v = this.value;
                this.nextSymbol();
                return v;
            }
            this.nextSymbol();
            return true;
        }
        return false;
    };
    Parser.prototype.acceptNumber = function () {
        return this.accept('number');
    };
    Parser.prototype.expect = function (name) {
        if (this.accept(name))
            return true;
        throw new Error('expected ' + name + ' but found ' + this.symbol);
    };
    return Parser;
}());
function parseText(text, language) {
    if (language === void 0) { language = ENGLISH; }
    var options = {};
    var ttr = new Parser$3(language.tokens);
    if (!ttr.start(text))
        return null;
    S();
    return options;
    function S() {
        // every [n]
        ttr.expect('every');
        var n = ttr.acceptNumber();
        if (n)
            options.interval = parseInt(n[0], 10);
        if (ttr.isDone())
            throw new Error('Unexpected end');
        switch (ttr.symbol) {
            case 'day(s)':
                options.freq = RRule.DAILY;
                if (ttr.nextSymbol()) {
                    AT();
                    F();
                }
                break;
            // FIXME Note: every 2 weekdays != every two weeks on weekdays.
            // DAILY on weekdays is not a valid rule
            case 'weekday(s)':
                options.freq = RRule.WEEKLY;
                options.byweekday = [RRule.MO, RRule.TU, RRule.WE, RRule.TH, RRule.FR];
                ttr.nextSymbol();
                AT();
                F();
                break;
            case 'week(s)':
                options.freq = RRule.WEEKLY;
                if (ttr.nextSymbol()) {
                    ON();
                    AT();
                    F();
                }
                break;
            case 'hour(s)':
                options.freq = RRule.HOURLY;
                if (ttr.nextSymbol()) {
                    ON();
                    F();
                }
                break;
            case 'minute(s)':
                options.freq = RRule.MINUTELY;
                if (ttr.nextSymbol()) {
                    ON();
                    F();
                }
                break;
            case 'month(s)':
                options.freq = RRule.MONTHLY;
                if (ttr.nextSymbol()) {
                    ON();
                    F();
                }
                break;
            case 'year(s)':
                options.freq = RRule.YEARLY;
                if (ttr.nextSymbol()) {
                    ON();
                    F();
                }
                break;
            case 'monday':
            case 'tuesday':
            case 'wednesday':
            case 'thursday':
            case 'friday':
            case 'saturday':
            case 'sunday':
                options.freq = RRule.WEEKLY;
                var key = ttr.symbol
                    .substr(0, 2)
                    .toUpperCase();
                options.byweekday = [RRule[key]];
                if (!ttr.nextSymbol())
                    return;
                // TODO check for duplicates
                while (ttr.accept('comma')) {
                    if (ttr.isDone())
                        throw new Error('Unexpected end');
                    var wkd = decodeWKD();
                    if (!wkd) {
                        throw new Error('Unexpected symbol ' + ttr.symbol + ', expected weekday');
                    }
                    options.byweekday.push(RRule[wkd]);
                    ttr.nextSymbol();
                }
                AT();
                MDAYs();
                F();
                break;
            case 'january':
            case 'february':
            case 'march':
            case 'april':
            case 'may':
            case 'june':
            case 'july':
            case 'august':
            case 'september':
            case 'october':
            case 'november':
            case 'december':
                options.freq = RRule.YEARLY;
                options.bymonth = [decodeM()];
                if (!ttr.nextSymbol())
                    return;
                // TODO check for duplicates
                while (ttr.accept('comma')) {
                    if (ttr.isDone())
                        throw new Error('Unexpected end');
                    var m = decodeM();
                    if (!m) {
                        throw new Error('Unexpected symbol ' + ttr.symbol + ', expected month');
                    }
                    options.bymonth.push(m);
                    ttr.nextSymbol();
                }
                ON();
                F();
                break;
            default:
                throw new Error('Unknown symbol');
        }
    }
    function ON() {
        var on = ttr.accept('on');
        var the = ttr.accept('the');
        if (!(on || the))
            return;
        do {
            var nth = decodeNTH();
            var wkd = decodeWKD();
            var m = decodeM();
            // nth <weekday> | <weekday>
            if (nth) {
                // ttr.nextSymbol()
                if (wkd) {
                    ttr.nextSymbol();
                    if (!options.byweekday)
                        options.byweekday = [];
                    options.byweekday.push(RRule[wkd].nth(nth));
                }
                else {
                    if (!options.bymonthday)
                        options.bymonthday = [];
                    options.bymonthday.push(nth);
                    ttr.accept('day(s)');
                }
                // <weekday>
            }
            else if (wkd) {
                ttr.nextSymbol();
                if (!options.byweekday)
                    options.byweekday = [];
                options.byweekday.push(RRule[wkd]);
            }
            else if (ttr.symbol === 'weekday(s)') {
                ttr.nextSymbol();
                if (!options.byweekday) {
                    options.byweekday = [RRule.MO, RRule.TU, RRule.WE, RRule.TH, RRule.FR];
                }
            }
            else if (ttr.symbol === 'week(s)') {
                ttr.nextSymbol();
                var n = ttr.acceptNumber();
                if (!n) {
                    throw new Error('Unexpected symbol ' + ttr.symbol + ', expected week number');
                }
                options.byweekno = [parseInt(n[0], 10)];
                while (ttr.accept('comma')) {
                    n = ttr.acceptNumber();
                    if (!n) {
                        throw new Error('Unexpected symbol ' + ttr.symbol + '; expected monthday');
                    }
                    options.byweekno.push(parseInt(n[0], 10));
                }
            }
            else if (m) {
                ttr.nextSymbol();
                if (!options.bymonth)
                    options.bymonth = [];
                options.bymonth.push(m);
            }
            else {
                return;
            }
        } while (ttr.accept('comma') || ttr.accept('the') || ttr.accept('on'));
    }
    function AT() {
        var at = ttr.accept('at');
        if (!at)
            return;
        do {
            var n = ttr.acceptNumber();
            if (!n) {
                throw new Error('Unexpected symbol ' + ttr.symbol + ', expected hour');
            }
            options.byhour = [parseInt(n[0], 10)];
            while (ttr.accept('comma')) {
                n = ttr.acceptNumber();
                if (!n) {
                    throw new Error('Unexpected symbol ' + ttr.symbol + '; expected hour');
                }
                options.byhour.push(parseInt(n[0], 10));
            }
        } while (ttr.accept('comma') || ttr.accept('at'));
    }
    function decodeM() {
        switch (ttr.symbol) {
            case 'january':
                return 1;
            case 'february':
                return 2;
            case 'march':
                return 3;
            case 'april':
                return 4;
            case 'may':
                return 5;
            case 'june':
                return 6;
            case 'july':
                return 7;
            case 'august':
                return 8;
            case 'september':
                return 9;
            case 'october':
                return 10;
            case 'november':
                return 11;
            case 'december':
                return 12;
            default:
                return false;
        }
    }
    function decodeWKD() {
        switch (ttr.symbol) {
            case 'monday':
            case 'tuesday':
            case 'wednesday':
            case 'thursday':
            case 'friday':
            case 'saturday':
            case 'sunday':
                return ttr.symbol.substr(0, 2).toUpperCase();
            default:
                return false;
        }
    }
    function decodeNTH() {
        switch (ttr.symbol) {
            case 'last':
                ttr.nextSymbol();
                return -1;
            case 'first':
                ttr.nextSymbol();
                return 1;
            case 'second':
                ttr.nextSymbol();
                return ttr.accept('last') ? -2 : 2;
            case 'third':
                ttr.nextSymbol();
                return ttr.accept('last') ? -3 : 3;
            case 'nth':
                var v = parseInt(ttr.value[1], 10);
                if (v < -366 || v > 366)
                    throw new Error('Nth out of range: ' + v);
                ttr.nextSymbol();
                return ttr.accept('last') ? -v : v;
            default:
                return false;
        }
    }
    function MDAYs() {
        ttr.accept('on');
        ttr.accept('the');
        var nth = decodeNTH();
        if (!nth)
            return;
        options.bymonthday = [nth];
        ttr.nextSymbol();
        while (ttr.accept('comma')) {
            nth = decodeNTH();
            if (!nth) {
                throw new Error('Unexpected symbol ' + ttr.symbol + '; expected monthday');
            }
            options.bymonthday.push(nth);
            ttr.nextSymbol();
        }
    }
    function F() {
        if (ttr.symbol === 'until') {
            var date = Date.parse(ttr.text);
            if (!date)
                throw new Error('Cannot parse until date:' + ttr.text);
            options.until = new Date(date);
        }
        else if (ttr.accept('for')) {
            options.count = parseInt(ttr.value[0], 10);
            ttr.expect('number');
            // ttr.expect('times')
        }
    }
}

var Frequency;
(function (Frequency) {
    Frequency[Frequency["YEARLY"] = 0] = "YEARLY";
    Frequency[Frequency["MONTHLY"] = 1] = "MONTHLY";
    Frequency[Frequency["WEEKLY"] = 2] = "WEEKLY";
    Frequency[Frequency["DAILY"] = 3] = "DAILY";
    Frequency[Frequency["HOURLY"] = 4] = "HOURLY";
    Frequency[Frequency["MINUTELY"] = 5] = "MINUTELY";
    Frequency[Frequency["SECONDLY"] = 6] = "SECONDLY";
})(Frequency || (Frequency = {}));
function freqIsDailyOrGreater(freq) {
    return freq < Frequency.HOURLY;
}

/* !
 * rrule.js - Library for working with recurrence rules for calendar dates.
 * https://github.com/jakubroztocil/rrule
 *
 * Copyright 2010, Jakub Roztocil and Lars Schoning
 * Licenced under the BSD licence.
 * https://github.com/jakubroztocil/rrule/blob/master/LICENCE
 *
 */
/**
 *
 * Implementation of RRule.fromText() and RRule::toText().
 *
 *
 * On the client side, this file needs to be included
 * when those functions are used.
 *
 */
// =============================================================================
// fromText
// =============================================================================
/**
 * Will be able to convert some of the below described rules from
 * text format to a rule object.
 *
 *
 * RULES
 *
 * Every ([n])
 * day(s)
 * | [weekday], ..., (and) [weekday]
 * | weekday(s)
 * | week(s)
 * | month(s)
 * | [month], ..., (and) [month]
 * | year(s)
 *
 *
 * Plus 0, 1, or multiple of these:
 *
 * on [weekday], ..., (or) [weekday] the [monthday], [monthday], ... (or) [monthday]
 *
 * on [weekday], ..., (and) [weekday]
 *
 * on the [monthday], [monthday], ... (and) [monthday] (day of the month)
 *
 * on the [nth-weekday], ..., (and) [nth-weekday] (of the month/year)
 *
 *
 * Plus 0 or 1 of these:
 *
 * for [n] time(s)
 *
 * until [date]
 *
 * Plus (.)
 *
 *
 * Definitely no supported for parsing:
 *
 * (for year):
 * in week(s) [n], ..., (and) [n]
 *
 * on the [yearday], ..., (and) [n] day of the year
 * on day [yearday], ..., (and) [n]
 *
 *
 * NON-TERMINALS
 *
 * [n]: 1, 2 ..., one, two, three ..
 * [month]: January, February, March, April, May, ... December
 * [weekday]: Monday, ... Sunday
 * [nth-weekday]: first [weekday], 2nd [weekday], ... last [weekday], ...
 * [monthday]: first, 1., 2., 1st, 2nd, second, ... 31st, last day, 2nd last day, ..
 * [date]:
 * - [month] (0-31(,) ([year])),
 * - (the) 0-31.(1-12.([year])),
 * - (the) 0-31/(1-12/([year])),
 * - [weekday]
 *
 * [year]: 0000, 0001, ... 01, 02, ..
 *
 * Definitely not supported for parsing:
 *
 * [yearday]: first, 1., 2., 1st, 2nd, second, ... 366th, last day, 2nd last day, ..
 *
 * @param {String} text
 * @return {Object, Boolean} the rule, or null.
 */
var fromText = function (text, language) {
    if (language === void 0) { language = ENGLISH; }
    return new RRule(parseText(text, language) || undefined);
};
var common = [
    'count',
    'until',
    'interval',
    'byweekday',
    'bymonthday',
    'bymonth',
];
ToText.IMPLEMENTED = [];
ToText.IMPLEMENTED[Frequency.HOURLY] = common;
ToText.IMPLEMENTED[Frequency.MINUTELY] = common;
ToText.IMPLEMENTED[Frequency.DAILY] = ['byhour'].concat(common);
ToText.IMPLEMENTED[Frequency.WEEKLY] = common;
ToText.IMPLEMENTED[Frequency.MONTHLY] = common;
ToText.IMPLEMENTED[Frequency.YEARLY] = ['byweekno', 'byyearday'].concat(common);
// =============================================================================
// Export
// =============================================================================
var toText = function (rrule, gettext, language, dateFormatter) {
    return new ToText(rrule, gettext, language, dateFormatter).toString();
};
var isFullyConvertible = ToText.isFullyConvertible;

var Time = /** @class */ (function () {
    function Time(hour, minute, second, millisecond) {
        this.hour = hour;
        this.minute = minute;
        this.second = second;
        this.millisecond = millisecond || 0;
    }
    Time.prototype.getHours = function () {
        return this.hour;
    };
    Time.prototype.getMinutes = function () {
        return this.minute;
    };
    Time.prototype.getSeconds = function () {
        return this.second;
    };
    Time.prototype.getMilliseconds = function () {
        return this.millisecond;
    };
    Time.prototype.getTime = function () {
        return ((this.hour * 60 * 60 + this.minute * 60 + this.second) * 1000 +
            this.millisecond);
    };
    return Time;
}());
var DateTime = /** @class */ (function (_super) {
    __extends(DateTime, _super);
    function DateTime(year, month, day, hour, minute, second, millisecond) {
        var _this = _super.call(this, hour, minute, second, millisecond) || this;
        _this.year = year;
        _this.month = month;
        _this.day = day;
        return _this;
    }
    DateTime.fromDate = function (date) {
        return new this(date.getUTCFullYear(), date.getUTCMonth() + 1, date.getUTCDate(), date.getUTCHours(), date.getUTCMinutes(), date.getUTCSeconds(), date.valueOf() % 1000);
    };
    DateTime.prototype.getWeekday = function () {
        return getWeekday(new Date(this.getTime()));
    };
    DateTime.prototype.getTime = function () {
        return new Date(Date.UTC(this.year, this.month - 1, this.day, this.hour, this.minute, this.second, this.millisecond)).getTime();
    };
    DateTime.prototype.getDay = function () {
        return this.day;
    };
    DateTime.prototype.getMonth = function () {
        return this.month;
    };
    DateTime.prototype.getYear = function () {
        return this.year;
    };
    DateTime.prototype.addYears = function (years) {
        this.year += years;
    };
    DateTime.prototype.addMonths = function (months) {
        this.month += months;
        if (this.month > 12) {
            var yearDiv = Math.floor(this.month / 12);
            var monthMod = pymod(this.month, 12);
            this.month = monthMod;
            this.year += yearDiv;
            if (this.month === 0) {
                this.month = 12;
                --this.year;
            }
        }
    };
    DateTime.prototype.addWeekly = function (days, wkst) {
        if (wkst > this.getWeekday()) {
            this.day += -(this.getWeekday() + 1 + (6 - wkst)) + days * 7;
        }
        else {
            this.day += -(this.getWeekday() - wkst) + days * 7;
        }
        this.fixDay();
    };
    DateTime.prototype.addDaily = function (days) {
        this.day += days;
        this.fixDay();
    };
    DateTime.prototype.addHours = function (hours, filtered, byhour) {
        if (filtered) {
            // Jump to one iteration before next day
            this.hour += Math.floor((23 - this.hour) / hours) * hours;
        }
        for (;;) {
            this.hour += hours;
            var _a = divmod(this.hour, 24), dayDiv = _a.div, hourMod = _a.mod;
            if (dayDiv) {
                this.hour = hourMod;
                this.addDaily(dayDiv);
            }
            if (empty(byhour) || includes(byhour, this.hour))
                break;
        }
    };
    DateTime.prototype.addMinutes = function (minutes, filtered, byhour, byminute) {
        if (filtered) {
            // Jump to one iteration before next day
            this.minute +=
                Math.floor((1439 - (this.hour * 60 + this.minute)) / minutes) * minutes;
        }
        for (;;) {
            this.minute += minutes;
            var _a = divmod(this.minute, 60), hourDiv = _a.div, minuteMod = _a.mod;
            if (hourDiv) {
                this.minute = minuteMod;
                this.addHours(hourDiv, false, byhour);
            }
            if ((empty(byhour) || includes(byhour, this.hour)) &&
                (empty(byminute) || includes(byminute, this.minute))) {
                break;
            }
        }
    };
    DateTime.prototype.addSeconds = function (seconds, filtered, byhour, byminute, bysecond) {
        if (filtered) {
            // Jump to one iteration before next day
            this.second +=
                Math.floor((86399 - (this.hour * 3600 + this.minute * 60 + this.second)) /
                    seconds) * seconds;
        }
        for (;;) {
            this.second += seconds;
            var _a = divmod(this.second, 60), minuteDiv = _a.div, secondMod = _a.mod;
            if (minuteDiv) {
                this.second = secondMod;
                this.addMinutes(minuteDiv, false, byhour, byminute);
            }
            if ((empty(byhour) || includes(byhour, this.hour)) &&
                (empty(byminute) || includes(byminute, this.minute)) &&
                (empty(bysecond) || includes(bysecond, this.second))) {
                break;
            }
        }
    };
    DateTime.prototype.fixDay = function () {
        if (this.day <= 28) {
            return;
        }
        var daysinmonth = monthRange(this.year, this.month - 1)[1];
        if (this.day <= daysinmonth) {
            return;
        }
        while (this.day > daysinmonth) {
            this.day -= daysinmonth;
            ++this.month;
            if (this.month === 13) {
                this.month = 1;
                ++this.year;
                if (this.year > MAXYEAR) {
                    return;
                }
            }
            daysinmonth = monthRange(this.year, this.month - 1)[1];
        }
    };
    DateTime.prototype.add = function (options, filtered) {
        var freq = options.freq, interval = options.interval, wkst = options.wkst, byhour = options.byhour, byminute = options.byminute, bysecond = options.bysecond;
        switch (freq) {
            case Frequency.YEARLY:
                return this.addYears(interval);
            case Frequency.MONTHLY:
                return this.addMonths(interval);
            case Frequency.WEEKLY:
                return this.addWeekly(interval, wkst);
            case Frequency.DAILY:
                return this.addDaily(interval);
            case Frequency.HOURLY:
                return this.addHours(interval, filtered, byhour);
            case Frequency.MINUTELY:
                return this.addMinutes(interval, filtered, byhour, byminute);
            case Frequency.SECONDLY:
                return this.addSeconds(interval, filtered, byhour, byminute, bysecond);
        }
    };
    return DateTime;
}(Time));

function initializeOptions$1(options) {
    var invalid = [];
    var keys = Object.keys(options);
    // Shallow copy for options and origOptions and check for invalid
    for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
        var key = keys_1[_i];
        if (!includes(defaultKeys, key))
            invalid.push(key);
        if (isDate(options[key]) && !isValidDate(options[key])) {
            invalid.push(key);
        }
    }
    if (invalid.length) {
        throw new Error('Invalid options: ' + invalid.join(', '));
    }
    return __assign({}, options);
}
function parseOptions(options) {
    var opts = __assign(__assign({}, DEFAULT_OPTIONS$1), initializeOptions$1(options));
    if (isPresent(opts.byeaster))
        opts.freq = RRule.YEARLY;
    if (!(isPresent(opts.freq) && RRule.FREQUENCIES[opts.freq])) {
        throw new Error("Invalid frequency: ".concat(opts.freq, " ").concat(options.freq));
    }
    if (!opts.dtstart)
        opts.dtstart = new Date(new Date().setMilliseconds(0));
    if (!isPresent(opts.wkst)) {
        opts.wkst = RRule.MO.weekday;
    }
    else if (isNumber$1(opts.wkst)) ;
    else {
        opts.wkst = opts.wkst.weekday;
    }
    if (isPresent(opts.bysetpos)) {
        if (isNumber$1(opts.bysetpos))
            opts.bysetpos = [opts.bysetpos];
        for (var i = 0; i < opts.bysetpos.length; i++) {
            var v = opts.bysetpos[i];
            if (v === 0 || !(v >= -366 && v <= 366)) {
                throw new Error('bysetpos must be between 1 and 366,' + ' or between -366 and -1');
            }
        }
    }
    if (!(Boolean(opts.byweekno) ||
        notEmpty(opts.byweekno) ||
        notEmpty(opts.byyearday) ||
        Boolean(opts.bymonthday) ||
        notEmpty(opts.bymonthday) ||
        isPresent(opts.byweekday) ||
        isPresent(opts.byeaster))) {
        switch (opts.freq) {
            case RRule.YEARLY:
                if (!opts.bymonth)
                    opts.bymonth = opts.dtstart.getUTCMonth() + 1;
                opts.bymonthday = opts.dtstart.getUTCDate();
                break;
            case RRule.MONTHLY:
                opts.bymonthday = opts.dtstart.getUTCDate();
                break;
            case RRule.WEEKLY:
                opts.byweekday = [getWeekday(opts.dtstart)];
                break;
        }
    }
    // bymonth
    if (isPresent(opts.bymonth) && !isArray(opts.bymonth)) {
        opts.bymonth = [opts.bymonth];
    }
    // byyearday
    if (isPresent(opts.byyearday) &&
        !isArray(opts.byyearday) &&
        isNumber$1(opts.byyearday)) {
        opts.byyearday = [opts.byyearday];
    }
    // bymonthday
    if (!isPresent(opts.bymonthday)) {
        opts.bymonthday = [];
        opts.bynmonthday = [];
    }
    else if (isArray(opts.bymonthday)) {
        var bymonthday = [];
        var bynmonthday = [];
        for (var i = 0; i < opts.bymonthday.length; i++) {
            var v = opts.bymonthday[i];
            if (v > 0) {
                bymonthday.push(v);
            }
            else if (v < 0) {
                bynmonthday.push(v);
            }
        }
        opts.bymonthday = bymonthday;
        opts.bynmonthday = bynmonthday;
    }
    else if (opts.bymonthday < 0) {
        opts.bynmonthday = [opts.bymonthday];
        opts.bymonthday = [];
    }
    else {
        opts.bynmonthday = [];
        opts.bymonthday = [opts.bymonthday];
    }
    // byweekno
    if (isPresent(opts.byweekno) && !isArray(opts.byweekno)) {
        opts.byweekno = [opts.byweekno];
    }
    // byweekday / bynweekday
    if (!isPresent(opts.byweekday)) {
        opts.bynweekday = null;
    }
    else if (isNumber$1(opts.byweekday)) {
        opts.byweekday = [opts.byweekday];
        opts.bynweekday = null;
    }
    else if (isWeekdayStr(opts.byweekday)) {
        opts.byweekday = [Weekday.fromStr(opts.byweekday).weekday];
        opts.bynweekday = null;
    }
    else if (opts.byweekday instanceof Weekday) {
        if (!opts.byweekday.n || opts.freq > RRule.MONTHLY) {
            opts.byweekday = [opts.byweekday.weekday];
            opts.bynweekday = null;
        }
        else {
            opts.bynweekday = [[opts.byweekday.weekday, opts.byweekday.n]];
            opts.byweekday = null;
        }
    }
    else {
        var byweekday = [];
        var bynweekday = [];
        for (var i = 0; i < opts.byweekday.length; i++) {
            var wday = opts.byweekday[i];
            if (isNumber$1(wday)) {
                byweekday.push(wday);
                continue;
            }
            else if (isWeekdayStr(wday)) {
                byweekday.push(Weekday.fromStr(wday).weekday);
                continue;
            }
            if (!wday.n || opts.freq > RRule.MONTHLY) {
                byweekday.push(wday.weekday);
            }
            else {
                bynweekday.push([wday.weekday, wday.n]);
            }
        }
        opts.byweekday = notEmpty(byweekday) ? byweekday : null;
        opts.bynweekday = notEmpty(bynweekday) ? bynweekday : null;
    }
    // byhour
    if (!isPresent(opts.byhour)) {
        opts.byhour = opts.freq < RRule.HOURLY ? [opts.dtstart.getUTCHours()] : null;
    }
    else if (isNumber$1(opts.byhour)) {
        opts.byhour = [opts.byhour];
    }
    // byminute
    if (!isPresent(opts.byminute)) {
        opts.byminute =
            opts.freq < RRule.MINUTELY ? [opts.dtstart.getUTCMinutes()] : null;
    }
    else if (isNumber$1(opts.byminute)) {
        opts.byminute = [opts.byminute];
    }
    // bysecond
    if (!isPresent(opts.bysecond)) {
        opts.bysecond =
            opts.freq < RRule.SECONDLY ? [opts.dtstart.getUTCSeconds()] : null;
    }
    else if (isNumber$1(opts.bysecond)) {
        opts.bysecond = [opts.bysecond];
    }
    return { parsedOptions: opts };
}
function buildTimeset(opts) {
    var millisecondModulo = opts.dtstart.getTime() % 1000;
    if (!freqIsDailyOrGreater(opts.freq)) {
        return [];
    }
    var timeset = [];
    opts.byhour.forEach(function (hour) {
        opts.byminute.forEach(function (minute) {
            opts.bysecond.forEach(function (second) {
                timeset.push(new Time(hour, minute, second, millisecondModulo));
            });
        });
    });
    return timeset;
}

function parseString(rfcString) {
    var options = rfcString
        .split('\n')
        .map(parseLine)
        .filter(function (x) { return x !== null; });
    return __assign(__assign({}, options[0]), options[1]);
}
function parseDtstart(line) {
    var options = {};
    var dtstartWithZone = /DTSTART(?:;TZID=([^:=]+?))?(?::|=)([^;\s]+)/i.exec(line);
    if (!dtstartWithZone) {
        return options;
    }
    var tzid = dtstartWithZone[1], dtstart = dtstartWithZone[2];
    if (tzid) {
        options.tzid = tzid;
    }
    options.dtstart = untilStringToDate(dtstart);
    return options;
}
function parseLine(rfcString) {
    rfcString = rfcString.replace(/^\s+|\s+$/, '');
    if (!rfcString.length)
        return null;
    var header = /^([A-Z]+?)[:;]/.exec(rfcString.toUpperCase());
    if (!header) {
        return parseRrule(rfcString);
    }
    var key = header[1];
    switch (key.toUpperCase()) {
        case 'RRULE':
        case 'EXRULE':
            return parseRrule(rfcString);
        case 'DTSTART':
            return parseDtstart(rfcString);
        default:
            throw new Error("Unsupported RFC prop ".concat(key, " in ").concat(rfcString));
    }
}
function parseRrule(line) {
    var strippedLine = line.replace(/^RRULE:/i, '');
    var options = parseDtstart(strippedLine);
    var attrs = line.replace(/^(?:RRULE|EXRULE):/i, '').split(';');
    attrs.forEach(function (attr) {
        var _a = attr.split('='), key = _a[0], value = _a[1];
        switch (key.toUpperCase()) {
            case 'FREQ':
                options.freq = Frequency[value.toUpperCase()];
                break;
            case 'WKST':
                options.wkst = Days[value.toUpperCase()];
                break;
            case 'COUNT':
            case 'INTERVAL':
            case 'BYSETPOS':
            case 'BYMONTH':
            case 'BYMONTHDAY':
            case 'BYYEARDAY':
            case 'BYWEEKNO':
            case 'BYHOUR':
            case 'BYMINUTE':
            case 'BYSECOND':
                var num = parseNumber(value);
                var optionKey = key.toLowerCase();
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-ignore
                options[optionKey] = num;
                break;
            case 'BYWEEKDAY':
            case 'BYDAY':
                options.byweekday = parseWeekday(value);
                break;
            case 'DTSTART':
            case 'TZID':
                // for backwards compatibility
                var dtstart = parseDtstart(line);
                options.tzid = dtstart.tzid;
                options.dtstart = dtstart.dtstart;
                break;
            case 'UNTIL':
                options.until = untilStringToDate(value);
                break;
            case 'BYEASTER':
                options.byeaster = Number(value);
                break;
            default:
                throw new Error("Unknown RRULE property '" + key + "'");
        }
    });
    return options;
}
function parseNumber(value) {
    if (value.indexOf(',') !== -1) {
        var values = value.split(',');
        return values.map(parseIndividualNumber);
    }
    return parseIndividualNumber(value);
}
function parseIndividualNumber(value) {
    if (/^[+-]?\d+$/.test(value)) {
        return Number(value);
    }
    return value;
}
function parseWeekday(value) {
    var days = value.split(',');
    return days.map(function (day) {
        if (day.length === 2) {
            // MO, TU, ...
            return Days[day]; // wday instanceof Weekday
        }
        // -1MO, +3FR, 1SO, 13TU ...
        var parts = day.match(/^([+-]?\d{1,2})([A-Z]{2})$/);
        if (!parts || parts.length < 3) {
            throw new SyntaxError("Invalid weekday string: ".concat(day));
        }
        var n = Number(parts[1]);
        var wdaypart = parts[2];
        var wday = Days[wdaypart].weekday;
        return new Weekday(wday, n);
    });
}

var DateWithZone = /** @class */ (function () {
    function DateWithZone(date, tzid) {
        if (isNaN(date.getTime())) {
            throw new RangeError('Invalid date passed to DateWithZone');
        }
        this.date = date;
        this.tzid = tzid;
    }
    Object.defineProperty(DateWithZone.prototype, "isUTC", {
        get: function () {
            return !this.tzid || this.tzid.toUpperCase() === 'UTC';
        },
        enumerable: false,
        configurable: true
    });
    DateWithZone.prototype.toString = function () {
        var datestr = timeToUntilString(this.date.getTime(), this.isUTC);
        if (!this.isUTC) {
            return ";TZID=".concat(this.tzid, ":").concat(datestr);
        }
        return ":".concat(datestr);
    };
    DateWithZone.prototype.getTime = function () {
        return this.date.getTime();
    };
    DateWithZone.prototype.rezonedDate = function () {
        if (this.isUTC) {
            return this.date;
        }
        return dateInTimeZone(this.date, this.tzid);
    };
    return DateWithZone;
}());

function optionsToString(options) {
    var rrule = [];
    var dtstart = '';
    var keys = Object.keys(options);
    var defaultKeys = Object.keys(DEFAULT_OPTIONS$1);
    for (var i = 0; i < keys.length; i++) {
        if (keys[i] === 'tzid')
            continue;
        if (!includes(defaultKeys, keys[i]))
            continue;
        var key = keys[i].toUpperCase();
        var value = options[keys[i]];
        var outValue = '';
        if (!isPresent(value) || (isArray(value) && !value.length))
            continue;
        switch (key) {
            case 'FREQ':
                outValue = RRule.FREQUENCIES[options.freq];
                break;
            case 'WKST':
                if (isNumber$1(value)) {
                    outValue = new Weekday(value).toString();
                }
                else {
                    outValue = value.toString();
                }
                break;
            case 'BYWEEKDAY':
                /*
                  NOTE: BYWEEKDAY is a special case.
                  RRule() deconstructs the rule.options.byweekday array
                  into an array of Weekday arguments.
                  On the other hand, rule.origOptions is an array of Weekdays.
                  We need to handle both cases here.
                  It might be worth change RRule to keep the Weekdays.
        
                  Also, BYWEEKDAY (used by RRule) vs. BYDAY (RFC)
        
                  */
                key = 'BYDAY';
                outValue = toArray(value)
                    .map(function (wday) {
                    if (wday instanceof Weekday) {
                        return wday;
                    }
                    if (isArray(wday)) {
                        return new Weekday(wday[0], wday[1]);
                    }
                    return new Weekday(wday);
                })
                    .toString();
                break;
            case 'DTSTART':
                dtstart = buildDtstart(value, options.tzid);
                break;
            case 'UNTIL':
                outValue = timeToUntilString(value, !options.tzid);
                break;
            default:
                if (isArray(value)) {
                    var strValues = [];
                    for (var j = 0; j < value.length; j++) {
                        strValues[j] = String(value[j]);
                    }
                    outValue = strValues.toString();
                }
                else {
                    outValue = String(value);
                }
        }
        if (outValue) {
            rrule.push([key, outValue]);
        }
    }
    var rules = rrule
        .map(function (_a) {
        var key = _a[0], value = _a[1];
        return "".concat(key, "=").concat(value.toString());
    })
        .join(';');
    var ruleString = '';
    if (rules !== '') {
        ruleString = "RRULE:".concat(rules);
    }
    return [dtstart, ruleString].filter(function (x) { return !!x; }).join('\n');
}
function buildDtstart(dtstart, tzid) {
    if (!dtstart) {
        return '';
    }
    return 'DTSTART' + new DateWithZone(new Date(dtstart), tzid).toString();
}

function argsMatch(left, right) {
    if (Array.isArray(left)) {
        if (!Array.isArray(right))
            return false;
        if (left.length !== right.length)
            return false;
        return left.every(function (date, i) { return date.getTime() === right[i].getTime(); });
    }
    if (left instanceof Date) {
        return right instanceof Date && left.getTime() === right.getTime();
    }
    return left === right;
}
var Cache = /** @class */ (function () {
    function Cache() {
        this.all = false;
        this.before = [];
        this.after = [];
        this.between = [];
    }
    /**
     * @param {String} what - all/before/after/between
     * @param {Array,Date} value - an array of dates, one date, or null
     * @param {Object?} args - _iter arguments
     */
    Cache.prototype._cacheAdd = function (what, value, args) {
        if (value) {
            value = value instanceof Date ? clone(value) : cloneDates(value);
        }
        if (what === 'all') {
            this.all = value;
        }
        else {
            args._value = value;
            this[what].push(args);
        }
    };
    /**
     * @return false - not in the cache
     * @return null  - cached, but zero occurrences (before/after)
     * @return Date  - cached (before/after)
     * @return []    - cached, but zero occurrences (all/between)
     * @return [Date1, DateN] - cached (all/between)
     */
    Cache.prototype._cacheGet = function (what, args) {
        var cached = false;
        var argsKeys = args ? Object.keys(args) : [];
        var findCacheDiff = function (item) {
            for (var i = 0; i < argsKeys.length; i++) {
                var key = argsKeys[i];
                if (!argsMatch(args[key], item[key])) {
                    return true;
                }
            }
            return false;
        };
        var cachedObject = this[what];
        if (what === 'all') {
            cached = this.all;
        }
        else if (isArray(cachedObject)) {
            // Let's see whether we've already called the
            // 'what' method with the same 'args'
            for (var i = 0; i < cachedObject.length; i++) {
                var item = cachedObject[i];
                if (argsKeys.length && findCacheDiff(item))
                    continue;
                cached = item._value;
                break;
            }
        }
        if (!cached && this.all) {
            // Not in the cache, but we already know all the occurrences,
            // so we can find the correct dates from the cached ones.
            var iterResult = new IterResult(what, args);
            for (var i = 0; i < this.all.length; i++) {
                if (!iterResult.accept(this.all[i]))
                    break;
            }
            cached = iterResult.getValue();
            this._cacheAdd(what, cached, args);
        }
        return isArray(cached)
            ? cloneDates(cached)
            : cached instanceof Date
                ? clone(cached)
                : cached;
    };
    return Cache;
}());

// =============================================================================
// Date masks
// =============================================================================
// Every mask is 7 days longer to handle cross-year weekly periods.
var M365MASK = __spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], repeat(1, 31), true), repeat(2, 28), true), repeat(3, 31), true), repeat(4, 30), true), repeat(5, 31), true), repeat(6, 30), true), repeat(7, 31), true), repeat(8, 31), true), repeat(9, 30), true), repeat(10, 31), true), repeat(11, 30), true), repeat(12, 31), true), repeat(1, 7), true);
var M366MASK = __spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], repeat(1, 31), true), repeat(2, 29), true), repeat(3, 31), true), repeat(4, 30), true), repeat(5, 31), true), repeat(6, 30), true), repeat(7, 31), true), repeat(8, 31), true), repeat(9, 30), true), repeat(10, 31), true), repeat(11, 30), true), repeat(12, 31), true), repeat(1, 7), true);
var M28 = range(1, 29);
var M29 = range(1, 30);
var M30 = range(1, 31);
var M31 = range(1, 32);
var MDAY366MASK = __spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], M31, true), M29, true), M31, true), M30, true), M31, true), M30, true), M31, true), M31, true), M30, true), M31, true), M30, true), M31, true), M31.slice(0, 7), true);
var MDAY365MASK = __spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], M31, true), M28, true), M31, true), M30, true), M31, true), M30, true), M31, true), M31, true), M30, true), M31, true), M30, true), M31, true), M31.slice(0, 7), true);
var NM28 = range(-28, 0);
var NM29 = range(-29, 0);
var NM30 = range(-30, 0);
var NM31 = range(-31, 0);
var NMDAY366MASK = __spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], NM31, true), NM29, true), NM31, true), NM30, true), NM31, true), NM30, true), NM31, true), NM31, true), NM30, true), NM31, true), NM30, true), NM31, true), NM31.slice(0, 7), true);
var NMDAY365MASK = __spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], NM31, true), NM28, true), NM31, true), NM30, true), NM31, true), NM30, true), NM31, true), NM31, true), NM30, true), NM31, true), NM30, true), NM31, true), NM31.slice(0, 7), true);
var M366RANGE = [0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335, 366];
var M365RANGE = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365];
var WDAYMASK = (function () {
    var wdaymask = [];
    for (var i = 0; i < 55; i++)
        wdaymask = wdaymask.concat(range(7));
    return wdaymask;
})();

function rebuildYear(year, options) {
    var firstyday = datetime(year, 1, 1);
    var yearlen = isLeapYear(year) ? 366 : 365;
    var nextyearlen = isLeapYear(year + 1) ? 366 : 365;
    var yearordinal = toOrdinal(firstyday);
    var yearweekday = getWeekday(firstyday);
    var result = __assign(__assign({ yearlen: yearlen, nextyearlen: nextyearlen, yearordinal: yearordinal, yearweekday: yearweekday }, baseYearMasks(year)), { wnomask: null });
    if (empty(options.byweekno)) {
        return result;
    }
    result.wnomask = repeat(0, yearlen + 7);
    var firstwkst;
    var wyearlen;
    var no1wkst = (firstwkst = pymod(7 - yearweekday + options.wkst, 7));
    if (no1wkst >= 4) {
        no1wkst = 0;
        // Number of days in the year, plus the days we got
        // from last year.
        wyearlen = result.yearlen + pymod(yearweekday - options.wkst, 7);
    }
    else {
        // Number of days in the year, minus the days we
        // left in last year.
        wyearlen = yearlen - no1wkst;
    }
    var div = Math.floor(wyearlen / 7);
    var mod = pymod(wyearlen, 7);
    var numweeks = Math.floor(div + mod / 4);
    for (var j = 0; j < options.byweekno.length; j++) {
        var n = options.byweekno[j];
        if (n < 0) {
            n += numweeks + 1;
        }
        if (!(n > 0 && n <= numweeks)) {
            continue;
        }
        var i = void 0;
        if (n > 1) {
            i = no1wkst + (n - 1) * 7;
            if (no1wkst !== firstwkst) {
                i -= 7 - firstwkst;
            }
        }
        else {
            i = no1wkst;
        }
        for (var k = 0; k < 7; k++) {
            result.wnomask[i] = 1;
            i++;
            if (result.wdaymask[i] === options.wkst)
                break;
        }
    }
    if (includes(options.byweekno, 1)) {
        // Check week number 1 of next year as well
        // orig-TODO : Check -numweeks for next year.
        var i = no1wkst + numweeks * 7;
        if (no1wkst !== firstwkst)
            i -= 7 - firstwkst;
        if (i < yearlen) {
            // If week starts in next year, we
            // don't care about it.
            for (var j = 0; j < 7; j++) {
                result.wnomask[i] = 1;
                i += 1;
                if (result.wdaymask[i] === options.wkst)
                    break;
            }
        }
    }
    if (no1wkst) {
        // Check last week number of last year as
        // well. If no1wkst is 0, either the year
        // started on week start, or week number 1
        // got days from last year, so there are no
        // days from last year's last week number in
        // this year.
        var lnumweeks = void 0;
        if (!includes(options.byweekno, -1)) {
            var lyearweekday = getWeekday(datetime(year - 1, 1, 1));
            var lno1wkst = pymod(7 - lyearweekday.valueOf() + options.wkst, 7);
            var lyearlen = isLeapYear(year - 1) ? 366 : 365;
            var weekst = void 0;
            if (lno1wkst >= 4) {
                lno1wkst = 0;
                weekst = lyearlen + pymod(lyearweekday - options.wkst, 7);
            }
            else {
                weekst = yearlen - no1wkst;
            }
            lnumweeks = Math.floor(52 + pymod(weekst, 7) / 4);
        }
        else {
            lnumweeks = -1;
        }
        if (includes(options.byweekno, lnumweeks)) {
            for (var i = 0; i < no1wkst; i++)
                result.wnomask[i] = 1;
        }
    }
    return result;
}
function baseYearMasks(year) {
    var yearlen = isLeapYear(year) ? 366 : 365;
    var firstyday = datetime(year, 1, 1);
    var wday = getWeekday(firstyday);
    if (yearlen === 365) {
        return {
            mmask: M365MASK,
            mdaymask: MDAY365MASK,
            nmdaymask: NMDAY365MASK,
            wdaymask: WDAYMASK.slice(wday),
            mrange: M365RANGE,
        };
    }
    return {
        mmask: M366MASK,
        mdaymask: MDAY366MASK,
        nmdaymask: NMDAY366MASK,
        wdaymask: WDAYMASK.slice(wday),
        mrange: M366RANGE,
    };
}

function rebuildMonth(year, month, yearlen, mrange, wdaymask, options) {
    var result = {
        lastyear: year,
        lastmonth: month,
        nwdaymask: [],
    };
    var ranges = [];
    if (options.freq === RRule.YEARLY) {
        if (empty(options.bymonth)) {
            ranges = [[0, yearlen]];
        }
        else {
            for (var j = 0; j < options.bymonth.length; j++) {
                month = options.bymonth[j];
                ranges.push(mrange.slice(month - 1, month + 1));
            }
        }
    }
    else if (options.freq === RRule.MONTHLY) {
        ranges = [mrange.slice(month - 1, month + 1)];
    }
    if (empty(ranges)) {
        return result;
    }
    // Weekly frequency won't get here, so we may not
    // care about cross-year weekly periods.
    result.nwdaymask = repeat(0, yearlen);
    for (var j = 0; j < ranges.length; j++) {
        var rang = ranges[j];
        var first = rang[0];
        var last = rang[1] - 1;
        for (var k = 0; k < options.bynweekday.length; k++) {
            var i = void 0;
            var _a = options.bynweekday[k], wday = _a[0], n = _a[1];
            if (n < 0) {
                i = last + (n + 1) * 7;
                i -= pymod(wdaymask[i] - wday, 7);
            }
            else {
                i = first + (n - 1) * 7;
                i += pymod(7 - wdaymask[i] + wday, 7);
            }
            if (first <= i && i <= last)
                result.nwdaymask[i] = 1;
        }
    }
    return result;
}

function easter(y, offset) {
    if (offset === void 0) { offset = 0; }
    var a = y % 19;
    var b = Math.floor(y / 100);
    var c = y % 100;
    var d = Math.floor(b / 4);
    var e = b % 4;
    var f = Math.floor((b + 8) / 25);
    var g = Math.floor((b - f + 1) / 3);
    var h = Math.floor(19 * a + b - d - g + 15) % 30;
    var i = Math.floor(c / 4);
    var k = c % 4;
    var l = Math.floor(32 + 2 * e + 2 * i - h - k) % 7;
    var m = Math.floor((a + 11 * h + 22 * l) / 451);
    var month = Math.floor((h + l - 7 * m + 114) / 31);
    var day = ((h + l - 7 * m + 114) % 31) + 1;
    var date = Date.UTC(y, month - 1, day + offset);
    var yearStart = Date.UTC(y, 0, 1);
    return [Math.ceil((date - yearStart) / (1000 * 60 * 60 * 24))];
}

// =============================================================================
// Iterinfo
// =============================================================================
var Iterinfo = /** @class */ (function () {
    // eslint-disable-next-line no-empty-function
    function Iterinfo(options) {
        this.options = options;
    }
    Iterinfo.prototype.rebuild = function (year, month) {
        var options = this.options;
        if (year !== this.lastyear) {
            this.yearinfo = rebuildYear(year, options);
        }
        if (notEmpty(options.bynweekday) &&
            (month !== this.lastmonth || year !== this.lastyear)) {
            var _a = this.yearinfo, yearlen = _a.yearlen, mrange = _a.mrange, wdaymask = _a.wdaymask;
            this.monthinfo = rebuildMonth(year, month, yearlen, mrange, wdaymask, options);
        }
        if (isPresent(options.byeaster)) {
            this.eastermask = easter(year, options.byeaster);
        }
    };
    Object.defineProperty(Iterinfo.prototype, "lastyear", {
        get: function () {
            return this.monthinfo ? this.monthinfo.lastyear : null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "lastmonth", {
        get: function () {
            return this.monthinfo ? this.monthinfo.lastmonth : null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "yearlen", {
        get: function () {
            return this.yearinfo.yearlen;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "yearordinal", {
        get: function () {
            return this.yearinfo.yearordinal;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "mrange", {
        get: function () {
            return this.yearinfo.mrange;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "wdaymask", {
        get: function () {
            return this.yearinfo.wdaymask;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "mmask", {
        get: function () {
            return this.yearinfo.mmask;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "wnomask", {
        get: function () {
            return this.yearinfo.wnomask;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "nwdaymask", {
        get: function () {
            return this.monthinfo ? this.monthinfo.nwdaymask : [];
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "nextyearlen", {
        get: function () {
            return this.yearinfo.nextyearlen;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "mdaymask", {
        get: function () {
            return this.yearinfo.mdaymask;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Iterinfo.prototype, "nmdaymask", {
        get: function () {
            return this.yearinfo.nmdaymask;
        },
        enumerable: false,
        configurable: true
    });
    Iterinfo.prototype.ydayset = function () {
        return [range(this.yearlen), 0, this.yearlen];
    };
    Iterinfo.prototype.mdayset = function (_, month) {
        var start = this.mrange[month - 1];
        var end = this.mrange[month];
        var set = repeat(null, this.yearlen);
        for (var i = start; i < end; i++)
            set[i] = i;
        return [set, start, end];
    };
    Iterinfo.prototype.wdayset = function (year, month, day) {
        // We need to handle cross-year weeks here.
        var set = repeat(null, this.yearlen + 7);
        var i = toOrdinal(datetime(year, month, day)) - this.yearordinal;
        var start = i;
        for (var j = 0; j < 7; j++) {
            set[i] = i;
            ++i;
            if (this.wdaymask[i] === this.options.wkst)
                break;
        }
        return [set, start, i];
    };
    Iterinfo.prototype.ddayset = function (year, month, day) {
        var set = repeat(null, this.yearlen);
        var i = toOrdinal(datetime(year, month, day)) - this.yearordinal;
        set[i] = i;
        return [set, i, i + 1];
    };
    Iterinfo.prototype.htimeset = function (hour, _, second, millisecond) {
        var _this = this;
        var set = [];
        this.options.byminute.forEach(function (minute) {
            set = set.concat(_this.mtimeset(hour, minute, second, millisecond));
        });
        sort(set);
        return set;
    };
    Iterinfo.prototype.mtimeset = function (hour, minute, _, millisecond) {
        var set = this.options.bysecond.map(function (second) { return new Time(hour, minute, second, millisecond); });
        sort(set);
        return set;
    };
    Iterinfo.prototype.stimeset = function (hour, minute, second, millisecond) {
        return [new Time(hour, minute, second, millisecond)];
    };
    Iterinfo.prototype.getdayset = function (freq) {
        switch (freq) {
            case Frequency.YEARLY:
                return this.ydayset.bind(this);
            case Frequency.MONTHLY:
                return this.mdayset.bind(this);
            case Frequency.WEEKLY:
                return this.wdayset.bind(this);
            case Frequency.DAILY:
                return this.ddayset.bind(this);
            default:
                return this.ddayset.bind(this);
        }
    };
    Iterinfo.prototype.gettimeset = function (freq) {
        switch (freq) {
            case Frequency.HOURLY:
                return this.htimeset.bind(this);
            case Frequency.MINUTELY:
                return this.mtimeset.bind(this);
            case Frequency.SECONDLY:
                return this.stimeset.bind(this);
        }
    };
    return Iterinfo;
}());

function buildPoslist(bysetpos, timeset, start, end, ii, dayset) {
    var poslist = [];
    for (var j = 0; j < bysetpos.length; j++) {
        var daypos = void 0;
        var timepos = void 0;
        var pos = bysetpos[j];
        if (pos < 0) {
            daypos = Math.floor(pos / timeset.length);
            timepos = pymod(pos, timeset.length);
        }
        else {
            daypos = Math.floor((pos - 1) / timeset.length);
            timepos = pymod(pos - 1, timeset.length);
        }
        var tmp = [];
        for (var k = start; k < end; k++) {
            var val = dayset[k];
            if (!isPresent(val))
                continue;
            tmp.push(val);
        }
        var i = void 0;
        if (daypos < 0) {
            i = tmp.slice(daypos)[0];
        }
        else {
            i = tmp[daypos];
        }
        var time = timeset[timepos];
        var date = fromOrdinal(ii.yearordinal + i);
        var res = combine(date, time);
        // XXX: can this ever be in the array?
        // - compare the actual date instead?
        if (!includes(poslist, res))
            poslist.push(res);
    }
    sort(poslist);
    return poslist;
}

function iter(iterResult, options) {
    var dtstart = options.dtstart, freq = options.freq, interval = options.interval, until = options.until, bysetpos = options.bysetpos;
    var count = options.count;
    if (count === 0 || interval === 0) {
        return emitResult(iterResult);
    }
    var counterDate = DateTime.fromDate(dtstart);
    var ii = new Iterinfo(options);
    ii.rebuild(counterDate.year, counterDate.month);
    var timeset = makeTimeset(ii, counterDate, options);
    for (;;) {
        var _a = ii.getdayset(freq)(counterDate.year, counterDate.month, counterDate.day), dayset = _a[0], start = _a[1], end = _a[2];
        var filtered = removeFilteredDays(dayset, start, end, ii, options);
        if (notEmpty(bysetpos)) {
            var poslist = buildPoslist(bysetpos, timeset, start, end, ii, dayset);
            for (var j = 0; j < poslist.length; j++) {
                var res = poslist[j];
                if (until && res > until) {
                    return emitResult(iterResult);
                }
                if (res >= dtstart) {
                    var rezonedDate = rezoneIfNeeded(res, options);
                    if (!iterResult.accept(rezonedDate)) {
                        return emitResult(iterResult);
                    }
                    if (count) {
                        --count;
                        if (!count) {
                            return emitResult(iterResult);
                        }
                    }
                }
            }
        }
        else {
            for (var j = start; j < end; j++) {
                var currentDay = dayset[j];
                if (!isPresent(currentDay)) {
                    continue;
                }
                var date = fromOrdinal(ii.yearordinal + currentDay);
                for (var k = 0; k < timeset.length; k++) {
                    var time = timeset[k];
                    var res = combine(date, time);
                    if (until && res > until) {
                        return emitResult(iterResult);
                    }
                    if (res >= dtstart) {
                        var rezonedDate = rezoneIfNeeded(res, options);
                        if (!iterResult.accept(rezonedDate)) {
                            return emitResult(iterResult);
                        }
                        if (count) {
                            --count;
                            if (!count) {
                                return emitResult(iterResult);
                            }
                        }
                    }
                }
            }
        }
        if (options.interval === 0) {
            return emitResult(iterResult);
        }
        // Handle frequency and interval
        counterDate.add(options, filtered);
        if (counterDate.year > MAXYEAR) {
            return emitResult(iterResult);
        }
        if (!freqIsDailyOrGreater(freq)) {
            timeset = ii.gettimeset(freq)(counterDate.hour, counterDate.minute, counterDate.second, 0);
        }
        ii.rebuild(counterDate.year, counterDate.month);
    }
}
function isFiltered(ii, currentDay, options) {
    var bymonth = options.bymonth, byweekno = options.byweekno, byweekday = options.byweekday, byeaster = options.byeaster, bymonthday = options.bymonthday, bynmonthday = options.bynmonthday, byyearday = options.byyearday;
    return ((notEmpty(bymonth) && !includes(bymonth, ii.mmask[currentDay])) ||
        (notEmpty(byweekno) && !ii.wnomask[currentDay]) ||
        (notEmpty(byweekday) && !includes(byweekday, ii.wdaymask[currentDay])) ||
        (notEmpty(ii.nwdaymask) && !ii.nwdaymask[currentDay]) ||
        (byeaster !== null && !includes(ii.eastermask, currentDay)) ||
        ((notEmpty(bymonthday) || notEmpty(bynmonthday)) &&
            !includes(bymonthday, ii.mdaymask[currentDay]) &&
            !includes(bynmonthday, ii.nmdaymask[currentDay])) ||
        (notEmpty(byyearday) &&
            ((currentDay < ii.yearlen &&
                !includes(byyearday, currentDay + 1) &&
                !includes(byyearday, -ii.yearlen + currentDay)) ||
                (currentDay >= ii.yearlen &&
                    !includes(byyearday, currentDay + 1 - ii.yearlen) &&
                    !includes(byyearday, -ii.nextyearlen + currentDay - ii.yearlen)))));
}
function rezoneIfNeeded(date, options) {
    return new DateWithZone(date, options.tzid).rezonedDate();
}
function emitResult(iterResult) {
    return iterResult.getValue();
}
function removeFilteredDays(dayset, start, end, ii, options) {
    var filtered = false;
    for (var dayCounter = start; dayCounter < end; dayCounter++) {
        var currentDay = dayset[dayCounter];
        filtered = isFiltered(ii, currentDay, options);
        if (filtered)
            dayset[currentDay] = null;
    }
    return filtered;
}
function makeTimeset(ii, counterDate, options) {
    var freq = options.freq, byhour = options.byhour, byminute = options.byminute, bysecond = options.bysecond;
    if (freqIsDailyOrGreater(freq)) {
        return buildTimeset(options);
    }
    if ((freq >= RRule.HOURLY &&
        notEmpty(byhour) &&
        !includes(byhour, counterDate.hour)) ||
        (freq >= RRule.MINUTELY &&
            notEmpty(byminute) &&
            !includes(byminute, counterDate.minute)) ||
        (freq >= RRule.SECONDLY &&
            notEmpty(bysecond) &&
            !includes(bysecond, counterDate.second))) {
        return [];
    }
    return ii.gettimeset(freq)(counterDate.hour, counterDate.minute, counterDate.second, counterDate.millisecond);
}

// =============================================================================
// RRule
// =============================================================================
var Days = {
    MO: new Weekday(0),
    TU: new Weekday(1),
    WE: new Weekday(2),
    TH: new Weekday(3),
    FR: new Weekday(4),
    SA: new Weekday(5),
    SU: new Weekday(6),
};
var DEFAULT_OPTIONS$1 = {
    freq: Frequency.YEARLY,
    dtstart: null,
    interval: 1,
    wkst: Days.MO,
    count: null,
    until: null,
    tzid: null,
    bysetpos: null,
    bymonth: null,
    bymonthday: null,
    bynmonthday: null,
    byyearday: null,
    byweekno: null,
    byweekday: null,
    bynweekday: null,
    byhour: null,
    byminute: null,
    bysecond: null,
    byeaster: null,
};
var defaultKeys = Object.keys(DEFAULT_OPTIONS$1);
/**
 *
 * @param {Options?} options - see <http://labix.org/python-dateutil/#head-cf004ee9a75592797e076752b2a889c10f445418>
 * - The only required option is `freq`, one of RRule.YEARLY, RRule.MONTHLY, ...
 * @constructor
 */
var RRule = /** @class */ (function () {
    function RRule(options, noCache) {
        if (options === void 0) { options = {}; }
        if (noCache === void 0) { noCache = false; }
        // RFC string
        this._cache = noCache ? null : new Cache();
        // used by toString()
        this.origOptions = initializeOptions$1(options);
        var parsedOptions = parseOptions(options).parsedOptions;
        this.options = parsedOptions;
    }
    RRule.parseText = function (text, language) {
        return parseText(text, language);
    };
    RRule.fromText = function (text, language) {
        return fromText(text, language);
    };
    RRule.fromString = function (str) {
        return new RRule(RRule.parseString(str) || undefined);
    };
    RRule.prototype._iter = function (iterResult) {
        return iter(iterResult, this.options);
    };
    RRule.prototype._cacheGet = function (what, args) {
        if (!this._cache)
            return false;
        return this._cache._cacheGet(what, args);
    };
    RRule.prototype._cacheAdd = function (what, value, args) {
        if (!this._cache)
            return;
        return this._cache._cacheAdd(what, value, args);
    };
    /**
     * @param {Function} iterator - optional function that will be called
     * on each date that is added. It can return false
     * to stop the iteration.
     * @return Array containing all recurrences.
     */
    RRule.prototype.all = function (iterator) {
        if (iterator) {
            return this._iter(new CallbackIterResult('all', {}, iterator));
        }
        var result = this._cacheGet('all');
        if (result === false) {
            result = this._iter(new IterResult('all', {}));
            this._cacheAdd('all', result);
        }
        return result;
    };
    /**
     * Returns all the occurrences of the rrule between after and before.
     * The inc keyword defines what happens if after and/or before are
     * themselves occurrences. With inc == True, they will be included in the
     * list, if they are found in the recurrence set.
     *
     * @return Array
     */
    RRule.prototype.between = function (after, before, inc, iterator) {
        if (inc === void 0) { inc = false; }
        if (!isValidDate(after) || !isValidDate(before)) {
            throw new Error('Invalid date passed in to RRule.between');
        }
        var args = {
            before: before,
            after: after,
            inc: inc,
        };
        if (iterator) {
            return this._iter(new CallbackIterResult('between', args, iterator));
        }
        var result = this._cacheGet('between', args);
        if (result === false) {
            result = this._iter(new IterResult('between', args));
            this._cacheAdd('between', result, args);
        }
        return result;
    };
    /**
     * Returns the last recurrence before the given datetime instance.
     * The inc keyword defines what happens if dt is an occurrence.
     * With inc == True, if dt itself is an occurrence, it will be returned.
     *
     * @return Date or null
     */
    RRule.prototype.before = function (dt, inc) {
        if (inc === void 0) { inc = false; }
        if (!isValidDate(dt)) {
            throw new Error('Invalid date passed in to RRule.before');
        }
        var args = { dt: dt, inc: inc };
        var result = this._cacheGet('before', args);
        if (result === false) {
            result = this._iter(new IterResult('before', args));
            this._cacheAdd('before', result, args);
        }
        return result;
    };
    /**
     * Returns the first recurrence after the given datetime instance.
     * The inc keyword defines what happens if dt is an occurrence.
     * With inc == True, if dt itself is an occurrence, it will be returned.
     *
     * @return Date or null
     */
    RRule.prototype.after = function (dt, inc) {
        if (inc === void 0) { inc = false; }
        if (!isValidDate(dt)) {
            throw new Error('Invalid date passed in to RRule.after');
        }
        var args = { dt: dt, inc: inc };
        var result = this._cacheGet('after', args);
        if (result === false) {
            result = this._iter(new IterResult('after', args));
            this._cacheAdd('after', result, args);
        }
        return result;
    };
    /**
     * Returns the number of recurrences in this set. It will have go trough
     * the whole recurrence, if this hasn't been done before.
     */
    RRule.prototype.count = function () {
        return this.all().length;
    };
    /**
     * Converts the rrule into its string representation
     *
     * @see <http://www.ietf.org/rfc/rfc2445.txt>
     * @return String
     */
    RRule.prototype.toString = function () {
        return optionsToString(this.origOptions);
    };
    /**
     * Will convert all rules described in nlp:ToText
     * to text.
     */
    RRule.prototype.toText = function (gettext, language, dateFormatter) {
        return toText(this, gettext, language, dateFormatter);
    };
    RRule.prototype.isFullyConvertibleToText = function () {
        return isFullyConvertible(this);
    };
    /**
     * @return a RRule instance with the same freq and options
     * as this one (cache is not cloned)
     */
    RRule.prototype.clone = function () {
        return new RRule(this.origOptions);
    };
    // RRule class 'constants'
    RRule.FREQUENCIES = [
        'YEARLY',
        'MONTHLY',
        'WEEKLY',
        'DAILY',
        'HOURLY',
        'MINUTELY',
        'SECONDLY',
    ];
    RRule.YEARLY = Frequency.YEARLY;
    RRule.MONTHLY = Frequency.MONTHLY;
    RRule.WEEKLY = Frequency.WEEKLY;
    RRule.DAILY = Frequency.DAILY;
    RRule.HOURLY = Frequency.HOURLY;
    RRule.MINUTELY = Frequency.MINUTELY;
    RRule.SECONDLY = Frequency.SECONDLY;
    RRule.MO = Days.MO;
    RRule.TU = Days.TU;
    RRule.WE = Days.WE;
    RRule.TH = Days.TH;
    RRule.FR = Days.FR;
    RRule.SA = Days.SA;
    RRule.SU = Days.SU;
    RRule.parseString = parseString;
    RRule.optionsToString = optionsToString;
    return RRule;
}());

function iterSet(iterResult, _rrule, _exrule, _rdate, _exdate, tzid) {
    var _exdateHash = {};
    var _accept = iterResult.accept;
    function evalExdate(after, before) {
        _exrule.forEach(function (rrule) {
            rrule.between(after, before, true).forEach(function (date) {
                _exdateHash[Number(date)] = true;
            });
        });
    }
    _exdate.forEach(function (date) {
        var zonedDate = new DateWithZone(date, tzid).rezonedDate();
        _exdateHash[Number(zonedDate)] = true;
    });
    iterResult.accept = function (date) {
        var dt = Number(date);
        if (isNaN(dt))
            return _accept.call(this, date);
        if (!_exdateHash[dt]) {
            evalExdate(new Date(dt - 1), new Date(dt + 1));
            if (!_exdateHash[dt]) {
                _exdateHash[dt] = true;
                return _accept.call(this, date);
            }
        }
        return true;
    };
    if (iterResult.method === 'between') {
        evalExdate(iterResult.args.after, iterResult.args.before);
        iterResult.accept = function (date) {
            var dt = Number(date);
            if (!_exdateHash[dt]) {
                _exdateHash[dt] = true;
                return _accept.call(this, date);
            }
            return true;
        };
    }
    for (var i = 0; i < _rdate.length; i++) {
        var zonedDate = new DateWithZone(_rdate[i], tzid).rezonedDate();
        if (!iterResult.accept(new Date(zonedDate.getTime())))
            break;
    }
    _rrule.forEach(function (rrule) {
        iter(iterResult, rrule.options);
    });
    var res = iterResult._result;
    sort(res);
    switch (iterResult.method) {
        case 'all':
        case 'between':
            return res;
        case 'before':
            return ((res.length && res[res.length - 1]) || null);
        case 'after':
        default:
            return ((res.length && res[0]) || null);
    }
}

/**
 * RRuleStr
 * To parse a set of rrule strings
 */
var DEFAULT_OPTIONS = {
    dtstart: null,
    cache: false,
    unfold: false,
    forceset: false,
    compatible: false,
    tzid: null,
};
function parseInput(s, options) {
    var rrulevals = [];
    var rdatevals = [];
    var exrulevals = [];
    var exdatevals = [];
    var parsedDtstart = parseDtstart(s);
    var dtstart = parsedDtstart.dtstart;
    var tzid = parsedDtstart.tzid;
    var lines = splitIntoLines(s, options.unfold);
    lines.forEach(function (line) {
        var _a;
        if (!line)
            return;
        var _b = breakDownLine(line), name = _b.name, parms = _b.parms, value = _b.value;
        switch (name.toUpperCase()) {
            case 'RRULE':
                if (parms.length) {
                    throw new Error("unsupported RRULE parm: ".concat(parms.join(',')));
                }
                rrulevals.push(parseString(line));
                break;
            case 'RDATE':
                var _c = (_a = /RDATE(?:;TZID=([^:=]+))?/i.exec(line)) !== null && _a !== void 0 ? _a : [], rdateTzid = _c[1];
                if (rdateTzid && !tzid) {
                    tzid = rdateTzid;
                }
                rdatevals = rdatevals.concat(parseRDate(value, parms));
                break;
            case 'EXRULE':
                if (parms.length) {
                    throw new Error("unsupported EXRULE parm: ".concat(parms.join(',')));
                }
                exrulevals.push(parseString(value));
                break;
            case 'EXDATE':
                exdatevals = exdatevals.concat(parseRDate(value, parms));
                break;
            case 'DTSTART':
                break;
            default:
                throw new Error('unsupported property: ' + name);
        }
    });
    return {
        dtstart: dtstart,
        tzid: tzid,
        rrulevals: rrulevals,
        rdatevals: rdatevals,
        exrulevals: exrulevals,
        exdatevals: exdatevals,
    };
}
function buildRule(s, options) {
    var _a = parseInput(s, options), rrulevals = _a.rrulevals, rdatevals = _a.rdatevals, exrulevals = _a.exrulevals, exdatevals = _a.exdatevals, dtstart = _a.dtstart, tzid = _a.tzid;
    var noCache = options.cache === false;
    if (options.compatible) {
        options.forceset = true;
        options.unfold = true;
    }
    if (options.forceset ||
        rrulevals.length > 1 ||
        rdatevals.length ||
        exrulevals.length ||
        exdatevals.length) {
        var rset_1 = new RRuleSet(noCache);
        rset_1.dtstart(dtstart);
        rset_1.tzid(tzid || undefined);
        rrulevals.forEach(function (val) {
            rset_1.rrule(new RRule(groomRruleOptions(val, dtstart, tzid), noCache));
        });
        rdatevals.forEach(function (date) {
            rset_1.rdate(date);
        });
        exrulevals.forEach(function (val) {
            rset_1.exrule(new RRule(groomRruleOptions(val, dtstart, tzid), noCache));
        });
        exdatevals.forEach(function (date) {
            rset_1.exdate(date);
        });
        if (options.compatible && options.dtstart)
            rset_1.rdate(dtstart);
        return rset_1;
    }
    var val = rrulevals[0] || {};
    return new RRule(groomRruleOptions(val, val.dtstart || options.dtstart || dtstart, val.tzid || options.tzid || tzid), noCache);
}
function rrulestr(s, options) {
    if (options === void 0) { options = {}; }
    return buildRule(s, initializeOptions(options));
}
function groomRruleOptions(val, dtstart, tzid) {
    return __assign(__assign({}, val), { dtstart: dtstart, tzid: tzid });
}
function initializeOptions(options) {
    var invalid = [];
    var keys = Object.keys(options);
    var defaultKeys = Object.keys(DEFAULT_OPTIONS);
    keys.forEach(function (key) {
        if (!includes(defaultKeys, key))
            invalid.push(key);
    });
    if (invalid.length) {
        throw new Error('Invalid options: ' + invalid.join(', '));
    }
    return __assign(__assign({}, DEFAULT_OPTIONS), options);
}
function extractName(line) {
    if (line.indexOf(':') === -1) {
        return {
            name: 'RRULE',
            value: line,
        };
    }
    var _a = split(line, ':', 1), name = _a[0], value = _a[1];
    return {
        name: name,
        value: value,
    };
}
function breakDownLine(line) {
    var _a = extractName(line), name = _a.name, value = _a.value;
    var parms = name.split(';');
    if (!parms)
        throw new Error('empty property name');
    return {
        name: parms[0].toUpperCase(),
        parms: parms.slice(1),
        value: value,
    };
}
function splitIntoLines(s, unfold) {
    if (unfold === void 0) { unfold = false; }
    s = s && s.trim();
    if (!s)
        throw new Error('Invalid empty string');
    // More info about 'unfold' option
    // Go head to http://www.ietf.org/rfc/rfc2445.txt
    if (!unfold) {
        return s.split(/\s/);
    }
    var lines = s.split('\n');
    var i = 0;
    while (i < lines.length) {
        // TODO
        var line = (lines[i] = lines[i].replace(/\s+$/g, ''));
        if (!line) {
            lines.splice(i, 1);
        }
        else if (i > 0 && line[0] === ' ') {
            lines[i - 1] += line.slice(1);
            lines.splice(i, 1);
        }
        else {
            i += 1;
        }
    }
    return lines;
}
function validateDateParm(parms) {
    parms.forEach(function (parm) {
        if (!/(VALUE=DATE(-TIME)?)|(TZID=)/.test(parm)) {
            throw new Error('unsupported RDATE/EXDATE parm: ' + parm);
        }
    });
}
function parseRDate(rdateval, parms) {
    validateDateParm(parms);
    return rdateval.split(',').map(function (datestr) { return untilStringToDate(datestr); });
}

function createGetterSetter(fieldName) {
    var _this = this;
    return function (field) {
        if (field !== undefined) {
            _this["_".concat(fieldName)] = field;
        }
        if (_this["_".concat(fieldName)] !== undefined) {
            return _this["_".concat(fieldName)];
        }
        for (var i = 0; i < _this._rrule.length; i++) {
            var field_1 = _this._rrule[i].origOptions[fieldName];
            if (field_1) {
                return field_1;
            }
        }
    };
}
var RRuleSet = /** @class */ (function (_super) {
    __extends(RRuleSet, _super);
    /**
     *
     * @param {Boolean?} noCache
     * The same stratagy as RRule on cache, default to false
     * @constructor
     */
    function RRuleSet(noCache) {
        if (noCache === void 0) { noCache = false; }
        var _this = _super.call(this, {}, noCache) || this;
        _this.dtstart = createGetterSetter.apply(_this, ['dtstart']);
        _this.tzid = createGetterSetter.apply(_this, ['tzid']);
        _this._rrule = [];
        _this._rdate = [];
        _this._exrule = [];
        _this._exdate = [];
        return _this;
    }
    RRuleSet.prototype._iter = function (iterResult) {
        return iterSet(iterResult, this._rrule, this._exrule, this._rdate, this._exdate, this.tzid());
    };
    /**
     * Adds an RRule to the set
     *
     * @param {RRule}
     */
    RRuleSet.prototype.rrule = function (rrule) {
        _addRule(rrule, this._rrule);
    };
    /**
     * Adds an EXRULE to the set
     *
     * @param {RRule}
     */
    RRuleSet.prototype.exrule = function (rrule) {
        _addRule(rrule, this._exrule);
    };
    /**
     * Adds an RDate to the set
     *
     * @param {Date}
     */
    RRuleSet.prototype.rdate = function (date) {
        _addDate(date, this._rdate);
    };
    /**
     * Adds an EXDATE to the set
     *
     * @param {Date}
     */
    RRuleSet.prototype.exdate = function (date) {
        _addDate(date, this._exdate);
    };
    /**
     * Get list of included rrules in this recurrence set.
     *
     * @return List of rrules
     */
    RRuleSet.prototype.rrules = function () {
        return this._rrule.map(function (e) { return rrulestr(e.toString()); });
    };
    /**
     * Get list of excluded rrules in this recurrence set.
     *
     * @return List of exrules
     */
    RRuleSet.prototype.exrules = function () {
        return this._exrule.map(function (e) { return rrulestr(e.toString()); });
    };
    /**
     * Get list of included datetimes in this recurrence set.
     *
     * @return List of rdates
     */
    RRuleSet.prototype.rdates = function () {
        return this._rdate.map(function (e) { return new Date(e.getTime()); });
    };
    /**
     * Get list of included datetimes in this recurrence set.
     *
     * @return List of exdates
     */
    RRuleSet.prototype.exdates = function () {
        return this._exdate.map(function (e) { return new Date(e.getTime()); });
    };
    RRuleSet.prototype.valueOf = function () {
        var result = [];
        if (!this._rrule.length && this._dtstart) {
            result = result.concat(optionsToString({ dtstart: this._dtstart }));
        }
        this._rrule.forEach(function (rrule) {
            result = result.concat(rrule.toString().split('\n'));
        });
        this._exrule.forEach(function (exrule) {
            result = result.concat(exrule
                .toString()
                .split('\n')
                .map(function (line) { return line.replace(/^RRULE:/, 'EXRULE:'); })
                .filter(function (line) { return !/^DTSTART/.test(line); }));
        });
        if (this._rdate.length) {
            result.push(rdatesToString('RDATE', this._rdate, this.tzid()));
        }
        if (this._exdate.length) {
            result.push(rdatesToString('EXDATE', this._exdate, this.tzid()));
        }
        return result;
    };
    /**
     * to generate recurrence field such as:
     * DTSTART:19970902T010000Z
     * RRULE:FREQ=YEARLY;COUNT=2;BYDAY=TU
     * RRULE:FREQ=YEARLY;COUNT=1;BYDAY=TH
     */
    RRuleSet.prototype.toString = function () {
        return this.valueOf().join('\n');
    };
    /**
     * Create a new RRuleSet Object completely base on current instance
     */
    RRuleSet.prototype.clone = function () {
        var rrs = new RRuleSet(!!this._cache);
        this._rrule.forEach(function (rule) { return rrs.rrule(rule.clone()); });
        this._exrule.forEach(function (rule) { return rrs.exrule(rule.clone()); });
        this._rdate.forEach(function (date) { return rrs.rdate(new Date(date.getTime())); });
        this._exdate.forEach(function (date) { return rrs.exdate(new Date(date.getTime())); });
        return rrs;
    };
    return RRuleSet;
}(RRule));
function _addRule(rrule, collection) {
    if (!(rrule instanceof RRule)) {
        throw new TypeError(String(rrule) + ' is not RRule instance');
    }
    if (!includes(collection.map(String), String(rrule))) {
        collection.push(rrule);
    }
}
function _addDate(date, collection) {
    if (!(date instanceof Date)) {
        throw new TypeError(String(date) + ' is not Date instance');
    }
    if (!includes(collection.map(Number), Number(date))) {
        collection.push(date);
        sort(collection);
    }
}
function rdatesToString(param, rdates, tzid) {
    var isUTC = !tzid || tzid.toUpperCase() === 'UTC';
    var header = isUTC ? "".concat(param, ":") : "".concat(param, ";TZID=").concat(tzid, ":");
    var dateString = rdates
        .map(function (rdate) { return timeToUntilString(rdate.valueOf(), isUTC); })
        .join(',');
    return "".concat(header).concat(dateString);
}

const consoleLogger = {
  type: 'logger',
  log(args) {
    this.output('log', args);
  },
  warn(args) {
    this.output('warn', args);
  },
  error(args) {
    this.output('error', args);
  },
  output(type, args) {
    if (console && console[type]) console[type].apply(console, args);
  }
};
class Logger {
  constructor(concreteLogger) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    this.init(concreteLogger, options);
  }
  init(concreteLogger) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    this.prefix = options.prefix || 'i18next:';
    this.logger = concreteLogger || consoleLogger;
    this.options = options;
    this.debug = options.debug;
  }
  log() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    return this.forward(args, 'log', '', true);
  }
  warn() {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }
    return this.forward(args, 'warn', '', true);
  }
  error() {
    for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      args[_key3] = arguments[_key3];
    }
    return this.forward(args, 'error', '');
  }
  deprecate() {
    for (var _len4 = arguments.length, args = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
      args[_key4] = arguments[_key4];
    }
    return this.forward(args, 'warn', 'WARNING DEPRECATED: ', true);
  }
  forward(args, lvl, prefix, debugOnly) {
    if (debugOnly && !this.debug) return null;
    if (typeof args[0] === 'string') args[0] = `${prefix}${this.prefix} ${args[0]}`;
    return this.logger[lvl](args);
  }
  create(moduleName) {
    return new Logger(this.logger, {
      ...{
        prefix: `${this.prefix}:${moduleName}:`
      },
      ...this.options
    });
  }
  clone(options) {
    options = options || this.options;
    options.prefix = options.prefix || this.prefix;
    return new Logger(this.logger, options);
  }
}
var baseLogger = new Logger();

class EventEmitter {
  constructor() {
    this.observers = {};
  }
  on(events, listener) {
    events.split(' ').forEach(event => {
      if (!this.observers[event]) this.observers[event] = new Map();
      const numListeners = this.observers[event].get(listener) || 0;
      this.observers[event].set(listener, numListeners + 1);
    });
    return this;
  }
  off(event, listener) {
    if (!this.observers[event]) return;
    if (!listener) {
      delete this.observers[event];
      return;
    }
    this.observers[event].delete(listener);
  }
  emit(event) {
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }
    if (this.observers[event]) {
      const cloned = Array.from(this.observers[event].entries());
      cloned.forEach(_ref => {
        let [observer, numTimesAdded] = _ref;
        for (let i = 0; i < numTimesAdded; i++) {
          observer(...args);
        }
      });
    }
    if (this.observers['*']) {
      const cloned = Array.from(this.observers['*'].entries());
      cloned.forEach(_ref2 => {
        let [observer, numTimesAdded] = _ref2;
        for (let i = 0; i < numTimesAdded; i++) {
          observer.apply(observer, [event, ...args]);
        }
      });
    }
  }
}

function defer() {
  let res;
  let rej;
  const promise = new Promise((resolve, reject) => {
    res = resolve;
    rej = reject;
  });
  promise.resolve = res;
  promise.reject = rej;
  return promise;
}
function makeString(object) {
  if (object == null) return '';
  return '' + object;
}
function copy(a, s, t) {
  a.forEach(m => {
    if (s[m]) t[m] = s[m];
  });
}
const lastOfPathSeparatorRegExp = /###/g;
function getLastOfPath(object, path, Empty) {
  function cleanKey(key) {
    return key && key.indexOf('###') > -1 ? key.replace(lastOfPathSeparatorRegExp, '.') : key;
  }
  function canNotTraverseDeeper() {
    return !object || typeof object === 'string';
  }
  const stack = typeof path !== 'string' ? path : path.split('.');
  let stackIndex = 0;
  while (stackIndex < stack.length - 1) {
    if (canNotTraverseDeeper()) return {};
    const key = cleanKey(stack[stackIndex]);
    if (!object[key] && Empty) object[key] = new Empty();
    if (Object.prototype.hasOwnProperty.call(object, key)) {
      object = object[key];
    } else {
      object = {};
    }
    ++stackIndex;
  }
  if (canNotTraverseDeeper()) return {};
  return {
    obj: object,
    k: cleanKey(stack[stackIndex])
  };
}
function setPath(object, path, newValue) {
  const {
    obj,
    k
  } = getLastOfPath(object, path, Object);
  if (obj !== undefined || path.length === 1) {
    obj[k] = newValue;
    return;
  }
  let e = path[path.length - 1];
  let p = path.slice(0, path.length - 1);
  let last = getLastOfPath(object, p, Object);
  while (last.obj === undefined && p.length) {
    e = `${p[p.length - 1]}.${e}`;
    p = p.slice(0, p.length - 1);
    last = getLastOfPath(object, p, Object);
    if (last && last.obj && typeof last.obj[`${last.k}.${e}`] !== 'undefined') {
      last.obj = undefined;
    }
  }
  last.obj[`${last.k}.${e}`] = newValue;
}
function pushPath(object, path, newValue, concat) {
  const {
    obj,
    k
  } = getLastOfPath(object, path, Object);
  obj[k] = obj[k] || [];
  if (concat) obj[k] = obj[k].concat(newValue);
  if (!concat) obj[k].push(newValue);
}
function getPath(object, path) {
  const {
    obj,
    k
  } = getLastOfPath(object, path);
  if (!obj) return undefined;
  return obj[k];
}
function getPathWithDefaults(data, defaultData, key) {
  const value = getPath(data, key);
  if (value !== undefined) {
    return value;
  }
  return getPath(defaultData, key);
}
function deepExtend(target, source, overwrite) {
  for (const prop in source) {
    if (prop !== '__proto__' && prop !== 'constructor') {
      if (prop in target) {
        if (typeof target[prop] === 'string' || target[prop] instanceof String || typeof source[prop] === 'string' || source[prop] instanceof String) {
          if (overwrite) target[prop] = source[prop];
        } else {
          deepExtend(target[prop], source[prop], overwrite);
        }
      } else {
        target[prop] = source[prop];
      }
    }
  }
  return target;
}
function regexEscape(str) {
  return str.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, '\\$&');
}
var _entityMap = {
  '&': '&amp;',
  '<': '&lt;',
  '>': '&gt;',
  '"': '&quot;',
  "'": '&#39;',
  '/': '&#x2F;'
};
function escape(data) {
  if (typeof data === 'string') {
    return data.replace(/[&<>"'\/]/g, s => _entityMap[s]);
  }
  return data;
}
class RegExpCache {
  constructor(capacity) {
    this.capacity = capacity;
    this.regExpMap = new Map();
    this.regExpQueue = [];
  }
  getRegExp(pattern) {
    const regExpFromCache = this.regExpMap.get(pattern);
    if (regExpFromCache !== undefined) {
      return regExpFromCache;
    }
    const regExpNew = new RegExp(pattern);
    if (this.regExpQueue.length === this.capacity) {
      this.regExpMap.delete(this.regExpQueue.shift());
    }
    this.regExpMap.set(pattern, regExpNew);
    this.regExpQueue.push(pattern);
    return regExpNew;
  }
}
const chars = [' ', ',', '?', '!', ';'];
const looksLikeObjectPathRegExpCache = new RegExpCache(20);
function looksLikeObjectPath(key, nsSeparator, keySeparator) {
  nsSeparator = nsSeparator || '';
  keySeparator = keySeparator || '';
  const possibleChars = chars.filter(c => nsSeparator.indexOf(c) < 0 && keySeparator.indexOf(c) < 0);
  if (possibleChars.length === 0) return true;
  const r = looksLikeObjectPathRegExpCache.getRegExp(`(${possibleChars.map(c => c === '?' ? '\\?' : c).join('|')})`);
  let matched = !r.test(key);
  if (!matched) {
    const ki = key.indexOf(keySeparator);
    if (ki > 0 && !r.test(key.substring(0, ki))) {
      matched = true;
    }
  }
  return matched;
}
function deepFind(obj, path) {
  let keySeparator = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '.';
  if (!obj) return undefined;
  if (obj[path]) return obj[path];
  const tokens = path.split(keySeparator);
  let current = obj;
  for (let i = 0; i < tokens.length;) {
    if (!current || typeof current !== 'object') {
      return undefined;
    }
    let next;
    let nextPath = '';
    for (let j = i; j < tokens.length; ++j) {
      if (j !== i) {
        nextPath += keySeparator;
      }
      nextPath += tokens[j];
      next = current[nextPath];
      if (next !== undefined) {
        if (['string', 'number', 'boolean'].indexOf(typeof next) > -1 && j < tokens.length - 1) {
          continue;
        }
        i += j - i + 1;
        break;
      }
    }
    current = next;
  }
  return current;
}
function getCleanedCode(code) {
  if (code && code.indexOf('_') > 0) return code.replace('_', '-');
  return code;
}

class ResourceStore extends EventEmitter {
  constructor(data) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
      ns: ['translation'],
      defaultNS: 'translation'
    };
    super();
    this.data = data || {};
    this.options = options;
    if (this.options.keySeparator === undefined) {
      this.options.keySeparator = '.';
    }
    if (this.options.ignoreJSONStructure === undefined) {
      this.options.ignoreJSONStructure = true;
    }
  }
  addNamespaces(ns) {
    if (this.options.ns.indexOf(ns) < 0) {
      this.options.ns.push(ns);
    }
  }
  removeNamespaces(ns) {
    const index = this.options.ns.indexOf(ns);
    if (index > -1) {
      this.options.ns.splice(index, 1);
    }
  }
  getResource(lng, ns, key) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
    const keySeparator = options.keySeparator !== undefined ? options.keySeparator : this.options.keySeparator;
    const ignoreJSONStructure = options.ignoreJSONStructure !== undefined ? options.ignoreJSONStructure : this.options.ignoreJSONStructure;
    let path;
    if (lng.indexOf('.') > -1) {
      path = lng.split('.');
    } else {
      path = [lng, ns];
      if (key) {
        if (Array.isArray(key)) {
          path.push(...key);
        } else if (typeof key === 'string' && keySeparator) {
          path.push(...key.split(keySeparator));
        } else {
          path.push(key);
        }
      }
    }
    const result = getPath(this.data, path);
    if (!result && !ns && !key && lng.indexOf('.') > -1) {
      lng = path[0];
      ns = path[1];
      key = path.slice(2).join('.');
    }
    if (result || !ignoreJSONStructure || typeof key !== 'string') return result;
    return deepFind(this.data && this.data[lng] && this.data[lng][ns], key, keySeparator);
  }
  addResource(lng, ns, key, value) {
    let options = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {
      silent: false
    };
    const keySeparator = options.keySeparator !== undefined ? options.keySeparator : this.options.keySeparator;
    let path = [lng, ns];
    if (key) path = path.concat(keySeparator ? key.split(keySeparator) : key);
    if (lng.indexOf('.') > -1) {
      path = lng.split('.');
      value = ns;
      ns = path[1];
    }
    this.addNamespaces(ns);
    setPath(this.data, path, value);
    if (!options.silent) this.emit('added', lng, ns, key, value);
  }
  addResources(lng, ns, resources) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {
      silent: false
    };
    for (const m in resources) {
      if (typeof resources[m] === 'string' || Array.isArray(resources[m])) this.addResource(lng, ns, m, resources[m], {
        silent: true
      });
    }
    if (!options.silent) this.emit('added', lng, ns, resources);
  }
  addResourceBundle(lng, ns, resources, deep, overwrite) {
    let options = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : {
      silent: false,
      skipCopy: false
    };
    let path = [lng, ns];
    if (lng.indexOf('.') > -1) {
      path = lng.split('.');
      deep = resources;
      resources = ns;
      ns = path[1];
    }
    this.addNamespaces(ns);
    let pack = getPath(this.data, path) || {};
    if (!options.skipCopy) resources = JSON.parse(JSON.stringify(resources));
    if (deep) {
      deepExtend(pack, resources, overwrite);
    } else {
      pack = {
        ...pack,
        ...resources
      };
    }
    setPath(this.data, path, pack);
    if (!options.silent) this.emit('added', lng, ns, resources);
  }
  removeResourceBundle(lng, ns) {
    if (this.hasResourceBundle(lng, ns)) {
      delete this.data[lng][ns];
    }
    this.removeNamespaces(ns);
    this.emit('removed', lng, ns);
  }
  hasResourceBundle(lng, ns) {
    return this.getResource(lng, ns) !== undefined;
  }
  getResourceBundle(lng, ns) {
    if (!ns) ns = this.options.defaultNS;
    if (this.options.compatibilityAPI === 'v1') return {
      ...{},
      ...this.getResource(lng, ns)
    };
    return this.getResource(lng, ns);
  }
  getDataByLanguage(lng) {
    return this.data[lng];
  }
  hasLanguageSomeTranslations(lng) {
    const data = this.getDataByLanguage(lng);
    const n = data && Object.keys(data) || [];
    return !!n.find(v => data[v] && Object.keys(data[v]).length > 0);
  }
  toJSON() {
    return this.data;
  }
}

var postProcessor = {
  processors: {},
  addPostProcessor(module) {
    this.processors[module.name] = module;
  },
  handle(processors, value, key, options, translator) {
    processors.forEach(processor => {
      if (this.processors[processor]) value = this.processors[processor].process(value, key, options, translator);
    });
    return value;
  }
};

const checkedLoadedFor = {};
class Translator extends EventEmitter {
  constructor(services) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    super();
    copy(['resourceStore', 'languageUtils', 'pluralResolver', 'interpolator', 'backendConnector', 'i18nFormat', 'utils'], services, this);
    this.options = options;
    if (this.options.keySeparator === undefined) {
      this.options.keySeparator = '.';
    }
    this.logger = baseLogger.create('translator');
  }
  changeLanguage(lng) {
    if (lng) this.language = lng;
  }
  exists(key) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
      interpolation: {}
    };
    if (key === undefined || key === null) {
      return false;
    }
    const resolved = this.resolve(key, options);
    return resolved && resolved.res !== undefined;
  }
  extractFromKey(key, options) {
    let nsSeparator = options.nsSeparator !== undefined ? options.nsSeparator : this.options.nsSeparator;
    if (nsSeparator === undefined) nsSeparator = ':';
    const keySeparator = options.keySeparator !== undefined ? options.keySeparator : this.options.keySeparator;
    let namespaces = options.ns || this.options.defaultNS || [];
    const wouldCheckForNsInKey = nsSeparator && key.indexOf(nsSeparator) > -1;
    const seemsNaturalLanguage = !this.options.userDefinedKeySeparator && !options.keySeparator && !this.options.userDefinedNsSeparator && !options.nsSeparator && !looksLikeObjectPath(key, nsSeparator, keySeparator);
    if (wouldCheckForNsInKey && !seemsNaturalLanguage) {
      const m = key.match(this.interpolator.nestingRegexp);
      if (m && m.length > 0) {
        return {
          key,
          namespaces
        };
      }
      const parts = key.split(nsSeparator);
      if (nsSeparator !== keySeparator || nsSeparator === keySeparator && this.options.ns.indexOf(parts[0]) > -1) namespaces = parts.shift();
      key = parts.join(keySeparator);
    }
    if (typeof namespaces === 'string') namespaces = [namespaces];
    return {
      key,
      namespaces
    };
  }
  translate(keys, options, lastKey) {
    if (typeof options !== 'object' && this.options.overloadTranslationOptionHandler) {
      options = this.options.overloadTranslationOptionHandler(arguments);
    }
    if (typeof options === 'object') options = {
      ...options
    };
    if (!options) options = {};
    if (keys === undefined || keys === null) return '';
    if (!Array.isArray(keys)) keys = [String(keys)];
    const returnDetails = options.returnDetails !== undefined ? options.returnDetails : this.options.returnDetails;
    const keySeparator = options.keySeparator !== undefined ? options.keySeparator : this.options.keySeparator;
    const {
      key,
      namespaces
    } = this.extractFromKey(keys[keys.length - 1], options);
    const namespace = namespaces[namespaces.length - 1];
    const lng = options.lng || this.language;
    const appendNamespaceToCIMode = options.appendNamespaceToCIMode || this.options.appendNamespaceToCIMode;
    if (lng && lng.toLowerCase() === 'cimode') {
      if (appendNamespaceToCIMode) {
        const nsSeparator = options.nsSeparator || this.options.nsSeparator;
        if (returnDetails) {
          return {
            res: `${namespace}${nsSeparator}${key}`,
            usedKey: key,
            exactUsedKey: key,
            usedLng: lng,
            usedNS: namespace,
            usedParams: this.getUsedParamsDetails(options)
          };
        }
        return `${namespace}${nsSeparator}${key}`;
      }
      if (returnDetails) {
        return {
          res: key,
          usedKey: key,
          exactUsedKey: key,
          usedLng: lng,
          usedNS: namespace,
          usedParams: this.getUsedParamsDetails(options)
        };
      }
      return key;
    }
    const resolved = this.resolve(keys, options);
    let res = resolved && resolved.res;
    const resUsedKey = resolved && resolved.usedKey || key;
    const resExactUsedKey = resolved && resolved.exactUsedKey || key;
    const resType = Object.prototype.toString.apply(res);
    const noObject = ['[object Number]', '[object Function]', '[object RegExp]'];
    const joinArrays = options.joinArrays !== undefined ? options.joinArrays : this.options.joinArrays;
    const handleAsObjectInI18nFormat = !this.i18nFormat || this.i18nFormat.handleAsObject;
    const handleAsObject = typeof res !== 'string' && typeof res !== 'boolean' && typeof res !== 'number';
    if (handleAsObjectInI18nFormat && res && handleAsObject && noObject.indexOf(resType) < 0 && !(typeof joinArrays === 'string' && Array.isArray(res))) {
      if (!options.returnObjects && !this.options.returnObjects) {
        if (!this.options.returnedObjectHandler) {
          this.logger.warn('accessing an object - but returnObjects options is not enabled!');
        }
        const r = this.options.returnedObjectHandler ? this.options.returnedObjectHandler(resUsedKey, res, {
          ...options,
          ns: namespaces
        }) : `key '${key} (${this.language})' returned an object instead of string.`;
        if (returnDetails) {
          resolved.res = r;
          resolved.usedParams = this.getUsedParamsDetails(options);
          return resolved;
        }
        return r;
      }
      if (keySeparator) {
        const resTypeIsArray = Array.isArray(res);
        const copy = resTypeIsArray ? [] : {};
        const newKeyToUse = resTypeIsArray ? resExactUsedKey : resUsedKey;
        for (const m in res) {
          if (Object.prototype.hasOwnProperty.call(res, m)) {
            const deepKey = `${newKeyToUse}${keySeparator}${m}`;
            copy[m] = this.translate(deepKey, {
              ...options,
              ...{
                joinArrays: false,
                ns: namespaces
              }
            });
            if (copy[m] === deepKey) copy[m] = res[m];
          }
        }
        res = copy;
      }
    } else if (handleAsObjectInI18nFormat && typeof joinArrays === 'string' && Array.isArray(res)) {
      res = res.join(joinArrays);
      if (res) res = this.extendTranslation(res, keys, options, lastKey);
    } else {
      let usedDefault = false;
      let usedKey = false;
      const needsPluralHandling = options.count !== undefined && typeof options.count !== 'string';
      const hasDefaultValue = Translator.hasDefaultValue(options);
      const defaultValueSuffix = needsPluralHandling ? this.pluralResolver.getSuffix(lng, options.count, options) : '';
      const defaultValueSuffixOrdinalFallback = options.ordinal && needsPluralHandling ? this.pluralResolver.getSuffix(lng, options.count, {
        ordinal: false
      }) : '';
      const needsZeroSuffixLookup = needsPluralHandling && !options.ordinal && options.count === 0 && this.pluralResolver.shouldUseIntlApi();
      const defaultValue = needsZeroSuffixLookup && options[`defaultValue${this.options.pluralSeparator}zero`] || options[`defaultValue${defaultValueSuffix}`] || options[`defaultValue${defaultValueSuffixOrdinalFallback}`] || options.defaultValue;
      if (!this.isValidLookup(res) && hasDefaultValue) {
        usedDefault = true;
        res = defaultValue;
      }
      if (!this.isValidLookup(res)) {
        usedKey = true;
        res = key;
      }
      const missingKeyNoValueFallbackToKey = options.missingKeyNoValueFallbackToKey || this.options.missingKeyNoValueFallbackToKey;
      const resForMissing = missingKeyNoValueFallbackToKey && usedKey ? undefined : res;
      const updateMissing = hasDefaultValue && defaultValue !== res && this.options.updateMissing;
      if (usedKey || usedDefault || updateMissing) {
        this.logger.log(updateMissing ? 'updateKey' : 'missingKey', lng, namespace, key, updateMissing ? defaultValue : res);
        if (keySeparator) {
          const fk = this.resolve(key, {
            ...options,
            keySeparator: false
          });
          if (fk && fk.res) this.logger.warn('Seems the loaded translations were in flat JSON format instead of nested. Either set keySeparator: false on init or make sure your translations are published in nested format.');
        }
        let lngs = [];
        const fallbackLngs = this.languageUtils.getFallbackCodes(this.options.fallbackLng, options.lng || this.language);
        if (this.options.saveMissingTo === 'fallback' && fallbackLngs && fallbackLngs[0]) {
          for (let i = 0; i < fallbackLngs.length; i++) {
            lngs.push(fallbackLngs[i]);
          }
        } else if (this.options.saveMissingTo === 'all') {
          lngs = this.languageUtils.toResolveHierarchy(options.lng || this.language);
        } else {
          lngs.push(options.lng || this.language);
        }
        const send = (l, k, specificDefaultValue) => {
          const defaultForMissing = hasDefaultValue && specificDefaultValue !== res ? specificDefaultValue : resForMissing;
          if (this.options.missingKeyHandler) {
            this.options.missingKeyHandler(l, namespace, k, defaultForMissing, updateMissing, options);
          } else if (this.backendConnector && this.backendConnector.saveMissing) {
            this.backendConnector.saveMissing(l, namespace, k, defaultForMissing, updateMissing, options);
          }
          this.emit('missingKey', l, namespace, k, res);
        };
        if (this.options.saveMissing) {
          if (this.options.saveMissingPlurals && needsPluralHandling) {
            lngs.forEach(language => {
              const suffixes = this.pluralResolver.getSuffixes(language, options);
              if (needsZeroSuffixLookup && options[`defaultValue${this.options.pluralSeparator}zero`] && suffixes.indexOf(`${this.options.pluralSeparator}zero`) < 0) {
                suffixes.push(`${this.options.pluralSeparator}zero`);
              }
              suffixes.forEach(suffix => {
                send([language], key + suffix, options[`defaultValue${suffix}`] || defaultValue);
              });
            });
          } else {
            send(lngs, key, defaultValue);
          }
        }
      }
      res = this.extendTranslation(res, keys, options, resolved, lastKey);
      if (usedKey && res === key && this.options.appendNamespaceToMissingKey) res = `${namespace}:${key}`;
      if ((usedKey || usedDefault) && this.options.parseMissingKeyHandler) {
        if (this.options.compatibilityAPI !== 'v1') {
          res = this.options.parseMissingKeyHandler(this.options.appendNamespaceToMissingKey ? `${namespace}:${key}` : key, usedDefault ? res : undefined);
        } else {
          res = this.options.parseMissingKeyHandler(res);
        }
      }
    }
    if (returnDetails) {
      resolved.res = res;
      resolved.usedParams = this.getUsedParamsDetails(options);
      return resolved;
    }
    return res;
  }
  extendTranslation(res, key, options, resolved, lastKey) {
    var _this = this;
    if (this.i18nFormat && this.i18nFormat.parse) {
      res = this.i18nFormat.parse(res, {
        ...this.options.interpolation.defaultVariables,
        ...options
      }, options.lng || this.language || resolved.usedLng, resolved.usedNS, resolved.usedKey, {
        resolved
      });
    } else if (!options.skipInterpolation) {
      if (options.interpolation) this.interpolator.init({
        ...options,
        ...{
          interpolation: {
            ...this.options.interpolation,
            ...options.interpolation
          }
        }
      });
      const skipOnVariables = typeof res === 'string' && (options && options.interpolation && options.interpolation.skipOnVariables !== undefined ? options.interpolation.skipOnVariables : this.options.interpolation.skipOnVariables);
      let nestBef;
      if (skipOnVariables) {
        const nb = res.match(this.interpolator.nestingRegexp);
        nestBef = nb && nb.length;
      }
      let data = options.replace && typeof options.replace !== 'string' ? options.replace : options;
      if (this.options.interpolation.defaultVariables) data = {
        ...this.options.interpolation.defaultVariables,
        ...data
      };
      res = this.interpolator.interpolate(res, data, options.lng || this.language, options);
      if (skipOnVariables) {
        const na = res.match(this.interpolator.nestingRegexp);
        const nestAft = na && na.length;
        if (nestBef < nestAft) options.nest = false;
      }
      if (!options.lng && this.options.compatibilityAPI !== 'v1' && resolved && resolved.res) options.lng = resolved.usedLng;
      if (options.nest !== false) res = this.interpolator.nest(res, function () {
        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }
        if (lastKey && lastKey[0] === args[0] && !options.context) {
          _this.logger.warn(`It seems you are nesting recursively key: ${args[0]} in key: ${key[0]}`);
          return null;
        }
        return _this.translate(...args, key);
      }, options);
      if (options.interpolation) this.interpolator.reset();
    }
    const postProcess = options.postProcess || this.options.postProcess;
    const postProcessorNames = typeof postProcess === 'string' ? [postProcess] : postProcess;
    if (res !== undefined && res !== null && postProcessorNames && postProcessorNames.length && options.applyPostProcessor !== false) {
      res = postProcessor.handle(postProcessorNames, res, key, this.options && this.options.postProcessPassResolved ? {
        i18nResolved: {
          ...resolved,
          usedParams: this.getUsedParamsDetails(options)
        },
        ...options
      } : options, this);
    }
    return res;
  }
  resolve(keys) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    let found;
    let usedKey;
    let exactUsedKey;
    let usedLng;
    let usedNS;
    if (typeof keys === 'string') keys = [keys];
    keys.forEach(k => {
      if (this.isValidLookup(found)) return;
      const extracted = this.extractFromKey(k, options);
      const key = extracted.key;
      usedKey = key;
      let namespaces = extracted.namespaces;
      if (this.options.fallbackNS) namespaces = namespaces.concat(this.options.fallbackNS);
      const needsPluralHandling = options.count !== undefined && typeof options.count !== 'string';
      const needsZeroSuffixLookup = needsPluralHandling && !options.ordinal && options.count === 0 && this.pluralResolver.shouldUseIntlApi();
      const needsContextHandling = options.context !== undefined && (typeof options.context === 'string' || typeof options.context === 'number') && options.context !== '';
      const codes = options.lngs ? options.lngs : this.languageUtils.toResolveHierarchy(options.lng || this.language, options.fallbackLng);
      namespaces.forEach(ns => {
        if (this.isValidLookup(found)) return;
        usedNS = ns;
        if (!checkedLoadedFor[`${codes[0]}-${ns}`] && this.utils && this.utils.hasLoadedNamespace && !this.utils.hasLoadedNamespace(usedNS)) {
          checkedLoadedFor[`${codes[0]}-${ns}`] = true;
          this.logger.warn(`key "${usedKey}" for languages "${codes.join(', ')}" won't get resolved as namespace "${usedNS}" was not yet loaded`, 'This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!');
        }
        codes.forEach(code => {
          if (this.isValidLookup(found)) return;
          usedLng = code;
          const finalKeys = [key];
          if (this.i18nFormat && this.i18nFormat.addLookupKeys) {
            this.i18nFormat.addLookupKeys(finalKeys, key, code, ns, options);
          } else {
            let pluralSuffix;
            if (needsPluralHandling) pluralSuffix = this.pluralResolver.getSuffix(code, options.count, options);
            const zeroSuffix = `${this.options.pluralSeparator}zero`;
            const ordinalPrefix = `${this.options.pluralSeparator}ordinal${this.options.pluralSeparator}`;
            if (needsPluralHandling) {
              finalKeys.push(key + pluralSuffix);
              if (options.ordinal && pluralSuffix.indexOf(ordinalPrefix) === 0) {
                finalKeys.push(key + pluralSuffix.replace(ordinalPrefix, this.options.pluralSeparator));
              }
              if (needsZeroSuffixLookup) {
                finalKeys.push(key + zeroSuffix);
              }
            }
            if (needsContextHandling) {
              const contextKey = `${key}${this.options.contextSeparator}${options.context}`;
              finalKeys.push(contextKey);
              if (needsPluralHandling) {
                finalKeys.push(contextKey + pluralSuffix);
                if (options.ordinal && pluralSuffix.indexOf(ordinalPrefix) === 0) {
                  finalKeys.push(contextKey + pluralSuffix.replace(ordinalPrefix, this.options.pluralSeparator));
                }
                if (needsZeroSuffixLookup) {
                  finalKeys.push(contextKey + zeroSuffix);
                }
              }
            }
          }
          let possibleKey;
          while (possibleKey = finalKeys.pop()) {
            if (!this.isValidLookup(found)) {
              exactUsedKey = possibleKey;
              found = this.getResource(code, ns, possibleKey, options);
            }
          }
        });
      });
    });
    return {
      res: found,
      usedKey,
      exactUsedKey,
      usedLng,
      usedNS
    };
  }
  isValidLookup(res) {
    return res !== undefined && !(!this.options.returnNull && res === null) && !(!this.options.returnEmptyString && res === '');
  }
  getResource(code, ns, key) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
    if (this.i18nFormat && this.i18nFormat.getResource) return this.i18nFormat.getResource(code, ns, key, options);
    return this.resourceStore.getResource(code, ns, key, options);
  }
  getUsedParamsDetails() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    const optionsKeys = ['defaultValue', 'ordinal', 'context', 'replace', 'lng', 'lngs', 'fallbackLng', 'ns', 'keySeparator', 'nsSeparator', 'returnObjects', 'returnDetails', 'joinArrays', 'postProcess', 'interpolation'];
    const useOptionsReplaceForData = options.replace && typeof options.replace !== 'string';
    let data = useOptionsReplaceForData ? options.replace : options;
    if (useOptionsReplaceForData && typeof options.count !== 'undefined') {
      data.count = options.count;
    }
    if (this.options.interpolation.defaultVariables) {
      data = {
        ...this.options.interpolation.defaultVariables,
        ...data
      };
    }
    if (!useOptionsReplaceForData) {
      data = {
        ...data
      };
      for (const key of optionsKeys) {
        delete data[key];
      }
    }
    return data;
  }
  static hasDefaultValue(options) {
    const prefix = 'defaultValue';
    for (const option in options) {
      if (Object.prototype.hasOwnProperty.call(options, option) && prefix === option.substring(0, prefix.length) && undefined !== options[option]) {
        return true;
      }
    }
    return false;
  }
}

function capitalize$1(string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}
class LanguageUtil {
  constructor(options) {
    this.options = options;
    this.supportedLngs = this.options.supportedLngs || false;
    this.logger = baseLogger.create('languageUtils');
  }
  getScriptPartFromCode(code) {
    code = getCleanedCode(code);
    if (!code || code.indexOf('-') < 0) return null;
    const p = code.split('-');
    if (p.length === 2) return null;
    p.pop();
    if (p[p.length - 1].toLowerCase() === 'x') return null;
    return this.formatLanguageCode(p.join('-'));
  }
  getLanguagePartFromCode(code) {
    code = getCleanedCode(code);
    if (!code || code.indexOf('-') < 0) return code;
    const p = code.split('-');
    return this.formatLanguageCode(p[0]);
  }
  formatLanguageCode(code) {
    if (typeof code === 'string' && code.indexOf('-') > -1) {
      const specialCases = ['hans', 'hant', 'latn', 'cyrl', 'cans', 'mong', 'arab'];
      let p = code.split('-');
      if (this.options.lowerCaseLng) {
        p = p.map(part => part.toLowerCase());
      } else if (p.length === 2) {
        p[0] = p[0].toLowerCase();
        p[1] = p[1].toUpperCase();
        if (specialCases.indexOf(p[1].toLowerCase()) > -1) p[1] = capitalize$1(p[1].toLowerCase());
      } else if (p.length === 3) {
        p[0] = p[0].toLowerCase();
        if (p[1].length === 2) p[1] = p[1].toUpperCase();
        if (p[0] !== 'sgn' && p[2].length === 2) p[2] = p[2].toUpperCase();
        if (specialCases.indexOf(p[1].toLowerCase()) > -1) p[1] = capitalize$1(p[1].toLowerCase());
        if (specialCases.indexOf(p[2].toLowerCase()) > -1) p[2] = capitalize$1(p[2].toLowerCase());
      }
      return p.join('-');
    }
    return this.options.cleanCode || this.options.lowerCaseLng ? code.toLowerCase() : code;
  }
  isSupportedCode(code) {
    if (this.options.load === 'languageOnly' || this.options.nonExplicitSupportedLngs) {
      code = this.getLanguagePartFromCode(code);
    }
    return !this.supportedLngs || !this.supportedLngs.length || this.supportedLngs.indexOf(code) > -1;
  }
  getBestMatchFromCodes(codes) {
    if (!codes) return null;
    let found;
    codes.forEach(code => {
      if (found) return;
      const cleanedLng = this.formatLanguageCode(code);
      if (!this.options.supportedLngs || this.isSupportedCode(cleanedLng)) found = cleanedLng;
    });
    if (!found && this.options.supportedLngs) {
      codes.forEach(code => {
        if (found) return;
        const lngOnly = this.getLanguagePartFromCode(code);
        if (this.isSupportedCode(lngOnly)) return found = lngOnly;
        found = this.options.supportedLngs.find(supportedLng => {
          if (supportedLng === lngOnly) return supportedLng;
          if (supportedLng.indexOf('-') < 0 && lngOnly.indexOf('-') < 0) return;
          if (supportedLng.indexOf('-') > 0 && lngOnly.indexOf('-') < 0 && supportedLng.substring(0, supportedLng.indexOf('-')) === lngOnly) return supportedLng;
          if (supportedLng.indexOf(lngOnly) === 0 && lngOnly.length > 1) return supportedLng;
        });
      });
    }
    if (!found) found = this.getFallbackCodes(this.options.fallbackLng)[0];
    return found;
  }
  getFallbackCodes(fallbacks, code) {
    if (!fallbacks) return [];
    if (typeof fallbacks === 'function') fallbacks = fallbacks(code);
    if (typeof fallbacks === 'string') fallbacks = [fallbacks];
    if (Array.isArray(fallbacks)) return fallbacks;
    if (!code) return fallbacks.default || [];
    let found = fallbacks[code];
    if (!found) found = fallbacks[this.getScriptPartFromCode(code)];
    if (!found) found = fallbacks[this.formatLanguageCode(code)];
    if (!found) found = fallbacks[this.getLanguagePartFromCode(code)];
    if (!found) found = fallbacks.default;
    return found || [];
  }
  toResolveHierarchy(code, fallbackCode) {
    const fallbackCodes = this.getFallbackCodes(fallbackCode || this.options.fallbackLng || [], code);
    const codes = [];
    const addCode = c => {
      if (!c) return;
      if (this.isSupportedCode(c)) {
        codes.push(c);
      } else {
        this.logger.warn(`rejecting language code not found in supportedLngs: ${c}`);
      }
    };
    if (typeof code === 'string' && (code.indexOf('-') > -1 || code.indexOf('_') > -1)) {
      if (this.options.load !== 'languageOnly') addCode(this.formatLanguageCode(code));
      if (this.options.load !== 'languageOnly' && this.options.load !== 'currentOnly') addCode(this.getScriptPartFromCode(code));
      if (this.options.load !== 'currentOnly') addCode(this.getLanguagePartFromCode(code));
    } else if (typeof code === 'string') {
      addCode(this.formatLanguageCode(code));
    }
    fallbackCodes.forEach(fc => {
      if (codes.indexOf(fc) < 0) addCode(this.formatLanguageCode(fc));
    });
    return codes;
  }
}

let sets = [{
  lngs: ['ach', 'ak', 'am', 'arn', 'br', 'fil', 'gun', 'ln', 'mfe', 'mg', 'mi', 'oc', 'pt', 'pt-BR', 'tg', 'tl', 'ti', 'tr', 'uz', 'wa'],
  nr: [1, 2],
  fc: 1
}, {
  lngs: ['af', 'an', 'ast', 'az', 'bg', 'bn', 'ca', 'da', 'de', 'dev', 'el', 'en', 'eo', 'es', 'et', 'eu', 'fi', 'fo', 'fur', 'fy', 'gl', 'gu', 'ha', 'hi', 'hu', 'hy', 'ia', 'it', 'kk', 'kn', 'ku', 'lb', 'mai', 'ml', 'mn', 'mr', 'nah', 'nap', 'nb', 'ne', 'nl', 'nn', 'no', 'nso', 'pa', 'pap', 'pms', 'ps', 'pt-PT', 'rm', 'sco', 'se', 'si', 'so', 'son', 'sq', 'sv', 'sw', 'ta', 'te', 'tk', 'ur', 'yo'],
  nr: [1, 2],
  fc: 2
}, {
  lngs: ['ay', 'bo', 'cgg', 'fa', 'ht', 'id', 'ja', 'jbo', 'ka', 'km', 'ko', 'ky', 'lo', 'ms', 'sah', 'su', 'th', 'tt', 'ug', 'vi', 'wo', 'zh'],
  nr: [1],
  fc: 3
}, {
  lngs: ['be', 'bs', 'cnr', 'dz', 'hr', 'ru', 'sr', 'uk'],
  nr: [1, 2, 5],
  fc: 4
}, {
  lngs: ['ar'],
  nr: [0, 1, 2, 3, 11, 100],
  fc: 5
}, {
  lngs: ['cs', 'sk'],
  nr: [1, 2, 5],
  fc: 6
}, {
  lngs: ['csb', 'pl'],
  nr: [1, 2, 5],
  fc: 7
}, {
  lngs: ['cy'],
  nr: [1, 2, 3, 8],
  fc: 8
}, {
  lngs: ['fr'],
  nr: [1, 2],
  fc: 9
}, {
  lngs: ['ga'],
  nr: [1, 2, 3, 7, 11],
  fc: 10
}, {
  lngs: ['gd'],
  nr: [1, 2, 3, 20],
  fc: 11
}, {
  lngs: ['is'],
  nr: [1, 2],
  fc: 12
}, {
  lngs: ['jv'],
  nr: [0, 1],
  fc: 13
}, {
  lngs: ['kw'],
  nr: [1, 2, 3, 4],
  fc: 14
}, {
  lngs: ['lt'],
  nr: [1, 2, 10],
  fc: 15
}, {
  lngs: ['lv'],
  nr: [1, 2, 0],
  fc: 16
}, {
  lngs: ['mk'],
  nr: [1, 2],
  fc: 17
}, {
  lngs: ['mnk'],
  nr: [0, 1, 2],
  fc: 18
}, {
  lngs: ['mt'],
  nr: [1, 2, 11, 20],
  fc: 19
}, {
  lngs: ['or'],
  nr: [2, 1],
  fc: 2
}, {
  lngs: ['ro'],
  nr: [1, 2, 20],
  fc: 20
}, {
  lngs: ['sl'],
  nr: [5, 1, 2, 3],
  fc: 21
}, {
  lngs: ['he', 'iw'],
  nr: [1, 2, 20, 21],
  fc: 22
}];
let _rulesPluralsTypes = {
  1: function (n) {
    return Number(n > 1);
  },
  2: function (n) {
    return Number(n != 1);
  },
  3: function (n) {
    return 0;
  },
  4: function (n) {
    return Number(n % 10 == 1 && n % 100 != 11 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2);
  },
  5: function (n) {
    return Number(n == 0 ? 0 : n == 1 ? 1 : n == 2 ? 2 : n % 100 >= 3 && n % 100 <= 10 ? 3 : n % 100 >= 11 ? 4 : 5);
  },
  6: function (n) {
    return Number(n == 1 ? 0 : n >= 2 && n <= 4 ? 1 : 2);
  },
  7: function (n) {
    return Number(n == 1 ? 0 : n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2);
  },
  8: function (n) {
    return Number(n == 1 ? 0 : n == 2 ? 1 : n != 8 && n != 11 ? 2 : 3);
  },
  9: function (n) {
    return Number(n >= 2);
  },
  10: function (n) {
    return Number(n == 1 ? 0 : n == 2 ? 1 : n < 7 ? 2 : n < 11 ? 3 : 4);
  },
  11: function (n) {
    return Number(n == 1 || n == 11 ? 0 : n == 2 || n == 12 ? 1 : n > 2 && n < 20 ? 2 : 3);
  },
  12: function (n) {
    return Number(n % 10 != 1 || n % 100 == 11);
  },
  13: function (n) {
    return Number(n !== 0);
  },
  14: function (n) {
    return Number(n == 1 ? 0 : n == 2 ? 1 : n == 3 ? 2 : 3);
  },
  15: function (n) {
    return Number(n % 10 == 1 && n % 100 != 11 ? 0 : n % 10 >= 2 && (n % 100 < 10 || n % 100 >= 20) ? 1 : 2);
  },
  16: function (n) {
    return Number(n % 10 == 1 && n % 100 != 11 ? 0 : n !== 0 ? 1 : 2);
  },
  17: function (n) {
    return Number(n == 1 || n % 10 == 1 && n % 100 != 11 ? 0 : 1);
  },
  18: function (n) {
    return Number(n == 0 ? 0 : n == 1 ? 1 : 2);
  },
  19: function (n) {
    return Number(n == 1 ? 0 : n == 0 || n % 100 > 1 && n % 100 < 11 ? 1 : n % 100 > 10 && n % 100 < 20 ? 2 : 3);
  },
  20: function (n) {
    return Number(n == 1 ? 0 : n == 0 || n % 100 > 0 && n % 100 < 20 ? 1 : 2);
  },
  21: function (n) {
    return Number(n % 100 == 1 ? 1 : n % 100 == 2 ? 2 : n % 100 == 3 || n % 100 == 4 ? 3 : 0);
  },
  22: function (n) {
    return Number(n == 1 ? 0 : n == 2 ? 1 : (n < 0 || n > 10) && n % 10 == 0 ? 2 : 3);
  }
};
const nonIntlVersions = ['v1', 'v2', 'v3'];
const intlVersions = ['v4'];
const suffixesOrder = {
  zero: 0,
  one: 1,
  two: 2,
  few: 3,
  many: 4,
  other: 5
};
function createRules() {
  const rules = {};
  sets.forEach(set => {
    set.lngs.forEach(l => {
      rules[l] = {
        numbers: set.nr,
        plurals: _rulesPluralsTypes[set.fc]
      };
    });
  });
  return rules;
}
class PluralResolver {
  constructor(languageUtils) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    this.languageUtils = languageUtils;
    this.options = options;
    this.logger = baseLogger.create('pluralResolver');
    if ((!this.options.compatibilityJSON || intlVersions.includes(this.options.compatibilityJSON)) && (typeof Intl === 'undefined' || !Intl.PluralRules)) {
      this.options.compatibilityJSON = 'v3';
      this.logger.error('Your environment seems not to be Intl API compatible, use an Intl.PluralRules polyfill. Will fallback to the compatibilityJSON v3 format handling.');
    }
    this.rules = createRules();
  }
  addRule(lng, obj) {
    this.rules[lng] = obj;
  }
  getRule(code) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    if (this.shouldUseIntlApi()) {
      try {
        return new Intl.PluralRules(getCleanedCode(code === 'dev' ? 'en' : code), {
          type: options.ordinal ? 'ordinal' : 'cardinal'
        });
      } catch (err) {
        return;
      }
    }
    return this.rules[code] || this.rules[this.languageUtils.getLanguagePartFromCode(code)];
  }
  needsPlural(code) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    const rule = this.getRule(code, options);
    if (this.shouldUseIntlApi()) {
      return rule && rule.resolvedOptions().pluralCategories.length > 1;
    }
    return rule && rule.numbers.length > 1;
  }
  getPluralFormsOfKey(code, key) {
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    return this.getSuffixes(code, options).map(suffix => `${key}${suffix}`);
  }
  getSuffixes(code) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    const rule = this.getRule(code, options);
    if (!rule) {
      return [];
    }
    if (this.shouldUseIntlApi()) {
      return rule.resolvedOptions().pluralCategories.sort((pluralCategory1, pluralCategory2) => suffixesOrder[pluralCategory1] - suffixesOrder[pluralCategory2]).map(pluralCategory => `${this.options.prepend}${options.ordinal ? `ordinal${this.options.prepend}` : ''}${pluralCategory}`);
    }
    return rule.numbers.map(number => this.getSuffix(code, number, options));
  }
  getSuffix(code, count) {
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    const rule = this.getRule(code, options);
    if (rule) {
      if (this.shouldUseIntlApi()) {
        return `${this.options.prepend}${options.ordinal ? `ordinal${this.options.prepend}` : ''}${rule.select(count)}`;
      }
      return this.getSuffixRetroCompatible(rule, count);
    }
    this.logger.warn(`no plural rule found for: ${code}`);
    return '';
  }
  getSuffixRetroCompatible(rule, count) {
    const idx = rule.noAbs ? rule.plurals(count) : rule.plurals(Math.abs(count));
    let suffix = rule.numbers[idx];
    if (this.options.simplifyPluralSuffix && rule.numbers.length === 2 && rule.numbers[0] === 1) {
      if (suffix === 2) {
        suffix = 'plural';
      } else if (suffix === 1) {
        suffix = '';
      }
    }
    const returnSuffix = () => this.options.prepend && suffix.toString() ? this.options.prepend + suffix.toString() : suffix.toString();
    if (this.options.compatibilityJSON === 'v1') {
      if (suffix === 1) return '';
      if (typeof suffix === 'number') return `_plural_${suffix.toString()}`;
      return returnSuffix();
    } else if (this.options.compatibilityJSON === 'v2') {
      return returnSuffix();
    } else if (this.options.simplifyPluralSuffix && rule.numbers.length === 2 && rule.numbers[0] === 1) {
      return returnSuffix();
    }
    return this.options.prepend && idx.toString() ? this.options.prepend + idx.toString() : idx.toString();
  }
  shouldUseIntlApi() {
    return !nonIntlVersions.includes(this.options.compatibilityJSON);
  }
}

function deepFindWithDefaults(data, defaultData, key) {
  let keySeparator = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '.';
  let ignoreJSONStructure = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : true;
  let path = getPathWithDefaults(data, defaultData, key);
  if (!path && ignoreJSONStructure && typeof key === 'string') {
    path = deepFind(data, key, keySeparator);
    if (path === undefined) path = deepFind(defaultData, key, keySeparator);
  }
  return path;
}
class Interpolator {
  constructor() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    this.logger = baseLogger.create('interpolator');
    this.options = options;
    this.format = options.interpolation && options.interpolation.format || (value => value);
    this.init(options);
  }
  init() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    if (!options.interpolation) options.interpolation = {
      escapeValue: true
    };
    const {
      escape: escape$1,
      escapeValue,
      useRawValueToEscape,
      prefix,
      prefixEscaped,
      suffix,
      suffixEscaped,
      formatSeparator,
      unescapeSuffix,
      unescapePrefix,
      nestingPrefix,
      nestingPrefixEscaped,
      nestingSuffix,
      nestingSuffixEscaped,
      nestingOptionsSeparator,
      maxReplaces,
      alwaysFormat
    } = options.interpolation;
    this.escape = escape$1 !== undefined ? escape$1 : escape;
    this.escapeValue = escapeValue !== undefined ? escapeValue : true;
    this.useRawValueToEscape = useRawValueToEscape !== undefined ? useRawValueToEscape : false;
    this.prefix = prefix ? regexEscape(prefix) : prefixEscaped || '{{';
    this.suffix = suffix ? regexEscape(suffix) : suffixEscaped || '}}';
    this.formatSeparator = formatSeparator || ',';
    this.unescapePrefix = unescapeSuffix ? '' : unescapePrefix || '-';
    this.unescapeSuffix = this.unescapePrefix ? '' : unescapeSuffix || '';
    this.nestingPrefix = nestingPrefix ? regexEscape(nestingPrefix) : nestingPrefixEscaped || regexEscape('$t(');
    this.nestingSuffix = nestingSuffix ? regexEscape(nestingSuffix) : nestingSuffixEscaped || regexEscape(')');
    this.nestingOptionsSeparator = nestingOptionsSeparator || ',';
    this.maxReplaces = maxReplaces || 1000;
    this.alwaysFormat = alwaysFormat !== undefined ? alwaysFormat : false;
    this.resetRegExp();
  }
  reset() {
    if (this.options) this.init(this.options);
  }
  resetRegExp() {
    const getOrResetRegExp = (existingRegExp, pattern) => {
      if (existingRegExp && existingRegExp.source === pattern) {
        existingRegExp.lastIndex = 0;
        return existingRegExp;
      }
      return new RegExp(pattern, 'g');
    };
    this.regexp = getOrResetRegExp(this.regexp, `${this.prefix}(.+?)${this.suffix}`);
    this.regexpUnescape = getOrResetRegExp(this.regexpUnescape, `${this.prefix}${this.unescapePrefix}(.+?)${this.unescapeSuffix}${this.suffix}`);
    this.nestingRegexp = getOrResetRegExp(this.nestingRegexp, `${this.nestingPrefix}(.+?)${this.nestingSuffix}`);
  }
  interpolate(str, data, lng, options) {
    let match;
    let value;
    let replaces;
    const defaultData = this.options && this.options.interpolation && this.options.interpolation.defaultVariables || {};
    function regexSafe(val) {
      return val.replace(/\$/g, '$$$$');
    }
    const handleFormat = key => {
      if (key.indexOf(this.formatSeparator) < 0) {
        const path = deepFindWithDefaults(data, defaultData, key, this.options.keySeparator, this.options.ignoreJSONStructure);
        return this.alwaysFormat ? this.format(path, undefined, lng, {
          ...options,
          ...data,
          interpolationkey: key
        }) : path;
      }
      const p = key.split(this.formatSeparator);
      const k = p.shift().trim();
      const f = p.join(this.formatSeparator).trim();
      return this.format(deepFindWithDefaults(data, defaultData, k, this.options.keySeparator, this.options.ignoreJSONStructure), f, lng, {
        ...options,
        ...data,
        interpolationkey: k
      });
    };
    this.resetRegExp();
    const missingInterpolationHandler = options && options.missingInterpolationHandler || this.options.missingInterpolationHandler;
    const skipOnVariables = options && options.interpolation && options.interpolation.skipOnVariables !== undefined ? options.interpolation.skipOnVariables : this.options.interpolation.skipOnVariables;
    const todos = [{
      regex: this.regexpUnescape,
      safeValue: val => regexSafe(val)
    }, {
      regex: this.regexp,
      safeValue: val => this.escapeValue ? regexSafe(this.escape(val)) : regexSafe(val)
    }];
    todos.forEach(todo => {
      replaces = 0;
      while (match = todo.regex.exec(str)) {
        const matchedVar = match[1].trim();
        value = handleFormat(matchedVar);
        if (value === undefined) {
          if (typeof missingInterpolationHandler === 'function') {
            const temp = missingInterpolationHandler(str, match, options);
            value = typeof temp === 'string' ? temp : '';
          } else if (options && Object.prototype.hasOwnProperty.call(options, matchedVar)) {
            value = '';
          } else if (skipOnVariables) {
            value = match[0];
            continue;
          } else {
            this.logger.warn(`missed to pass in variable ${matchedVar} for interpolating ${str}`);
            value = '';
          }
        } else if (typeof value !== 'string' && !this.useRawValueToEscape) {
          value = makeString(value);
        }
        const safeValue = todo.safeValue(value);
        str = str.replace(match[0], safeValue);
        if (skipOnVariables) {
          todo.regex.lastIndex += value.length;
          todo.regex.lastIndex -= match[0].length;
        } else {
          todo.regex.lastIndex = 0;
        }
        replaces++;
        if (replaces >= this.maxReplaces) {
          break;
        }
      }
    });
    return str;
  }
  nest(str, fc) {
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    let match;
    let value;
    let clonedOptions;
    function handleHasOptions(key, inheritedOptions) {
      const sep = this.nestingOptionsSeparator;
      if (key.indexOf(sep) < 0) return key;
      const c = key.split(new RegExp(`${sep}[ ]*{`));
      let optionsString = `{${c[1]}`;
      key = c[0];
      optionsString = this.interpolate(optionsString, clonedOptions);
      const matchedSingleQuotes = optionsString.match(/'/g);
      const matchedDoubleQuotes = optionsString.match(/"/g);
      if (matchedSingleQuotes && matchedSingleQuotes.length % 2 === 0 && !matchedDoubleQuotes || matchedDoubleQuotes.length % 2 !== 0) {
        optionsString = optionsString.replace(/'/g, '"');
      }
      try {
        clonedOptions = JSON.parse(optionsString);
        if (inheritedOptions) clonedOptions = {
          ...inheritedOptions,
          ...clonedOptions
        };
      } catch (e) {
        this.logger.warn(`failed parsing options string in nesting for key ${key}`, e);
        return `${key}${sep}${optionsString}`;
      }
      if (clonedOptions.defaultValue && clonedOptions.defaultValue.indexOf(this.prefix) > -1) delete clonedOptions.defaultValue;
      return key;
    }
    while (match = this.nestingRegexp.exec(str)) {
      let formatters = [];
      clonedOptions = {
        ...options
      };
      clonedOptions = clonedOptions.replace && typeof clonedOptions.replace !== 'string' ? clonedOptions.replace : clonedOptions;
      clonedOptions.applyPostProcessor = false;
      delete clonedOptions.defaultValue;
      let doReduce = false;
      if (match[0].indexOf(this.formatSeparator) !== -1 && !/{.*}/.test(match[1])) {
        const r = match[1].split(this.formatSeparator).map(elem => elem.trim());
        match[1] = r.shift();
        formatters = r;
        doReduce = true;
      }
      value = fc(handleHasOptions.call(this, match[1].trim(), clonedOptions), clonedOptions);
      if (value && match[0] === str && typeof value !== 'string') return value;
      if (typeof value !== 'string') value = makeString(value);
      if (!value) {
        this.logger.warn(`missed to resolve ${match[1]} for nesting ${str}`);
        value = '';
      }
      if (doReduce) {
        value = formatters.reduce((v, f) => this.format(v, f, options.lng, {
          ...options,
          interpolationkey: match[1].trim()
        }), value.trim());
      }
      str = str.replace(match[0], value);
      this.regexp.lastIndex = 0;
    }
    return str;
  }
}

function parseFormatStr(formatStr) {
  let formatName = formatStr.toLowerCase().trim();
  const formatOptions = {};
  if (formatStr.indexOf('(') > -1) {
    const p = formatStr.split('(');
    formatName = p[0].toLowerCase().trim();
    const optStr = p[1].substring(0, p[1].length - 1);
    if (formatName === 'currency' && optStr.indexOf(':') < 0) {
      if (!formatOptions.currency) formatOptions.currency = optStr.trim();
    } else if (formatName === 'relativetime' && optStr.indexOf(':') < 0) {
      if (!formatOptions.range) formatOptions.range = optStr.trim();
    } else {
      const opts = optStr.split(';');
      opts.forEach(opt => {
        if (opt) {
          const [key, ...rest] = opt.split(':');
          const val = rest.join(':').trim().replace(/^'+|'+$/g, '');
          const trimmedKey = key.trim();
          if (!formatOptions[trimmedKey]) formatOptions[trimmedKey] = val;
          if (val === 'false') formatOptions[trimmedKey] = false;
          if (val === 'true') formatOptions[trimmedKey] = true;
          if (!isNaN(val)) formatOptions[trimmedKey] = parseInt(val, 10);
        }
      });
    }
  }
  return {
    formatName,
    formatOptions
  };
}
function createCachedFormatter(fn) {
  const cache = {};
  return function invokeFormatter(val, lng, options) {
    const key = lng + JSON.stringify(options);
    let formatter = cache[key];
    if (!formatter) {
      formatter = fn(getCleanedCode(lng), options);
      cache[key] = formatter;
    }
    return formatter(val);
  };
}
class Formatter {
  constructor() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    this.logger = baseLogger.create('formatter');
    this.options = options;
    this.formats = {
      number: createCachedFormatter((lng, opt) => {
        const formatter = new Intl.NumberFormat(lng, {
          ...opt
        });
        return val => formatter.format(val);
      }),
      currency: createCachedFormatter((lng, opt) => {
        const formatter = new Intl.NumberFormat(lng, {
          ...opt,
          style: 'currency'
        });
        return val => formatter.format(val);
      }),
      datetime: createCachedFormatter((lng, opt) => {
        const formatter = new Intl.DateTimeFormat(lng, {
          ...opt
        });
        return val => formatter.format(val);
      }),
      relativetime: createCachedFormatter((lng, opt) => {
        const formatter = new Intl.RelativeTimeFormat(lng, {
          ...opt
        });
        return val => formatter.format(val, opt.range || 'day');
      }),
      list: createCachedFormatter((lng, opt) => {
        const formatter = new Intl.ListFormat(lng, {
          ...opt
        });
        return val => formatter.format(val);
      })
    };
    this.init(options);
  }
  init(services) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
      interpolation: {}
    };
    const iOpts = options.interpolation;
    this.formatSeparator = iOpts.formatSeparator ? iOpts.formatSeparator : iOpts.formatSeparator || ',';
  }
  add(name, fc) {
    this.formats[name.toLowerCase().trim()] = fc;
  }
  addCached(name, fc) {
    this.formats[name.toLowerCase().trim()] = createCachedFormatter(fc);
  }
  format(value, format, lng) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
    const formats = format.split(this.formatSeparator);
    const result = formats.reduce((mem, f) => {
      const {
        formatName,
        formatOptions
      } = parseFormatStr(f);
      if (this.formats[formatName]) {
        let formatted = mem;
        try {
          const valOptions = options && options.formatParams && options.formatParams[options.interpolationkey] || {};
          const l = valOptions.locale || valOptions.lng || options.locale || options.lng || lng;
          formatted = this.formats[formatName](mem, l, {
            ...formatOptions,
            ...options,
            ...valOptions
          });
        } catch (error) {
          this.logger.warn(error);
        }
        return formatted;
      } else {
        this.logger.warn(`there was no format function for ${formatName}`);
      }
      return mem;
    }, value);
    return result;
  }
}

function removePending(q, name) {
  if (q.pending[name] !== undefined) {
    delete q.pending[name];
    q.pendingCount--;
  }
}
class Connector extends EventEmitter {
  constructor(backend, store, services) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
    super();
    this.backend = backend;
    this.store = store;
    this.services = services;
    this.languageUtils = services.languageUtils;
    this.options = options;
    this.logger = baseLogger.create('backendConnector');
    this.waitingReads = [];
    this.maxParallelReads = options.maxParallelReads || 10;
    this.readingCalls = 0;
    this.maxRetries = options.maxRetries >= 0 ? options.maxRetries : 5;
    this.retryTimeout = options.retryTimeout >= 1 ? options.retryTimeout : 350;
    this.state = {};
    this.queue = [];
    if (this.backend && this.backend.init) {
      this.backend.init(services, options.backend, options);
    }
  }
  queueLoad(languages, namespaces, options, callback) {
    const toLoad = {};
    const pending = {};
    const toLoadLanguages = {};
    const toLoadNamespaces = {};
    languages.forEach(lng => {
      let hasAllNamespaces = true;
      namespaces.forEach(ns => {
        const name = `${lng}|${ns}`;
        if (!options.reload && this.store.hasResourceBundle(lng, ns)) {
          this.state[name] = 2;
        } else if (this.state[name] < 0) ; else if (this.state[name] === 1) {
          if (pending[name] === undefined) pending[name] = true;
        } else {
          this.state[name] = 1;
          hasAllNamespaces = false;
          if (pending[name] === undefined) pending[name] = true;
          if (toLoad[name] === undefined) toLoad[name] = true;
          if (toLoadNamespaces[ns] === undefined) toLoadNamespaces[ns] = true;
        }
      });
      if (!hasAllNamespaces) toLoadLanguages[lng] = true;
    });
    if (Object.keys(toLoad).length || Object.keys(pending).length) {
      this.queue.push({
        pending,
        pendingCount: Object.keys(pending).length,
        loaded: {},
        errors: [],
        callback
      });
    }
    return {
      toLoad: Object.keys(toLoad),
      pending: Object.keys(pending),
      toLoadLanguages: Object.keys(toLoadLanguages),
      toLoadNamespaces: Object.keys(toLoadNamespaces)
    };
  }
  loaded(name, err, data) {
    const s = name.split('|');
    const lng = s[0];
    const ns = s[1];
    if (err) this.emit('failedLoading', lng, ns, err);
    if (data) {
      this.store.addResourceBundle(lng, ns, data, undefined, undefined, {
        skipCopy: true
      });
    }
    this.state[name] = err ? -1 : 2;
    const loaded = {};
    this.queue.forEach(q => {
      pushPath(q.loaded, [lng], ns);
      removePending(q, name);
      if (err) q.errors.push(err);
      if (q.pendingCount === 0 && !q.done) {
        Object.keys(q.loaded).forEach(l => {
          if (!loaded[l]) loaded[l] = {};
          const loadedKeys = q.loaded[l];
          if (loadedKeys.length) {
            loadedKeys.forEach(n => {
              if (loaded[l][n] === undefined) loaded[l][n] = true;
            });
          }
        });
        q.done = true;
        if (q.errors.length) {
          q.callback(q.errors);
        } else {
          q.callback();
        }
      }
    });
    this.emit('loaded', loaded);
    this.queue = this.queue.filter(q => !q.done);
  }
  read(lng, ns, fcName) {
    let tried = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
    let wait = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : this.retryTimeout;
    let callback = arguments.length > 5 ? arguments[5] : undefined;
    if (!lng.length) return callback(null, {});
    if (this.readingCalls >= this.maxParallelReads) {
      this.waitingReads.push({
        lng,
        ns,
        fcName,
        tried,
        wait,
        callback
      });
      return;
    }
    this.readingCalls++;
    const resolver = (err, data) => {
      this.readingCalls--;
      if (this.waitingReads.length > 0) {
        const next = this.waitingReads.shift();
        this.read(next.lng, next.ns, next.fcName, next.tried, next.wait, next.callback);
      }
      if (err && data && tried < this.maxRetries) {
        setTimeout(() => {
          this.read.call(this, lng, ns, fcName, tried + 1, wait * 2, callback);
        }, wait);
        return;
      }
      callback(err, data);
    };
    const fc = this.backend[fcName].bind(this.backend);
    if (fc.length === 2) {
      try {
        const r = fc(lng, ns);
        if (r && typeof r.then === 'function') {
          r.then(data => resolver(null, data)).catch(resolver);
        } else {
          resolver(null, r);
        }
      } catch (err) {
        resolver(err);
      }
      return;
    }
    return fc(lng, ns, resolver);
  }
  prepareLoading(languages, namespaces) {
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    let callback = arguments.length > 3 ? arguments[3] : undefined;
    if (!this.backend) {
      this.logger.warn('No backend was added via i18next.use. Will not load resources.');
      return callback && callback();
    }
    if (typeof languages === 'string') languages = this.languageUtils.toResolveHierarchy(languages);
    if (typeof namespaces === 'string') namespaces = [namespaces];
    const toLoad = this.queueLoad(languages, namespaces, options, callback);
    if (!toLoad.toLoad.length) {
      if (!toLoad.pending.length) callback();
      return null;
    }
    toLoad.toLoad.forEach(name => {
      this.loadOne(name);
    });
  }
  load(languages, namespaces, callback) {
    this.prepareLoading(languages, namespaces, {}, callback);
  }
  reload(languages, namespaces, callback) {
    this.prepareLoading(languages, namespaces, {
      reload: true
    }, callback);
  }
  loadOne(name) {
    let prefix = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    const s = name.split('|');
    const lng = s[0];
    const ns = s[1];
    this.read(lng, ns, 'read', undefined, undefined, (err, data) => {
      if (err) this.logger.warn(`${prefix}loading namespace ${ns} for language ${lng} failed`, err);
      if (!err && data) this.logger.log(`${prefix}loaded namespace ${ns} for language ${lng}`, data);
      this.loaded(name, err, data);
    });
  }
  saveMissing(languages, namespace, key, fallbackValue, isUpdate) {
    let options = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : {};
    let clb = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : () => {};
    if (this.services.utils && this.services.utils.hasLoadedNamespace && !this.services.utils.hasLoadedNamespace(namespace)) {
      this.logger.warn(`did not save key "${key}" as the namespace "${namespace}" was not yet loaded`, 'This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!');
      return;
    }
    if (key === undefined || key === null || key === '') return;
    if (this.backend && this.backend.create) {
      const opts = {
        ...options,
        isUpdate
      };
      const fc = this.backend.create.bind(this.backend);
      if (fc.length < 6) {
        try {
          let r;
          if (fc.length === 5) {
            r = fc(languages, namespace, key, fallbackValue, opts);
          } else {
            r = fc(languages, namespace, key, fallbackValue);
          }
          if (r && typeof r.then === 'function') {
            r.then(data => clb(null, data)).catch(clb);
          } else {
            clb(null, r);
          }
        } catch (err) {
          clb(err);
        }
      } else {
        fc(languages, namespace, key, fallbackValue, clb, opts);
      }
    }
    if (!languages || !languages[0]) return;
    this.store.addResource(languages[0], namespace, key, fallbackValue);
  }
}

function get() {
  return {
    debug: false,
    initImmediate: true,
    ns: ['translation'],
    defaultNS: ['translation'],
    fallbackLng: ['dev'],
    fallbackNS: false,
    supportedLngs: false,
    nonExplicitSupportedLngs: false,
    load: 'all',
    preload: false,
    simplifyPluralSuffix: true,
    keySeparator: '.',
    nsSeparator: ':',
    pluralSeparator: '_',
    contextSeparator: '_',
    partialBundledLanguages: false,
    saveMissing: false,
    updateMissing: false,
    saveMissingTo: 'fallback',
    saveMissingPlurals: true,
    missingKeyHandler: false,
    missingInterpolationHandler: false,
    postProcess: false,
    postProcessPassResolved: false,
    returnNull: false,
    returnEmptyString: true,
    returnObjects: false,
    joinArrays: false,
    returnedObjectHandler: false,
    parseMissingKeyHandler: false,
    appendNamespaceToMissingKey: false,
    appendNamespaceToCIMode: false,
    overloadTranslationOptionHandler: function handle(args) {
      let ret = {};
      if (typeof args[1] === 'object') ret = args[1];
      if (typeof args[1] === 'string') ret.defaultValue = args[1];
      if (typeof args[2] === 'string') ret.tDescription = args[2];
      if (typeof args[2] === 'object' || typeof args[3] === 'object') {
        const options = args[3] || args[2];
        Object.keys(options).forEach(key => {
          ret[key] = options[key];
        });
      }
      return ret;
    },
    interpolation: {
      escapeValue: true,
      format: value => value,
      prefix: '{{',
      suffix: '}}',
      formatSeparator: ',',
      unescapePrefix: '-',
      nestingPrefix: '$t(',
      nestingSuffix: ')',
      nestingOptionsSeparator: ',',
      maxReplaces: 1000,
      skipOnVariables: true
    }
  };
}
function transformOptions(options) {
  if (typeof options.ns === 'string') options.ns = [options.ns];
  if (typeof options.fallbackLng === 'string') options.fallbackLng = [options.fallbackLng];
  if (typeof options.fallbackNS === 'string') options.fallbackNS = [options.fallbackNS];
  if (options.supportedLngs && options.supportedLngs.indexOf('cimode') < 0) {
    options.supportedLngs = options.supportedLngs.concat(['cimode']);
  }
  return options;
}

function noop() {}
function bindMemberFunctions(inst) {
  const mems = Object.getOwnPropertyNames(Object.getPrototypeOf(inst));
  mems.forEach(mem => {
    if (typeof inst[mem] === 'function') {
      inst[mem] = inst[mem].bind(inst);
    }
  });
}
class I18n extends EventEmitter {
  constructor() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let callback = arguments.length > 1 ? arguments[1] : undefined;
    super();
    this.options = transformOptions(options);
    this.services = {};
    this.logger = baseLogger;
    this.modules = {
      external: []
    };
    bindMemberFunctions(this);
    if (callback && !this.isInitialized && !options.isClone) {
      if (!this.options.initImmediate) {
        this.init(options, callback);
        return this;
      }
      setTimeout(() => {
        this.init(options, callback);
      }, 0);
    }
  }
  init() {
    var _this = this;
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let callback = arguments.length > 1 ? arguments[1] : undefined;
    this.isInitializing = true;
    if (typeof options === 'function') {
      callback = options;
      options = {};
    }
    if (!options.defaultNS && options.defaultNS !== false && options.ns) {
      if (typeof options.ns === 'string') {
        options.defaultNS = options.ns;
      } else if (options.ns.indexOf('translation') < 0) {
        options.defaultNS = options.ns[0];
      }
    }
    const defOpts = get();
    this.options = {
      ...defOpts,
      ...this.options,
      ...transformOptions(options)
    };
    if (this.options.compatibilityAPI !== 'v1') {
      this.options.interpolation = {
        ...defOpts.interpolation,
        ...this.options.interpolation
      };
    }
    if (options.keySeparator !== undefined) {
      this.options.userDefinedKeySeparator = options.keySeparator;
    }
    if (options.nsSeparator !== undefined) {
      this.options.userDefinedNsSeparator = options.nsSeparator;
    }
    function createClassOnDemand(ClassOrObject) {
      if (!ClassOrObject) return null;
      if (typeof ClassOrObject === 'function') return new ClassOrObject();
      return ClassOrObject;
    }
    if (!this.options.isClone) {
      if (this.modules.logger) {
        baseLogger.init(createClassOnDemand(this.modules.logger), this.options);
      } else {
        baseLogger.init(null, this.options);
      }
      let formatter;
      if (this.modules.formatter) {
        formatter = this.modules.formatter;
      } else if (typeof Intl !== 'undefined') {
        formatter = Formatter;
      }
      const lu = new LanguageUtil(this.options);
      this.store = new ResourceStore(this.options.resources, this.options);
      const s = this.services;
      s.logger = baseLogger;
      s.resourceStore = this.store;
      s.languageUtils = lu;
      s.pluralResolver = new PluralResolver(lu, {
        prepend: this.options.pluralSeparator,
        compatibilityJSON: this.options.compatibilityJSON,
        simplifyPluralSuffix: this.options.simplifyPluralSuffix
      });
      if (formatter && (!this.options.interpolation.format || this.options.interpolation.format === defOpts.interpolation.format)) {
        s.formatter = createClassOnDemand(formatter);
        s.formatter.init(s, this.options);
        this.options.interpolation.format = s.formatter.format.bind(s.formatter);
      }
      s.interpolator = new Interpolator(this.options);
      s.utils = {
        hasLoadedNamespace: this.hasLoadedNamespace.bind(this)
      };
      s.backendConnector = new Connector(createClassOnDemand(this.modules.backend), s.resourceStore, s, this.options);
      s.backendConnector.on('*', function (event) {
        for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
          args[_key - 1] = arguments[_key];
        }
        _this.emit(event, ...args);
      });
      if (this.modules.languageDetector) {
        s.languageDetector = createClassOnDemand(this.modules.languageDetector);
        if (s.languageDetector.init) s.languageDetector.init(s, this.options.detection, this.options);
      }
      if (this.modules.i18nFormat) {
        s.i18nFormat = createClassOnDemand(this.modules.i18nFormat);
        if (s.i18nFormat.init) s.i18nFormat.init(this);
      }
      this.translator = new Translator(this.services, this.options);
      this.translator.on('*', function (event) {
        for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
          args[_key2 - 1] = arguments[_key2];
        }
        _this.emit(event, ...args);
      });
      this.modules.external.forEach(m => {
        if (m.init) m.init(this);
      });
    }
    this.format = this.options.interpolation.format;
    if (!callback) callback = noop;
    if (this.options.fallbackLng && !this.services.languageDetector && !this.options.lng) {
      const codes = this.services.languageUtils.getFallbackCodes(this.options.fallbackLng);
      if (codes.length > 0 && codes[0] !== 'dev') this.options.lng = codes[0];
    }
    if (!this.services.languageDetector && !this.options.lng) {
      this.logger.warn('init: no languageDetector is used and no lng is defined');
    }
    const storeApi = ['getResource', 'hasResourceBundle', 'getResourceBundle', 'getDataByLanguage'];
    storeApi.forEach(fcName => {
      this[fcName] = function () {
        return _this.store[fcName](...arguments);
      };
    });
    const storeApiChained = ['addResource', 'addResources', 'addResourceBundle', 'removeResourceBundle'];
    storeApiChained.forEach(fcName => {
      this[fcName] = function () {
        _this.store[fcName](...arguments);
        return _this;
      };
    });
    const deferred = defer();
    const load = () => {
      const finish = (err, t) => {
        this.isInitializing = false;
        if (this.isInitialized && !this.initializedStoreOnce) this.logger.warn('init: i18next is already initialized. You should call init just once!');
        this.isInitialized = true;
        if (!this.options.isClone) this.logger.log('initialized', this.options);
        this.emit('initialized', this.options);
        deferred.resolve(t);
        callback(err, t);
      };
      if (this.languages && this.options.compatibilityAPI !== 'v1' && !this.isInitialized) return finish(null, this.t.bind(this));
      this.changeLanguage(this.options.lng, finish);
    };
    if (this.options.resources || !this.options.initImmediate) {
      load();
    } else {
      setTimeout(load, 0);
    }
    return deferred;
  }
  loadResources(language) {
    let callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : noop;
    let usedCallback = callback;
    const usedLng = typeof language === 'string' ? language : this.language;
    if (typeof language === 'function') usedCallback = language;
    if (!this.options.resources || this.options.partialBundledLanguages) {
      if (usedLng && usedLng.toLowerCase() === 'cimode' && (!this.options.preload || this.options.preload.length === 0)) return usedCallback();
      const toLoad = [];
      const append = lng => {
        if (!lng) return;
        if (lng === 'cimode') return;
        const lngs = this.services.languageUtils.toResolveHierarchy(lng);
        lngs.forEach(l => {
          if (l === 'cimode') return;
          if (toLoad.indexOf(l) < 0) toLoad.push(l);
        });
      };
      if (!usedLng) {
        const fallbacks = this.services.languageUtils.getFallbackCodes(this.options.fallbackLng);
        fallbacks.forEach(l => append(l));
      } else {
        append(usedLng);
      }
      if (this.options.preload) {
        this.options.preload.forEach(l => append(l));
      }
      this.services.backendConnector.load(toLoad, this.options.ns, e => {
        if (!e && !this.resolvedLanguage && this.language) this.setResolvedLanguage(this.language);
        usedCallback(e);
      });
    } else {
      usedCallback(null);
    }
  }
  reloadResources(lngs, ns, callback) {
    const deferred = defer();
    if (!lngs) lngs = this.languages;
    if (!ns) ns = this.options.ns;
    if (!callback) callback = noop;
    this.services.backendConnector.reload(lngs, ns, err => {
      deferred.resolve();
      callback(err);
    });
    return deferred;
  }
  use(module) {
    if (!module) throw new Error('You are passing an undefined module! Please check the object you are passing to i18next.use()');
    if (!module.type) throw new Error('You are passing a wrong module! Please check the object you are passing to i18next.use()');
    if (module.type === 'backend') {
      this.modules.backend = module;
    }
    if (module.type === 'logger' || module.log && module.warn && module.error) {
      this.modules.logger = module;
    }
    if (module.type === 'languageDetector') {
      this.modules.languageDetector = module;
    }
    if (module.type === 'i18nFormat') {
      this.modules.i18nFormat = module;
    }
    if (module.type === 'postProcessor') {
      postProcessor.addPostProcessor(module);
    }
    if (module.type === 'formatter') {
      this.modules.formatter = module;
    }
    if (module.type === '3rdParty') {
      this.modules.external.push(module);
    }
    return this;
  }
  setResolvedLanguage(l) {
    if (!l || !this.languages) return;
    if (['cimode', 'dev'].indexOf(l) > -1) return;
    for (let li = 0; li < this.languages.length; li++) {
      const lngInLngs = this.languages[li];
      if (['cimode', 'dev'].indexOf(lngInLngs) > -1) continue;
      if (this.store.hasLanguageSomeTranslations(lngInLngs)) {
        this.resolvedLanguage = lngInLngs;
        break;
      }
    }
  }
  changeLanguage(lng, callback) {
    var _this2 = this;
    this.isLanguageChangingTo = lng;
    const deferred = defer();
    this.emit('languageChanging', lng);
    const setLngProps = l => {
      this.language = l;
      this.languages = this.services.languageUtils.toResolveHierarchy(l);
      this.resolvedLanguage = undefined;
      this.setResolvedLanguage(l);
    };
    const done = (err, l) => {
      if (l) {
        setLngProps(l);
        this.translator.changeLanguage(l);
        this.isLanguageChangingTo = undefined;
        this.emit('languageChanged', l);
        this.logger.log('languageChanged', l);
      } else {
        this.isLanguageChangingTo = undefined;
      }
      deferred.resolve(function () {
        return _this2.t(...arguments);
      });
      if (callback) callback(err, function () {
        return _this2.t(...arguments);
      });
    };
    const setLng = lngs => {
      if (!lng && !lngs && this.services.languageDetector) lngs = [];
      const l = typeof lngs === 'string' ? lngs : this.services.languageUtils.getBestMatchFromCodes(lngs);
      if (l) {
        if (!this.language) {
          setLngProps(l);
        }
        if (!this.translator.language) this.translator.changeLanguage(l);
        if (this.services.languageDetector && this.services.languageDetector.cacheUserLanguage) this.services.languageDetector.cacheUserLanguage(l);
      }
      this.loadResources(l, err => {
        done(err, l);
      });
    };
    if (!lng && this.services.languageDetector && !this.services.languageDetector.async) {
      setLng(this.services.languageDetector.detect());
    } else if (!lng && this.services.languageDetector && this.services.languageDetector.async) {
      if (this.services.languageDetector.detect.length === 0) {
        this.services.languageDetector.detect().then(setLng);
      } else {
        this.services.languageDetector.detect(setLng);
      }
    } else {
      setLng(lng);
    }
    return deferred;
  }
  getFixedT(lng, ns, keyPrefix) {
    var _this3 = this;
    const fixedT = function (key, opts) {
      let options;
      if (typeof opts !== 'object') {
        for (var _len3 = arguments.length, rest = new Array(_len3 > 2 ? _len3 - 2 : 0), _key3 = 2; _key3 < _len3; _key3++) {
          rest[_key3 - 2] = arguments[_key3];
        }
        options = _this3.options.overloadTranslationOptionHandler([key, opts].concat(rest));
      } else {
        options = {
          ...opts
        };
      }
      options.lng = options.lng || fixedT.lng;
      options.lngs = options.lngs || fixedT.lngs;
      options.ns = options.ns || fixedT.ns;
      options.keyPrefix = options.keyPrefix || keyPrefix || fixedT.keyPrefix;
      const keySeparator = _this3.options.keySeparator || '.';
      let resultKey;
      if (options.keyPrefix && Array.isArray(key)) {
        resultKey = key.map(k => `${options.keyPrefix}${keySeparator}${k}`);
      } else {
        resultKey = options.keyPrefix ? `${options.keyPrefix}${keySeparator}${key}` : key;
      }
      return _this3.t(resultKey, options);
    };
    if (typeof lng === 'string') {
      fixedT.lng = lng;
    } else {
      fixedT.lngs = lng;
    }
    fixedT.ns = ns;
    fixedT.keyPrefix = keyPrefix;
    return fixedT;
  }
  t() {
    return this.translator && this.translator.translate(...arguments);
  }
  exists() {
    return this.translator && this.translator.exists(...arguments);
  }
  setDefaultNamespace(ns) {
    this.options.defaultNS = ns;
  }
  hasLoadedNamespace(ns) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    if (!this.isInitialized) {
      this.logger.warn('hasLoadedNamespace: i18next was not initialized', this.languages);
      return false;
    }
    if (!this.languages || !this.languages.length) {
      this.logger.warn('hasLoadedNamespace: i18n.languages were undefined or empty', this.languages);
      return false;
    }
    const lng = options.lng || this.resolvedLanguage || this.languages[0];
    const fallbackLng = this.options ? this.options.fallbackLng : false;
    const lastLng = this.languages[this.languages.length - 1];
    if (lng.toLowerCase() === 'cimode') return true;
    const loadNotPending = (l, n) => {
      const loadState = this.services.backendConnector.state[`${l}|${n}`];
      return loadState === -1 || loadState === 2;
    };
    if (options.precheck) {
      const preResult = options.precheck(this, loadNotPending);
      if (preResult !== undefined) return preResult;
    }
    if (this.hasResourceBundle(lng, ns)) return true;
    if (!this.services.backendConnector.backend || this.options.resources && !this.options.partialBundledLanguages) return true;
    if (loadNotPending(lng, ns) && (!fallbackLng || loadNotPending(lastLng, ns))) return true;
    return false;
  }
  loadNamespaces(ns, callback) {
    const deferred = defer();
    if (!this.options.ns) {
      if (callback) callback();
      return Promise.resolve();
    }
    if (typeof ns === 'string') ns = [ns];
    ns.forEach(n => {
      if (this.options.ns.indexOf(n) < 0) this.options.ns.push(n);
    });
    this.loadResources(err => {
      deferred.resolve();
      if (callback) callback(err);
    });
    return deferred;
  }
  loadLanguages(lngs, callback) {
    const deferred = defer();
    if (typeof lngs === 'string') lngs = [lngs];
    const preloaded = this.options.preload || [];
    const newLngs = lngs.filter(lng => preloaded.indexOf(lng) < 0 && this.services.languageUtils.isSupportedCode(lng));
    if (!newLngs.length) {
      if (callback) callback();
      return Promise.resolve();
    }
    this.options.preload = preloaded.concat(newLngs);
    this.loadResources(err => {
      deferred.resolve();
      if (callback) callback(err);
    });
    return deferred;
  }
  dir(lng) {
    if (!lng) lng = this.resolvedLanguage || (this.languages && this.languages.length > 0 ? this.languages[0] : this.language);
    if (!lng) return 'rtl';
    const rtlLngs = ['ar', 'shu', 'sqr', 'ssh', 'xaa', 'yhd', 'yud', 'aao', 'abh', 'abv', 'acm', 'acq', 'acw', 'acx', 'acy', 'adf', 'ads', 'aeb', 'aec', 'afb', 'ajp', 'apc', 'apd', 'arb', 'arq', 'ars', 'ary', 'arz', 'auz', 'avl', 'ayh', 'ayl', 'ayn', 'ayp', 'bbz', 'pga', 'he', 'iw', 'ps', 'pbt', 'pbu', 'pst', 'prp', 'prd', 'ug', 'ur', 'ydd', 'yds', 'yih', 'ji', 'yi', 'hbo', 'men', 'xmn', 'fa', 'jpr', 'peo', 'pes', 'prs', 'dv', 'sam', 'ckb'];
    const languageUtils = this.services && this.services.languageUtils || new LanguageUtil(get());
    return rtlLngs.indexOf(languageUtils.getLanguagePartFromCode(lng)) > -1 || lng.toLowerCase().indexOf('-arab') > 1 ? 'rtl' : 'ltr';
  }
  static createInstance() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let callback = arguments.length > 1 ? arguments[1] : undefined;
    return new I18n(options, callback);
  }
  cloneInstance() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : noop;
    const forkResourceStore = options.forkResourceStore;
    if (forkResourceStore) delete options.forkResourceStore;
    const mergedOptions = {
      ...this.options,
      ...options,
      ...{
        isClone: true
      }
    };
    const clone = new I18n(mergedOptions);
    if (options.debug !== undefined || options.prefix !== undefined) {
      clone.logger = clone.logger.clone(options);
    }
    const membersToCopy = ['store', 'services', 'language'];
    membersToCopy.forEach(m => {
      clone[m] = this[m];
    });
    clone.services = {
      ...this.services
    };
    clone.services.utils = {
      hasLoadedNamespace: clone.hasLoadedNamespace.bind(clone)
    };
    if (forkResourceStore) {
      clone.store = new ResourceStore(this.store.data, mergedOptions);
      clone.services.resourceStore = clone.store;
    }
    clone.translator = new Translator(clone.services, mergedOptions);
    clone.translator.on('*', function (event) {
      for (var _len4 = arguments.length, args = new Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
        args[_key4 - 1] = arguments[_key4];
      }
      clone.emit(event, ...args);
    });
    clone.init(mergedOptions, callback);
    clone.translator.options = mergedOptions;
    clone.translator.backendConnector.services.utils = {
      hasLoadedNamespace: clone.hasLoadedNamespace.bind(clone)
    };
    return clone;
  }
  toJSON() {
    return {
      options: this.options,
      store: this.store,
      language: this.language,
      languages: this.languages,
      resolvedLanguage: this.resolvedLanguage
    };
  }
}
const instance = I18n.createInstance();
instance.createInstance = I18n.createInstance;

const noDateSelected$8 = "No date selected";
const rescheduleTitle$8 = "Choose another time slot to reschedule your meeting";
const allDay$8 = "All day";
const today$8 = "Today";
const spotsLeft$8 = "{{count}} spots left";
const search$8 = "Search";
const selectOneOrMoreOptions$8 = "Select one or more options";
const days$8 = {
	sunday: "SUN",
	monday: "MON",
	tuesday: "TUE",
	wednesday: "WED",
	thursday: "THU",
	friday: "FRI",
	saturday: "SAT"
};
const time$8 = {
	hour: "hour",
	hours: "hours",
	minute: "minute",
	minutes: "minutes",
	day: "day",
	days: "days",
	week: "week",
	weeks: "weeks",
	month: "month",
	months: "months",
	year: "year",
	years: "years"
};
const months$8 = {
	january: "January",
	february: "February",
	march: "March",
	april: "April",
	may: "May",
	june: "June",
	july: "July",
	august: "August",
	september: "September",
	october: "October",
	november: "November",
	december: "December"
};
const multipleOptionsSelected$8 = "Multiple options selected";
const selectAtLeastOneOption$8 = "Please select at least one option";
const nextButton$8 = "Next";
const selectedDayAndYear$8 = "{{date}}";
const selectedTime$8 = "{{time}}";
const name$8 = "Name";
const namePlaceholder$8 = "Enter your name";
const email$8 = "Email";
const emailPlaceholder$8 = "Enter your email";
const guestEmail$8 = "Guest email";
const guestEmailPlaceholder$8 = "Enter guest email";
const addGuest$8 = "Add guest";
const addAnotherGuest$8 = "Add another guest";
const backButton$8 = "Back";
const bookNowButton$8 = "Book now";
const bookingConfirmed$8 = "Booking confirmed";
const bookingConfirmedDescription$8 = "You'll receive an email confirmation soon.";
const bookingSent$8 = "Booking sent";
const bookingSentDescription$8 = "You will receive an email once the booking is confirmed.";
const bookingRescheduled$8 = "Booking rescheduled";
const bookingDateAndTimeHeader$8 = "Booking date and time";
const cancelBookingButton$8 = "Cancel booking";
const rescheduleBookingButton$8 = "Reschedule";
const rejectBookingButton$8 = "Reject booking";
const confirmBookingButton$8 = "Confirm booking";
const bookingPendingTitle$8 = "Booking pending";
const bookingPendingnDescription$8 = "Manage your booking below. The invitee will receive an email informing them of the request status.";
const confirmedEventCardTitle$8 = "Your booking has been confirmed successfully";
const confirmedEventCardDescription$8 = "A confirmation email has been sent to";
const cancelBookingTitle$8 = "Cancel booking?";
const cancelBookingMessage$8 = "Your current timeslot will become available to others.";
const reasonForCancellation$8 = "Reason for cancellation";
const goBackButton$8 = "Go back";
const bookingCancelledTitle$8 = "Your booking has been cancelled successfully";
const bookingCancelledMessage$8 = "A cancellation email has been sent to";
const bookingCancelledMessage_theParticipants$8 = "the participants";
const closeButton$8 = "Close";
const closingButton$8 = "Closing";
const fieldRequired$8 = "{{field}} is required.";
const invalidInputFormat$8 = "{{field}} has invalid format.";
const createBookingErrorTitle$8 = "Create Booking";
const getAvailabilityErrorTitle$8 = "Get Availability";
const cancelBookingErrorTitle$8 = "Cancel Booking";
const rescheduleBookingErrorTitle$8 = "Reschedule Booking";
const getUISettingErrorTitle$8 = "Get UI Settings";
const rejectBookingErrorTitle$8 = "Reject Booking";
const confirmBookingErrorTitle$8 = "Confirm Booking";
const genericErrorTitle$8 = "Something went wrong...";
const schedulingComponentErrorTitle$8 = "Scheduling Component Error";
const sessionIdRequiredErrorMessage$8 = "'sessionId' is required for private configs.";
const publicConfigErrorMessage$8 = "If using public config either pass a configurationId or a combination of 'slug' and 'clientId'.";
const invalidTimeslotErrorTitle$7 = "Invalid timeslot!";
const invalidTimeslotErrorMessage$8 = "The selected timeslot is invalid";
const cancellationErrorTitle$8 = "Cancellation Error";
const cancellationErrorMessage$8 = "Please provide a reason for cancellation.";
const minimumCancellationErrorMessage$8 = "You cannot cancel the booking within {{minCancellationNotice}} minutes of the event";
const cancelBokingFormError$8 = "Cancel booking form error";
const feedbackFormTitle$8 = "Share Your Feedback";
const feedbackFormDescription$8 = "Providing us with your feedback and reporting errors helps us create a better experience for you.";
const feedbackMessageLabel$8 = "Please give us a detailed description of the feature you’re commenting on, or where you’ve experienced an issue.";
const feedbackMessagePlaceholder$8 = "Provide your feedback here";
const feedbackModalCloseButton$8 = "Cancel";
const feedbackModalSubmitButton$8 = "Submit";
const deleteSchedulingPageTitle$8 = "Delete this scheduling page?";
const deleteSchedulingPageDescription$8 = "Upon confirmation, this page and it’s connected scheduling links will be permanently deleted and deactivated. This action cannot be undone.";
const deleteSchedulingPageConfirmButton$8 = "Delete page";
const deleteSchedulingPageCancelButton$8 = "Cancel";
const schedulerEditorTitle$8 = "Scheduler Editor";
const allSchedulingPages$8 = "All Scheduling Pages";
const createAndManageSchedulingPages$8 = "Create and manage your Scheduling Pages.";
const createNewSchedulingPageButtonText$8 = "Create new";
const pageTitle$8 = "Page title";
const durationTitle$8 = "Duration";
const loading$8 = "Loading";
const required$8 = "Required";
const optional$8 = "Optional";
const loadingPagesDescription$8 = "Please wait while we fetch the scheduling pages";
const noSchedulingPages$8 = "No scheduling pages found";
const createFirstSchedulingPage$8 = "Get started with creating your first scheduling page";
const editSchedulingPageButtonText$8 = "Edit";
const eventInfoTab$8 = "Event info";
const availabilityTab$8 = "Availability";
const participantsTab$8 = "Participants";
const bookingOptionsTab$8 = "Booking Options";
const returnToCalendarView$8 = "Return to Calendar view";
const bookingFormTab$8 = "Booking Form";
const communicationsTab$8 = "Communications";
const pageStylesTab$8 = "Page styles";
const savingButtonText$8 = "Saving";
const saveChangesButtonText$8 = "Save changes";
const createButtonText$8 = "Create";
const timePeriod_day$8 = "day";
const timePeriod_week$8 = "week";
const timePeriod_month$8 = "month";
const timePeriod_year$8 = "year";
const timeDuration_minute$8 = "minute";
const timeDuration_hour$8 = "hour";
const eventCommunicationsTitle$8 = "Event communications";
const eventCommunicationsDescription$8 = "Set up automatic confirmation emails.";
const unsavedChangesLabel$8 = "Unsaved changes";
const changesSavedLabel$8 = "Changes saved";
const fixFormErrors$8 = "Please fix the form errors.";
const nylasEditorTabs$8 = {
	bookingFormError: "Booking form error: ",
	bookingFormError_label: "Label is required for field of type {{type}}.",
	bookingFormError_option: "Empty option detected inside {{label}} of type {{type}}.",
	updateConfigError: "Update config error: ",
	createConfigError: "Create config error: ",
	deleteConfigError: "Delete config error: ",
	getConfigsError: "Get configs error: ",
	formErrorTitle: "Form Error:"
};
const nylasEditorTabsGroup$8 = {
	eventTitleRequired: "Event title is required.",
	eventTimeRequired: "Event time is required.",
	participantsRequired: "Participants are required.",
	participantEmailRequired: "Participant email is required.",
	errorOccured: "An error occurred while saving changes.",
	createGroupEventError: "Create group event error: ",
	updateGroupEventError: "Update group event error: ",
	deleteGroupEventError: "Delete group event error: ",
	importGroupEventError: "Import group event error: ",
	getGroupEventsError: "Get group events error: "
};
const nylasListConfigurations$8 = {
	previewButtonText: "Preview",
	copyLinkButtonText: "Copy link",
	deleteButtonText: "Delete"
};
const nylasAdditionalParticipants$8 = {
	headerTitle: "Participants",
	headerSubTitle: "Add people in your team or organization to join the event.",
	organizerAsParticipant: "Participant",
	organizer: "Organizer",
	participant: "Participant",
	addParticipant_first: "Add a participant",
	addParticipant_next: "Add another participant",
	tooltip: {
		includeOrganizer: "Include Organizer",
		includeOrganizerDesc: "The organizer (you) will be included in the round-robin rotation.",
		excludeOrganizer: "Exclude Organizer",
		excludeOrganizerDesc: "The organizer (you) will not be included in the round-robin rotation."
	},
	error: "Please add at least one participant"
};
const nylasAvailabilityPicker$8 = {
	headerTitle: "Default open hours",
	headerSubTitle: "Set when you're regularly available for event bookings.",
	tooltip: {
		desc: "This is the default availability for participants who don’t have availability set on the Participants tab."
	},
	selectTimezone: "Select timezone",
	unavailable: "Unavailable",
	days: {
		SUN: "SUN",
		MON: "MON",
		TUE: "TUE",
		WED: "WED",
		THU: "THU",
		FRI: "FRI",
		SAT: "SAT"
	}
};
const nylasTimeWindowPicker$4 = {
	errors: {
		invalid: "Invalid"
	}
};
const nylasBookingCalendarPicker$8 = {
	headerTitle: "Calendar booking",
	headerSubTitle: "Select the calendar where you want to add event bookings.",
	tooltip: {
		desc: "The calendar will be used to create events."
	},
	selectOptionLabel: "Select an option",
	selectCalendarErrorMessage: "Please select a calendar"
};
const nylasBookingConfirmationRedirect$8 = {
	dropdownLabel: "When a booking is confirmed",
	tooltip: {
		desc: "You can either display the default confirmation page or redirect users to your own confirmation page."
	},
	redirectOption_default: "Display default confirmation page",
	redirectOption_custom: "Redirect to custom URL"
};
const nylasBookingConfirmationType$8 = {
	dropdownLabel: "When a booking is requested",
	tooltip: {
		desc: "Manually accept bookings allows you to review and either accept or decline each booking request"
	},
	bookingOption_booking: "Automatically accept bookings",
	bookingOption_organizerConfirmation: "Manually accept bookings"
};
const nylasBookingFormConfig$8 = {
	headerTitle: "Booking form",
	headerSubTitle: "Add custom fields to the booking form.",
	dropdownButtonText: "Add new field",
	addOption: "Add an option",
	allOptionsHeader: "ALL OPTIONS",
	fieldInTitleError: "This field is used in the event title and cannot be removed.",
	fieldInDescriptionError: "This field is used in the event description and cannot be removed.",
	label: "Label",
	defaultValue: "Default value",
	fieldType: {
		text: "Short text",
		multi_line_text: "Long text",
		email: "Email",
		phone_number: "Phone number",
		dropdown: "Dropdown",
		radio_button: "Radio button",
		checkbox: "Checkbox",
		date: "Date",
		metadata: "Metadata",
		multi_select: "Multi-select"
	},
	fieldLabel: {
		your_name: "Your name",
		your_email: "Your email",
		email: "Additional email",
		phone_number: "Phone number label",
		dropdown: "Dropdown label",
		text: "Short text label",
		multi_line_text: "Long text label",
		radio_button: "Radio button label",
		checkbox: "Checkbox label",
		date: "Date label",
		metadata: "Metadata label",
		multi_select: "Multi-select label"
	}
};
const nylasBufferTime$8 = {
	headerTitle: "Buffer time",
	headerSubTitle: "Require empty buffer time before and after an event.",
	tooltip: {
		desc: "Scheduler does not book the buffer time."
	},
	beforeBufferLabel: "Before the event",
	afterBufferLabel: "After the event",
	minutesShort: "mins",
	previewHeader: "PREVIEW"
};
const nylasCalendarPicker$8 = {
	calendarPickerLabel: "Select calendars that will be checked for availability",
	selectAtLeastOneCalendar: "Select at least one calendar."
};
const nylasCancellationPolicy$8 = {
	cancellationPolicyLabel: "Cancellation policy message",
	tooltip: {
		desc: "Attendees receive this message if trying to cancel the event. Attendees are asked to provide a reason for cancellation."
	}
};
const nylasConfirmationEmail$8 = {
	headerTitle: "Booking confirmed{{organizerName}}",
	headerSubTitle: "Booking confirmation email",
	editButtonText: "Edit",
	error: {
		invalidImageUrl: "Invalid image URL."
	},
	confirmationEmail: {
		label: "Enable email notifications",
		tooltip: {
			desc: "Allow Nylas to send email notifications, including confirmation messages and event reminders.",
			language: "This language will be used for the email notifications to the organizers."
		},
		language: "Select language"
	},
	nylasBranding: {
		label: "Show Nylas branding",
		tooltip: {
			desc: "Uncheck this to hide the footer in the email communication."
		}
	},
	companyLogoUrl: {
		label: "Company logo URL",
		tooltip: {
			desc: "This logo appears in the booking confirmation email. The URL must be publicly accessible. The image will be scaled down to a max size of 200px x 100px."
		}
	},
	emailMessage: {
		header: "Email message",
		label: "Custom email title",
		tooltip: {
			desc: "An email title is a headline within the body of the email. This doesn't change the subject line."
		},
		additionalInfoLabel: "Additional info",
		additionalInfoTooltip: "Scheduler adds the content of the box to the email body.",
		additionalInfoPlaceholder: "Default body"
	},
	allHosts: "All host & guests",
	immediatelyUponBooking: "Immediately upon booking"
};
const nylasConnectedCalendars$8 = {
	headerTitle: "Connected calendars",
	headerSubTitle: "Select the calendars to use for checking your availability.",
	tooltip: {
		desc: "Check availability across one or more calendars. If you select multiple calendars for a participant, the participant must be available across all of their calendars to be considered available."
	},
	participantCalendarTitle: "{{participantName}}'s connected calendars",
	selectAtLeastOneCalendar: "Please select at least one calendar for each participant."
};
const nylasCustomBookingFlow$8 = {
	headerTitle: "Custom booking flow"
};
const nylasCustomEventSlug$8 = {
	headerTitle: "Custom page slug",
	headerSubTitle: "Create a custom URL slug for this page.",
	eventSlugLabel: "Page URL slug",
	tooltip: {
		desc: "Provide a custom slug for your URL to help uniquely identify your page (letters, numbers, and hyphens only)"
	},
	copied: "Copied!"
};
const nylasCustomizeBookingSettings$8 = {
	headerTitle: "Additional settings",
	headerSubTitle: "Booking settings for the event.",
	tooltip: {
		desc: "Customize your booking settings."
	},
	allowGuests: {
		label: "Allow guests to invite additional guests."
	},
	hideReschedule: {
		label: "Hide rescheduling option.",
		tooltip: {
			desc: "Hide the 'Reschedule' button in the booking confirmation and email notifications."
		}
	},
	hideCancel: {
		label: "Hide cancellation option.",
		tooltip: {
			desc: "Hide the 'Cancel' button in the booking confirmation and email notifications."
		}
	}
};
const nylasEventDescription$8 = {
	headerTitle: "Event description",
	addAdditionalFields: {
		buttonText: "Auto-populate additional fields",
		tooltip: {
			desc: "Click this once you have added all the fields you want to include in the description. Important: Please leave the markers '--- Additional Fields ---' and '--- End Additional Fields ---' unchanged so that everything works correctly."
		}
	},
	tooltip: {
		desc: "The event description appears in the Scheduler Editor’s manager view and in the response payload when a booking is created."
	}
};
const nylasEventDuration$8 = {
	headerTitle: "Event duration",
	error: {
		durationMustBeMultipleOf5: "Duration must be a multiple of 5",
		durationMustBeGreaterThan0: "Duration must be greater than 0"
	}
};
const nylasEventInfo$8 = {
	headerTitle: "Event information"
};
const nylasEventLimits$8 = {
	headerTitle: "Event limits"
};
const nylasEventLocation$8 = {
	headerTitle: "Event meeting or location",
	tooltip: {
		desc: "Select a conferencing option or add a custom location."
	},
	conferenceOptions: {
		none: "None",
		zoom: "Zoom Meeting",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "Custom location"
	}
};
const nylasEventTitle$8 = {
	headerTitle: "Event title",
	helpText_start: "Create a dynamic templated event {{field}} by typing",
	helpText_end: "and selecting a template item.",
	title: "title",
	description: "description",
	tooltip: {
		desc: "For example, Interview with"
	},
	eventTitleRequired: "Event title is required",
	eventTitleTokenDescription: {
		invitee: "The name of the primary invitee.",
		inviteeEmail: "The email of the primary invitee.",
		duration: "The length in time of the event."
	}
};
const nylasLimitFutureBookings$8 = {
	headerTitle: "Limit future bookings",
	tooltip: {
		desc: "The limit on how far in the future bookings can be made."
	}
};
const nylasMinBookingNotice$8 = {
	headerTitle: "Minimum booking notice",
	tooltip: {
		desc: "The minimum amount of time in the future that a new booking can be made."
	}
};
const nylasMinCancellationNotice$8 = {
	headerTitle: "Minimum cancellation notice",
	tooltip: {
		desc: "The minimum amount of time required to cancel a booking."
	}
};
const nylasPageName$8 = {
	headerTitle: "Page name",
	headerSubTitle: "Set the Scheduling Page name.",
	pageNameError: "Please enter a page name",
	tooltip: {
		desc: "By default, Scheduling Pages use your user name as the Page name. The Page name is displayed in the top-left corner of the calendar view."
	}
};
const nylasPageStyling$8 = {
	headerTitle: "Page styling and customization"
};
const nylasParticipantBookingCalendars$8 = {
	headerTitle: "Book to this calendar",
	headerSubTitle: "Select the calendar where you want to add event bookings.",
	participantBookingCalendarTitle: "{{participantName}}'s booking calendars",
	selectAtLeastOneCalendar: "Please select at least one calendar for each participant."
};
const nylasParticipantCustomAvailability$8 = {
	headerTitle: "Participant open hours",
	headerSubTitle: "If not set, the default open hours will be used to calculate availability for this participant.",
	participantOpenHoursTitle: "{{participantName}}'s open hours"
};
const nylasReminderEmails$8 = {
	headerTitle: "Upcoming meeting{{organizerName}}",
	headerSubTitle: "Reminder before event",
	editButtonText: "Edit",
	recipientOptions_all: "All host & guests",
	recipientOptions_guest: "All event guests",
	recipientOptions_host: "Only event host",
	beforeTheEvent: "before the event",
	emailRecipients: {
		label: "Email recipients"
	},
	sendConfirmation: {
		label: "Send confirmation email when",
		tooltip: {
			desc: "The recipients will receive a reminder email at the specified time before the event."
		}
	},
	emailSubject: {
		label: "Email subject",
		placeholder: "Upcoming meeting{{organizerName}}"
	},
	reminderMinutesValidationError: "Please enter the reminder minutes in multiples of 5. Try ",
	newReminderButtonText: "New reminder"
};
const nylasSchedulingMethod$8 = {
	headerTitle: "Scheduling method",
	headerSubTitle: "Select a scheduling method for the event.",
	tooltip: {
		standard: {
			label: "Standard",
			desc: "Allows 1:1 bookings, or n:1 bookings with additional participants."
		},
		maxFairness: {
			label: "Round-Robin Maximize Fairness",
			desc: "Rotates through the list of participants you select, displaying the participant with the fewest recent bookings."
		},
		maxAvailability: {
			label: "Round-Robin Maximize Availability",
			desc: "Rotates through the list of participants you select, prioritizing participants with the fewest recent bookings, but making as many time-slots available as possible."
		}
	},
	schedulingMethodOptions_collective: "Standard booking",
	schedulingMethodOptions_maxFairness: "Round-Robin max Fairness",
	schedulingMethodOptions_maxAvailability: "Round-Robin max Availability"
};
const nylasTimeslotInterval$8 = {
	minutesShort: "mins",
	lengthOfMeeting: "Length of the booking",
	headerTitle: "Time slot settings",
	timeslotInterval: {
		label: "Time slot interval."
	},
	timeslotRounding: {
		label: "Time slot rounding type",
		tooltip: {
			desc: "The interval at which time slots are displayed."
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "Interval rounding",
			desc: "Time slots will begin at times rounded to the interval value."
		},
		noRounding: {
			label: "Default",
			desc: "Time slots will be rounded to the nearest quarter-hour."
		}
	}
};
const nylasEventTimeslot$8 = {
	recurrenceOptions: {
		none: "Does not repeat",
		daily: "Daily",
		weekly: "Weekly every {{dayOfWeek}}",
		monthly: "Monthly on the {{dayOfMonth}}",
		monthOnDay: "Monthly on day {{date}}",
		yearly: "Annually on {{dateOfMonth}}",
		custom: "Custom"
	},
	recurrenceLabel: "Repeat this event",
	endDate: "End date",
	customRecurrence: {
		repeatEvery: "Repeat every",
		repeatOn: "Repeat on",
		ends: "Ends",
		endsOptions: {
			never: "Never",
			after: "After",
			on: "On"
		},
		occurrences: "occurrences"
	},
	dateTimeLabel: "Date and time",
	errors: {
		invalidTimeRange: "Invalid time range",
		startTimeSameAsEndTime: "Start time and end time cannot be the same",
		startTimeBeforeCurrentDate: "Start time cannot be in the past",
		invalid: "Invalid"
	}
};
const nylasEventCapacity$8 = {
	headerTitle: "Invitees",
	headerSubTitle: "Set the maximum number of invitees for this event time slot.",
	tooltip: {
		desc: "The organizer and participants configured in the scheduling page are not counted as invitees."
	},
	attendees: "attendees"
};
const nylasSelectEventType$8 = {
	returnToAllSchedulingPages: "Return to all scheduling pages",
	createEventHeaderTitle: "Create an event",
	eventTypeHeaderTitle: "Event type",
	noEventTypesEnabled: "No event types enabled",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "Allows 1:1 bookings"
		},
		collective: {
			label: "Collective",
			desc: "Allows n:1 bookings with additional participants"
		},
		maxFairness: {
			label: "Round-Robin Maximize Fairness",
			desc: "Rotates through the list of participants you select, displaying the participant with the fewest recent bookings."
		},
		maxAvailability: {
			label: "Round-Robin Maximize Availability",
			desc: "Rotates through the list of participants you select, prioritizing participants with the fewest recent bookings, but making as many time-slots available as possible."
		},
		group: {
			label: "Group / Class",
			desc: "These are events which generally have one organizer and multiple participants"
		}
	}
};
const pageSettingsButton$8 = "Page settings";
const nylasEventCalendar$8 = {
	hideNonGroupEvents: {
		showLabel: "Filter events",
		tooltip: {
			desc: "Select the type of events to display in the calendar."
		},
		options: {
			all: "All",
			group: "Group only"
		}
	},
	createEventDetails: {
		headerTitle: "Event Details",
		closeButtonTooltip: "Close",
		cancelButton: "Cancel",
		createButton: "Create"
	},
	discardChanges: {
		headerTitle: "Discard unsaved changes?",
		cancelButton: "Cancel",
		discardButton: "Discard"
	},
	unsavedChanges: "Unsaved changes",
	editEventDetails: {
		headerTitle: "Event Details",
		closeButtonTooltip: "Close",
		deleteButton: "Delete",
		saveButton: "Save",
		pastEventTooltip: "This event is in the past and cannot be edited."
	},
	importEvent: {
		closeButtonTooltip: "Close",
		importButton: "Import",
		participantsLabel: "Participants"
	},
	deleteEvent: {
		closeButtonTooltip: "Close",
		deleting: "Deleting..."
	},
	editOptions: {
		headerTitle: "Actions",
		closeButtonTooltip: "Close",
		deleting: "Deleting...",
		"import": "Import",
		edit: "Edit",
		deleteThis: "Delete this event only",
		deleteAll: "Delete all events",
		importTooltip: "Allows you to select existing events from a calendar and configure it as group events"
	},
	updateOptions: {
		updateThis: "Update this event",
		updateAll: "Update all events",
		updateFuture: "Update all future occurrences"
	},
	deleteOptions: {
		deleteThis: "Delete this event",
		deleteFuture: "Delete this and all future occurrences",
		deleteAll: "Delete all events"
	}
};
const en = {
	noDateSelected: noDateSelected$8,
	rescheduleTitle: rescheduleTitle$8,
	allDay: allDay$8,
	today: today$8,
	spotsLeft: spotsLeft$8,
	search: search$8,
	selectOneOrMoreOptions: selectOneOrMoreOptions$8,
	days: days$8,
	time: time$8,
	months: months$8,
	multipleOptionsSelected: multipleOptionsSelected$8,
	selectAtLeastOneOption: selectAtLeastOneOption$8,
	nextButton: nextButton$8,
	selectedDayAndYear: selectedDayAndYear$8,
	selectedTime: selectedTime$8,
	name: name$8,
	namePlaceholder: namePlaceholder$8,
	email: email$8,
	emailPlaceholder: emailPlaceholder$8,
	guestEmail: guestEmail$8,
	guestEmailPlaceholder: guestEmailPlaceholder$8,
	addGuest: addGuest$8,
	addAnotherGuest: addAnotherGuest$8,
	backButton: backButton$8,
	bookNowButton: bookNowButton$8,
	bookingConfirmed: bookingConfirmed$8,
	bookingConfirmedDescription: bookingConfirmedDescription$8,
	bookingSent: bookingSent$8,
	bookingSentDescription: bookingSentDescription$8,
	bookingRescheduled: bookingRescheduled$8,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$8,
	cancelBookingButton: cancelBookingButton$8,
	rescheduleBookingButton: rescheduleBookingButton$8,
	rejectBookingButton: rejectBookingButton$8,
	confirmBookingButton: confirmBookingButton$8,
	bookingPendingTitle: bookingPendingTitle$8,
	bookingPendingnDescription: bookingPendingnDescription$8,
	confirmedEventCardTitle: confirmedEventCardTitle$8,
	confirmedEventCardDescription: confirmedEventCardDescription$8,
	cancelBookingTitle: cancelBookingTitle$8,
	cancelBookingMessage: cancelBookingMessage$8,
	reasonForCancellation: reasonForCancellation$8,
	goBackButton: goBackButton$8,
	bookingCancelledTitle: bookingCancelledTitle$8,
	bookingCancelledMessage: bookingCancelledMessage$8,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$8,
	closeButton: closeButton$8,
	closingButton: closingButton$8,
	fieldRequired: fieldRequired$8,
	invalidInputFormat: invalidInputFormat$8,
	createBookingErrorTitle: createBookingErrorTitle$8,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$8,
	cancelBookingErrorTitle: cancelBookingErrorTitle$8,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$8,
	getUISettingErrorTitle: getUISettingErrorTitle$8,
	rejectBookingErrorTitle: rejectBookingErrorTitle$8,
	confirmBookingErrorTitle: confirmBookingErrorTitle$8,
	genericErrorTitle: genericErrorTitle$8,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$8,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$8,
	publicConfigErrorMessage: publicConfigErrorMessage$8,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$7,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$8,
	cancellationErrorTitle: cancellationErrorTitle$8,
	cancellationErrorMessage: cancellationErrorMessage$8,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$8,
	cancelBokingFormError: cancelBokingFormError$8,
	feedbackFormTitle: feedbackFormTitle$8,
	feedbackFormDescription: feedbackFormDescription$8,
	feedbackMessageLabel: feedbackMessageLabel$8,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$8,
	feedbackModalCloseButton: feedbackModalCloseButton$8,
	feedbackModalSubmitButton: feedbackModalSubmitButton$8,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$8,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$8,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$8,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$8,
	schedulerEditorTitle: schedulerEditorTitle$8,
	allSchedulingPages: allSchedulingPages$8,
	createAndManageSchedulingPages: createAndManageSchedulingPages$8,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$8,
	pageTitle: pageTitle$8,
	durationTitle: durationTitle$8,
	loading: loading$8,
	required: required$8,
	optional: optional$8,
	loadingPagesDescription: loadingPagesDescription$8,
	noSchedulingPages: noSchedulingPages$8,
	createFirstSchedulingPage: createFirstSchedulingPage$8,
	editSchedulingPageButtonText: editSchedulingPageButtonText$8,
	eventInfoTab: eventInfoTab$8,
	availabilityTab: availabilityTab$8,
	participantsTab: participantsTab$8,
	bookingOptionsTab: bookingOptionsTab$8,
	returnToCalendarView: returnToCalendarView$8,
	bookingFormTab: bookingFormTab$8,
	communicationsTab: communicationsTab$8,
	pageStylesTab: pageStylesTab$8,
	savingButtonText: savingButtonText$8,
	saveChangesButtonText: saveChangesButtonText$8,
	createButtonText: createButtonText$8,
	timePeriod_day: timePeriod_day$8,
	timePeriod_week: timePeriod_week$8,
	timePeriod_month: timePeriod_month$8,
	timePeriod_year: timePeriod_year$8,
	timeDuration_minute: timeDuration_minute$8,
	timeDuration_hour: timeDuration_hour$8,
	eventCommunicationsTitle: eventCommunicationsTitle$8,
	eventCommunicationsDescription: eventCommunicationsDescription$8,
	unsavedChangesLabel: unsavedChangesLabel$8,
	changesSavedLabel: changesSavedLabel$8,
	fixFormErrors: fixFormErrors$8,
	nylasEditorTabs: nylasEditorTabs$8,
	nylasEditorTabsGroup: nylasEditorTabsGroup$8,
	nylasListConfigurations: nylasListConfigurations$8,
	nylasAdditionalParticipants: nylasAdditionalParticipants$8,
	nylasAvailabilityPicker: nylasAvailabilityPicker$8,
	nylasTimeWindowPicker: nylasTimeWindowPicker$4,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$8,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$8,
	nylasBookingConfirmationType: nylasBookingConfirmationType$8,
	nylasBookingFormConfig: nylasBookingFormConfig$8,
	nylasBufferTime: nylasBufferTime$8,
	nylasCalendarPicker: nylasCalendarPicker$8,
	nylasCancellationPolicy: nylasCancellationPolicy$8,
	nylasConfirmationEmail: nylasConfirmationEmail$8,
	nylasConnectedCalendars: nylasConnectedCalendars$8,
	nylasCustomBookingFlow: nylasCustomBookingFlow$8,
	nylasCustomEventSlug: nylasCustomEventSlug$8,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$8,
	nylasEventDescription: nylasEventDescription$8,
	nylasEventDuration: nylasEventDuration$8,
	nylasEventInfo: nylasEventInfo$8,
	nylasEventLimits: nylasEventLimits$8,
	nylasEventLocation: nylasEventLocation$8,
	nylasEventTitle: nylasEventTitle$8,
	nylasLimitFutureBookings: nylasLimitFutureBookings$8,
	nylasMinBookingNotice: nylasMinBookingNotice$8,
	nylasMinCancellationNotice: nylasMinCancellationNotice$8,
	nylasPageName: nylasPageName$8,
	nylasPageStyling: nylasPageStyling$8,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$8,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$8,
	nylasReminderEmails: nylasReminderEmails$8,
	nylasSchedulingMethod: nylasSchedulingMethod$8,
	nylasTimeslotInterval: nylasTimeslotInterval$8,
	nylasEventTimeslot: nylasEventTimeslot$8,
	nylasEventCapacity: nylasEventCapacity$8,
	nylasSelectEventType: nylasSelectEventType$8,
	pageSettingsButton: pageSettingsButton$8,
	nylasEventCalendar: nylasEventCalendar$8
};

const enTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$8,
  rescheduleTitle: rescheduleTitle$8,
  allDay: allDay$8,
  today: today$8,
  spotsLeft: spotsLeft$8,
  search: search$8,
  selectOneOrMoreOptions: selectOneOrMoreOptions$8,
  days: days$8,
  time: time$8,
  months: months$8,
  multipleOptionsSelected: multipleOptionsSelected$8,
  selectAtLeastOneOption: selectAtLeastOneOption$8,
  nextButton: nextButton$8,
  selectedDayAndYear: selectedDayAndYear$8,
  selectedTime: selectedTime$8,
  name: name$8,
  namePlaceholder: namePlaceholder$8,
  email: email$8,
  emailPlaceholder: emailPlaceholder$8,
  guestEmail: guestEmail$8,
  guestEmailPlaceholder: guestEmailPlaceholder$8,
  addGuest: addGuest$8,
  addAnotherGuest: addAnotherGuest$8,
  backButton: backButton$8,
  bookNowButton: bookNowButton$8,
  bookingConfirmed: bookingConfirmed$8,
  bookingConfirmedDescription: bookingConfirmedDescription$8,
  bookingSent: bookingSent$8,
  bookingSentDescription: bookingSentDescription$8,
  bookingRescheduled: bookingRescheduled$8,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$8,
  cancelBookingButton: cancelBookingButton$8,
  rescheduleBookingButton: rescheduleBookingButton$8,
  rejectBookingButton: rejectBookingButton$8,
  confirmBookingButton: confirmBookingButton$8,
  bookingPendingTitle: bookingPendingTitle$8,
  bookingPendingnDescription: bookingPendingnDescription$8,
  confirmedEventCardTitle: confirmedEventCardTitle$8,
  confirmedEventCardDescription: confirmedEventCardDescription$8,
  cancelBookingTitle: cancelBookingTitle$8,
  cancelBookingMessage: cancelBookingMessage$8,
  reasonForCancellation: reasonForCancellation$8,
  goBackButton: goBackButton$8,
  bookingCancelledTitle: bookingCancelledTitle$8,
  bookingCancelledMessage: bookingCancelledMessage$8,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$8,
  closeButton: closeButton$8,
  closingButton: closingButton$8,
  fieldRequired: fieldRequired$8,
  invalidInputFormat: invalidInputFormat$8,
  createBookingErrorTitle: createBookingErrorTitle$8,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$8,
  cancelBookingErrorTitle: cancelBookingErrorTitle$8,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$8,
  getUISettingErrorTitle: getUISettingErrorTitle$8,
  rejectBookingErrorTitle: rejectBookingErrorTitle$8,
  confirmBookingErrorTitle: confirmBookingErrorTitle$8,
  genericErrorTitle: genericErrorTitle$8,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$8,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$8,
  publicConfigErrorMessage: publicConfigErrorMessage$8,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$7,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$8,
  cancellationErrorTitle: cancellationErrorTitle$8,
  cancellationErrorMessage: cancellationErrorMessage$8,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$8,
  cancelBokingFormError: cancelBokingFormError$8,
  feedbackFormTitle: feedbackFormTitle$8,
  feedbackFormDescription: feedbackFormDescription$8,
  feedbackMessageLabel: feedbackMessageLabel$8,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$8,
  feedbackModalCloseButton: feedbackModalCloseButton$8,
  feedbackModalSubmitButton: feedbackModalSubmitButton$8,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$8,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$8,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$8,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$8,
  schedulerEditorTitle: schedulerEditorTitle$8,
  allSchedulingPages: allSchedulingPages$8,
  createAndManageSchedulingPages: createAndManageSchedulingPages$8,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$8,
  pageTitle: pageTitle$8,
  durationTitle: durationTitle$8,
  loading: loading$8,
  required: required$8,
  optional: optional$8,
  loadingPagesDescription: loadingPagesDescription$8,
  noSchedulingPages: noSchedulingPages$8,
  createFirstSchedulingPage: createFirstSchedulingPage$8,
  editSchedulingPageButtonText: editSchedulingPageButtonText$8,
  eventInfoTab: eventInfoTab$8,
  availabilityTab: availabilityTab$8,
  participantsTab: participantsTab$8,
  bookingOptionsTab: bookingOptionsTab$8,
  returnToCalendarView: returnToCalendarView$8,
  bookingFormTab: bookingFormTab$8,
  communicationsTab: communicationsTab$8,
  pageStylesTab: pageStylesTab$8,
  savingButtonText: savingButtonText$8,
  saveChangesButtonText: saveChangesButtonText$8,
  createButtonText: createButtonText$8,
  timePeriod_day: timePeriod_day$8,
  timePeriod_week: timePeriod_week$8,
  timePeriod_month: timePeriod_month$8,
  timePeriod_year: timePeriod_year$8,
  timeDuration_minute: timeDuration_minute$8,
  timeDuration_hour: timeDuration_hour$8,
  eventCommunicationsTitle: eventCommunicationsTitle$8,
  eventCommunicationsDescription: eventCommunicationsDescription$8,
  unsavedChangesLabel: unsavedChangesLabel$8,
  changesSavedLabel: changesSavedLabel$8,
  fixFormErrors: fixFormErrors$8,
  nylasEditorTabs: nylasEditorTabs$8,
  nylasEditorTabsGroup: nylasEditorTabsGroup$8,
  nylasListConfigurations: nylasListConfigurations$8,
  nylasAdditionalParticipants: nylasAdditionalParticipants$8,
  nylasAvailabilityPicker: nylasAvailabilityPicker$8,
  nylasTimeWindowPicker: nylasTimeWindowPicker$4,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$8,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$8,
  nylasBookingConfirmationType: nylasBookingConfirmationType$8,
  nylasBookingFormConfig: nylasBookingFormConfig$8,
  nylasBufferTime: nylasBufferTime$8,
  nylasCalendarPicker: nylasCalendarPicker$8,
  nylasCancellationPolicy: nylasCancellationPolicy$8,
  nylasConfirmationEmail: nylasConfirmationEmail$8,
  nylasConnectedCalendars: nylasConnectedCalendars$8,
  nylasCustomBookingFlow: nylasCustomBookingFlow$8,
  nylasCustomEventSlug: nylasCustomEventSlug$8,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$8,
  nylasEventDescription: nylasEventDescription$8,
  nylasEventDuration: nylasEventDuration$8,
  nylasEventInfo: nylasEventInfo$8,
  nylasEventLimits: nylasEventLimits$8,
  nylasEventLocation: nylasEventLocation$8,
  nylasEventTitle: nylasEventTitle$8,
  nylasLimitFutureBookings: nylasLimitFutureBookings$8,
  nylasMinBookingNotice: nylasMinBookingNotice$8,
  nylasMinCancellationNotice: nylasMinCancellationNotice$8,
  nylasPageName: nylasPageName$8,
  nylasPageStyling: nylasPageStyling$8,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$8,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$8,
  nylasReminderEmails: nylasReminderEmails$8,
  nylasSchedulingMethod: nylasSchedulingMethod$8,
  nylasTimeslotInterval: nylasTimeslotInterval$8,
  nylasEventTimeslot: nylasEventTimeslot$8,
  nylasEventCapacity: nylasEventCapacity$8,
  nylasSelectEventType: nylasSelectEventType$8,
  pageSettingsButton: pageSettingsButton$8,
  nylasEventCalendar: nylasEventCalendar$8,
  'default': en
});

const noDateSelected$7 = "Aucune date sélectionnée";
const rescheduleTitle$7 = "Choisissez un autre créneau horaire pour reprogrammer votre réunion";
const allDay$7 = "Toute la journée";
const today$7 = "Aujourd'hui";
const spotsLeft$7 = "{{count}} places restantes";
const search$7 = "Rechercher";
const selectOneOrMoreOptions$7 = "Sélectionnez une ou plusieurs options";
const days$7 = {
	sunday: "DIM",
	monday: "LUN",
	tuesday: "MAR",
	wednesday: "MER",
	thursday: "JEU",
	friday: "VEN",
	saturday: "SAM"
};
const time$7 = {
	hour: "heure",
	hours: "heures",
	minute: "minute",
	minutes: "minutes",
	day: "jour",
	days: "jours",
	week: "semaine",
	weeks: "semaines",
	month: "mois",
	months: "mois",
	year: "année",
	years: "années"
};
const months$7 = {
	january: "Janvier",
	february: "Février",
	march: "Mars",
	april: "Avril",
	may: "Mai",
	june: "Juin",
	july: "Juillet",
	august: "Août",
	september: "Septembre",
	october: "Octobre",
	november: "Novembre",
	december: "Décembre"
};
const multipleOptionsSelected$7 = "Plusieurs options sélectionnées";
const selectAtLeastOneOption$7 = "Veuillez sélectionner au moins une option";
const nextButton$7 = "Suivant";
const selectedDayAndYear$7 = "{{date}}";
const selectedTime$7 = "{{time}}";
const name$7 = "Nom";
const namePlaceholder$7 = "Entrez votre nom";
const email$7 = "E-mail";
const emailPlaceholder$7 = "Entrer votre E-mail";
const guestEmail$7 = "E-mail invité";
const guestEmailPlaceholder$7 = "Entrez l'adresse e-mail de l'invité";
const addGuest$7 = "Ajouter un invité";
const addAnotherGuest$7 = "Ajouter un autre invité";
const backButton$7 = "Retour";
const bookNowButton$7 = "Réservez maintenant";
const bookingConfirmed$7 = "Réservation confirmée";
const bookingConfirmedDescription$7 = "Vous recevrez bientôt un e-mail de confirmation.";
const bookingSent$7 = "Réservation envoyée";
const bookingSentDescription$7 = "Vous recevrez un e-mail une fois la réservation confirmée.";
const bookingRescheduled$7 = "Réservation reprogrammée";
const bookingDateAndTimeHeader$7 = "Date et heure de la réservation";
const cancelBookingButton$7 = "Annuler la réservation";
const rescheduleBookingButton$7 = "Replanifier";
const rejectBookingButton$7 = "Refuser la réservation";
const confirmBookingButton$7 = "Confirmer la réservation";
const bookingPendingTitle$7 = "Réservation en attente";
const bookingPendingnDescription$7 = "Gérez votre réservation ci-dessous. L'invité recevra un e-mail l'informant du statut de la demande.";
const confirmedEventCardTitle$7 = "Votre réservation a été confirmée avec succès";
const confirmedEventCardDescription$7 = "Un e-mail de confirmation a été envoyé à";
const cancelBookingTitle$7 = "Annuler la réservation?";
const cancelBookingMessage$7 = "Votre créneau horaire actuel sera disponible pour les autres.";
const reasonForCancellation$7 = "Raison de l'annulation";
const goBackButton$7 = "Retourner";
const bookingCancelledTitle$7 = "Votre réservation a été annulée avec succès";
const bookingCancelledMessage$7 = "Un e-mail d'annulation a été envoyé à";
const bookingCancelledMessage_theParticipants$7 = "les participants";
const closeButton$7 = "Fermer";
const closingButton$7 = "Fermeture";
const fieldRequired$7 = "{{field}} est requis.";
const invalidInputFormat$7 = "{{field}} a un format invalide.";
const createBookingErrorTitle$7 = "Créer une Réservation";
const getAvailabilityErrorTitle$7 = "Obtenir la Disponibilité";
const cancelBookingErrorTitle$7 = "Annuler la Réservation";
const rescheduleBookingErrorTitle$7 = "Reprogrammer la Réservation";
const getUISettingErrorTitle$7 = "Obtenir les Paramètres UI";
const rejectBookingErrorTitle$7 = "Refuser la Réservation";
const confirmBookingErrorTitle$7 = "Confirmer la Réservation";
const genericErrorTitle$7 = "Quelque chose a mal tourné...";
const schedulingComponentErrorTitle$7 = "Erreur du composant de planification";
const sessionIdRequiredErrorMessage$7 = "'sessionId' est requis pour les configurations privées.";
const publicConfigErrorMessage$7 = "Si vous utilisez une configuration publique, passez soit un configurationId, soit une combinaison de 'slug' et 'clientId'.";
const invalidTimeslotErrorTitle$6 = "Créneau horaire invalide !";
const invalidTimeslotErrorMessage$7 = "Le créneau horaire sélectionné est invalide";
const cancellationErrorTitle$7 = "Erreur d'annulation";
const cancellationErrorMessage$7 = "Veuillez fournir une raison pour l'annulation.";
const minimumCancellationErrorMessage$7 = "Vous ne pouvez pas annuler la réservation dans les {{minCancellationNotice}} minutes avant l'événement";
const cancelBokingFormError$7 = "Erreur de formulaire d'annulation de réservation";
const feedbackFormTitle$7 = "Partagez vos commentaires";
const feedbackFormDescription$7 = "Nous fournir vos commentaires et signaler des erreurs nous aide à créer une meilleure expérience pour vous.";
const feedbackMessageLabel$7 = "Veuillez nous fournir une description détaillée de la fonctionnalité sur laquelle vous commentez ou du problème que vous avez rencontré.";
const feedbackMessagePlaceholder$7 = "Saisissez vos commentaires ici";
const feedbackModalCloseButton$7 = "Annuler";
const feedbackModalSubmitButton$7 = "Envoyer";
const deleteSchedulingPageTitle$7 = "Supprimer cette page de planification?";
const deleteSchedulingPageDescription$7 = "Après confirmation, cette page et ses liens de planification associés seront définitivement supprimés et désactivés. Cette action est irréversible.";
const deleteSchedulingPageConfirmButton$7 = "Supprimer la page";
const deleteSchedulingPageCancelButton$7 = "Annuler";
const schedulerEditorTitle$7 = "Éditeur de planification";
const allSchedulingPages$7 = "Toutes les pages de planification";
const createAndManageSchedulingPages$7 = "Créez et gérez vos pages de planification.";
const createNewSchedulingPageButtonText$7 = "Créer un nouveau";
const pageTitle$7 = "Titre de la page";
const durationTitle$7 = "Durée";
const loading$7 = "Chargement";
const required$7 = "Requis";
const optional$7 = "Facultatif";
const loadingPagesDescription$7 = "Veuillez patienter pendant que nous récupérons les pages de planification";
const noSchedulingPages$7 = "Aucune page de planification trouvée";
const createFirstSchedulingPage$7 = "Commencez par créer votre première page de planification";
const editSchedulingPageButtonText$7 = "Modifier";
const eventInfoTab$7 = "Informations sur l'événement";
const availabilityTab$7 = "Disponibilité";
const participantsTab$7 = "Participants";
const bookingOptionsTab$7 = "Options de réservation";
const returnToCalendarView$7 = "Retour à la vue du calendrier";
const bookingFormTab$7 = "Formulaire de réservation";
const communicationsTab$7 = "Communications";
const pageStylesTab$7 = "Styles de page";
const savingButtonText$7 = "Enregistrement";
const saveChangesButtonText$7 = "Enregistrer les modifications";
const createButtonText$7 = "Créer";
const timePeriod_day$7 = "jour";
const timePeriod_week$7 = "semaine";
const timePeriod_month$7 = "mois";
const timePeriod_year$7 = "année";
const timeDuration_minute$7 = "minute";
const timeDuration_hour$7 = "heure";
const eventCommunicationsTitle$7 = "Communications de l'événement";
const eventCommunicationsDescription$7 = "Configurez des e-mails de confirmation automatiques.";
const unsavedChangesLabel$7 = "Modifications non enregistrées";
const changesSavedLabel$7 = "Modifications enregistrées";
const fixFormErrors$7 = "Veuillez corriger les erreurs du formulaire.";
const nylasEditorTabs$7 = {
	bookingFormError: "Erreur de formulaire de réservation: ",
	bookingFormError_label: "Étiquette requise pour le champ de type {{type}}.",
	bookingFormError_option: "Option vide détectée dans {{label}} de type {{type}}.",
	formErrorTitle: "Erreur de formulaire",
	updateConfigError: "Erreur de mise à jour de la configuration: ",
	createConfigError: "Erreur de création de la configuration: ",
	deleteConfigError: "Erreur de suppression de la configuration: ",
	getConfigsError: "Erreur lors de la récupération des configurations: "
};
const nylasEditorTabsGroup$7 = {
	eventTitleRequired: "Le titre de l'événement est requis.",
	eventTimeRequired: "Le temps de l'événement est requis.",
	participantsRequired: "Les participants sont requis.",
	participantEmailRequired: "L'adresse e-mail du participant est requise.",
	errorOccured: "Erreur lors de la sauvegarde des modifications.",
	createGroupEventError: "Erreur lors de la création de l'événement du groupe: ",
	updateGroupEventError: "Erreur lors de la mise à jour de l'événement du groupe: ",
	deleteGroupEventError: "Erreur lors de la suppression de l'événement du groupe: ",
	importGroupEventError: "Erreur lors de l'importation de l'événement du groupe: ",
	getGroupEventsError: "Erreur lors de la récupération des événements du groupe: "
};
const nylasListConfigurations$7 = {
	previewButtonText: "Aperçu",
	copyLinkButtonText: "Copier le lien",
	deleteButtonText: "Supprimer"
};
const nylasAdditionalParticipants$7 = {
	headerTitle: "Participants",
	headerSubTitle: "Ajoutez des personnes de votre équipe ou organisation pour participer à l'événement.",
	organizerAsParticipant: "Participant",
	organizer: "Organisateur",
	participant: "Participant",
	addParticipant_first: "Ajouter un participant",
	addParticipant_next: "Ajouter un autre participant",
	tooltip: {
		includeOrganizer: "Inclure l'organisateur",
		includeOrganizerDesc: "L'organisateur (vous) sera inclus dans la rotation.",
		excludeOrganizer: "Exclure l'organisateur",
		excludeOrganizerDesc: "L'organisateur (vous) ne sera pas inclus dans la rotation."
	},
	error: "Veuillez ajouter au moins un participant"
};
const nylasAvailabilityPicker$7 = {
	headerTitle: "Horaires d'ouverture par défaut",
	headerSubTitle: "Définissez vos disponibilités régulières pour les réservations d'événements.",
	tooltip: {
		desc: "Ce sont les disponibilités par défaut pour les participants qui n'ont pas défini de disponibilités dans l'onglet Participants."
	},
	selectTimezone: "Sélectionnez un fuseau horaire",
	unavailable: "Indisponible",
	days: {
		SUN: "DIM",
		MON: "LUN",
		TUE: "MAR",
		WED: "MER",
		THU: "JEU",
		FRI: "VEN",
		SAT: "SAM"
	}
};
const nylasTimeWindowPicker$3 = {
	errors: {
		invalid: "Invalide"
	}
};
const nylasBookingCalendarPicker$7 = {
	headerTitle: "Réservation de calendrier",
	headerSubTitle: "Sélectionnez le calendrier où vous souhaitez ajouter des réservations.",
	tooltip: {
		desc: "Le calendrier sera utilisé pour créer des événements."
	},
	selectOptionLabel: "Sélectionnez une option",
	selectCalendarErrorMessage: "Veuillez sélectionner un calendrier"
};
const nylasBookingConfirmationRedirect$7 = {
	dropdownLabel: "Lorsque la réservation est confirmée",
	tooltip: {
		desc: "Vous pouvez afficher la page de confirmation par défaut ou rediriger les utilisateurs vers votre propre page de confirmation."
	},
	redirectOption_default: "Afficher la page de confirmation par défaut",
	redirectOption_custom: "Rediriger vers une URL personnalisée"
};
const nylasBookingConfirmationType$7 = {
	dropdownLabel: "Lorsque la réservation est demandée",
	tooltip: {
		desc: "Accepter les réservations manuellement vous permet d'examiner et d'accepter ou de refuser chaque demande de réservation."
	},
	bookingOption_booking: "Accepter automatiquement les réservations",
	bookingOption_organizerConfirmation: "Accepter les réservations manuellement"
};
const nylasBookingFormConfig$7 = {
	headerTitle: "Formulaire de réservation",
	headerSubTitle: "Ajoutez des champs personnalisés au formulaire de réservation.",
	dropdownButtonText: "Ajouter un nouveau champ",
	addOption: "Ajouter une option",
	allOptionsHeader: "TOUTES LES OPTIONS",
	fieldInTitleError: "Ce champ est utilisé dans le titre de l'événement et ne peut pas être supprimé.",
	fieldInDescriptionError: "Ce champ est utilisé dans la description de l'événement et ne peut pas être supprimé.",
	label: "Étiquette",
	defaultValue: "Valeur par défaut",
	fieldType: {
		text: "Texte court",
		multi_line_text: "Texte long",
		email: "Email",
		phone_number: "Numéro de téléphone",
		dropdown: "Menu déroulant",
		radio_button: "Bouton radio",
		checkbox: "Case à cocher",
		date: "Date",
		metadata: "Métadonnées",
		multi_select: "Sélection multiple"
	},
	fieldLabel: {
		your_name: "Votre nom",
		your_email: "Votre e-mail",
		email: "E-mail supplémentaire",
		phone_number: "Étiquette du numéro de téléphone",
		dropdown: "Étiquette de menu déroulant",
		text: "Étiquette de texte court",
		multi_line_text: "Étiquette de texte long",
		radio_button: "Étiquette du bouton radio",
		checkbox: "Étiquette de case à cocher",
		date: "Étiquette de date",
		metadata: "Étiquette des métadonnées",
		multi_select: "Étiquette de sélection multiple"
	}
};
const nylasBufferTime$7 = {
	headerTitle: "Temps tampon",
	headerSubTitle: "Exigez un temps tampon avant et après un événement.",
	tooltip: {
		desc: "Le planificateur ne réservera pas le temps tampon."
	},
	beforeBufferLabel: "Avant l'événement",
	afterBufferLabel: "Après l'événement",
	minutesShort: "min",
	previewHeader: "APERÇU"
};
const nylasCalendarPicker$7 = {
	calendarPickerLabel: "Sélectionnez les calendriers à vérifier pour les disponibilités",
	selectAtLeastOneCalendar: "Veuillez sélectionner au moins un calendrier pour chaque participant."
};
const nylasCancellationPolicy$7 = {
	cancellationPolicyLabel: "Message de politique d'annulation",
	tooltip: {
		desc: "Les participants reçoivent ce message s'ils essaient d'annuler l'événement. Ils doivent fournir une raison pour l'annulation."
	}
};
const nylasConfirmationEmail$7 = {
	headerTitle: "Réservation confirmée{{organizerName}}",
	headerSubTitle: "E-mail de confirmation de réservation",
	editButtonText: "Modifier",
	error: {
		invalidImageUrl: "URL de l'image invalide."
	},
	confirmationEmail: {
		label: "Activer les notifications par e-mail",
		tooltip: {
			desc: "Autorisez Nylas à envoyer des notifications par e-mail, y compris des messages de confirmation et des rappels d'événements.",
			language: "Cette langue sera utilisée pour les notifications par e-mail aux organisateurs."
		},
		language: "Sélectionner la langue"
	},
	nylasBranding: {
		label: "Afficher la marque Nylas",
		tooltip: {
			desc: "Décochez cette option pour masquer le pied de page dans la communication par e-mail."
		}
	},
	companyLogoUrl: {
		label: "URL du logo de l'entreprise",
		tooltip: {
			desc: "Ce logo apparaît dans l'e-mail de confirmation de réservation. L'URL doit être accessible publiquement. L'image sera redimensionnée à une taille maximale de 200px x 100px."
		}
	},
	emailMessage: {
		header: "Message e-mail",
		label: "Titre personnalisé de l'e-mail",
		tooltip: {
			desc: "Un titre d'e-mail est une en-tête dans le corps de l'e-mail. Cela ne modifie pas la ligne d'objet."
		},
		additionalInfoLabel: "Informations supplémentaires",
		additionalInfoTooltip: "Le planificateur ajoute le contenu de cette case au corps de l'e-mail.",
		additionalInfoPlaceholder: "Texte par défaut"
	},
	allHosts: "Tous les hôtes et invités",
	immediatelyUponBooking: "Immédiatement après la réservation"
};
const nylasConnectedCalendars$7 = {
	headerTitle: "Calendriers connectés",
	headerSubTitle: "Sélectionnez les calendriers à utiliser pour vérifier votre disponibilité.",
	tooltip: {
		desc: "Vérifiez la disponibilité sur un ou plusieurs calendriers. Si vous sélectionnez plusieurs calendriers pour un participant, celui-ci doit être disponible sur tous ses calendriers pour être considéré comme disponible."
	},
	participantCalendarTitle: "Calendriers connectés de {{participantName}}",
	selectAtLeastOneCalendar: "Veuillez sélectionner au moins un calendrier pour chaque participant."
};
const nylasCustomBookingFlow$7 = {
	headerTitle: "Flux de réservation personnalisé"
};
const nylasCustomEventSlug$7 = {
	headerTitle: "Slug personnalisé de page",
	headerSubTitle: "Créez un slug d'URL personnalisé pour cette page.",
	eventSlugLabel: "Slug d'URL de la page",
	tooltip: {
		desc: "Fournissez un slug personnalisé pour votre URL afin d'identifier de manière unique votre page (lettres, chiffres et tirets uniquement)."
	},
	copied: "Copié !"
};
const nylasCustomizeBookingSettings$7 = {
	headerTitle: "Paramètres supplémentaires",
	headerSubTitle: "Paramètres de réservation pour l'événement.",
	tooltip: {
		desc: "Personnalisez vos paramètres de réservation."
	},
	allowGuests: {
		label: "Autoriser les invités à inviter d'autres invités."
	},
	hideReschedule: {
		label: "Masquer l'option de reprogrammation.",
		tooltip: {
			desc: "Masquer le bouton 'Reprogrammer' dans la confirmation de réservation et les notifications par e-mail."
		}
	},
	hideCancel: {
		label: "Masquer l'option d'annulation",
		tooltip: {
			desc: "Masquer le bouton 'Annuler' dans la confirmation de réservation et les notifications par e-mail."
		}
	}
};
const nylasEventDescription$7 = {
	headerTitle: "Description de l'événement",
	addAdditionalFields: {
		buttonText: "Remplir automatiquement les champs supplémentaires",
		tooltip: {
			desc: "Cliquez ici une fois que vous avez ajouté tous les champs que vous souhaitez inclure dans la description. Important : Veuillez ne pas modifier les marqueurs '--- Additional Fields ---' et '--- End Additional Fields ---' pour assurer le bon fonctionnement."
		}
	},
	tooltip: {
		desc: "La description de l'événement apparaît dans la vue gestionnaire de l'éditeur de planification et dans la réponse lors de la création d'une réservation."
	}
};
const nylasEventDuration$7 = {
	headerTitle: "Durée de l'événement",
	error: {
		durationMustBeMultipleOf5: "La durée doit être un multiple de 5",
		durationMustBeGreaterThan0: "La durée doit être supérieure à 0"
	}
};
const nylasEventInfo$7 = {
	headerTitle: "Informations sur l'événement"
};
const nylasEventLimits$7 = {
	headerTitle: "Limites de l'événement"
};
const nylasEventLocation$7 = {
	headerTitle: "Lieu ou réunion de l'événement",
	tooltip: {
		desc: "Sélectionnez une option de conférence ou ajoutez un lieu personnalisé."
	},
	conferenceOptions: {
		none: "Aucun",
		zoom: "Réunion Zoom",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "Emplacement personnalisé"
	}
};
const nylasEventTitle$7 = {
	headerTitle: "Titre de l'événement",
	helpText_start: "Créez un événement dynamique basé sur un modèle {{field}} en tapant",
	helpText_end: "et en sélectionnant un élément de modèle.",
	title: "titre",
	description: "description",
	tooltip: {
		desc: "Par exemple : Entretien avec"
	},
	eventTitleRequired: "Le titre de l'événement est requis",
	eventTitleTokenDescription: {
		invitee: "Le nom du participant principal.",
		inviteeEmail: "L'adresse e-mail du participant principal.",
		duration: "La durée de l'événement."
	}
};
const nylasLimitFutureBookings$7 = {
	headerTitle: "Limiter les réservations futures",
	tooltip: {
		desc: "La limite pour déterminer jusqu'où dans le futur les réservations peuvent être effectuées."
	}
};
const nylasMinBookingNotice$7 = {
	headerTitle: "Préavis minimal pour les réservations",
	tooltip: {
		desc: "Le délai minimal à l'avance pour effectuer une nouvelle réservation."
	}
};
const nylasMinCancellationNotice$7 = {
	headerTitle: "Préavis minimal d'annulation",
	tooltip: {
		desc: "Le délai minimal nécessaire pour annuler une réservation."
	}
};
const nylasPageName$7 = {
	headerTitle: "Nom de la page",
	headerSubTitle: "Définissez le nom de la page de planification.",
	pageNameError: "Veuillez entrer un nom de page",
	tooltip: {
		desc: "Par défaut, les pages de planification utilisent votre nom d'utilisateur comme nom de page. Le nom de la page est affiché dans le coin supérieur gauche de la vue du calendrier."
	}
};
const nylasPageStyling$7 = {
	headerTitle: "Personnalisation et style de la page"
};
const nylasParticipantBookingCalendars$7 = {
	headerTitle: "Réserver sur ce calendrier",
	headerSubTitle: "Sélectionnez le calendrier où vous souhaitez ajouter des réservations d'événements.",
	participantBookingCalendarTitle: "Calendriers de réservation de {{participantName}}",
	selectAtLeastOneCalendar: "Veuillez sélectionner au moins un calendrier pour chaque participant."
};
const nylasParticipantCustomAvailability$7 = {
	headerTitle: "Horaires d'ouverture des participants",
	headerSubTitle: "Si ce n'est pas défini, les horaires d'ouverture par défaut seront utilisés pour calculer la disponibilité de ce participant.",
	participantOpenHoursTitle: "Horaires d'ouverture de {{participantName}}"
};
const nylasReminderEmails$7 = {
	headerTitle: "Prochaine réunion {{organizerName}}",
	headerSubTitle: "Rappel avant l'événement",
	editButtonText: "Modifier",
	recipientOptions_all: "Tous les hôtes et invités",
	recipientOptions_guest: "Tous les invités de l'événement",
	recipientOptions_host: "Uniquement l'hôte de l'événement",
	beforeTheEvent: "avant l'événement",
	emailRecipients: {
		label: "Destinataires de l'e-mail"
	},
	sendConfirmation: {
		label: "Envoyer un e-mail de confirmation lorsque",
		tooltip: {
			desc: "Les destinataires recevront un e-mail de rappel au moment spécifié avant l'événement."
		}
	},
	emailSubject: {
		label: "Objet de l'e-mail",
		placeholder: "Prochaine réunion {{organizerName}}"
	},
	reminderMinutesValidationError: "Veuillez entrer les minutes du rappel par multiples de 5. Essayez ",
	newReminderButtonText: "Nouveau rappel"
};
const nylasSchedulingMethod$7 = {
	headerTitle: "Méthode de planification",
	headerSubTitle: "Sélectionnez une méthode de planification pour l'événement.",
	tooltip: {
		standard: {
			label: "Standard",
			desc: "Permet des réservations 1:1 ou n:1 avec des participants supplémentaires."
		},
		maxFairness: {
			label: "Tour de rôle - Maximiser l'équité",
			desc: "Fait tourner la liste des participants que vous sélectionnez, en affichant le participant avec le moins de réservations récentes."
		},
		maxAvailability: {
			label: "Tour de rôle - Maximiser la disponibilité",
			desc: "Fait tourner la liste des participants que vous sélectionnez, en priorisant ceux ayant le moins de réservations récentes tout en rendant autant de créneaux horaires disponibles que possible."
		}
	},
	schedulingMethodOptions_collective: "Réservation standard",
	schedulingMethodOptions_maxFairness: "Tour de rôle - Maximiser l'équité",
	schedulingMethodOptions_maxAvailability: "Tour de rôle - Maximiser la disponibilité"
};
const nylasTimeslotInterval$7 = {
	minutesShort: "min",
	lengthOfMeeting: "Durée de la réunion",
	headerTitle: "Paramètres des créneaux horaires",
	timeslotInterval: {
		label: "Intervalle des créneaux horaires."
	},
	timeslotRounding: {
		label: "Type d'arrondi des créneaux horaires",
		tooltip: {
			desc: "L'intervalle auquel les créneaux horaires sont affichés."
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "Arrondi d'intervalle",
			desc: "Les créneaux horaires commenceront à des heures arrondies à la valeur de l'intervalle."
		},
		noRounding: {
			label: "Par défaut",
			desc: "Les créneaux horaires seront arrondis au quart d'heure le plus proche."
		}
	}
};
const nylasEventTimeslot$7 = {
	recurrenceOptions: {
		none: "Ne se répète pas",
		daily: "Quotidien",
		weekly: "Hebdomadaire chaque {{dayOfWeek}}",
		monthly: "Mensuel le {{dayOfMonth}}",
		monthOnDay: "Mensuel le jour {{date}}",
		yearly: "Annuel le {{dateOfMonth}}",
		custom: "Personnalisé"
	},
	recurrenceLabel: "Répéter cet événement",
	endDate: "Date de fin",
	customRecurrence: {
		repeatEvery: "Répéter tous les",
		repeatOn: "Répéter le",
		ends: "Se termine",
		endsOptions: {
			never: "Jamais",
			after: "Après",
			on: "Le"
		},
		occurrences: "occurrences"
	},
	dateTimeLabel: "Date et heure",
	errors: {
		invalidTimeRange: "Plage de temps invalide",
		startTimeSameAsEndTime: "L'heure de début et l'heure de fin ne peuvent pas être identiques",
		startTimeBeforeCurrentDate: "L'heure de début ne peut pas être dans le passé",
		invalid: "Invalide"
	}
};
const nylasEventCapacity$7 = {
	headerTitle: "Invités",
	headerSubTitle: "Définissez le nombre maximum d'invités pour ce créneau horaire de l'événement.",
	tooltip: {
		desc: "L'organisateur et les participants configurés sur la page de planification ne sont pas comptés comme invités."
	},
	attendees: "invités"
};
const nylasSelectEventType$7 = {
	returnToAllSchedulingPages: "Retour à toutes les pages de planification",
	createEventHeaderTitle: "Créer un événement",
	eventTypeHeaderTitle: "Type d'événement",
	noEventTypesEnabled: "Aucun type d'événement activé",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "Permet des réservations 1:1"
		},
		collective: {
			label: "Réservation standard",
			desc: "Permet des réservations n:1 avec des participants supplémentaires"
		},
		maxFairness: {
			label: "Tour de rôle - Maximiser l'équité",
			desc: "Fait tourner la liste des participants que vous sélectionnez, en affichant le participant avec le moins de réservations récentes."
		},
		maxAvailability: {
			label: "Tour de rôle - Maximiser la disponibilité",
			desc: "Fait tourner la liste des participants que vous sélectionnez, en priorisant ceux ayant le moins de réservations récentes tout en rendant autant de créneaux horaires disponibles que possible."
		},
		group: {
			label: "Événement de groupe / classe",
			desc: "Ces événements ont généralement un organisateur et plusieurs participants."
		}
	}
};
const pageSettingsButton$7 = "Paramètres de la page";
const nylasEventCalendar$7 = {
	hideNonGroupEvents: {
		showLabel: "Filtrer les événements",
		tooltip: {
			desc: "Sélectionnez le type d'événements à afficher dans le calendrier."
		},
		options: {
			all: "Tous",
			group: "Groupes uniquement"
		}
	},
	createEventDetails: {
		headerTitle: "Détails de l'événement",
		closeButtonTooltip: "Fermer",
		cancelButton: "Annuler",
		createButton: "Créer"
	},
	discardChanges: {
		headerTitle: "Voulez-vous vraiment annuler les modifications non enregistrées ?",
		cancelButton: "Annuler",
		discardButton: "Descartar"
	},
	unsavedChanges: "Modifications non enregistrées",
	editEventDetails: {
		headerTitle: "Détails de l'événement",
		closeButtonTooltip: "Fermer",
		deleteButton: "Supprimer",
		saveButton: "Enregistrer",
		pastEventTooltip: "Cet événement est passé et ne peut pas être modifié."
	},
	importEvent: {
		closeButtonTooltip: "Fermer",
		importButton: "Importer",
		participantsLabel: "Participants"
	},
	deleteEvent: {
		closeButtonTooltip: "Fermer",
		deleting: "Suppression..."
	},
	editOptions: {
		headerTitle: "Actions",
		closeButtonTooltip: "Fermer",
		deleting: "Suppression...",
		"import": "Importer",
		edit: "Modifier",
		deleteThis: "Supprimer cet événement",
		deleteAll: "Supprimer tous les événements",
		importTooltip: "Permet de sélectionner des événements existants d'un calendrier et de les configurer comme événements de groupe"
	},
	updateOptions: {
		updateThis: "Mettre à jour cet événement",
		updateAll: "Mettre à jour tous les événements",
		updateFuture: "Mettre à jour tous les futurs événements"
	},
	deleteOptions: {
		deleteThis: "Supprimer",
		deleteFuture: "Supprimer et tous les futurs événements",
		deleteAll: "Supprimer tous les événements"
	}
};
const fr$1 = {
	noDateSelected: noDateSelected$7,
	rescheduleTitle: rescheduleTitle$7,
	allDay: allDay$7,
	today: today$7,
	spotsLeft: spotsLeft$7,
	search: search$7,
	selectOneOrMoreOptions: selectOneOrMoreOptions$7,
	days: days$7,
	time: time$7,
	months: months$7,
	multipleOptionsSelected: multipleOptionsSelected$7,
	selectAtLeastOneOption: selectAtLeastOneOption$7,
	nextButton: nextButton$7,
	selectedDayAndYear: selectedDayAndYear$7,
	selectedTime: selectedTime$7,
	name: name$7,
	namePlaceholder: namePlaceholder$7,
	email: email$7,
	emailPlaceholder: emailPlaceholder$7,
	guestEmail: guestEmail$7,
	guestEmailPlaceholder: guestEmailPlaceholder$7,
	addGuest: addGuest$7,
	addAnotherGuest: addAnotherGuest$7,
	backButton: backButton$7,
	bookNowButton: bookNowButton$7,
	bookingConfirmed: bookingConfirmed$7,
	bookingConfirmedDescription: bookingConfirmedDescription$7,
	bookingSent: bookingSent$7,
	bookingSentDescription: bookingSentDescription$7,
	bookingRescheduled: bookingRescheduled$7,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$7,
	cancelBookingButton: cancelBookingButton$7,
	rescheduleBookingButton: rescheduleBookingButton$7,
	rejectBookingButton: rejectBookingButton$7,
	confirmBookingButton: confirmBookingButton$7,
	bookingPendingTitle: bookingPendingTitle$7,
	bookingPendingnDescription: bookingPendingnDescription$7,
	confirmedEventCardTitle: confirmedEventCardTitle$7,
	confirmedEventCardDescription: confirmedEventCardDescription$7,
	cancelBookingTitle: cancelBookingTitle$7,
	cancelBookingMessage: cancelBookingMessage$7,
	reasonForCancellation: reasonForCancellation$7,
	goBackButton: goBackButton$7,
	bookingCancelledTitle: bookingCancelledTitle$7,
	bookingCancelledMessage: bookingCancelledMessage$7,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$7,
	closeButton: closeButton$7,
	closingButton: closingButton$7,
	fieldRequired: fieldRequired$7,
	invalidInputFormat: invalidInputFormat$7,
	createBookingErrorTitle: createBookingErrorTitle$7,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$7,
	cancelBookingErrorTitle: cancelBookingErrorTitle$7,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$7,
	getUISettingErrorTitle: getUISettingErrorTitle$7,
	rejectBookingErrorTitle: rejectBookingErrorTitle$7,
	confirmBookingErrorTitle: confirmBookingErrorTitle$7,
	genericErrorTitle: genericErrorTitle$7,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$7,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$7,
	publicConfigErrorMessage: publicConfigErrorMessage$7,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$6,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$7,
	cancellationErrorTitle: cancellationErrorTitle$7,
	cancellationErrorMessage: cancellationErrorMessage$7,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$7,
	cancelBokingFormError: cancelBokingFormError$7,
	feedbackFormTitle: feedbackFormTitle$7,
	feedbackFormDescription: feedbackFormDescription$7,
	feedbackMessageLabel: feedbackMessageLabel$7,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$7,
	feedbackModalCloseButton: feedbackModalCloseButton$7,
	feedbackModalSubmitButton: feedbackModalSubmitButton$7,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$7,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$7,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$7,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$7,
	schedulerEditorTitle: schedulerEditorTitle$7,
	allSchedulingPages: allSchedulingPages$7,
	createAndManageSchedulingPages: createAndManageSchedulingPages$7,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$7,
	pageTitle: pageTitle$7,
	durationTitle: durationTitle$7,
	loading: loading$7,
	required: required$7,
	optional: optional$7,
	loadingPagesDescription: loadingPagesDescription$7,
	noSchedulingPages: noSchedulingPages$7,
	createFirstSchedulingPage: createFirstSchedulingPage$7,
	editSchedulingPageButtonText: editSchedulingPageButtonText$7,
	eventInfoTab: eventInfoTab$7,
	availabilityTab: availabilityTab$7,
	participantsTab: participantsTab$7,
	bookingOptionsTab: bookingOptionsTab$7,
	returnToCalendarView: returnToCalendarView$7,
	bookingFormTab: bookingFormTab$7,
	communicationsTab: communicationsTab$7,
	pageStylesTab: pageStylesTab$7,
	savingButtonText: savingButtonText$7,
	saveChangesButtonText: saveChangesButtonText$7,
	createButtonText: createButtonText$7,
	timePeriod_day: timePeriod_day$7,
	timePeriod_week: timePeriod_week$7,
	timePeriod_month: timePeriod_month$7,
	timePeriod_year: timePeriod_year$7,
	timeDuration_minute: timeDuration_minute$7,
	timeDuration_hour: timeDuration_hour$7,
	eventCommunicationsTitle: eventCommunicationsTitle$7,
	eventCommunicationsDescription: eventCommunicationsDescription$7,
	unsavedChangesLabel: unsavedChangesLabel$7,
	changesSavedLabel: changesSavedLabel$7,
	fixFormErrors: fixFormErrors$7,
	nylasEditorTabs: nylasEditorTabs$7,
	nylasEditorTabsGroup: nylasEditorTabsGroup$7,
	nylasListConfigurations: nylasListConfigurations$7,
	nylasAdditionalParticipants: nylasAdditionalParticipants$7,
	nylasAvailabilityPicker: nylasAvailabilityPicker$7,
	nylasTimeWindowPicker: nylasTimeWindowPicker$3,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$7,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$7,
	nylasBookingConfirmationType: nylasBookingConfirmationType$7,
	nylasBookingFormConfig: nylasBookingFormConfig$7,
	nylasBufferTime: nylasBufferTime$7,
	nylasCalendarPicker: nylasCalendarPicker$7,
	nylasCancellationPolicy: nylasCancellationPolicy$7,
	nylasConfirmationEmail: nylasConfirmationEmail$7,
	nylasConnectedCalendars: nylasConnectedCalendars$7,
	nylasCustomBookingFlow: nylasCustomBookingFlow$7,
	nylasCustomEventSlug: nylasCustomEventSlug$7,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$7,
	nylasEventDescription: nylasEventDescription$7,
	nylasEventDuration: nylasEventDuration$7,
	nylasEventInfo: nylasEventInfo$7,
	nylasEventLimits: nylasEventLimits$7,
	nylasEventLocation: nylasEventLocation$7,
	nylasEventTitle: nylasEventTitle$7,
	nylasLimitFutureBookings: nylasLimitFutureBookings$7,
	nylasMinBookingNotice: nylasMinBookingNotice$7,
	nylasMinCancellationNotice: nylasMinCancellationNotice$7,
	nylasPageName: nylasPageName$7,
	nylasPageStyling: nylasPageStyling$7,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$7,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$7,
	nylasReminderEmails: nylasReminderEmails$7,
	nylasSchedulingMethod: nylasSchedulingMethod$7,
	nylasTimeslotInterval: nylasTimeslotInterval$7,
	nylasEventTimeslot: nylasEventTimeslot$7,
	nylasEventCapacity: nylasEventCapacity$7,
	nylasSelectEventType: nylasSelectEventType$7,
	pageSettingsButton: pageSettingsButton$7,
	nylasEventCalendar: nylasEventCalendar$7
};

const frTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$7,
  rescheduleTitle: rescheduleTitle$7,
  allDay: allDay$7,
  today: today$7,
  spotsLeft: spotsLeft$7,
  search: search$7,
  selectOneOrMoreOptions: selectOneOrMoreOptions$7,
  days: days$7,
  time: time$7,
  months: months$7,
  multipleOptionsSelected: multipleOptionsSelected$7,
  selectAtLeastOneOption: selectAtLeastOneOption$7,
  nextButton: nextButton$7,
  selectedDayAndYear: selectedDayAndYear$7,
  selectedTime: selectedTime$7,
  name: name$7,
  namePlaceholder: namePlaceholder$7,
  email: email$7,
  emailPlaceholder: emailPlaceholder$7,
  guestEmail: guestEmail$7,
  guestEmailPlaceholder: guestEmailPlaceholder$7,
  addGuest: addGuest$7,
  addAnotherGuest: addAnotherGuest$7,
  backButton: backButton$7,
  bookNowButton: bookNowButton$7,
  bookingConfirmed: bookingConfirmed$7,
  bookingConfirmedDescription: bookingConfirmedDescription$7,
  bookingSent: bookingSent$7,
  bookingSentDescription: bookingSentDescription$7,
  bookingRescheduled: bookingRescheduled$7,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$7,
  cancelBookingButton: cancelBookingButton$7,
  rescheduleBookingButton: rescheduleBookingButton$7,
  rejectBookingButton: rejectBookingButton$7,
  confirmBookingButton: confirmBookingButton$7,
  bookingPendingTitle: bookingPendingTitle$7,
  bookingPendingnDescription: bookingPendingnDescription$7,
  confirmedEventCardTitle: confirmedEventCardTitle$7,
  confirmedEventCardDescription: confirmedEventCardDescription$7,
  cancelBookingTitle: cancelBookingTitle$7,
  cancelBookingMessage: cancelBookingMessage$7,
  reasonForCancellation: reasonForCancellation$7,
  goBackButton: goBackButton$7,
  bookingCancelledTitle: bookingCancelledTitle$7,
  bookingCancelledMessage: bookingCancelledMessage$7,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$7,
  closeButton: closeButton$7,
  closingButton: closingButton$7,
  fieldRequired: fieldRequired$7,
  invalidInputFormat: invalidInputFormat$7,
  createBookingErrorTitle: createBookingErrorTitle$7,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$7,
  cancelBookingErrorTitle: cancelBookingErrorTitle$7,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$7,
  getUISettingErrorTitle: getUISettingErrorTitle$7,
  rejectBookingErrorTitle: rejectBookingErrorTitle$7,
  confirmBookingErrorTitle: confirmBookingErrorTitle$7,
  genericErrorTitle: genericErrorTitle$7,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$7,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$7,
  publicConfigErrorMessage: publicConfigErrorMessage$7,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$6,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$7,
  cancellationErrorTitle: cancellationErrorTitle$7,
  cancellationErrorMessage: cancellationErrorMessage$7,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$7,
  cancelBokingFormError: cancelBokingFormError$7,
  feedbackFormTitle: feedbackFormTitle$7,
  feedbackFormDescription: feedbackFormDescription$7,
  feedbackMessageLabel: feedbackMessageLabel$7,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$7,
  feedbackModalCloseButton: feedbackModalCloseButton$7,
  feedbackModalSubmitButton: feedbackModalSubmitButton$7,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$7,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$7,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$7,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$7,
  schedulerEditorTitle: schedulerEditorTitle$7,
  allSchedulingPages: allSchedulingPages$7,
  createAndManageSchedulingPages: createAndManageSchedulingPages$7,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$7,
  pageTitle: pageTitle$7,
  durationTitle: durationTitle$7,
  loading: loading$7,
  required: required$7,
  optional: optional$7,
  loadingPagesDescription: loadingPagesDescription$7,
  noSchedulingPages: noSchedulingPages$7,
  createFirstSchedulingPage: createFirstSchedulingPage$7,
  editSchedulingPageButtonText: editSchedulingPageButtonText$7,
  eventInfoTab: eventInfoTab$7,
  availabilityTab: availabilityTab$7,
  participantsTab: participantsTab$7,
  bookingOptionsTab: bookingOptionsTab$7,
  returnToCalendarView: returnToCalendarView$7,
  bookingFormTab: bookingFormTab$7,
  communicationsTab: communicationsTab$7,
  pageStylesTab: pageStylesTab$7,
  savingButtonText: savingButtonText$7,
  saveChangesButtonText: saveChangesButtonText$7,
  createButtonText: createButtonText$7,
  timePeriod_day: timePeriod_day$7,
  timePeriod_week: timePeriod_week$7,
  timePeriod_month: timePeriod_month$7,
  timePeriod_year: timePeriod_year$7,
  timeDuration_minute: timeDuration_minute$7,
  timeDuration_hour: timeDuration_hour$7,
  eventCommunicationsTitle: eventCommunicationsTitle$7,
  eventCommunicationsDescription: eventCommunicationsDescription$7,
  unsavedChangesLabel: unsavedChangesLabel$7,
  changesSavedLabel: changesSavedLabel$7,
  fixFormErrors: fixFormErrors$7,
  nylasEditorTabs: nylasEditorTabs$7,
  nylasEditorTabsGroup: nylasEditorTabsGroup$7,
  nylasListConfigurations: nylasListConfigurations$7,
  nylasAdditionalParticipants: nylasAdditionalParticipants$7,
  nylasAvailabilityPicker: nylasAvailabilityPicker$7,
  nylasTimeWindowPicker: nylasTimeWindowPicker$3,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$7,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$7,
  nylasBookingConfirmationType: nylasBookingConfirmationType$7,
  nylasBookingFormConfig: nylasBookingFormConfig$7,
  nylasBufferTime: nylasBufferTime$7,
  nylasCalendarPicker: nylasCalendarPicker$7,
  nylasCancellationPolicy: nylasCancellationPolicy$7,
  nylasConfirmationEmail: nylasConfirmationEmail$7,
  nylasConnectedCalendars: nylasConnectedCalendars$7,
  nylasCustomBookingFlow: nylasCustomBookingFlow$7,
  nylasCustomEventSlug: nylasCustomEventSlug$7,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$7,
  nylasEventDescription: nylasEventDescription$7,
  nylasEventDuration: nylasEventDuration$7,
  nylasEventInfo: nylasEventInfo$7,
  nylasEventLimits: nylasEventLimits$7,
  nylasEventLocation: nylasEventLocation$7,
  nylasEventTitle: nylasEventTitle$7,
  nylasLimitFutureBookings: nylasLimitFutureBookings$7,
  nylasMinBookingNotice: nylasMinBookingNotice$7,
  nylasMinCancellationNotice: nylasMinCancellationNotice$7,
  nylasPageName: nylasPageName$7,
  nylasPageStyling: nylasPageStyling$7,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$7,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$7,
  nylasReminderEmails: nylasReminderEmails$7,
  nylasSchedulingMethod: nylasSchedulingMethod$7,
  nylasTimeslotInterval: nylasTimeslotInterval$7,
  nylasEventTimeslot: nylasEventTimeslot$7,
  nylasEventCapacity: nylasEventCapacity$7,
  nylasSelectEventType: nylasSelectEventType$7,
  pageSettingsButton: pageSettingsButton$7,
  nylasEventCalendar: nylasEventCalendar$7,
  'default': fr$1
});

const noDateSelected$6 = "No has seleccionado ninguna fecha";
const rescheduleTitle$6 = "Elige otro horario para reprogramar tu reunión";
const allDay$6 = "Todo el día";
const today$6 = "Hoy";
const spotsLeft$6 = "{{count}} plazas libres";
const search$6 = "Buscar";
const selectOneOrMoreOptions$6 = "Selecciona una o varias opciones";
const days$6 = {
	sunday: "DOM",
	monday: "LUN",
	tuesday: "MAR",
	wednesday: "MIÉ",
	thursday: "JUE",
	friday: "VIE",
	saturday: "SÁB"
};
const time$6 = {
	hour: "hora",
	hours: "horas",
	minute: "minuto",
	minutes: "minutos",
	day: "día",
	days: "días",
	week: "semana",
	weeks: "semanas",
	month: "mes",
	months: "meses",
	year: "año",
	years: "años"
};
const months$6 = {
	january: "Enero",
	february: "Febrero",
	march: "Marzo",
	april: "Abril",
	may: "Mayo",
	june: "Junio",
	july: "Julio",
	august: "Agosto",
	september: "Septiembre",
	october: "Octubre",
	november: "Noviembre",
	december: "Diciembre"
};
const multipleOptionsSelected$6 = "Múltiples opciones seleccionadas";
const selectAtLeastOneOption$6 = "Por favor, seleccione al menos una opción";
const nextButton$6 = "Siguiente";
const selectedDayAndYear$6 = "{{date}}";
const selectedTime$6 = "{{time}}";
const name$6 = "Nombre";
const namePlaceholder$6 = "Introduce tu nombre";
const email$6 = "Correo electrónico";
const emailPlaceholder$6 = "Introduce tu correo electrónico";
const guestEmail$6 = "Correo electrónico del invitado";
const guestEmailPlaceholder$6 = "Introduce el correo electrónico del invitado";
const addGuest$6 = "Añadir invitado";
const addAnotherGuest$6 = "Añadir otro invitado";
const backButton$6 = "Atrás";
const bookNowButton$6 = "Reservar ahora";
const bookingConfirmed$6 = "Reserva confirmada";
const bookingConfirmedDescription$6 = "Recibirás una confirmación por correo electrónico pronto.";
const bookingSent$6 = "Reserva enviada";
const bookingSentDescription$6 = "Recibirás un correo electrónico una vez que se confirme la reserva.";
const bookingRescheduled$6 = "Reserva reprogramada";
const bookingDateAndTimeHeader$6 = "Fecha y hora de la reserva";
const cancelBookingButton$6 = "Cancelar reserva";
const rescheduleBookingButton$6 = "Reprogramar";
const rejectBookingButton$6 = "Rechazar reserva";
const confirmBookingButton$6 = "Confirmar reserva";
const bookingPendingTitle$6 = "Reserva pendiente";
const bookingPendingnDescription$6 = "Gestiona tu reserva a continuación. El invitado recibirá un correo electrónico informándole del estado de la solicitud.";
const confirmedEventCardTitle$6 = "Tu reserva ha sido confirmada con éxito";
const confirmedEventCardDescription$6 = "Se ha enviado un correo de confirmación a";
const cancelBookingTitle$6 = "¿Cancelar reserva?";
const cancelBookingMessage$6 = "Su horario actual estará disponible para otros.";
const reasonForCancellation$6 = "Motivo de la cancelación";
const goBackButton$6 = "Regresar";
const bookingCancelledTitle$6 = "Su reserva ha sido cancelada con éxito";
const bookingCancelledMessage$6 = "Se ha enviado un correo electrónico de cancelación a";
const bookingCancelledMessage_theParticipants$6 = "los participantes";
const closeButton$6 = "Cerrar";
const closingButton$6 = "Cerrando";
const fieldRequired$6 = "{{field}} es obligatorio.";
const invalidInputFormat$6 = "{{field}} tiene un formato no válido.";
const createBookingErrorTitle$6 = "Crear Reserva";
const getAvailabilityErrorTitle$6 = "Obtener Disponibilidad";
const cancelBookingErrorTitle$6 = "Cancelar Reserva";
const rescheduleBookingErrorTitle$6 = "Reprogramar Reserva";
const getUISettingErrorTitle$6 = "Obtener Configuraciones de UI";
const rejectBookingErrorTitle$6 = "Rechazar Reserva";
const confirmBookingErrorTitle$6 = "Confirmar Reserva";
const genericErrorTitle$6 = "Algo salió mal...";
const schedulingComponentErrorTitle$6 = "Error en el componente de programación";
const sessionIdRequiredErrorMessage$6 = "'sessionId' es necesario para configuraciones privadas.";
const publicConfigErrorMessage$6 = "Si se usa una configuración pública, pase una configurationId o una combinación de 'slug' y 'clientId'.";
const invalidTimeslotErrorTitle$5 = "¡Intervalo de tiempo no válido!";
const invalidTimeslotErrorMessage$6 = "El intervalo de tiempo seleccionado no es válido";
const cancellationErrorTitle$6 = "Error de Cancelación";
const cancellationErrorMessage$6 = "Por favor, indique el motivo de la cancelación.";
const minimumCancellationErrorMessage$6 = "No puede cancelar la reserva dentro de los {{minCancellationNotice}} minutos del evento";
const cancelBokingFormError$6 = "Error en el formulario de cancelación de la reserva";
const feedbackFormTitle$6 = "Comparta su opinión";
const feedbackFormDescription$6 = "Proporcionarnos su opinión y reportar errores nos ayuda a crear una mejor experiencia para usted.";
const feedbackMessageLabel$6 = "Por favor, proporcione una descripción detallada de la función sobre la que está comentando o dónde ha experimentado un problema.";
const feedbackMessagePlaceholder$6 = "Proporcione su opinión aquí";
const feedbackModalCloseButton$6 = "Cancelar";
const feedbackModalSubmitButton$6 = "Enviar";
const deleteSchedulingPageTitle$6 = "¿Eliminar esta página de programación?";
const deleteSchedulingPageDescription$6 = "Al confirmar, esta página y sus enlaces de programación conectados serán eliminados y desactivados permanentemente. Esta acción no se puede deshacer.";
const deleteSchedulingPageConfirmButton$6 = "Eliminar página";
const deleteSchedulingPageCancelButton$6 = "Cancelar";
const schedulerEditorTitle$6 = "Editor de programación";
const allSchedulingPages$6 = "Todas las páginas de programación";
const createAndManageSchedulingPages$6 = "Crea y gestiona tus páginas de programación.";
const createNewSchedulingPageButtonText$6 = "Crear nuevo";
const pageTitle$6 = "Título de la página";
const durationTitle$6 = "Duración";
const loading$6 = "Cargando";
const required$6 = "Requerido";
const optional$6 = "Opcional";
const loadingPagesDescription$6 = "Por favor, espera mientras cargamos las páginas de programación";
const noSchedulingPages$6 = "No se encontraron páginas de programación";
const createFirstSchedulingPage$6 = "Comienza creando tu primera página de programación";
const editSchedulingPageButtonText$6 = "Editar";
const eventInfoTab$6 = "Información del evento";
const availabilityTab$6 = "Disponibilidad";
const participantsTab$6 = "Participantes";
const bookingOptionsTab$6 = "Opciones de reserva";
const returnToCalendarView$6 = "Volver a la vista de calendario";
const bookingFormTab$6 = "Formulario de reserva";
const communicationsTab$6 = "Comunicaciones";
const pageStylesTab$6 = "Estilos de página";
const savingButtonText$6 = "Guardando";
const saveChangesButtonText$6 = "Guardar cambios";
const createButtonText$6 = "Crear";
const timePeriod_day$6 = "día";
const timePeriod_week$6 = "semana";
const timePeriod_month$6 = "mes";
const timePeriod_year$6 = "año";
const timeDuration_minute$6 = "minuto";
const timeDuration_hour$6 = "hora";
const eventCommunicationsTitle$6 = "Comunicaciones del evento";
const eventCommunicationsDescription$6 = "Configura correos electrónicos de confirmación automáticos.";
const unsavedChangesLabel$6 = "Cambios no guardados";
const changesSavedLabel$6 = "Cambios guardados";
const fixFormErrors$6 = "Por favor, corrija los errores del formulario.";
const nylasEditorTabs$6 = {
	bookingFormError: "Error en el formulario de reserva: ",
	bookingFormError_label: "Etiqueta requerida para el campo de tipo {{type}}.",
	bookingFormError_option: "Opción vacía detectada dentro de {{label}} de tipo {{type}}.",
	formErrorTitle: "Error en el formulario",
	updateConfigError: "Error al actualizar la configuración: ",
	deleteConfigError: "Error al eliminar la configuración: ",
	createConfigError: "Error al crear la configuración: ",
	getConfigsError: "Error al obtener las configuraciones: "
};
const nylasEditorTabsGroup$6 = {
	eventTitleRequired: "El título del evento es obligatorio.",
	eventTimeRequired: "El tiempo del evento es obligatorio.",
	participantsRequired: "Los participantes son obligatorios.",
	participantEmailRequired: "El correo electrónico del participante es obligatorio.",
	errorOccured: "Error al guardar los cambios.",
	createGroupEventError: "Error al crear el evento del grupo: ",
	updateGroupEventError: "Error al actualizar el evento del grupo: ",
	deleteGroupEventError: "Error al eliminar el evento del grupo: ",
	importGroupEventError: "Error al importar el evento del grupo: ",
	getGroupEventsError: "Error al obtener los eventos del grupo: "
};
const nylasListConfigurations$6 = {
	previewButtonText: "Vista previa",
	copyLinkButtonText: "Copiar enlace",
	deleteButtonText: "Eliminar"
};
const nylasAdditionalParticipants$6 = {
	headerTitle: "Participantes",
	headerSubTitle: "Agregue personas de su equipo u organización para unirse al evento.",
	organizerAsParticipant: "Participante",
	organizer: "Organizador",
	participant: "Participante",
	addParticipant_first: "Agregar un participante",
	addParticipant_next: "Agregar otro participante",
	tooltip: {
		includeOrganizer: "Incluir organizador",
		includeOrganizerDesc: "El organizador (usted) será incluido en la rotación de turnos.",
		excludeOrganizer: "Excluir organizador",
		excludeOrganizerDesc: "El organizador (usted) no será incluido en la rotación de turnos."
	},
	error: "Por favor, agregue al menos un participante"
};
const nylasAvailabilityPicker$6 = {
	headerTitle: "Horario abierto predeterminado",
	headerSubTitle: "Establezca cuándo está disponible regularmente para reservas de eventos.",
	tooltip: {
		desc: "Esta es la disponibilidad predeterminada para los participantes que no tienen disponibilidad configurada en la pestaña de Participantes."
	},
	selectTimezone: "Seleccionar zona horaria",
	unavailable: "No disponible",
	days: {
		SUN: "DOM",
		MON: "LUN",
		TUE: "MAR",
		WED: "MIÉ",
		THU: "JUE",
		FRI: "VIE",
		SAT: "SÁB"
	}
};
const nylasTimeWindowPicker$2 = {
	errors: {
		invalid: "Inválido"
	}
};
const nylasBookingCalendarPicker$6 = {
	headerTitle: "Reserva de calendario",
	headerSubTitle: "Seleccione el calendario donde desea agregar reservas de eventos.",
	tooltip: {
		desc: "El calendario se usará para crear eventos."
	},
	selectOptionLabel: "Seleccionar una opción",
	selectCalendarErrorMessage: "Por favor seleccione un calendario"
};
const nylasBookingConfirmationRedirect$6 = {
	dropdownLabel: "Cuando se confirma una reserva",
	tooltip: {
		desc: "Puede mostrar la página de confirmación predeterminada o redirigir a los usuarios a su propia página de confirmación."
	},
	redirectOption_default: "Mostrar página de confirmación predeterminada",
	redirectOption_custom: "Redirigir a una URL personalizada"
};
const nylasBookingConfirmationType$6 = {
	dropdownLabel: "Cuando se solicita una reserva",
	tooltip: {
		desc: "Aceptar reservas manualmente le permite revisar y aceptar o rechazar cada solicitud de reserva."
	},
	bookingOption_booking: "Aceptar reservas automáticamente",
	bookingOption_organizerConfirmation: "Aceptar reservas manualmente"
};
const nylasBookingFormConfig$6 = {
	headerTitle: "Formulario de reserva",
	headerSubTitle: "Agregue campos personalizados al formulario de reserva.",
	dropdownButtonText: "Agregar nuevo campo",
	addOption: "Agregar una opción",
	allOptionsHeader: "TODAS LAS OPCIONES",
	fieldInTitleError: "Este campo se utiliza en el título del evento y no se puede eliminar.",
	fieldInDescriptionError: "Este campo se utiliza en la descripción del evento y no se puede eliminar.",
	label: "Etiqueta",
	defaultValue: "Valor predeterminado",
	fieldType: {
		text: "Texto corto",
		multi_line_text: "Texto largo",
		email: "Correo electrónico",
		phone_number: "Número de teléfono",
		dropdown: "Desplegable",
		radio_button: "Botón de opción",
		checkbox: "Casilla de verificación",
		date: "Fecha",
		metadata: "Metadatos",
		multi_select: "Selección múltiple"
	},
	fieldLabel: {
		your_name: "Tu nombre",
		your_email: "Tu correo electrónico",
		email: "Correo electrónico adicional",
		phone_number: "Etiqueta de número de teléfono",
		dropdown: "Etiqueta de menú desplegable",
		text: "Etiqueta de texto corto",
		multi_line_text: "Etiqueta de texto largo",
		radio_button: "Etiqueta de botón de opción",
		checkbox: "Etiqueta de casilla de verificación",
		date: "Etiqueta de fecha",
		metadata: "Etiqueta de metadatos",
		multi_select: "Etiqueta de selección múltiple"
	}
};
const nylasBufferTime$6 = {
	headerTitle: "Tiempo de buffer",
	headerSubTitle: "Requiere tiempo de buffer vacío antes y después de un evento.",
	tooltip: {
		desc: "El planificador no reserva el tiempo de buffer."
	},
	beforeBufferLabel: "Antes del evento",
	afterBufferLabel: "Después del evento",
	minutesShort: "mins",
	previewHeader: "PREVISUALIZAR"
};
const nylasCalendarPicker$6 = {
	calendarPickerLabel: "Seleccione los calendarios que se verificarán para la disponibilidad",
	selectAtLeastOneCalendar: "Por favor, seleccione al menos un calendario para cada participante."
};
const nylasCancellationPolicy$6 = {
	cancellationPolicyLabel: "Mensaje de política de cancelación",
	tooltip: {
		desc: "Los asistentes reciben este mensaje si intentan cancelar el evento. Se les pide que proporcionen una razón para la cancelación."
	}
};
const nylasConfirmationEmail$6 = {
	headerTitle: "Reserva confirmada{{organizerName}}",
	headerSubTitle: "Correo de confirmación de reserva",
	editButtonText: "Editar",
	error: {
		invalidImageUrl: "URL de imagen no válida."
	},
	confirmationEmail: {
		label: "Habilitar notificaciones por correo electrónico",
		tooltip: {
			desc: "Permita que Nylas envíe notificaciones por correo electrónico, incluidos mensajes de confirmación y recordatorios de eventos.",
			language: "Esta idioma se usará para las notificaciones por correo electrónico a los organizadores."
		},
		language: "Seleccionar idioma"
	},
	nylasBranding: {
		label: "Mostrar la marca de Nylas",
		tooltip: {
			desc: "Desmarque esta opción para ocultar el pie de página en la comunicación por correo electrónico."
		}
	},
	companyLogoUrl: {
		label: "URL del logo de la empresa",
		tooltip: {
			desc: "Este logo aparece en el correo de confirmación de reserva. La URL debe ser accesible públicamente. La imagen se reducirá a un tamaño máximo de 200px x 100px."
		}
	},
	emailMessage: {
		header: "Mensaje de correo",
		label: "Título personalizado del correo",
		tooltip: {
			desc: "Un título de correo es un encabezado dentro del cuerpo del correo. Esto no cambia la línea de asunto."
		},
		additionalInfoLabel: "Información adicional",
		additionalInfoTooltip: "El planificador agrega el contenido de este cuadro al cuerpo del correo.",
		additionalInfoPlaceholder: "Cuerpo predeterminado"
	},
	allHosts: "Todos los anfitriones e invitados",
	immediatelyUponBooking: "Inmediatamente después de la reserva"
};
const nylasConnectedCalendars$6 = {
	headerTitle: "Calendarios conectados",
	headerSubTitle: "Seleccione los calendarios que se utilizarán para verificar su disponibilidad.",
	tooltip: {
		desc: "Verifique la disponibilidad en uno o más calendarios. Si selecciona varios calendarios para un participante, el participante debe estar disponible en todos sus calendarios para considerarse disponible."
	},
	participantCalendarTitle: "Calendarios conectados de {{participantName}}",
	selectAtLeastOneCalendar: "Por favor, seleccione al menos un calendario para cada participante."
};
const nylasCustomBookingFlow$6 = {
	headerTitle: "Flujo de reserva personalizado"
};
const nylasCustomEventSlug$6 = {
	headerTitle: "Slug personalizado de la página",
	headerSubTitle: "Crea un slug de URL personalizado para esta página.",
	eventSlugLabel: "Slug de URL de la página",
	tooltip: {
		desc: "Proporcione un slug personalizado para su URL que identifique de manera única su página (solo letras, números y guiones)."
	},
	copied: "¡Copiado!"
};
const nylasCustomizeBookingSettings$6 = {
	headerTitle: "Configuraciones adicionales",
	headerSubTitle: "Configuraciones de reserva para el evento.",
	tooltip: {
		desc: "Personalice sus configuraciones de reserva."
	},
	allowGuests: {
		label: "Permitir que los invitados inviten a otros invitados."
	},
	hideReschedule: {
		label: "Ocultar opción de reprogramación.",
		tooltip: {
			desc: "Ocultar el botón 'Reprogramar' en la confirmación de reserva y las notificaciones por correo electrónico."
		}
	},
	hideCancel: {
		label: "Ocultar opción de cancelación",
		tooltip: {
			desc: "Ocultar el botón 'Cancelar' en la confirmación de reserva y las notificaciones por correo electrónico."
		}
	}
};
const nylasEventDescription$6 = {
	headerTitle: "Descripción del evento",
	addAdditionalFields: {
		buttonText: "Auto-completar campos adicionales",
		tooltip: {
			desc: "Haga clic en esto una vez que haya agregado todos los campos que desea incluir en la descripción. Importante: Por favor, no modifique los marcadores '--- Additional Fields ---' y '--- End Additional Fields ---' para asegurar que todo funcione correctamente."
		}
	},
	tooltip: {
		desc: "La descripción del evento aparece en la vista del administrador del Editor de Programación y en la respuesta cuando se crea una reserva."
	}
};
const nylasEventDuration$6 = {
	headerTitle: "Duración del evento",
	error: {
		durationMustBeMultipleOf5: "La duración debe ser un múltiplo de 5",
		durationMustBeGreaterThan0: "La duración debe ser mayor que 0"
	}
};
const nylasEventInfo$6 = {
	headerTitle: "Información del evento"
};
const nylasEventLimits$6 = {
	headerTitle: "Límites del evento"
};
const nylasEventLocation$6 = {
	headerTitle: "Ubicación o reunión del evento",
	tooltip: {
		desc: "Seleccione una opción de conferencia o agregue una ubicación personalizada."
	},
	conferenceOptions: {
		none: "Ninguno",
		zoom: "Reunión de Zoom",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "Ubicación personalizada"
	}
};
const nylasEventTitle$6 = {
	headerTitle: "Título del evento",
	helpText_start: "Crea un evento dinámico con plantilla {{field}} escribiendo",
	helpText_end: "y seleccionando un elemento de plantilla.",
	title: "título",
	description: "descripción",
	tooltip: {
		desc: "Por ejemplo, Entrevista con"
	},
	eventTitleRequired: "El título del evento es obligatorio",
	eventTitleTokenDescription: {
		invitee: "El nombre del invitado principal.",
		inviteeEmail: "La dirección de correo electrónico del invitado principal.",
		duration: "La duración del evento."
	}
};
const nylasLimitFutureBookings$6 = {
	headerTitle: "Limitar reservas futuras",
	tooltip: {
		desc: "El límite de cuán lejos en el futuro se pueden hacer las reservas."
	}
};
const nylasMinBookingNotice$6 = {
	headerTitle: "Aviso mínimo de reserva",
	tooltip: {
		desc: "La cantidad mínima de tiempo en el futuro en que se puede realizar una nueva reserva."
	}
};
const nylasMinCancellationNotice$6 = {
	headerTitle: "Aviso mínimo de cancelación",
	tooltip: {
		desc: "La cantidad mínima de tiempo requerida para cancelar una reserva."
	}
};
const nylasPageName$6 = {
	headerTitle: "Nombre de la página",
	headerSubTitle: "Establezca el nombre de la página de programación.",
	pageNameError: "Por favor, ingrese un nombre de página",
	tooltip: {
		desc: "Por defecto, las páginas de programación utilizan su nombre de usuario como nombre de la página. El nombre de la página se muestra en la esquina superior izquierda de la vista del calendario."
	}
};
const nylasPageStyling$6 = {
	headerTitle: "Estilo y personalización de la página"
};
const nylasParticipantBookingCalendars$6 = {
	headerTitle: "Reservar en este calendario",
	headerSubTitle: "Seleccione el calendario donde desea agregar reservas de eventos.",
	participantBookingCalendarTitle: "Calendarios de reserva de {{participantName}}",
	selectAtLeastOneCalendar: "Por favor, seleccione al menos un calendario para cada participante."
};
const nylasParticipantCustomAvailability$6 = {
	headerTitle: "Horario de apertura del participante",
	headerSubTitle: "Si no se establece, se utilizarán las horas de apertura predeterminadas para calcular la disponibilidad de este participante.",
	participantOpenHoursTitle: "Horario de apertura de {{participantName}}"
};
const nylasReminderEmails$6 = {
	headerTitle: "Próxima reunión {{organizerName}}",
	headerSubTitle: "Recordatorio antes del evento",
	editButtonText: "Editar",
	recipientOptions_all: "Todos los anfitriones e invitados",
	recipientOptions_guest: "Todos los invitados al evento",
	recipientOptions_host: "Solo el anfitrión del evento",
	beforeTheEvent: "antes del evento",
	emailRecipients: {
		label: "Destinatarios del correo electrónico"
	},
	sendConfirmation: {
		label: "Enviar correo de confirmación cuando",
		tooltip: {
			desc: "Los destinatarios recibirán un correo de recordatorio en el tiempo especificado antes del evento."
		}
	},
	emailSubject: {
		label: "Asunto del correo",
		placeholder: "Próxima reunión {{organizerName}}"
	},
	reminderMinutesValidationError: "Por favor, ingrese los minutos del recordatorio en múltiplos de 5. Intente ",
	newReminderButtonText: "Nuevo recordatorio"
};
const nylasSchedulingMethod$6 = {
	headerTitle: "Método de programación",
	headerSubTitle: "Seleccione un método de programación para el evento.",
	tooltip: {
		standard: {
			label: "Estándar",
			desc: "Permite reservas 1:1 o n:1 con participantes adicionales."
		},
		maxFairness: {
			label: "Rotación - Maximizar equidad",
			desc: "Rota por la lista de participantes que selecciona, mostrando al participante con menos reservas recientes."
		},
		maxAvailability: {
			label: "Rotación - Maximizar disponibilidad",
			desc: "Rota por la lista de participantes que selecciona, priorizando a los participantes con menos reservas recientes, pero haciendo la mayor cantidad de franjas horarias disponibles."
		}
	},
	schedulingMethodOptions_collective: "Reserva estándar",
	schedulingMethodOptions_maxFairness: "Rotación - Máxima equidad",
	schedulingMethodOptions_maxAvailability: "Rotación - Máxima disponibilidad"
};
const nylasTimeslotInterval$6 = {
	minutesShort: "mins",
	lengthOfMeeting: "Duración de la reunión",
	headerTitle: "Configuración de intervalos de tiempo",
	timeslotInterval: {
		label: "Intervalo de tiempo."
	},
	timeslotRounding: {
		label: "Tipo de redondeo de intervalo",
		tooltip: {
			desc: "El intervalo en el que se muestran los intervalos de tiempo."
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "Redondeo de intervalos",
			desc: "Los intervalos de tiempo comenzarán en horarios redondeados al valor del intervalo."
		},
		noRounding: {
			label: "Predeterminado",
			desc: "Los intervalos de tiempo se redondearán al cuarto de hora más cercano."
		}
	}
};
const nylasEventTimeslot$6 = {
	recurrenceOptions: {
		none: "No se repite",
		daily: "Diario",
		weekly: "Semanalmente cada {{dayOfWeek}}",
		monthly: "Mensualmente el {{dayOfMonth}}",
		monthOnDay: "Mensualmente el día {{date}}",
		yearly: "Anualmente el {{dateOfMonth}}",
		custom: "Personalizado"
	},
	recurrenceLabel: "Repetir este evento",
	endDate: "Fecha de finalización",
	customRecurrence: {
		repeatEvery: "Repetir cada",
		repeatOn: "Repetir el",
		ends: "Termina",
		endsOptions: {
			never: "Nunca",
			after: "Después",
			on: "En"
		},
		occurrences: "ocurrencias"
	},
	dateTimeLabel: "Fecha y hora",
	errors: {
		invalidTimeRange: "Rango de tiempo inválido",
		startTimeSameAsEndTime: "La hora de inicio y la hora de finalización no pueden ser iguales",
		startTimeBeforeCurrentDate: "La hora de inicio no puede ser en el pasado",
		invalid: "Inválido"
	}
};
const nylasEventCapacity$6 = {
	headerTitle: "Invitados",
	headerSubTitle: "Establezca el número máximo de invitados para este intervalo de tiempo del evento.",
	tooltip: {
		desc: "El organizador y los participantes configurados en la página de programación no se cuentan como invitados."
	},
	attendees: "invitados"
};
const nylasSelectEventType$6 = {
	returnToAllSchedulingPages: "Volver a todas las páginas de programación",
	createEventHeaderTitle: "Crear un evento",
	eventTypeHeaderTitle: "Tipo de evento",
	noEventTypesEnabled: "No hay tipos de evento habilitados",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "Permite reservas 1:1"
		},
		collective: {
			label: "Reserva estándar",
			desc: "Permite reservas n:1 con participantes adicionales"
		},
		maxFairness: {
			label: "Rotación - Maximizar equidad",
			desc: "Rota por la lista de participantes que selecciona, mostrando al participante con menos reservas recientes."
		},
		maxAvailability: {
			label: "Rotación - Maximizar disponibilidad",
			desc: "Rota por la lista de participantes que selecciona, priorizando a los participantes con menos reservas recientes, pero haciendo la mayor cantidad de franjas horarias disponibles."
		},
		group: {
			label: "Evento de grupo / clase",
			desc: "Estos son eventos que generalmente tienen un organizador y varios participantes"
		}
	}
};
const pageSettingsButton$6 = "Configuración de la página";
const nylasEventCalendar$6 = {
	hideNonGroupEvents: {
		showLabel: "Filtrar eventos",
		tooltip: {
			desc: "Seleccione el tipo de eventos que se mostrarán en el calendario."
		},
		options: {
			all: "Todos",
			group: "Solo grupales"
		}
	},
	createEventDetails: {
		headerTitle: "Detalles del evento",
		closeButtonTooltip: "Cerrar",
		cancelButton: "Cancelar",
		createButton: "Crear"
	},
	discardChanges: {
		headerTitle: "¿Desea descartar los cambios no guardados?",
		cancelButton: "Cancelar",
		discardButton: "Descartar"
	},
	unsavedChanges: "Cambios no guardados",
	editEventDetails: {
		headerTitle: "Detalles del evento",
		closeButtonTooltip: "Cerrar",
		deleteButton: "Eliminar",
		saveButton: "Guardar",
		pastEventTooltip: "Este evento es pasado y no puede ser editado."
	},
	importEvent: {
		closeButtonTooltip: "Cerrar",
		importButton: "Importar",
		participantsLabel: "Participantes"
	},
	deleteEvent: {
		closeButtonTooltip: "Cerrar",
		deleting: "Eliminando..."
	},
	editOptions: {
		headerTitle: "Acciones",
		closeButtonTooltip: "Cerrar",
		deleting: "Eliminando...",
		"import": "Importar",
		edit: "Editar",
		deleteThis: "Eliminar este evento",
		deleteAll: "Eliminar todos los eventos",
		importTooltip: "Permite seleccionar eventos existentes de un calendario y configurarlos como eventos de grupo"
	},
	updateOptions: {
		updateThis: "Actualizar este evento",
		updateAll: "Actualizar todos los eventos",
		updateFuture: "Actualizar todos los futuros eventos"
	},
	deleteOptions: {
		deleteThis: "Eliminar",
		deleteFuture: "Eliminar y todos los futuros eventos",
		deleteAll: "Eliminar todos los eventos"
	}
};
const es$1 = {
	noDateSelected: noDateSelected$6,
	rescheduleTitle: rescheduleTitle$6,
	allDay: allDay$6,
	today: today$6,
	spotsLeft: spotsLeft$6,
	search: search$6,
	selectOneOrMoreOptions: selectOneOrMoreOptions$6,
	days: days$6,
	time: time$6,
	months: months$6,
	multipleOptionsSelected: multipleOptionsSelected$6,
	selectAtLeastOneOption: selectAtLeastOneOption$6,
	nextButton: nextButton$6,
	selectedDayAndYear: selectedDayAndYear$6,
	selectedTime: selectedTime$6,
	name: name$6,
	namePlaceholder: namePlaceholder$6,
	email: email$6,
	emailPlaceholder: emailPlaceholder$6,
	guestEmail: guestEmail$6,
	guestEmailPlaceholder: guestEmailPlaceholder$6,
	addGuest: addGuest$6,
	addAnotherGuest: addAnotherGuest$6,
	backButton: backButton$6,
	bookNowButton: bookNowButton$6,
	bookingConfirmed: bookingConfirmed$6,
	bookingConfirmedDescription: bookingConfirmedDescription$6,
	bookingSent: bookingSent$6,
	bookingSentDescription: bookingSentDescription$6,
	bookingRescheduled: bookingRescheduled$6,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$6,
	cancelBookingButton: cancelBookingButton$6,
	rescheduleBookingButton: rescheduleBookingButton$6,
	rejectBookingButton: rejectBookingButton$6,
	confirmBookingButton: confirmBookingButton$6,
	bookingPendingTitle: bookingPendingTitle$6,
	bookingPendingnDescription: bookingPendingnDescription$6,
	confirmedEventCardTitle: confirmedEventCardTitle$6,
	confirmedEventCardDescription: confirmedEventCardDescription$6,
	cancelBookingTitle: cancelBookingTitle$6,
	cancelBookingMessage: cancelBookingMessage$6,
	reasonForCancellation: reasonForCancellation$6,
	goBackButton: goBackButton$6,
	bookingCancelledTitle: bookingCancelledTitle$6,
	bookingCancelledMessage: bookingCancelledMessage$6,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$6,
	closeButton: closeButton$6,
	closingButton: closingButton$6,
	fieldRequired: fieldRequired$6,
	invalidInputFormat: invalidInputFormat$6,
	createBookingErrorTitle: createBookingErrorTitle$6,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$6,
	cancelBookingErrorTitle: cancelBookingErrorTitle$6,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$6,
	getUISettingErrorTitle: getUISettingErrorTitle$6,
	rejectBookingErrorTitle: rejectBookingErrorTitle$6,
	confirmBookingErrorTitle: confirmBookingErrorTitle$6,
	genericErrorTitle: genericErrorTitle$6,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$6,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$6,
	publicConfigErrorMessage: publicConfigErrorMessage$6,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$5,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$6,
	cancellationErrorTitle: cancellationErrorTitle$6,
	cancellationErrorMessage: cancellationErrorMessage$6,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$6,
	cancelBokingFormError: cancelBokingFormError$6,
	feedbackFormTitle: feedbackFormTitle$6,
	feedbackFormDescription: feedbackFormDescription$6,
	feedbackMessageLabel: feedbackMessageLabel$6,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$6,
	feedbackModalCloseButton: feedbackModalCloseButton$6,
	feedbackModalSubmitButton: feedbackModalSubmitButton$6,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$6,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$6,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$6,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$6,
	schedulerEditorTitle: schedulerEditorTitle$6,
	allSchedulingPages: allSchedulingPages$6,
	createAndManageSchedulingPages: createAndManageSchedulingPages$6,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$6,
	pageTitle: pageTitle$6,
	durationTitle: durationTitle$6,
	loading: loading$6,
	required: required$6,
	optional: optional$6,
	loadingPagesDescription: loadingPagesDescription$6,
	noSchedulingPages: noSchedulingPages$6,
	createFirstSchedulingPage: createFirstSchedulingPage$6,
	editSchedulingPageButtonText: editSchedulingPageButtonText$6,
	eventInfoTab: eventInfoTab$6,
	availabilityTab: availabilityTab$6,
	participantsTab: participantsTab$6,
	bookingOptionsTab: bookingOptionsTab$6,
	returnToCalendarView: returnToCalendarView$6,
	bookingFormTab: bookingFormTab$6,
	communicationsTab: communicationsTab$6,
	pageStylesTab: pageStylesTab$6,
	savingButtonText: savingButtonText$6,
	saveChangesButtonText: saveChangesButtonText$6,
	createButtonText: createButtonText$6,
	timePeriod_day: timePeriod_day$6,
	timePeriod_week: timePeriod_week$6,
	timePeriod_month: timePeriod_month$6,
	timePeriod_year: timePeriod_year$6,
	timeDuration_minute: timeDuration_minute$6,
	timeDuration_hour: timeDuration_hour$6,
	eventCommunicationsTitle: eventCommunicationsTitle$6,
	eventCommunicationsDescription: eventCommunicationsDescription$6,
	unsavedChangesLabel: unsavedChangesLabel$6,
	changesSavedLabel: changesSavedLabel$6,
	fixFormErrors: fixFormErrors$6,
	nylasEditorTabs: nylasEditorTabs$6,
	nylasEditorTabsGroup: nylasEditorTabsGroup$6,
	nylasListConfigurations: nylasListConfigurations$6,
	nylasAdditionalParticipants: nylasAdditionalParticipants$6,
	nylasAvailabilityPicker: nylasAvailabilityPicker$6,
	nylasTimeWindowPicker: nylasTimeWindowPicker$2,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$6,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$6,
	nylasBookingConfirmationType: nylasBookingConfirmationType$6,
	nylasBookingFormConfig: nylasBookingFormConfig$6,
	nylasBufferTime: nylasBufferTime$6,
	nylasCalendarPicker: nylasCalendarPicker$6,
	nylasCancellationPolicy: nylasCancellationPolicy$6,
	nylasConfirmationEmail: nylasConfirmationEmail$6,
	nylasConnectedCalendars: nylasConnectedCalendars$6,
	nylasCustomBookingFlow: nylasCustomBookingFlow$6,
	nylasCustomEventSlug: nylasCustomEventSlug$6,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$6,
	nylasEventDescription: nylasEventDescription$6,
	nylasEventDuration: nylasEventDuration$6,
	nylasEventInfo: nylasEventInfo$6,
	nylasEventLimits: nylasEventLimits$6,
	nylasEventLocation: nylasEventLocation$6,
	nylasEventTitle: nylasEventTitle$6,
	nylasLimitFutureBookings: nylasLimitFutureBookings$6,
	nylasMinBookingNotice: nylasMinBookingNotice$6,
	nylasMinCancellationNotice: nylasMinCancellationNotice$6,
	nylasPageName: nylasPageName$6,
	nylasPageStyling: nylasPageStyling$6,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$6,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$6,
	nylasReminderEmails: nylasReminderEmails$6,
	nylasSchedulingMethod: nylasSchedulingMethod$6,
	nylasTimeslotInterval: nylasTimeslotInterval$6,
	nylasEventTimeslot: nylasEventTimeslot$6,
	nylasEventCapacity: nylasEventCapacity$6,
	nylasSelectEventType: nylasSelectEventType$6,
	pageSettingsButton: pageSettingsButton$6,
	nylasEventCalendar: nylasEventCalendar$6
};

const esTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$6,
  rescheduleTitle: rescheduleTitle$6,
  allDay: allDay$6,
  today: today$6,
  spotsLeft: spotsLeft$6,
  search: search$6,
  selectOneOrMoreOptions: selectOneOrMoreOptions$6,
  days: days$6,
  time: time$6,
  months: months$6,
  multipleOptionsSelected: multipleOptionsSelected$6,
  selectAtLeastOneOption: selectAtLeastOneOption$6,
  nextButton: nextButton$6,
  selectedDayAndYear: selectedDayAndYear$6,
  selectedTime: selectedTime$6,
  name: name$6,
  namePlaceholder: namePlaceholder$6,
  email: email$6,
  emailPlaceholder: emailPlaceholder$6,
  guestEmail: guestEmail$6,
  guestEmailPlaceholder: guestEmailPlaceholder$6,
  addGuest: addGuest$6,
  addAnotherGuest: addAnotherGuest$6,
  backButton: backButton$6,
  bookNowButton: bookNowButton$6,
  bookingConfirmed: bookingConfirmed$6,
  bookingConfirmedDescription: bookingConfirmedDescription$6,
  bookingSent: bookingSent$6,
  bookingSentDescription: bookingSentDescription$6,
  bookingRescheduled: bookingRescheduled$6,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$6,
  cancelBookingButton: cancelBookingButton$6,
  rescheduleBookingButton: rescheduleBookingButton$6,
  rejectBookingButton: rejectBookingButton$6,
  confirmBookingButton: confirmBookingButton$6,
  bookingPendingTitle: bookingPendingTitle$6,
  bookingPendingnDescription: bookingPendingnDescription$6,
  confirmedEventCardTitle: confirmedEventCardTitle$6,
  confirmedEventCardDescription: confirmedEventCardDescription$6,
  cancelBookingTitle: cancelBookingTitle$6,
  cancelBookingMessage: cancelBookingMessage$6,
  reasonForCancellation: reasonForCancellation$6,
  goBackButton: goBackButton$6,
  bookingCancelledTitle: bookingCancelledTitle$6,
  bookingCancelledMessage: bookingCancelledMessage$6,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$6,
  closeButton: closeButton$6,
  closingButton: closingButton$6,
  fieldRequired: fieldRequired$6,
  invalidInputFormat: invalidInputFormat$6,
  createBookingErrorTitle: createBookingErrorTitle$6,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$6,
  cancelBookingErrorTitle: cancelBookingErrorTitle$6,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$6,
  getUISettingErrorTitle: getUISettingErrorTitle$6,
  rejectBookingErrorTitle: rejectBookingErrorTitle$6,
  confirmBookingErrorTitle: confirmBookingErrorTitle$6,
  genericErrorTitle: genericErrorTitle$6,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$6,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$6,
  publicConfigErrorMessage: publicConfigErrorMessage$6,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$5,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$6,
  cancellationErrorTitle: cancellationErrorTitle$6,
  cancellationErrorMessage: cancellationErrorMessage$6,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$6,
  cancelBokingFormError: cancelBokingFormError$6,
  feedbackFormTitle: feedbackFormTitle$6,
  feedbackFormDescription: feedbackFormDescription$6,
  feedbackMessageLabel: feedbackMessageLabel$6,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$6,
  feedbackModalCloseButton: feedbackModalCloseButton$6,
  feedbackModalSubmitButton: feedbackModalSubmitButton$6,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$6,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$6,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$6,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$6,
  schedulerEditorTitle: schedulerEditorTitle$6,
  allSchedulingPages: allSchedulingPages$6,
  createAndManageSchedulingPages: createAndManageSchedulingPages$6,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$6,
  pageTitle: pageTitle$6,
  durationTitle: durationTitle$6,
  loading: loading$6,
  required: required$6,
  optional: optional$6,
  loadingPagesDescription: loadingPagesDescription$6,
  noSchedulingPages: noSchedulingPages$6,
  createFirstSchedulingPage: createFirstSchedulingPage$6,
  editSchedulingPageButtonText: editSchedulingPageButtonText$6,
  eventInfoTab: eventInfoTab$6,
  availabilityTab: availabilityTab$6,
  participantsTab: participantsTab$6,
  bookingOptionsTab: bookingOptionsTab$6,
  returnToCalendarView: returnToCalendarView$6,
  bookingFormTab: bookingFormTab$6,
  communicationsTab: communicationsTab$6,
  pageStylesTab: pageStylesTab$6,
  savingButtonText: savingButtonText$6,
  saveChangesButtonText: saveChangesButtonText$6,
  createButtonText: createButtonText$6,
  timePeriod_day: timePeriod_day$6,
  timePeriod_week: timePeriod_week$6,
  timePeriod_month: timePeriod_month$6,
  timePeriod_year: timePeriod_year$6,
  timeDuration_minute: timeDuration_minute$6,
  timeDuration_hour: timeDuration_hour$6,
  eventCommunicationsTitle: eventCommunicationsTitle$6,
  eventCommunicationsDescription: eventCommunicationsDescription$6,
  unsavedChangesLabel: unsavedChangesLabel$6,
  changesSavedLabel: changesSavedLabel$6,
  fixFormErrors: fixFormErrors$6,
  nylasEditorTabs: nylasEditorTabs$6,
  nylasEditorTabsGroup: nylasEditorTabsGroup$6,
  nylasListConfigurations: nylasListConfigurations$6,
  nylasAdditionalParticipants: nylasAdditionalParticipants$6,
  nylasAvailabilityPicker: nylasAvailabilityPicker$6,
  nylasTimeWindowPicker: nylasTimeWindowPicker$2,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$6,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$6,
  nylasBookingConfirmationType: nylasBookingConfirmationType$6,
  nylasBookingFormConfig: nylasBookingFormConfig$6,
  nylasBufferTime: nylasBufferTime$6,
  nylasCalendarPicker: nylasCalendarPicker$6,
  nylasCancellationPolicy: nylasCancellationPolicy$6,
  nylasConfirmationEmail: nylasConfirmationEmail$6,
  nylasConnectedCalendars: nylasConnectedCalendars$6,
  nylasCustomBookingFlow: nylasCustomBookingFlow$6,
  nylasCustomEventSlug: nylasCustomEventSlug$6,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$6,
  nylasEventDescription: nylasEventDescription$6,
  nylasEventDuration: nylasEventDuration$6,
  nylasEventInfo: nylasEventInfo$6,
  nylasEventLimits: nylasEventLimits$6,
  nylasEventLocation: nylasEventLocation$6,
  nylasEventTitle: nylasEventTitle$6,
  nylasLimitFutureBookings: nylasLimitFutureBookings$6,
  nylasMinBookingNotice: nylasMinBookingNotice$6,
  nylasMinCancellationNotice: nylasMinCancellationNotice$6,
  nylasPageName: nylasPageName$6,
  nylasPageStyling: nylasPageStyling$6,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$6,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$6,
  nylasReminderEmails: nylasReminderEmails$6,
  nylasSchedulingMethod: nylasSchedulingMethod$6,
  nylasTimeslotInterval: nylasTimeslotInterval$6,
  nylasEventTimeslot: nylasEventTimeslot$6,
  nylasEventCapacity: nylasEventCapacity$6,
  nylasSelectEventType: nylasSelectEventType$6,
  pageSettingsButton: pageSettingsButton$6,
  nylasEventCalendar: nylasEventCalendar$6,
  'default': es$1
});

const noDateSelected$5 = "日付が選択されていません";
const rescheduleTitle$5 = "別の時間を選択してください";
const allDay$5 = "全天";
const today$5 = "今日";
const spotsLeft$5 = "{{count}} スポット残り";
const search$5 = "検索";
const selectOneOrMoreOptions$5 = "1つ以上のオプションを選択してください";
const days$5 = {
	sunday: "日",
	monday: "月",
	tuesday: "火",
	wednesday: "水",
	thursday: "木",
	friday: "金",
	saturday: "土"
};
const time$5 = {
	hour: "時間",
	hours: "時間",
	minute: "分",
	minutes: "分",
	day: "日",
	days: "日",
	week: "週",
	weeks: "週",
	month: "月",
	months: "月",
	year: "年",
	years: "年"
};
const months$5 = {
	january: "1月",
	february: "2月",
	march: "3月",
	april: "4月",
	may: "5月",
	june: "6月",
	july: "7月",
	august: "8月",
	september: "9月",
	october: "10月",
	november: "11月",
	december: "12月"
};
const multipleOptionsSelected$5 = "複数のオプションが選択されています";
const selectAtLeastOneOption$5 = "少なくとも1つのオプションを選択してください";
const nextButton$5 = "次";
const selectedDayAndYear$5 = "{{date}}";
const selectedTime$5 = "{{time}}";
const name$5 = "名前";
const namePlaceholder$5 = "名前を入力してください";
const email$5 = "メールアドレス";
const emailPlaceholder$5 = "メールアドレスを入力してください";
const guestEmail$5 = "ゲストのメールアドレス";
const guestEmailPlaceholder$5 = "ゲストのメールアドレスを入力してください";
const addGuest$5 = "ゲストを追加";
const addAnotherGuest$5 = "他のゲストを追加";
const backButton$5 = "戻る";
const bookNowButton$5 = "今すぐ予約";
const bookingConfirmed$5 = "予約が確認されました";
const bookingConfirmedDescription$5 = "間もなくメールで確認が届きます。";
const bookingSent$5 = "予約が送信されました";
const bookingSentDescription$5 = "予約が確認され次第、メールをお送りします。";
const bookingRescheduled$5 = "予約が再予定されました";
const bookingDateAndTimeHeader$5 = "予約の日付と時間";
const cancelBookingButton$5 = "予約をキャンセル";
const rescheduleBookingButton$5 = "再調整";
const rejectBookingButton$5 = "予約を拒否";
const confirmBookingButton$5 = "予約を確認";
const bookingPendingTitle$5 = "予約保留中";
const bookingPendingnDescription$5 = "以下で予約を管理します。招待者にはリクエストステータスを知らせるメールが届きます。";
const confirmedEventCardTitle$5 = "予約が正常に確認されました";
const confirmedEventCardDescription$5 = "確認メールが送信されました";
const cancelBookingTitle$5 = "予約をキャンセルしますか？";
const cancelBookingMessage$5 = "現在の時間枠は他の人に利用可能になります。";
const reasonForCancellation$5 = "キャンセルの理由";
const goBackButton$5 = "戻る";
const bookingCancelledTitle$5 = "予約が正常にキャンセルされました";
const bookingCancelledMessage$5 = "キャンセルメールが送信されました";
const bookingCancelledMessage_theParticipants$5 = "参加者に送信されました";
const closeButton$5 = "閉じる";
const closingButton$5 = "閉じる";
const fieldRequired$5 = "{{field}} は必須です.";
const invalidInputFormat$5 = "{{field}} の形式が無効です.";
const createBookingErrorTitle$5 = "予約作成";
const getAvailabilityErrorTitle$5 = "空き状況を取得";
const cancelBookingErrorTitle$5 = "予約をキャンセル";
const rescheduleBookingErrorTitle$5 = "予約の再スケジュール";
const getUISettingErrorTitle$5 = "UI設定を取得";
const rejectBookingErrorTitle$5 = "予約を拒否";
const confirmBookingErrorTitle$5 = "予約を確認";
const genericErrorTitle$5 = "何かがうまくいかなかった...";
const schedulingComponentErrorTitle$5 = "スケジューリングコンポーネントエラー";
const sessionIdRequiredErrorMessage$5 = "プライベート構成には 'sessionId' が必要です。";
const publicConfigErrorMessage$5 = "公開設定を使用する場合は、configurationId または 'slug' と 'clientId' の組み合わせを渡します。";
const invalidTimeslotErrorTitle$4 = "無効な時間帯！";
const invalidTimeslotErrorMessage$5 = "選択された時間帯は無効です";
const cancellationErrorTitle$5 = "キャンセルエラー";
const cancellationErrorMessage$5 = "キャンセルの理由を入力してください。";
const minimumCancellationErrorMessage$5 = "イベントの{{minCancellationNotice}}分前には予約をキャンセルできません";
const cancelBokingFormError$5 = "予約キャンセルフォームエラー";
const feedbackFormTitle$5 = "フィードバックを共有する";
const feedbackFormDescription$5 = "フィードバックを提供し、エラーを報告することで、より良い体験を提供するためのサポートになります。";
const feedbackMessageLabel$5 = "コメントしている機能や問題が発生した箇所の詳細な説明をお願いします。";
const feedbackMessagePlaceholder$5 = "ここにフィードバックを記入してください";
const feedbackModalCloseButton$5 = "キャンセル";
const feedbackModalSubmitButton$5 = "送信";
const deleteSchedulingPageTitle$5 = "このスケジューリングページを削除しますか？";
const deleteSchedulingPageDescription$5 = "確認すると、このページと接続されているスケジュールリンクは完全に削除および無効化されます。この操作は元に戻せません。";
const deleteSchedulingPageConfirmButton$5 = "ページを削除";
const deleteSchedulingPageCancelButton$5 = "キャンセル";
const schedulerEditorTitle$5 = "スケジューラーエディター";
const allSchedulingPages$5 = "すべてのスケジュールページ";
const createAndManageSchedulingPages$5 = "スケジュールページを作成して管理します。";
const createNewSchedulingPageButtonText$5 = "新規作成";
const pageTitle$5 = "ページタイトル";
const durationTitle$5 = "期間";
const loading$5 = "読み込み中";
const required$5 = "必須";
const optional$5 = "任意";
const loadingPagesDescription$5 = "スケジュールページを取得しています。お待ちください。";
const noSchedulingPages$5 = "スケジュールページが見つかりません";
const createFirstSchedulingPage$5 = "最初のスケジュールページを作成して始めましょう";
const editSchedulingPageButtonText$5 = "編集";
const eventInfoTab$5 = "イベント情報";
const availabilityTab$5 = "利用可能時間";
const participantsTab$5 = "参加者";
const bookingOptionsTab$5 = "予約オプション";
const returnToCalendarView$5 = "カレンダーに戻る";
const bookingFormTab$5 = "予約フォーム";
const communicationsTab$5 = "通信";
const pageStylesTab$5 = "ページスタイル";
const savingButtonText$5 = "保存中";
const saveChangesButtonText$5 = "変更を保存";
const createButtonText$5 = "作成";
const timePeriod_day$5 = "日";
const timePeriod_week$5 = "週";
const timePeriod_month$5 = "月";
const timePeriod_year$5 = "年";
const timeDuration_minute$5 = "分";
const timeDuration_hour$5 = "時間";
const eventCommunicationsTitle$5 = "イベント通信";
const eventCommunicationsDescription$5 = "自動確認メールを設定します。";
const unsavedChangesLabel$5 = "未保存の変更";
const changesSavedLabel$5 = "変更が保存されました";
const fixFormErrors$5 = "フォームエラーを修正してください。";
const nylasEditorTabs$5 = {
	bookingFormError: "予約フォームエラー：",
	bookingFormError_label: "{{type}} タイプのフィールドにはラベルが必要です。",
	bookingFormError_option: "{{label}} の {{type}} タイプの空のオプションが検出されました。",
	formErrorTitle: "フォームエラー",
	updateConfigError: "更新エラー: ",
	createConfigError: "作成エラー: ",
	deleteConfigError: "削除エラー: ",
	getConfigsError: "構成の取得にエラーが発生しました: "
};
const nylasEditorTabsGroup$5 = {
	eventTitleRequired: "イベントタイトルが必要です。",
	eventTimeRequired: "イベント時間が必要です。",
	participantsRequired: "参加者が必要です。",
	participantEmailRequired: "参加者のEメールが必要です。",
	errorOccured: "変更の保存にエラーが発生しました。",
	createGroupEventError: "グループイベントの作成にエラーが発生しました: ",
	updateGroupEventError: "グループイベントの更新にエラーが発生しました: ",
	deleteGroupEventError: "グループイベントの削除にエラーが発生しました: ",
	importGroupEventError: "グループイベントのインポートにエラーが発生しました: ",
	getGroupEventsError: "グループイベントの取得にエラーが発生しました: "
};
const nylasListConfigurations$5 = {
	previewButtonText: "プレビュー",
	copyLinkButtonText: "リンクをコピー",
	deleteButtonText: "削除"
};
const nylasAdditionalParticipants$5 = {
	headerTitle: "参加者",
	headerSubTitle: "チームや組織のメンバーをイベントに追加します。",
	organizerAsParticipant: "参加者",
	organizer: "主催者",
	participant: "参加者",
	addParticipant_first: "参加者を追加",
	addParticipant_next: "別の参加者を追加",
	tooltip: {
		includeOrganizer: "主催者を含む",
		includeOrganizerDesc: "主催者（あなた）はローテーションに含まれます。",
		excludeOrganizer: "主催者を除外する",
		excludeOrganizerDesc: "主催者（あなた）はローテーションに含まれません。"
	},
	error: "少なくとも1人の参加者を追加してください"
};
const nylasAvailabilityPicker$5 = {
	headerTitle: "デフォルトの空き時間",
	headerSubTitle: "イベント予約のための通常の空き時間を設定します。",
	tooltip: {
		desc: "これは、参加者タブで空き時間が設定されていない参加者のデフォルトの可用性です。"
	},
	selectTimezone: "タイムゾーンを選択",
	unavailable: "利用不可",
	days: {
		SUN: "日",
		MON: "月",
		TUE: "火",
		WED: "水",
		THU: "木",
		FRI: "金",
		SAT: "土"
	}
};
const nylasTimeWindowPicker$1 = {
	errors: {
		invalid: "無効"
	}
};
const nylasBookingCalendarPicker$5 = {
	headerTitle: "カレンダー予約",
	headerSubTitle: "イベント予約を追加するカレンダーを選択します。",
	tooltip: {
		desc: "カレンダーはイベントを作成するために使用されます。"
	},
	selectOptionLabel: "オプションを選択",
	selectCalendarErrorMessage: "カレンダーを選択してください"
};
const nylasBookingConfirmationRedirect$5 = {
	dropdownLabel: "予約が確定した場合",
	tooltip: {
		desc: "デフォルトの確認ページを表示するか、独自の確認ページにリダイレクトできます。"
	},
	redirectOption_default: "デフォルトの確認ページを表示",
	redirectOption_custom: "カスタムURLにリダイレクト"
};
const nylasBookingConfirmationType$5 = {
	dropdownLabel: "予約がリクエストされた場合",
	tooltip: {
		desc: "手動で予約を承認すると、各予約リクエストを確認して承認または拒否できます。"
	},
	bookingOption_booking: "予約を自動的に承認",
	bookingOption_organizerConfirmation: "予約を手動で承認"
};
const nylasBookingFormConfig$5 = {
	headerTitle: "予約フォーム",
	headerSubTitle: "予約フォームにカスタムフィールドを追加します。",
	dropdownButtonText: "新しいフィールドを追加",
	addOption: "オプションを追加",
	allOptionsHeader: "すべてのオプション",
	fieldInTitleError: "このフィールドはイベントのタイトルで使用されているため、削除できません。",
	fieldInDescriptionError: "このフィールドはイベントの説明で使用されているため、削除できません。",
	label: "ラベル",
	defaultValue: "デフォルト値",
	fieldType: {
		text: "短いテキスト",
		multi_line_text: "長いテキスト",
		email: "メール",
		phone_number: "電話番号",
		dropdown: "ドロップダウン",
		radio_button: "ラジオボタン",
		checkbox: "チェックボックス",
		date: "日付",
		metadata: "メタデータ",
		multi_select: "マルチセレクト"
	},
	fieldLabel: {
		your_name: "あなたの名前",
		your_email: "あなたのメール",
		email: "追加のメール",
		phone_number: "電話番号ラベル",
		dropdown: "ドロップダウンラベル",
		text: "短いテキストラベル",
		multi_line_text: "長いテキストラベル",
		radio_button: "ラジオボタンラベル",
		checkbox: "チェックボックスラベル",
		date: "日付ラベル",
		metadata: "メタデータラベル",
		multi_select: "マルチセレクトラベル"
	}
};
const nylasBufferTime$5 = {
	headerTitle: "バッファ時間",
	headerSubTitle: "イベントの前後に空き時間を確保します。",
	tooltip: {
		desc: "スケジューラーはバッファ時間を予約しません。"
	},
	beforeBufferLabel: "イベントの前",
	afterBufferLabel: "イベントの後",
	minutesShort: "分",
	previewHeader: "プレビュー"
};
const nylasCalendarPicker$5 = {
	calendarPickerLabel: "可用性を確認するカレンダーを選択",
	selectAtLeastOneCalendar: "少なくとも1つのカレンダーを選択してください。"
};
const nylasCancellationPolicy$5 = {
	cancellationPolicyLabel: "キャンセルポリシーメッセージ",
	tooltip: {
		desc: "イベントをキャンセルしようとした場合、参加者にはこのメッセージが表示されます。キャンセルの理由を提供するよう求められます。"
	}
};
const nylasConfirmationEmail$5 = {
	headerTitle: "予約が確認されました{{organizerName}}",
	headerSubTitle: "予約確認メール",
	editButtonText: "編集",
	error: {
		invalidImageUrl: "無効な画像URLです。"
	},
	confirmationEmail: {
		label: "メール通知を有効にする",
		tooltip: {
			desc: "Nylasが確認メッセージやイベントリマインダーを含むメール通知を送信できるようにします。",
			language: "この言語は、主催者に対するメール通知に使用されます。"
		},
		language: "言語を選択"
	},
	nylasBranding: {
		label: "Nylasのブランディングを表示",
		tooltip: {
			desc: "メールのフッターを非表示にするには、このチェックを外してください。"
		}
	},
	companyLogoUrl: {
		label: "会社ロゴURL",
		tooltip: {
			desc: "このロゴは予約確認メールに表示されます。URLは公開可能である必要があります。画像は最大サイズ200px x 100pxに縮小されます。"
		}
	},
	emailMessage: {
		header: "メールメッセージ",
		label: "カスタムメールタイトル",
		tooltip: {
			desc: "メールタイトルは、メール本文内の見出しです。これは件名を変更しません。"
		},
		additionalInfoLabel: "追加情報",
		additionalInfoTooltip: "スケジューラーは、このボックスの内容をメール本文に追加します。",
		additionalInfoPlaceholder: "デフォルト本文"
	},
	allHosts: "すべてのホストとゲスト",
	immediatelyUponBooking: "予約後すぐに"
};
const nylasConnectedCalendars$5 = {
	headerTitle: "接続されたカレンダー",
	headerSubTitle: "利用可能性を確認するために使用するカレンダーを選択します。",
	tooltip: {
		desc: "1つ以上のカレンダーで利用可能性を確認します。参加者に複数のカレンダーを選択した場合、すべてのカレンダーで利用可能である必要があります。"
	},
	participantCalendarTitle: "{{participantName}}の接続されたカレンダー",
	selectAtLeastOneCalendar: "少なくとも1つのカレンダーを選択してください。"
};
const nylasCustomBookingFlow$5 = {
	headerTitle: "カスタム予約フロー"
};
const nylasCustomEventSlug$5 = {
	headerTitle: "カスタムページスラッグ",
	headerSubTitle: "このページのカスタムURLスラッグを作成します。",
	eventSlugLabel: "ページURLスラッグ",
	tooltip: {
		desc: "URLにカスタムスラッグを指定して、ページを一意に識別します（文字、数字、ハイフンのみ）。"
	},
	copied: "コピーしました！"
};
const nylasCustomizeBookingSettings$5 = {
	headerTitle: "追加設定",
	headerSubTitle: "イベントの予約設定。",
	tooltip: {
		desc: "予約設定をカスタマイズします。"
	},
	allowGuests: {
		label: "ゲストが追加のゲストを招待することを許可します。"
	},
	hideReschedule: {
		label: "再スケジュールオプションを非表示",
		tooltip: {
			desc: "予約確認とメール通知で「再スケジュール」ボタンを非表示にします。"
		}
	},
	hideCancel: {
		label: "キャンセルオプションを非表示",
		tooltip: {
			desc: "予約確認とメール通知で「キャンセル」ボタンを非表示にします。"
		}
	}
};
const nylasEventDescription$5 = {
	headerTitle: "イベントの説明",
	addAdditionalFields: {
		buttonText: "追加フィールドを自動入力",
		tooltip: {
			desc: "説明に含めたいすべてのフィールドを追加した後、これをクリックしてください。重要：すべてが正しく機能するために、'--- Additional Fields ---'と'--- End Additional Fields ---'のマーカーは変更しないでください。"
		}
	},
	tooltip: {
		desc: "イベントの説明はスケジューラーエディターの管理ビューに表示され、予約が作成されたときのレスポンスペイロードにも含まれます。"
	}
};
const nylasEventDuration$5 = {
	headerTitle: "イベントの期間",
	error: {
		durationMustBeMultipleOf5: "期間は5の倍数でなければなりません",
		durationMustBeGreaterThan0: "期間は0より大きくなければなりません"
	}
};
const nylasEventInfo$5 = {
	headerTitle: "イベント情報"
};
const nylasEventLimits$5 = {
	headerTitle: "イベントの制限"
};
const nylasEventLocation$5 = {
	headerTitle: "イベントの会場または会議",
	tooltip: {
		desc: "会議オプションを選択するか、カスタムロケーションを追加します。"
	},
	conferenceOptions: {
		none: "なし",
		zoom: "Zoomミーティング",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "カスタムの場所"
	}
};
const nylasEventTitle$5 = {
	headerTitle: "イベントタイトル",
	helpText_start: "入力して動的なテンプレートイベント {{field}} を作成します",
	helpText_end: "およびテンプレート項目を選択。",
	title: "タイトル",
	description: "説明",
	tooltip: {
		desc: "例: インタビュー（候補者）"
	},
	eventTitleRequired: "イベントタイトルは必須です",
	eventTitleTokenDescription: {
		invitee: "主催者の名前",
		inviteeEmail: "主催者のメールアドレス",
		duration: "イベントの長さ"
	}
};
const nylasLimitFutureBookings$5 = {
	headerTitle: "今後の予約を制限する",
	tooltip: {
		desc: "予約を未来にどれだけ作成できるかの制限です。"
	}
};
const nylasMinBookingNotice$5 = {
	headerTitle: "最小予約通知",
	tooltip: {
		desc: "新しい予約を行うために必要な、未来にある最小の時間猶予です。"
	}
};
const nylasMinCancellationNotice$5 = {
	headerTitle: "最小キャンセル通知",
	tooltip: {
		desc: "予約をキャンセルするために必要な最小の時間です。"
	}
};
const nylasPageName$5 = {
	headerTitle: "ページ名",
	headerSubTitle: "スケジュールページの名前を設定してください。",
	pageNameError: "ページ名を入力してください",
	tooltip: {
		desc: "デフォルトでは、スケジュールページはあなたのユーザー名をページ名として使用します。ページ名はカレンダー表示の左上に表示されます。"
	}
};
const nylasPageStyling$5 = {
	headerTitle: "ページのスタイリングとカスタマイズ"
};
const nylasParticipantBookingCalendars$5 = {
	headerTitle: "このカレンダーへの予約",
	headerSubTitle: "イベントの予約を追加するカレンダーを選択してください。",
	participantBookingCalendarTitle: "{{participantName}} の予約カレンダー",
	selectAtLeastOneCalendar: "少なくとも1つのカレンダーを選択してください。"
};
const nylasParticipantCustomAvailability$5 = {
	headerTitle: "参加者の利用可能時間",
	headerSubTitle: "設定されていない場合、標準の営業時間が参加者の利用可能時間を計算するために使用されます。",
	participantOpenHoursTitle: "{{participantName}} の営業時間"
};
const nylasReminderEmails$5 = {
	headerTitle: "今後の会議 {{organizerName}}",
	headerSubTitle: "イベント前のリマインダー",
	editButtonText: "編集",
	recipientOptions_all: "すべてのホストとゲスト",
	recipientOptions_guest: "イベントのすべてのゲスト",
	recipientOptions_host: "イベントホストのみ",
	beforeTheEvent: "イベント前",
	emailRecipients: {
		label: "メール受信者"
	},
	sendConfirmation: {
		label: "以下の場合に確認メールを送信",
		tooltip: {
			desc: "受信者は、指定されたイベント前の時刻にリマインダーメールを受け取ります。"
		}
	},
	emailSubject: {
		label: "メールの件名",
		placeholder: "今後の会議 {{organizerName}}"
	},
	reminderMinutesValidationError: "リマインダーの分数を5の倍数で入力してください。試してください: ",
	newReminderButtonText: "新しいリマインダー"
};
const nylasSchedulingMethod$5 = {
	headerTitle: "スケジューリング方法",
	headerSubTitle: "イベントのスケジューリング方法を選択してください。",
	tooltip: {
		standard: {
			label: "標準",
			desc: "1対1の予約または追加参加者を含むn対1の予約を許可します。"
		},
		maxFairness: {
			label: "ラウンドロビン - 最大の公平性",
			desc: "選択された参加者のリストを順に処理し、直近の予約が最も少ない参加者を表示します。"
		},
		maxAvailability: {
			label: "ラウンドロビン - 最大の利用可能性",
			desc: "選択された参加者のリストを順に処理し、予約が最も少ない参加者を優先しながら、できるだけ多くの時間枠を利用可能にします。"
		}
	},
	schedulingMethodOptions_collective: "標準予約",
	schedulingMethodOptions_maxFairness: "ラウンドロビン - 最大の公平性",
	schedulingMethodOptions_maxAvailability: "ラウンドロビン - 最大の利用可能性"
};
const nylasTimeslotInterval$5 = {
	minutesShort: "分",
	lengthOfMeeting: "会議の長さ",
	headerTitle: "時間枠設定",
	timeslotInterval: {
		label: "時間枠の間隔。"
	},
	timeslotRounding: {
		label: "時間枠の丸めタイプ",
		tooltip: {
			desc: "時間枠が表示される間隔。"
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "間隔の丸め",
			desc: "時間枠は間隔値に丸められた時刻から始まります。"
		},
		noRounding: {
			label: "デフォルト",
			desc: "時間枠は最も近い15分単位に丸められます。"
		}
	}
};
const nylasEventTimeslot$5 = {
	recurrenceOptions: {
		none: "繰り返しません",
		daily: "毎日",
		weekly: "{{dayOfWeek}}ごとに毎週",
		monthly: "毎月{{dayOfMonth}}",
		monthOnDay: "毎月{{date}}の日",
		yearly: "毎年{{dateOfMonth}}",
		custom: "カスタム"
	},
	recurrenceLabel: "このイベントを繰り返す",
	endDate: "終了日",
	customRecurrence: {
		repeatEvery: "毎回繰り返す",
		repeatOn: "繰り返す日",
		ends: "終了",
		endsOptions: {
			never: "終了しない",
			after: "後",
			on: "終了日"
		},
		occurrences: "回数"
	},
	dateTimeLabel: "日時",
	errors: {
		invalidTimeRange: "時間範囲が無効です",
		startTimeSameAsEndTime: "開始時間と終了時間は同じにできません",
		startTimeBeforeCurrentDate: "開始時間は過去にできません",
		invalid: "無効"
	}
};
const nylasEventCapacity$5 = {
	headerTitle: "招待者",
	headerSubTitle: "このイベントのタイムスロットの最大招待者数を設定します。",
	tooltip: {
		desc: "スケジュールページで設定された主催者および参加者は招待者としてカウントされません。"
	},
	attendees: "招待者"
};
const nylasSelectEventType$5 = {
	returnToAllSchedulingPages: "すべてのスケジュールページに戻る",
	createEventHeaderTitle: "イベントを作成する",
	eventTypeHeaderTitle: "イベントの種類",
	noEventTypesEnabled: "イベントの種類が有効化されていません",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "1対1の予約を許可します。"
		},
		collective: {
			label: "標準予約",
			desc: "追加の参加者を含むn対1の予約を許可します。"
		},
		maxFairness: {
			label: "ラウンドロビン-最大の公平性",
			desc: "選択された参加者のリストを順に処理し、直近の予約が最も少ない参加者を表示します。"
		},
		maxAvailability: {
			label: "ラウンドロビン-最大の利用可能性",
			desc: "選択された参加者のリストを順に処理し、予約が最も少ない参加者を優先しながら、できるだけ多くの時間枠を利用可能にします。"
		},
		group: {
			label: "グループ/クラス",
			desc: "これらは通常、1つの主催者と複数の参加者を持つイベントです。"
		}
	}
};
const pageSettingsButton$5 = "ページの設定";
const nylasEventCalendar$5 = {
	hideNonGroupEvents: {
		showLabel: "イベントをフィルター",
		tooltip: {
			desc: "カレンダーに表示するイベントの種類を選択します。"
		},
		options: {
			all: "すべて",
			group: "グループのみ"
		}
	},
	createEventDetails: {
		headerTitle: "イベントの詳細",
		closeButtonTooltip: "閉じる",
		cancelButton: "キャンセル",
		createButton: "作成"
	},
	discardChanges: {
		headerTitle: "変更を破棄しますか？",
		cancelButton: "キャンセル",
		discardButton: "破棄"
	},
	unsavedChanges: "未保存の変更",
	editEventDetails: {
		headerTitle: "イベントの詳細",
		closeButtonTooltip: "閉じる",
		deleteButton: "削除",
		saveButton: "保存",
		pastEventTooltip: "このイベントは過去にあり、編集できません。"
	},
	importEvent: {
		closeButtonTooltip: "閉じる",
		importButton: "インポート",
		participantsLabel: "参加者"
	},
	deleteEvent: {
		closeButtonTooltip: "閉じる",
		deleting: "削除中..."
	},
	editOptions: {
		headerTitle: "アクション",
		closeButtonTooltip: "閉じる",
		deleting: "削除中...",
		"import": "インポート",
		edit: "編集",
		deleteThis: "このイベントを削除",
		deleteAll: "すべてのイベントを削除",
		importTooltip: "既存のイベントをカレンダーから選択し、グループイベントとして設定できます"
	},
	updateOptions: {
		updateThis: "このイベントを更新",
		updateAll: "すべてのイベントを更新",
		updateFuture: "すべての将来のイベントを更新"
	},
	deleteOptions: {
		deleteThis: "削除",
		deleteFuture: "このイベントとすべての将来のイベントを削除",
		deleteAll: "すべてのイベントを削除"
	}
};
const ja$1 = {
	noDateSelected: noDateSelected$5,
	rescheduleTitle: rescheduleTitle$5,
	allDay: allDay$5,
	today: today$5,
	spotsLeft: spotsLeft$5,
	search: search$5,
	selectOneOrMoreOptions: selectOneOrMoreOptions$5,
	days: days$5,
	time: time$5,
	months: months$5,
	multipleOptionsSelected: multipleOptionsSelected$5,
	selectAtLeastOneOption: selectAtLeastOneOption$5,
	nextButton: nextButton$5,
	selectedDayAndYear: selectedDayAndYear$5,
	selectedTime: selectedTime$5,
	name: name$5,
	namePlaceholder: namePlaceholder$5,
	email: email$5,
	emailPlaceholder: emailPlaceholder$5,
	guestEmail: guestEmail$5,
	guestEmailPlaceholder: guestEmailPlaceholder$5,
	addGuest: addGuest$5,
	addAnotherGuest: addAnotherGuest$5,
	backButton: backButton$5,
	bookNowButton: bookNowButton$5,
	bookingConfirmed: bookingConfirmed$5,
	bookingConfirmedDescription: bookingConfirmedDescription$5,
	bookingSent: bookingSent$5,
	bookingSentDescription: bookingSentDescription$5,
	bookingRescheduled: bookingRescheduled$5,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$5,
	cancelBookingButton: cancelBookingButton$5,
	rescheduleBookingButton: rescheduleBookingButton$5,
	rejectBookingButton: rejectBookingButton$5,
	confirmBookingButton: confirmBookingButton$5,
	bookingPendingTitle: bookingPendingTitle$5,
	bookingPendingnDescription: bookingPendingnDescription$5,
	confirmedEventCardTitle: confirmedEventCardTitle$5,
	confirmedEventCardDescription: confirmedEventCardDescription$5,
	cancelBookingTitle: cancelBookingTitle$5,
	cancelBookingMessage: cancelBookingMessage$5,
	reasonForCancellation: reasonForCancellation$5,
	goBackButton: goBackButton$5,
	bookingCancelledTitle: bookingCancelledTitle$5,
	bookingCancelledMessage: bookingCancelledMessage$5,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$5,
	closeButton: closeButton$5,
	closingButton: closingButton$5,
	fieldRequired: fieldRequired$5,
	invalidInputFormat: invalidInputFormat$5,
	createBookingErrorTitle: createBookingErrorTitle$5,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$5,
	cancelBookingErrorTitle: cancelBookingErrorTitle$5,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$5,
	getUISettingErrorTitle: getUISettingErrorTitle$5,
	rejectBookingErrorTitle: rejectBookingErrorTitle$5,
	confirmBookingErrorTitle: confirmBookingErrorTitle$5,
	genericErrorTitle: genericErrorTitle$5,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$5,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$5,
	publicConfigErrorMessage: publicConfigErrorMessage$5,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$4,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$5,
	cancellationErrorTitle: cancellationErrorTitle$5,
	cancellationErrorMessage: cancellationErrorMessage$5,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$5,
	cancelBokingFormError: cancelBokingFormError$5,
	feedbackFormTitle: feedbackFormTitle$5,
	feedbackFormDescription: feedbackFormDescription$5,
	feedbackMessageLabel: feedbackMessageLabel$5,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$5,
	feedbackModalCloseButton: feedbackModalCloseButton$5,
	feedbackModalSubmitButton: feedbackModalSubmitButton$5,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$5,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$5,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$5,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$5,
	schedulerEditorTitle: schedulerEditorTitle$5,
	allSchedulingPages: allSchedulingPages$5,
	createAndManageSchedulingPages: createAndManageSchedulingPages$5,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$5,
	pageTitle: pageTitle$5,
	durationTitle: durationTitle$5,
	loading: loading$5,
	required: required$5,
	optional: optional$5,
	loadingPagesDescription: loadingPagesDescription$5,
	noSchedulingPages: noSchedulingPages$5,
	createFirstSchedulingPage: createFirstSchedulingPage$5,
	editSchedulingPageButtonText: editSchedulingPageButtonText$5,
	eventInfoTab: eventInfoTab$5,
	availabilityTab: availabilityTab$5,
	participantsTab: participantsTab$5,
	bookingOptionsTab: bookingOptionsTab$5,
	returnToCalendarView: returnToCalendarView$5,
	bookingFormTab: bookingFormTab$5,
	communicationsTab: communicationsTab$5,
	pageStylesTab: pageStylesTab$5,
	savingButtonText: savingButtonText$5,
	saveChangesButtonText: saveChangesButtonText$5,
	createButtonText: createButtonText$5,
	timePeriod_day: timePeriod_day$5,
	timePeriod_week: timePeriod_week$5,
	timePeriod_month: timePeriod_month$5,
	timePeriod_year: timePeriod_year$5,
	timeDuration_minute: timeDuration_minute$5,
	timeDuration_hour: timeDuration_hour$5,
	eventCommunicationsTitle: eventCommunicationsTitle$5,
	eventCommunicationsDescription: eventCommunicationsDescription$5,
	unsavedChangesLabel: unsavedChangesLabel$5,
	changesSavedLabel: changesSavedLabel$5,
	fixFormErrors: fixFormErrors$5,
	nylasEditorTabs: nylasEditorTabs$5,
	nylasEditorTabsGroup: nylasEditorTabsGroup$5,
	nylasListConfigurations: nylasListConfigurations$5,
	nylasAdditionalParticipants: nylasAdditionalParticipants$5,
	nylasAvailabilityPicker: nylasAvailabilityPicker$5,
	nylasTimeWindowPicker: nylasTimeWindowPicker$1,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$5,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$5,
	nylasBookingConfirmationType: nylasBookingConfirmationType$5,
	nylasBookingFormConfig: nylasBookingFormConfig$5,
	nylasBufferTime: nylasBufferTime$5,
	nylasCalendarPicker: nylasCalendarPicker$5,
	nylasCancellationPolicy: nylasCancellationPolicy$5,
	nylasConfirmationEmail: nylasConfirmationEmail$5,
	nylasConnectedCalendars: nylasConnectedCalendars$5,
	nylasCustomBookingFlow: nylasCustomBookingFlow$5,
	nylasCustomEventSlug: nylasCustomEventSlug$5,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$5,
	nylasEventDescription: nylasEventDescription$5,
	nylasEventDuration: nylasEventDuration$5,
	nylasEventInfo: nylasEventInfo$5,
	nylasEventLimits: nylasEventLimits$5,
	nylasEventLocation: nylasEventLocation$5,
	nylasEventTitle: nylasEventTitle$5,
	nylasLimitFutureBookings: nylasLimitFutureBookings$5,
	nylasMinBookingNotice: nylasMinBookingNotice$5,
	nylasMinCancellationNotice: nylasMinCancellationNotice$5,
	nylasPageName: nylasPageName$5,
	nylasPageStyling: nylasPageStyling$5,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$5,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$5,
	nylasReminderEmails: nylasReminderEmails$5,
	nylasSchedulingMethod: nylasSchedulingMethod$5,
	nylasTimeslotInterval: nylasTimeslotInterval$5,
	nylasEventTimeslot: nylasEventTimeslot$5,
	nylasEventCapacity: nylasEventCapacity$5,
	nylasSelectEventType: nylasSelectEventType$5,
	pageSettingsButton: pageSettingsButton$5,
	nylasEventCalendar: nylasEventCalendar$5
};

const jaTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$5,
  rescheduleTitle: rescheduleTitle$5,
  allDay: allDay$5,
  today: today$5,
  spotsLeft: spotsLeft$5,
  search: search$5,
  selectOneOrMoreOptions: selectOneOrMoreOptions$5,
  days: days$5,
  time: time$5,
  months: months$5,
  multipleOptionsSelected: multipleOptionsSelected$5,
  selectAtLeastOneOption: selectAtLeastOneOption$5,
  nextButton: nextButton$5,
  selectedDayAndYear: selectedDayAndYear$5,
  selectedTime: selectedTime$5,
  name: name$5,
  namePlaceholder: namePlaceholder$5,
  email: email$5,
  emailPlaceholder: emailPlaceholder$5,
  guestEmail: guestEmail$5,
  guestEmailPlaceholder: guestEmailPlaceholder$5,
  addGuest: addGuest$5,
  addAnotherGuest: addAnotherGuest$5,
  backButton: backButton$5,
  bookNowButton: bookNowButton$5,
  bookingConfirmed: bookingConfirmed$5,
  bookingConfirmedDescription: bookingConfirmedDescription$5,
  bookingSent: bookingSent$5,
  bookingSentDescription: bookingSentDescription$5,
  bookingRescheduled: bookingRescheduled$5,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$5,
  cancelBookingButton: cancelBookingButton$5,
  rescheduleBookingButton: rescheduleBookingButton$5,
  rejectBookingButton: rejectBookingButton$5,
  confirmBookingButton: confirmBookingButton$5,
  bookingPendingTitle: bookingPendingTitle$5,
  bookingPendingnDescription: bookingPendingnDescription$5,
  confirmedEventCardTitle: confirmedEventCardTitle$5,
  confirmedEventCardDescription: confirmedEventCardDescription$5,
  cancelBookingTitle: cancelBookingTitle$5,
  cancelBookingMessage: cancelBookingMessage$5,
  reasonForCancellation: reasonForCancellation$5,
  goBackButton: goBackButton$5,
  bookingCancelledTitle: bookingCancelledTitle$5,
  bookingCancelledMessage: bookingCancelledMessage$5,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$5,
  closeButton: closeButton$5,
  closingButton: closingButton$5,
  fieldRequired: fieldRequired$5,
  invalidInputFormat: invalidInputFormat$5,
  createBookingErrorTitle: createBookingErrorTitle$5,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$5,
  cancelBookingErrorTitle: cancelBookingErrorTitle$5,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$5,
  getUISettingErrorTitle: getUISettingErrorTitle$5,
  rejectBookingErrorTitle: rejectBookingErrorTitle$5,
  confirmBookingErrorTitle: confirmBookingErrorTitle$5,
  genericErrorTitle: genericErrorTitle$5,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$5,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$5,
  publicConfigErrorMessage: publicConfigErrorMessage$5,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$4,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$5,
  cancellationErrorTitle: cancellationErrorTitle$5,
  cancellationErrorMessage: cancellationErrorMessage$5,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$5,
  cancelBokingFormError: cancelBokingFormError$5,
  feedbackFormTitle: feedbackFormTitle$5,
  feedbackFormDescription: feedbackFormDescription$5,
  feedbackMessageLabel: feedbackMessageLabel$5,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$5,
  feedbackModalCloseButton: feedbackModalCloseButton$5,
  feedbackModalSubmitButton: feedbackModalSubmitButton$5,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$5,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$5,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$5,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$5,
  schedulerEditorTitle: schedulerEditorTitle$5,
  allSchedulingPages: allSchedulingPages$5,
  createAndManageSchedulingPages: createAndManageSchedulingPages$5,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$5,
  pageTitle: pageTitle$5,
  durationTitle: durationTitle$5,
  loading: loading$5,
  required: required$5,
  optional: optional$5,
  loadingPagesDescription: loadingPagesDescription$5,
  noSchedulingPages: noSchedulingPages$5,
  createFirstSchedulingPage: createFirstSchedulingPage$5,
  editSchedulingPageButtonText: editSchedulingPageButtonText$5,
  eventInfoTab: eventInfoTab$5,
  availabilityTab: availabilityTab$5,
  participantsTab: participantsTab$5,
  bookingOptionsTab: bookingOptionsTab$5,
  returnToCalendarView: returnToCalendarView$5,
  bookingFormTab: bookingFormTab$5,
  communicationsTab: communicationsTab$5,
  pageStylesTab: pageStylesTab$5,
  savingButtonText: savingButtonText$5,
  saveChangesButtonText: saveChangesButtonText$5,
  createButtonText: createButtonText$5,
  timePeriod_day: timePeriod_day$5,
  timePeriod_week: timePeriod_week$5,
  timePeriod_month: timePeriod_month$5,
  timePeriod_year: timePeriod_year$5,
  timeDuration_minute: timeDuration_minute$5,
  timeDuration_hour: timeDuration_hour$5,
  eventCommunicationsTitle: eventCommunicationsTitle$5,
  eventCommunicationsDescription: eventCommunicationsDescription$5,
  unsavedChangesLabel: unsavedChangesLabel$5,
  changesSavedLabel: changesSavedLabel$5,
  fixFormErrors: fixFormErrors$5,
  nylasEditorTabs: nylasEditorTabs$5,
  nylasEditorTabsGroup: nylasEditorTabsGroup$5,
  nylasListConfigurations: nylasListConfigurations$5,
  nylasAdditionalParticipants: nylasAdditionalParticipants$5,
  nylasAvailabilityPicker: nylasAvailabilityPicker$5,
  nylasTimeWindowPicker: nylasTimeWindowPicker$1,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$5,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$5,
  nylasBookingConfirmationType: nylasBookingConfirmationType$5,
  nylasBookingFormConfig: nylasBookingFormConfig$5,
  nylasBufferTime: nylasBufferTime$5,
  nylasCalendarPicker: nylasCalendarPicker$5,
  nylasCancellationPolicy: nylasCancellationPolicy$5,
  nylasConfirmationEmail: nylasConfirmationEmail$5,
  nylasConnectedCalendars: nylasConnectedCalendars$5,
  nylasCustomBookingFlow: nylasCustomBookingFlow$5,
  nylasCustomEventSlug: nylasCustomEventSlug$5,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$5,
  nylasEventDescription: nylasEventDescription$5,
  nylasEventDuration: nylasEventDuration$5,
  nylasEventInfo: nylasEventInfo$5,
  nylasEventLimits: nylasEventLimits$5,
  nylasEventLocation: nylasEventLocation$5,
  nylasEventTitle: nylasEventTitle$5,
  nylasLimitFutureBookings: nylasLimitFutureBookings$5,
  nylasMinBookingNotice: nylasMinBookingNotice$5,
  nylasMinCancellationNotice: nylasMinCancellationNotice$5,
  nylasPageName: nylasPageName$5,
  nylasPageStyling: nylasPageStyling$5,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$5,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$5,
  nylasReminderEmails: nylasReminderEmails$5,
  nylasSchedulingMethod: nylasSchedulingMethod$5,
  nylasTimeslotInterval: nylasTimeslotInterval$5,
  nylasEventTimeslot: nylasEventTimeslot$5,
  nylasEventCapacity: nylasEventCapacity$5,
  nylasSelectEventType: nylasSelectEventType$5,
  pageSettingsButton: pageSettingsButton$5,
  nylasEventCalendar: nylasEventCalendar$5,
  'default': ja$1
});

const noDateSelected$4 = "Kein Datum ausgewählt";
const rescheduleTitle$4 = "Wählen Sie einen anderen Zeitpunkt, um Ihr Meeting neu zu planen";
const allDay$4 = "Ganzer Tag";
const today$4 = "Heute";
const spotsLeft$4 = "{{count}} Plätze frei";
const search$4 = "Suchen";
const selectOneOrMoreOptions$4 = "Wählen Sie mindestens eine Option";
const days$4 = {
	sunday: "SO",
	monday: "MO",
	tuesday: "DI",
	wednesday: "MI",
	thursday: "DO",
	friday: "FR",
	saturday: "SA"
};
const time$4 = {
	hour: "Stunde",
	hours: "Stunden",
	minute: "Minute",
	minutes: "Minuten",
	day: "Tag",
	days: "Tage",
	week: "Woche",
	weeks: "Wochen",
	month: "Monat",
	months: "Monate",
	year: "Jahr",
	years: "Jahre"
};
const months$4 = {
	january: "Januar",
	february: "Februar",
	march: "März",
	april: "April",
	may: "Mai",
	june: "Juni",
	july: "Juli",
	august: "August",
	september: "September",
	october: "Oktober",
	november: "November",
	december: "Dezember"
};
const multipleOptionsSelected$4 = "Mehrere Optionen ausgewählt";
const selectAtLeastOneOption$4 = "Bitte wählen Sie mindestens eine Option";
const nextButton$4 = "Weiter";
const selectedDayAndYear$4 = "{{date}}";
const selectedTime$4 = "{{time}}";
const name$4 = "Name";
const namePlaceholder$4 = "Geben Sie Ihren Namen ein";
const email$4 = "E-Mail";
const emailPlaceholder$4 = "Geben Sie Ihre E-Mail-Adresse ein";
const guestEmail$4 = "Gast E-Mail";
const guestEmailPlaceholder$4 = "Geben Sie die E-Mail-Adresse des Gastes ein";
const addGuest$4 = "Gast hinzufügen";
const addAnotherGuest$4 = "Weiteren Gast hinzufügen";
const backButton$4 = "Zurück";
const bookNowButton$4 = "Jetzt buchen";
const bookingConfirmed$4 = "Buchung bestätigt";
const bookingConfirmedDescription$4 = "Sie erhalten in Kürze eine E-Mail-Bestätigung.";
const bookingSent$4 = "Buchung gesendet";
const bookingSentDescription$4 = "Sie erhalten eine E-Mail, sobald die Buchung bestätigt ist.";
const bookingRescheduled$4 = "Buchung umgebucht";
const bookingDateAndTimeHeader$4 = "Buchungsdatum und -zeit";
const cancelBookingButton$4 = "Buchung stornieren";
const rescheduleBookingButton$4 = "Umplanen";
const rejectBookingButton$4 = "Buchung ablehnen";
const confirmBookingButton$4 = "Buchung bestätigen";
const bookingPendingTitle$4 = "Buchung ausstehend";
const bookingPendingnDescription$4 = "Verwalten Sie Ihre Buchung unten. Der Eingeladene erhält eine E-Mail mit dem Status der Anfrage.";
const confirmedEventCardTitle$4 = "Ihre Buchung wurde erfolgreich bestätigt";
const confirmedEventCardDescription$4 = "Eine Bestätigungs-E-Mail wurde gesendet an";
const cancelBookingTitle$4 = "Buchung stornieren?";
const cancelBookingMessage$4 = "Ihr aktueller Zeitraum wird für andere verfügbar.";
const reasonForCancellation$4 = "Grund für die Stornierung";
const goBackButton$4 = "Zurück";
const bookingCancelledTitle$4 = "Ihre Buchung wurde erfolgreich storniert";
const bookingCancelledMessage$4 = "Eine Stornierungs-E-Mail wurde an";
const bookingCancelledMessage_theParticipants$4 = "die Teilnehmer versendet";
const closeButton$4 = "Schließen";
const closingButton$4 = "Schließen";
const fieldRequired$4 = "{{field}} ist erforderlich.";
const invalidInputFormat$4 = "{{field}} hat ein ungültiges Format.";
const createBookingErrorTitle$4 = "Buchung Erstellen";
const getAvailabilityErrorTitle$4 = "Verfügbarkeit Ermitteln";
const cancelBookingErrorTitle$4 = "Buchung Stornieren";
const rescheduleBookingErrorTitle$4 = "Buchung Verschieben";
const getUISettingErrorTitle$4 = "UI-Einstellungen Abrufen";
const rejectBookingErrorTitle$4 = "Buchung Ablehnen";
const confirmBookingErrorTitle$4 = "Buchung Bestätigen";
const genericErrorTitle$4 = "Etwas ist schief gelaufen...";
const schedulingComponentErrorTitle$4 = "Fehler im Planungskomponent";
const sessionIdRequiredErrorMessage$4 = "'sessionId' ist für private Konfigurationen erforderlich.";
const publicConfigErrorMessage$4 = "Bei Verwendung einer öffentlichen Konfiguration geben Sie entweder eine Konfigurations-ID oder eine Kombination aus 'slug' und 'clientId' an.";
const invalidTimeslotErrorTitle$3 = "Ungültiges Zeitfenster!";
const invalidTimeslotErrorMessage$4 = "Das ausgewählte Zeitfenster ist ungültig";
const cancellationErrorTitle$4 = "Stornierungsfehler";
const cancellationErrorMessage$4 = "Bitte geben Sie einen Grund für die Stornierung an.";
const minimumCancellationErrorMessage$4 = "Sie können die Buchung nicht innerhalb von {{minCancellationNotice}} Minuten vor der Veranstaltung stornieren";
const cancelBokingFormError$4 = "Fehler im Stornierungsformular";
const feedbackFormTitle$4 = "Teilen Sie Ihr Feedback";
const feedbackFormDescription$4 = "Indem Sie uns Ihr Feedback geben und Fehler melden, helfen Sie uns, eine bessere Erfahrung für Sie zu schaffen.";
const feedbackMessageLabel$4 = "Bitte geben Sie uns eine detaillierte Beschreibung der Funktion, über die Sie kommentieren, oder wo Sie ein Problem festgestellt haben.";
const feedbackMessagePlaceholder$4 = "Geben Sie hier Ihr Feedback ein";
const feedbackModalCloseButton$4 = "Annuleren";
const feedbackModalSubmitButton$4 = "Absenden";
const deleteSchedulingPageTitle$4 = "Diese Terminseite löschen?";
const deleteSchedulingPageDescription$4 = "Nach Bestätigung werden diese Seite und die damit verbundenen Terminplanungslinks dauerhaft gelöscht und deaktiviert. Diese Aktion kann nicht rückgängig gemacht werden.";
const deleteSchedulingPageConfirmButton$4 = "Seite löschen";
const deleteSchedulingPageCancelButton$4 = "Abbrechen";
const schedulerEditorTitle$4 = "Planungseditor";
const allSchedulingPages$4 = "Alle Planungsseiten";
const createAndManageSchedulingPages$4 = "Erstellen und verwalten Sie Ihre Planungsseiten.";
const createNewSchedulingPageButtonText$4 = "Neu erstellen";
const pageTitle$4 = "Seitentitel";
const durationTitle$4 = "Dauer";
const loading$4 = "Wird geladen";
const required$4 = "Erforderlich";
const optional$4 = "Optional";
const loadingPagesDescription$4 = "Bitte warten Sie, während wir die Planungsseiten abrufen";
const noSchedulingPages$4 = "Keine Planungsseiten gefunden";
const createFirstSchedulingPage$4 = "Erstellen Sie Ihre erste Planungsseite";
const editSchedulingPageButtonText$4 = "Bearbeiten";
const eventInfoTab$4 = "Veranstaltungsinfo";
const availabilityTab$4 = "Verfügbarkeit";
const participantsTab$4 = "Teilnehmer";
const bookingOptionsTab$4 = "Buchungsoptionen";
const returnToCalendarView$4 = "Zurück zur Kalenderansicht";
const bookingFormTab$4 = "Buchungsformular";
const communicationsTab$4 = "Kommunikationen";
const pageStylesTab$4 = "Seitenstile";
const savingButtonText$4 = "Speichern";
const saveChangesButtonText$4 = "Änderungen speichern";
const createButtonText$4 = "Erstellen";
const timePeriod_day$4 = "Tag";
const timePeriod_week$4 = "Woche";
const timePeriod_month$4 = "Monat";
const timePeriod_year$4 = "Jahr";
const timeDuration_minute$4 = "Minute";
const timeDuration_hour$4 = "Stunde";
const eventCommunicationsTitle$4 = "Veranstaltungskommunikation";
const eventCommunicationsDescription$4 = "Richten Sie automatische Bestätigungs-E-Mails ein.";
const unsavedChangesLabel$4 = "Ungespeicherte Änderungen";
const changesSavedLabel$4 = "Änderungen gespeichert";
const fixFormErrors$4 = "Bitte korrigieren Sie die Formularfehler.";
const nylasEditorTabs$4 = {
	bookingFormError: "Buchungsformularfehler: ",
	bookingFormError_label: "Bezeichnung ist erforderlich für das Feld des Typs {{type}}.",
	bookingFormError_option: "Leere Option innerhalb von {{label}} des Typs {{type}} erkannt.",
	updateConfigError: "Fehler beim Aktualisieren der Konfiguration: ",
	createConfigError: "Fehler beim Erstellen der Konfiguration: ",
	deleteConfigError: "Fehler beim Löschen der Konfiguration: ",
	getConfigsError: "Fehler beim Abrufen der Konfigurationen: ",
	formErrorTitle: "Formularfehler"
};
const nylasEditorTabsGroup$4 = {
	eventTitleRequired: "Ereignistitel ist erforderlich.",
	eventTimeRequired: "Ereigniszeit ist erforderlich.",
	participantsRequired: "Teilnehmer sind erforderlich.",
	participantEmailRequired: "Teilnehmer-E-Mail ist erforderlich.",
	errorOccured: "Fehler beim Speichern der Änderungen.",
	createGroupEventError: "Fehler beim Erstellen des Gruppenergebnisses: ",
	updateGroupEventError: "Fehler beim Aktualisieren des Gruppenergebnisses: ",
	deleteGroupEventError: "Fehler beim Löschen des Gruppenergebnisses: ",
	importGroupEventError: "Fehler beim Importieren des Gruppenergebnisses: ",
	getGroupEventsError: "Fehler beim Abrufen der Gruppenergebnisse: "
};
const nylasListConfigurations$4 = {
	previewButtonText: "Vorschau",
	copyLinkButtonText: "Link kopieren",
	deleteButtonText: "Löschen"
};
const nylasAdditionalParticipants$4 = {
	headerTitle: "Teilnehmer",
	headerSubTitle: "Fügen Sie Personen aus Ihrem Team oder Ihrer Organisation hinzu, um an der Veranstaltung teilzunehmen.",
	organizerAsParticipant: "Teilnehmer",
	organizer: "Organisator",
	participant: "Teilnehmer",
	addParticipant_first: "Einen Teilnehmer hinzufügen",
	addParticipant_next: "Einen weiteren Teilnehmer hinzufügen",
	tooltip: {
		includeOrganizer: "Organisator einschließen",
		includeOrganizerDesc: "Der Organisator (Sie) wird in die Rundlauf-Rotation einbezogen.",
		excludeOrganizer: "Organisator ausschließen",
		excludeOrganizerDesc: "Der Organisator (Sie) wird nicht in die Rundlauf-Rotation einbezogen."
	},
	error: "Bitte fügen Sie mindestens einen Teilnehmer hinzu"
};
const nylasAvailabilityPicker$4 = {
	headerTitle: "Standard-Öffnungszeiten",
	headerSubTitle: "Legen Sie fest, wann Sie regelmäßig für Buchungen verfügbar sind.",
	tooltip: {
		desc: "Dies ist die Standardverfügbarkeit für Teilnehmer, die keine Verfügbarkeit auf der Teilnehmer-Registerkarte festgelegt haben."
	},
	selectTimezone: "Zeitzone auswählen",
	unavailable: "Nicht verfügbar",
	days: {
		SUN: "SO",
		MON: "MO",
		TUE: "DI",
		WED: "MI",
		THU: "DO",
		FRI: "FR",
		SAT: "SA"
	}
};
const nylasTimeWindowPicker = {
	errors: {
		invalid: "Ungültig"
	}
};
const nylasBookingCalendarPicker$4 = {
	headerTitle: "Kalenderbuchung",
	headerSubTitle: "Wählen Sie den Kalender aus, in dem Sie Buchungen hinzufügen möchten.",
	tooltip: {
		desc: "Der Kalender wird verwendet, um Ereignisse zu erstellen."
	},
	selectOptionLabel: "Eine Option auswählen",
	selectCalendarErrorMessage: "Bitte wählen Sie einen Kalender"
};
const nylasBookingConfirmationRedirect$4 = {
	dropdownLabel: "Wenn eine Buchung bestätigt wird",
	tooltip: {
		desc: "Sie können entweder die Standard-Bestätigungsseite anzeigen oder Benutzer auf Ihre eigene Bestätigungsseite umleiten."
	},
	redirectOption_default: "Standard-Bestätigungsseite anzeigen",
	redirectOption_custom: "Zu einer benutzerdefinierten URL umleiten"
};
const nylasBookingConfirmationType$4 = {
	dropdownLabel: "Wenn eine Buchung angefordert wird",
	tooltip: {
		desc: "Das manuelle Akzeptieren von Buchungen ermöglicht es Ihnen, jede Buchungsanfrage zu überprüfen und entweder zu akzeptieren oder abzulehnen."
	},
	bookingOption_booking: "Buchungen automatisch akzeptieren",
	bookingOption_organizerConfirmation: "Buchungen manuell akzeptieren"
};
const nylasBookingFormConfig$4 = {
	headerTitle: "Buchungsformular",
	headerSubTitle: "Fügen Sie benutzerdefinierte Felder zum Buchungsformular hinzu.",
	dropdownButtonText: "Neues Feld hinzufügen",
	addOption: "Option hinzufügen",
	allOptionsHeader: "ALLE OPTIONEN",
	fieldInTitleError: "Dieses Feld wird im Veranstaltungstitel verwendet und kann nicht entfernt werden.",
	fieldInDescriptionError: "Dieses Feld wird in der Veranstaltungsbeschreibung verwendet und kann nicht entfernt werden.",
	label: "Bezeichnung",
	defaultValue: "Standardwert",
	fieldType: {
		text: "Kurzer Text",
		multi_line_text: "Langer Text",
		email: "E-Mail",
		phone_number: "Telefonnummer",
		dropdown: "Auswahlmenü",
		radio_button: "Optionsfeld",
		checkbox: "Kontrollkästchen",
		date: "Datum",
		metadata: "Metadaten",
		multi_select: "Mehrfachauswahl"
	},
	fieldLabel: {
		your_name: "Ihr Name",
		your_email: "Ihre E-Mail",
		email: "Zusätzliche E-Mail",
		phone_number: "Telefonnummernbezeichnung",
		dropdown: "Dropdown-Bezeichnung",
		text: "Kurztextbezeichnung",
		multi_line_text: "Langtextbezeichnung",
		radio_button: "Radiobutton-Beschriftung",
		checkbox: "Checkbox-Beschriftung",
		date: "Datumsbezeichnung",
		metadata: "Metadatenbezeichnung",
		multi_select: "Mehrfachauswahl-Bezeichnung"
	}
};
const nylasBufferTime$4 = {
	headerTitle: "Pufferzeit",
	headerSubTitle: "Erfordert leere Pufferzeit vor und nach einem Ereignis.",
	tooltip: {
		desc: "Der Planer bucht die Pufferzeit nicht."
	},
	beforeBufferLabel: "Vor dem Ereignis",
	afterBufferLabel: "Nach dem Ereignis",
	minutesShort: "Min",
	previewHeader: "VORSCHAU"
};
const nylasCalendarPicker$4 = {
	calendarPickerLabel: "Wählen Sie die Kalender aus, die auf Verfügbarkeit überprüft werden sollen",
	selectAtLeastOneCalendar: "Bitte wählen Sie mindestens einen Kalender für jeden Teilnehmer."
};
const nylasCancellationPolicy$4 = {
	cancellationPolicyLabel: "Nachricht zur Stornierungsrichtlinie",
	tooltip: {
		desc: "Teilnehmer erhalten diese Nachricht, wenn sie versuchen, das Ereignis abzusagen. Sie werden gebeten, einen Grund für die Stornierung anzugeben."
	}
};
const nylasConfirmationEmail$4 = {
	headerTitle: "Buchung bestätigt{{organizerName}}",
	headerSubTitle: "Buchungsbestätigungs-E-Mail",
	editButtonText: "Bearbeiten",
	error: {
		invalidImageUrl: "Ungültige Bild-URL."
	},
	confirmationEmail: {
		label: "E-Mail-Benachrichtigungen aktivieren",
		tooltip: {
			desc: "Erlauben Sie Nylas, E-Mail-Benachrichtigungen zu senden, einschließlich Bestätigungsnachrichten und Veranstaltungserinnerungen.",
			language: "Diese Sprache wird für die E-Mail-Benachrichtigungen an die Organisatoren verwendet."
		},
		language: "Sprache auswählen"
	},
	nylasBranding: {
		label: "Nylas-Branding anzeigen",
		tooltip: {
			desc: "Deaktivieren Sie diese Option, um die Fußzeile in der E-Mail-Kommunikation auszublenden."
		}
	},
	companyLogoUrl: {
		label: "Firmenlogo-URL",
		tooltip: {
			desc: "Dieses Logo erscheint in der Buchungsbestätigungs-E-Mail. Die URL muss öffentlich zugänglich sein. Das Bild wird auf eine maximale Größe von 200px x 100px skaliert."
		}
	},
	emailMessage: {
		header: "E-Mail-Nachricht",
		label: "Benutzerdefinierter E-Mail-Titel",
		tooltip: {
			desc: "Ein E-Mail-Titel ist eine Überschrift innerhalb des E-Mail-Textes. Dies ändert nicht die Betreffzeile."
		},
		additionalInfoLabel: "Zusätzliche Informationen",
		additionalInfoTooltip: "Der Planer fügt den Inhalt dieses Felds in den E-Mail-Text ein.",
		additionalInfoPlaceholder: "Standardtext"
	},
	allHosts: "Alle Gastgeber und Gäste",
	immediatelyUponBooking: "Unmittelbar nach der Buchung"
};
const nylasConnectedCalendars$4 = {
	headerTitle: "Verknüpfte Kalender",
	headerSubTitle: "Wählen Sie die Kalender aus, die für die Verfügbarkeitsprüfung verwendet werden sollen.",
	tooltip: {
		desc: "Überprüfen Sie die Verfügbarkeit in einem oder mehreren Kalendern. Wenn Sie mehrere Kalender für einen Teilnehmer auswählen, muss der Teilnehmer in all seinen Kalendern verfügbar sein, um als verfügbar zu gelten."
	},
	participantCalendarTitle: "Verknüpfte Kalender von {{participantName}}",
	selectAtLeastOneCalendar: "Bitte wählen Sie mindestens einen Kalender für jeden Teilnehmer."
};
const nylasCustomBookingFlow$4 = {
	headerTitle: "Benutzerdefinierter Buchungsablauf"
};
const nylasCustomEventSlug$4 = {
	headerTitle: "Benutzerdefinierter Seiten-Slug",
	headerSubTitle: "Erstellen Sie einen benutzerdefinierten URL-Slug für diese Seite.",
	eventSlugLabel: "Seiten-URL-Slug",
	tooltip: {
		desc: "Geben Sie einen benutzerdefinierten Slug für Ihre URL an, um Ihre Seite eindeutig zu identifizieren (nur Buchstaben, Zahlen und Bindestriche)."
	},
	copied: "Kopiert!"
};
const nylasCustomizeBookingSettings$4 = {
	headerTitle: "Zusätzliche Einstellungen",
	headerSubTitle: "Buchungseinstellungen für das Ereignis.",
	tooltip: {
		desc: "Passen Sie Ihre Buchungseinstellungen an."
	},
	allowGuests: {
		label: "Gästen erlauben, zusätzliche Gäste einzuladen."
	},
	hideReschedule: {
		label: "Option zur Neuplanung ausblenden.",
		tooltip: {
			desc: "Blenden Sie die Schaltfläche 'Neu planen' in der Buchungsbestätigung und in E-Mail-Benachrichtigungen aus."
		}
	},
	hideCancel: {
		label: "Option zur Stornierung ausblenden",
		tooltip: {
			desc: "Blenden Sie die Schaltfläche 'Stornieren' in der Buchungsbestätigung und in E-Mail-Benachrichtigungen aus."
		}
	}
};
const nylasEventDescription$4 = {
	headerTitle: "Ereignisbeschreibung",
	addAdditionalFields: {
		buttonText: "Zusätzliche Felder automatisch ausfüllen",
		tooltip: {
			desc: "Klicken Sie hier, nachdem Sie alle Felder hinzugefügt haben, die Sie in die Beschreibung aufnehmen möchten. Wichtig: Bitte lassen Sie die Markierungen '--- Additional Fields ---' und '--- End Additional Fields ---' unverändert, damit alles korrekt funktioniert."
		}
	},
	tooltip: {
		desc: "Die Ereignisbeschreibung erscheint in der Ansicht des Planungseditors und in der Antwort, wenn eine Buchung erstellt wird."
	}
};
const nylasEventDuration$4 = {
	headerTitle: "Ereignisdauer",
	error: {
		durationMustBeMultipleOf5: "Die Dauer muss ein Vielfaches von 5 sein",
		durationMustBeGreaterThan0: "Die Dauer muss größer als 0 sein"
	}
};
const nylasEventInfo$4 = {
	headerTitle: "Ereignisinformationen"
};
const nylasEventLimits$4 = {
	headerTitle: "Ereignisbeschränkungen"
};
const nylasEventLocation$4 = {
	headerTitle: "Veranstaltungsort oder -besprechung",
	tooltip: {
		desc: "Wählen Sie eine Konferenzoption oder fügen Sie einen benutzerdefinierten Standort hinzu."
	},
	conferenceOptions: {
		none: "Keiner",
		zoom: "Zoom-Meeting",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "Individueller Standort"
	}
};
const nylasEventTitle$4 = {
	headerTitle: "Ereignistitel",
	helpText_start: "Erstellen Sie ein dynamisches, vorlagenbasiertes Ereignis {{field}}, indem Sie eingeben",
	helpText_end: "und ein Vorlagenelement auswählen.",
	title: "Titel",
	description: "Beschreibung",
	tooltip: {
		desc: "Zum Beispiel: Interview mit"
	},
	eventTitleRequired: "Ereignistitel ist erforderlich",
	eventTitleTokenDescription: {
		invitee: "Der Name des Haupteinladungsbenutzers.",
		inviteeEmail: "Die E-Mail-Adresse des Haupteinladungsbenutzers.",
		duration: "Die Dauer des Ereignisses."
	}
};
const nylasLimitFutureBookings$4 = {
	headerTitle: "Zukünftige Buchungen begrenzen",
	tooltip: {
		desc: "Die Begrenzung, wie weit in die Zukunft Buchungen vorgenommen werden können."
	}
};
const nylasMinBookingNotice$4 = {
	headerTitle: "Mindestbuchungsfrist",
	tooltip: {
		desc: "Die minimale Zeit im Voraus, die für eine neue Buchung erforderlich ist."
	}
};
const nylasMinCancellationNotice$4 = {
	headerTitle: "Mindestkündigungsfrist",
	tooltip: {
		desc: "Die minimale Zeit, die benötigt wird, um eine Buchung zu stornieren."
	}
};
const nylasPageName$4 = {
	headerTitle: "Seitenname",
	headerSubTitle: "Legen Sie den Namen der Planungsseite fest.",
	pageNameError: "Bitte geben Sie einen Seitennamen ein",
	tooltip: {
		desc: "Standardmäßig verwenden Planungsseiten Ihren Benutzernamen als Seitennamen. Der Seitenname wird oben links in der Kalenderansicht angezeigt."
	}
};
const nylasPageStyling$4 = {
	headerTitle: "Seitengestaltung und -anpassung"
};
const nylasParticipantBookingCalendars$4 = {
	headerTitle: "In diesem Kalender buchen",
	headerSubTitle: "Wählen Sie den Kalender aus, in dem Sie Veranstaltungsbuchungen hinzufügen möchten.",
	participantBookingCalendarTitle: "{{participantName}}s Buchungskalender",
	selectAtLeastOneCalendar: "Bitte wählen Sie mindestens einen Kalender für jeden Teilnehmer."
};
const nylasParticipantCustomAvailability$4 = {
	headerTitle: "Öffnungszeiten des Teilnehmers",
	headerSubTitle: "Wenn nicht festgelegt, werden die Standardöffnungszeiten verwendet, um die Verfügbarkeit dieses Teilnehmers zu berechnen.",
	participantOpenHoursTitle: "{{participantName}}s Öffnungszeiten"
};
const nylasReminderEmails$4 = {
	headerTitle: "Nächstes Meeting {{organizerName}}",
	headerSubTitle: "Erinnerung vor dem Event",
	editButtonText: "Bearbeiten",
	recipientOptions_all: "Alle Gastgeber und Gäste",
	recipientOptions_guest: "Alle Eventgäste",
	recipientOptions_host: "Nur Event-Gastgeber",
	beforeTheEvent: "vor dem Event",
	emailRecipients: {
		label: "E-Mail-Empfänger"
	},
	sendConfirmation: {
		label: "Bestätigungsmail senden, wenn",
		tooltip: {
			desc: "Die Empfänger erhalten eine Erinnerungsmail zur angegebenen Zeit vor dem Event."
		}
	},
	emailSubject: {
		label: "Betreff der E-Mail",
		placeholder: "Nächstes Meeting {{organizerName}}"
	},
	reminderMinutesValidationError: "Bitte geben Sie die Erinnerungsminuten in Vielfachen von 5 ein. Versuchen Sie es mit ",
	newReminderButtonText: "Neue Erinnerung"
};
const nylasSchedulingMethod$4 = {
	headerTitle: "Planungsmethode",
	headerSubTitle: "Wählen Sie eine Planungsmethode für das Event aus.",
	tooltip: {
		standard: {
			label: "Standard",
			desc: "Ermöglicht 1:1-Buchungen oder n:1-Buchungen mit zusätzlichen Teilnehmern."
		},
		maxFairness: {
			label: "Rundlauf - Maximale Fairness",
			desc: "Rotiert durch die Liste der ausgewählten Teilnehmer und zeigt den Teilnehmer mit den wenigsten Buchungen an."
		},
		maxAvailability: {
			label: "Rundlauf - Maximale Verfügbarkeit",
			desc: "Rotiert durch die Liste der ausgewählten Teilnehmer und priorisiert diejenigen mit den wenigsten Buchungen, bietet jedoch so viele Zeitslots wie möglich an."
		}
	},
	schedulingMethodOptions_collective: "Standardbuchung",
	schedulingMethodOptions_maxFairness: "Rundlauf - Maximale Fairness",
	schedulingMethodOptions_maxAvailability: "Rundlauf - Maximale Verfügbarkeit"
};
const nylasTimeslotInterval$4 = {
	minutesShort: "Mins",
	lengthOfMeeting: "Dauer Der Buchung",
	headerTitle: "Zeitfenster-Einstellungen",
	timeslotInterval: {
		label: "Zeitfenster-Intervall."
	},
	timeslotRounding: {
		label: "Zeitfenster-Rundungstyp",
		tooltip: {
			desc: "Das Intervall, in dem Zeitfenster angezeigt werden."
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "Intervall-Rundung",
			desc: "Zeitfenster beginnen zu Zeiten, die auf den Intervallwert gerundet sind."
		},
		noRounding: {
			label: "Standard",
			desc: "Zeitfenster werden auf die nächste Viertelstunde gerundet."
		}
	}
};
const nylasEventTimeslot$4 = {
	recurrenceOptions: {
		none: "Wiederholt sich nicht",
		daily: "Täglich",
		weekly: "Wöchentlich jeden {{dayOfWeek}}",
		monthly: "Monatlich am {{dayOfMonth}}",
		monthOnDay: "Monatlich am Tag {{date}}",
		yearly: "Jährlich am {{dateOfMonth}}",
		custom: "Benutzerdefiniert"
	},
	recurrenceLabel: "Wiederhole dieses Ereignis",
	endDate: "Enddatum",
	customRecurrence: {
		repeatEvery: "Wiederhole alle",
		repeatOn: "Wiederhole am",
		ends: "Endet",
		endsOptions: {
			never: "Nie",
			after: "Nach",
			on: "Am"
		},
		occurrences: "Vorkommen"
	},
	dateTimeLabel: "Datum und Uhrzeit",
	errors: {
		invalidTimeRange: "Ungültige Zeitspanne",
		startTimeSameAsEndTime: "Startzeit und Endzeit können nicht gleich sein",
		startTimeBeforeCurrentDate: "Startzeit kann nicht in der Vergangenheit liegen",
		invalid: "Ungültig"
	}
};
const nylasEventCapacity$4 = {
	headerTitle: "Teilnehmer",
	headerSubTitle: "Legen Sie die maximale Anzahl von Teilnehmern für diesen Ereignis-Zeitblock fest.",
	tooltip: {
		desc: "Der Organisator und die auf der Planungsseite konfigurierten Teilnehmer werden nicht als Teilnehmer gezählt."
	},
	attendees: "Teilnehmer"
};
const nylasSelectEventType$4 = {
	returnToAllSchedulingPages: "Zurück zur Planungsseite",
	createEventHeaderTitle: "Ereignis erstellen",
	eventTypeHeaderTitle: "Ereignisart",
	noEventTypesEnabled: "Keine Ereignisarten aktiviert",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "Erlaubt 1:1-Buchungen"
		},
		collective: {
			label: "Standardbuchung",
			desc: "Erlaubt n:1-Buchungen mit zusätzlichen Teilnehmern"
		},
		maxFairness: {
			label: "Rundlauf-Rotation - Maximale Fairness",
			desc: "Rotiert durch die Liste der ausgewählten Teilnehmer und zeigt den Teilnehmer mit den wenigsten Buchungen an."
		},
		maxAvailability: {
			label: "Rundlauf-Rotation - Maximale Verfügbarkeit",
			desc: "Rotiert durch die Liste der ausgewählten Teilnehmer und priorisiert diejenigen mit den wenigsten Buchungen, bietet jedoch so viele Zeitslots wie möglich an."
		},
		group: {
			label: "Gruppenbuchung",
			desc: "Diese sind Ereignisse, die in der Regel einen Organisator und mehrere Teilnehmer haben."
		}
	}
};
const pageSettingsButton$4 = "Seiteneinstellungen";
const nylasEventCalendar$4 = {
	hideNonGroupEvents: {
		showLabel: "Ereignisse filtern",
		tooltip: {
			desc: "Wählen Sie die Art der Ereignisse, die im Kalender angezeigt werden sollen."
		},
		options: {
			all: "Alle",
			group: "Nur Gruppen"
		}
	},
	createEventDetails: {
		headerTitle: "Ereignisdetails",
		closeButtonTooltip: "Schließen",
		cancelButton: "Abbrechen",
		createButton: "Erstellen"
	},
	discardChanges: {
		headerTitle: "Nicht gespeicherte Änderungen verwerfen?",
		cancelButton: "Abbrechen",
		discardButton: "Entfernen"
	},
	unsavedChanges: "Ungespeicherte Änderungen",
	editEventDetails: {
		headerTitle: "Ereignisdetails",
		closeButtonTooltip: "Schließen",
		deleteButton: "Löschen",
		saveButton: "Speichern",
		pastEventTooltip: "Dieses Ereignis ist in der Vergangenheit und kann nicht bearbeitet werden."
	},
	importEvent: {
		closeButtonTooltip: "Schließen",
		importButton: "Importieren",
		participantsLabel: "Teilnehmer"
	},
	deleteEvent: {
		closeButtonTooltip: "Schließen",
		deleting: "Löschen..."
	},
	editOptions: {
		headerTitle: "Aktionen",
		closeButtonTooltip: "Schließen",
		deleting: "Löschen...",
		"import": "Importieren",
		edit: "Bearbeiten",
		deleteThis: "Dieses Ereignis nur löschen",
		deleteAll: "Alle Ereignisse löschen",
		importTooltip: "Erlaubt das Auswählen vorhandener Ereignisse aus einem Kalender und das Konfigurieren als Gruppenereignisse"
	},
	updateOptions: {
		updateThis: "Aktualisieren",
		updateAll: "Alle Ereignisse aktualisieren",
		updateFuture: "Alle zukünftigen Vorkommen aktualisieren"
	},
	deleteOptions: {
		deleteThis: "Löschen",
		deleteFuture: "Löschen und alle zukünftigen Vorkommen",
		deleteAll: "Alle Ereignisse löschen"
	}
};
const de$1 = {
	noDateSelected: noDateSelected$4,
	rescheduleTitle: rescheduleTitle$4,
	allDay: allDay$4,
	today: today$4,
	spotsLeft: spotsLeft$4,
	search: search$4,
	selectOneOrMoreOptions: selectOneOrMoreOptions$4,
	days: days$4,
	time: time$4,
	months: months$4,
	multipleOptionsSelected: multipleOptionsSelected$4,
	selectAtLeastOneOption: selectAtLeastOneOption$4,
	nextButton: nextButton$4,
	selectedDayAndYear: selectedDayAndYear$4,
	selectedTime: selectedTime$4,
	name: name$4,
	namePlaceholder: namePlaceholder$4,
	email: email$4,
	emailPlaceholder: emailPlaceholder$4,
	guestEmail: guestEmail$4,
	guestEmailPlaceholder: guestEmailPlaceholder$4,
	addGuest: addGuest$4,
	addAnotherGuest: addAnotherGuest$4,
	backButton: backButton$4,
	bookNowButton: bookNowButton$4,
	bookingConfirmed: bookingConfirmed$4,
	bookingConfirmedDescription: bookingConfirmedDescription$4,
	bookingSent: bookingSent$4,
	bookingSentDescription: bookingSentDescription$4,
	bookingRescheduled: bookingRescheduled$4,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$4,
	cancelBookingButton: cancelBookingButton$4,
	rescheduleBookingButton: rescheduleBookingButton$4,
	rejectBookingButton: rejectBookingButton$4,
	confirmBookingButton: confirmBookingButton$4,
	bookingPendingTitle: bookingPendingTitle$4,
	bookingPendingnDescription: bookingPendingnDescription$4,
	confirmedEventCardTitle: confirmedEventCardTitle$4,
	confirmedEventCardDescription: confirmedEventCardDescription$4,
	cancelBookingTitle: cancelBookingTitle$4,
	cancelBookingMessage: cancelBookingMessage$4,
	reasonForCancellation: reasonForCancellation$4,
	goBackButton: goBackButton$4,
	bookingCancelledTitle: bookingCancelledTitle$4,
	bookingCancelledMessage: bookingCancelledMessage$4,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$4,
	closeButton: closeButton$4,
	closingButton: closingButton$4,
	fieldRequired: fieldRequired$4,
	invalidInputFormat: invalidInputFormat$4,
	createBookingErrorTitle: createBookingErrorTitle$4,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$4,
	cancelBookingErrorTitle: cancelBookingErrorTitle$4,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$4,
	getUISettingErrorTitle: getUISettingErrorTitle$4,
	rejectBookingErrorTitle: rejectBookingErrorTitle$4,
	confirmBookingErrorTitle: confirmBookingErrorTitle$4,
	genericErrorTitle: genericErrorTitle$4,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$4,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$4,
	publicConfigErrorMessage: publicConfigErrorMessage$4,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$3,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$4,
	cancellationErrorTitle: cancellationErrorTitle$4,
	cancellationErrorMessage: cancellationErrorMessage$4,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$4,
	cancelBokingFormError: cancelBokingFormError$4,
	feedbackFormTitle: feedbackFormTitle$4,
	feedbackFormDescription: feedbackFormDescription$4,
	feedbackMessageLabel: feedbackMessageLabel$4,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$4,
	feedbackModalCloseButton: feedbackModalCloseButton$4,
	feedbackModalSubmitButton: feedbackModalSubmitButton$4,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$4,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$4,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$4,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$4,
	schedulerEditorTitle: schedulerEditorTitle$4,
	allSchedulingPages: allSchedulingPages$4,
	createAndManageSchedulingPages: createAndManageSchedulingPages$4,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$4,
	pageTitle: pageTitle$4,
	durationTitle: durationTitle$4,
	loading: loading$4,
	required: required$4,
	optional: optional$4,
	loadingPagesDescription: loadingPagesDescription$4,
	noSchedulingPages: noSchedulingPages$4,
	createFirstSchedulingPage: createFirstSchedulingPage$4,
	editSchedulingPageButtonText: editSchedulingPageButtonText$4,
	eventInfoTab: eventInfoTab$4,
	availabilityTab: availabilityTab$4,
	participantsTab: participantsTab$4,
	bookingOptionsTab: bookingOptionsTab$4,
	returnToCalendarView: returnToCalendarView$4,
	bookingFormTab: bookingFormTab$4,
	communicationsTab: communicationsTab$4,
	pageStylesTab: pageStylesTab$4,
	savingButtonText: savingButtonText$4,
	saveChangesButtonText: saveChangesButtonText$4,
	createButtonText: createButtonText$4,
	timePeriod_day: timePeriod_day$4,
	timePeriod_week: timePeriod_week$4,
	timePeriod_month: timePeriod_month$4,
	timePeriod_year: timePeriod_year$4,
	timeDuration_minute: timeDuration_minute$4,
	timeDuration_hour: timeDuration_hour$4,
	eventCommunicationsTitle: eventCommunicationsTitle$4,
	eventCommunicationsDescription: eventCommunicationsDescription$4,
	unsavedChangesLabel: unsavedChangesLabel$4,
	changesSavedLabel: changesSavedLabel$4,
	fixFormErrors: fixFormErrors$4,
	nylasEditorTabs: nylasEditorTabs$4,
	nylasEditorTabsGroup: nylasEditorTabsGroup$4,
	nylasListConfigurations: nylasListConfigurations$4,
	nylasAdditionalParticipants: nylasAdditionalParticipants$4,
	nylasAvailabilityPicker: nylasAvailabilityPicker$4,
	nylasTimeWindowPicker: nylasTimeWindowPicker,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$4,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$4,
	nylasBookingConfirmationType: nylasBookingConfirmationType$4,
	nylasBookingFormConfig: nylasBookingFormConfig$4,
	nylasBufferTime: nylasBufferTime$4,
	nylasCalendarPicker: nylasCalendarPicker$4,
	nylasCancellationPolicy: nylasCancellationPolicy$4,
	nylasConfirmationEmail: nylasConfirmationEmail$4,
	nylasConnectedCalendars: nylasConnectedCalendars$4,
	nylasCustomBookingFlow: nylasCustomBookingFlow$4,
	nylasCustomEventSlug: nylasCustomEventSlug$4,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$4,
	nylasEventDescription: nylasEventDescription$4,
	nylasEventDuration: nylasEventDuration$4,
	nylasEventInfo: nylasEventInfo$4,
	nylasEventLimits: nylasEventLimits$4,
	nylasEventLocation: nylasEventLocation$4,
	nylasEventTitle: nylasEventTitle$4,
	nylasLimitFutureBookings: nylasLimitFutureBookings$4,
	nylasMinBookingNotice: nylasMinBookingNotice$4,
	nylasMinCancellationNotice: nylasMinCancellationNotice$4,
	nylasPageName: nylasPageName$4,
	nylasPageStyling: nylasPageStyling$4,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$4,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$4,
	nylasReminderEmails: nylasReminderEmails$4,
	nylasSchedulingMethod: nylasSchedulingMethod$4,
	nylasTimeslotInterval: nylasTimeslotInterval$4,
	nylasEventTimeslot: nylasEventTimeslot$4,
	nylasEventCapacity: nylasEventCapacity$4,
	nylasSelectEventType: nylasSelectEventType$4,
	pageSettingsButton: pageSettingsButton$4,
	nylasEventCalendar: nylasEventCalendar$4
};

const deTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$4,
  rescheduleTitle: rescheduleTitle$4,
  allDay: allDay$4,
  today: today$4,
  spotsLeft: spotsLeft$4,
  search: search$4,
  selectOneOrMoreOptions: selectOneOrMoreOptions$4,
  days: days$4,
  time: time$4,
  months: months$4,
  multipleOptionsSelected: multipleOptionsSelected$4,
  selectAtLeastOneOption: selectAtLeastOneOption$4,
  nextButton: nextButton$4,
  selectedDayAndYear: selectedDayAndYear$4,
  selectedTime: selectedTime$4,
  name: name$4,
  namePlaceholder: namePlaceholder$4,
  email: email$4,
  emailPlaceholder: emailPlaceholder$4,
  guestEmail: guestEmail$4,
  guestEmailPlaceholder: guestEmailPlaceholder$4,
  addGuest: addGuest$4,
  addAnotherGuest: addAnotherGuest$4,
  backButton: backButton$4,
  bookNowButton: bookNowButton$4,
  bookingConfirmed: bookingConfirmed$4,
  bookingConfirmedDescription: bookingConfirmedDescription$4,
  bookingSent: bookingSent$4,
  bookingSentDescription: bookingSentDescription$4,
  bookingRescheduled: bookingRescheduled$4,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$4,
  cancelBookingButton: cancelBookingButton$4,
  rescheduleBookingButton: rescheduleBookingButton$4,
  rejectBookingButton: rejectBookingButton$4,
  confirmBookingButton: confirmBookingButton$4,
  bookingPendingTitle: bookingPendingTitle$4,
  bookingPendingnDescription: bookingPendingnDescription$4,
  confirmedEventCardTitle: confirmedEventCardTitle$4,
  confirmedEventCardDescription: confirmedEventCardDescription$4,
  cancelBookingTitle: cancelBookingTitle$4,
  cancelBookingMessage: cancelBookingMessage$4,
  reasonForCancellation: reasonForCancellation$4,
  goBackButton: goBackButton$4,
  bookingCancelledTitle: bookingCancelledTitle$4,
  bookingCancelledMessage: bookingCancelledMessage$4,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$4,
  closeButton: closeButton$4,
  closingButton: closingButton$4,
  fieldRequired: fieldRequired$4,
  invalidInputFormat: invalidInputFormat$4,
  createBookingErrorTitle: createBookingErrorTitle$4,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$4,
  cancelBookingErrorTitle: cancelBookingErrorTitle$4,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$4,
  getUISettingErrorTitle: getUISettingErrorTitle$4,
  rejectBookingErrorTitle: rejectBookingErrorTitle$4,
  confirmBookingErrorTitle: confirmBookingErrorTitle$4,
  genericErrorTitle: genericErrorTitle$4,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$4,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$4,
  publicConfigErrorMessage: publicConfigErrorMessage$4,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$3,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$4,
  cancellationErrorTitle: cancellationErrorTitle$4,
  cancellationErrorMessage: cancellationErrorMessage$4,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$4,
  cancelBokingFormError: cancelBokingFormError$4,
  feedbackFormTitle: feedbackFormTitle$4,
  feedbackFormDescription: feedbackFormDescription$4,
  feedbackMessageLabel: feedbackMessageLabel$4,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$4,
  feedbackModalCloseButton: feedbackModalCloseButton$4,
  feedbackModalSubmitButton: feedbackModalSubmitButton$4,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$4,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$4,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$4,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$4,
  schedulerEditorTitle: schedulerEditorTitle$4,
  allSchedulingPages: allSchedulingPages$4,
  createAndManageSchedulingPages: createAndManageSchedulingPages$4,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$4,
  pageTitle: pageTitle$4,
  durationTitle: durationTitle$4,
  loading: loading$4,
  required: required$4,
  optional: optional$4,
  loadingPagesDescription: loadingPagesDescription$4,
  noSchedulingPages: noSchedulingPages$4,
  createFirstSchedulingPage: createFirstSchedulingPage$4,
  editSchedulingPageButtonText: editSchedulingPageButtonText$4,
  eventInfoTab: eventInfoTab$4,
  availabilityTab: availabilityTab$4,
  participantsTab: participantsTab$4,
  bookingOptionsTab: bookingOptionsTab$4,
  returnToCalendarView: returnToCalendarView$4,
  bookingFormTab: bookingFormTab$4,
  communicationsTab: communicationsTab$4,
  pageStylesTab: pageStylesTab$4,
  savingButtonText: savingButtonText$4,
  saveChangesButtonText: saveChangesButtonText$4,
  createButtonText: createButtonText$4,
  timePeriod_day: timePeriod_day$4,
  timePeriod_week: timePeriod_week$4,
  timePeriod_month: timePeriod_month$4,
  timePeriod_year: timePeriod_year$4,
  timeDuration_minute: timeDuration_minute$4,
  timeDuration_hour: timeDuration_hour$4,
  eventCommunicationsTitle: eventCommunicationsTitle$4,
  eventCommunicationsDescription: eventCommunicationsDescription$4,
  unsavedChangesLabel: unsavedChangesLabel$4,
  changesSavedLabel: changesSavedLabel$4,
  fixFormErrors: fixFormErrors$4,
  nylasEditorTabs: nylasEditorTabs$4,
  nylasEditorTabsGroup: nylasEditorTabsGroup$4,
  nylasListConfigurations: nylasListConfigurations$4,
  nylasAdditionalParticipants: nylasAdditionalParticipants$4,
  nylasAvailabilityPicker: nylasAvailabilityPicker$4,
  nylasTimeWindowPicker: nylasTimeWindowPicker,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$4,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$4,
  nylasBookingConfirmationType: nylasBookingConfirmationType$4,
  nylasBookingFormConfig: nylasBookingFormConfig$4,
  nylasBufferTime: nylasBufferTime$4,
  nylasCalendarPicker: nylasCalendarPicker$4,
  nylasCancellationPolicy: nylasCancellationPolicy$4,
  nylasConfirmationEmail: nylasConfirmationEmail$4,
  nylasConnectedCalendars: nylasConnectedCalendars$4,
  nylasCustomBookingFlow: nylasCustomBookingFlow$4,
  nylasCustomEventSlug: nylasCustomEventSlug$4,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$4,
  nylasEventDescription: nylasEventDescription$4,
  nylasEventDuration: nylasEventDuration$4,
  nylasEventInfo: nylasEventInfo$4,
  nylasEventLimits: nylasEventLimits$4,
  nylasEventLocation: nylasEventLocation$4,
  nylasEventTitle: nylasEventTitle$4,
  nylasLimitFutureBookings: nylasLimitFutureBookings$4,
  nylasMinBookingNotice: nylasMinBookingNotice$4,
  nylasMinCancellationNotice: nylasMinCancellationNotice$4,
  nylasPageName: nylasPageName$4,
  nylasPageStyling: nylasPageStyling$4,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$4,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$4,
  nylasReminderEmails: nylasReminderEmails$4,
  nylasSchedulingMethod: nylasSchedulingMethod$4,
  nylasTimeslotInterval: nylasTimeslotInterval$4,
  nylasEventTimeslot: nylasEventTimeslot$4,
  nylasEventCapacity: nylasEventCapacity$4,
  nylasSelectEventType: nylasSelectEventType$4,
  pageSettingsButton: pageSettingsButton$4,
  nylasEventCalendar: nylasEventCalendar$4,
  'default': de$1
});

const noDateSelected$3 = "Ingen dag vald";
const rescheduleTitle$3 = "Välj en annan tid för att boka om din tid";
const allDay$3 = "Alla dagar";
const today$3 = "Idag";
const spotsLeft$3 = "{{count}} platser kvar";
const search$3 = "Sök";
const selectOneOrMoreOptions$3 = "Välj minst en alternativ";
const days$3 = {
	sunday: "SÖN",
	monday: "MÅN",
	tuesday: "TIS",
	wednesday: "ONS",
	thursday: "TOR",
	friday: "FRE",
	saturday: "LÖR"
};
const time$3 = {
	hour: "timme",
	hours: "timmar",
	minute: "minut",
	minutes: "minuter",
	day: "dag",
	days: "dagar",
	week: "vecka",
	weeks: "veckor",
	month: "månad",
	months: "månader",
	year: "år",
	years: "år"
};
const months$3 = {
	january: "Januari",
	february: "Februari",
	march: "Mars",
	april: "April",
	may: "Maj",
	june: "Juni",
	july: "Juli",
	august: "Augusti",
	september: "September",
	october: "Oktober",
	november: "November",
	december: "December"
};
const multipleOptionsSelected$3 = "Flera val";
const selectAtLeastOneOption$3 = "Vänligen välj minst ett alternativ";
const nextButton$3 = "Nästa";
const selectedDayAndYear$3 = "{{date}}";
const selectedTime$3 = "{{time}}";
const name$3 = "Namn";
const namePlaceholder$3 = "Ange ditt namn";
const email$3 = "E-post";
const emailPlaceholder$3 = "Ange din e-postadress";
const guestEmail$3 = "Gästens e-post";
const guestEmailPlaceholder$3 = "Ange gästens e-postadress";
const addGuest$3 = "Lägg till gäst";
const addAnotherGuest$3 = "Lägg till en gäst till";
const backButton$3 = "Tillbaka";
const bookNowButton$3 = "Boka nu";
const bookingConfirmed$3 = "Bokning bekräftad";
const bookingConfirmedDescription$3 = "Du kommer snart att få en bekräftelse via e-post.";
const bookingSent$3 = "Bokning skickad";
const bookingSentDescription$3 = "Du kommer att få ett e-mail när bokningen är bekräftad.";
const bookingRescheduled$3 = "Bokning ombokad";
const bookingDateAndTimeHeader$3 = "Bokningsdatum och tid";
const cancelBookingButton$3 = "Avboka bokning";
const rescheduleBookingButton$3 = "Omboka";
const rejectBookingButton$3 = "Avvisa bokning";
const confirmBookingButton$3 = "Bekräfta bokning";
const bookingPendingTitle$3 = "Bokning pågår";
const bookingPendingnDescription$3 = "Hantera din bokning nedan. Inbjudna kommer att få ett e-postmeddelande om begärans status.";
const confirmedEventCardTitle$3 = "Din bokning har bekräftats framgångsrikt";
const confirmedEventCardDescription$3 = "Ett bekräftelsemail har skickats till";
const cancelBookingTitle$3 = "Avboka bokning?";
const cancelBookingMessage$3 = "Din nuvarande tidslucka kommer att bli tillgänglig för andra.";
const reasonForCancellation$3 = "Anledning till avbokning";
const goBackButton$3 = "Gå tillbaka";
const bookingCancelledTitle$3 = "Din bokning har avbokats framgångsrikt";
const bookingCancelledMessage$3 = "Ett avbokningsmejl har skickats till";
const bookingCancelledMessage_theParticipants$3 = "deltagarna";
const closeButton$3 = "Stäng";
const closingButton$3 = "Stänger";
const fieldRequired$3 = "{{field}} är obligatoriskt.";
const invalidInputFormat$3 = "{{field}} har ogiltigt format.";
const createBookingErrorTitle$3 = "Skapa Bokning";
const getAvailabilityErrorTitle$3 = "Hämta Tillgänglighet";
const cancelBookingErrorTitle$3 = "Avboka Bokning";
const rescheduleBookingErrorTitle$3 = "Omboka Bokning";
const getUISettingErrorTitle$3 = "Hämta UI-inställningar";
const rejectBookingErrorTitle$3 = "Avvisa Bokning";
const confirmBookingErrorTitle$3 = "Bekräfta Bokning";
const genericErrorTitle$3 = "Något gick fel...";
const schedulingComponentErrorTitle$3 = "Schemaläggningskomponentfel";
const sessionIdRequiredErrorMessage$3 = "'sessionId' krävs för privata konfigurationer.";
const publicConfigErrorMessage$3 = "Om du använder offentlig konfiguration anger du antingen en konfigurations-ID eller en kombination av 'slug' och 'clientId'.";
const invalidTimeslotErrorTitle$2 = "Ogiltig tidslucka!";
const invalidTimeslotErrorMessage$3 = "Den valda tidsluckan är ogiltig";
const cancellationErrorTitle$3 = "Avbokningsfel";
const cancellationErrorMessage$3 = "Vänligen ange en anledning till avbokningen.";
const minimumCancellationErrorMessage$3 = "Du kan inte avboka bokningen inom {{minCancellationNotice}} minuter före evenemanget";
const cancelBokingFormError$3 = "Fel i avbokningsformuläret";
const feedbackFormTitle$3 = "Dela din feedback";
const feedbackFormDescription$3 = "Att ge oss din feedback och rapportera fel hjälper oss att skapa en bättre upplevelse för dig.";
const feedbackMessageLabel$3 = "Ge oss en detaljerad beskrivning av funktionen du kommenterar eller där du har upplevt ett problem.";
const feedbackMessagePlaceholder$3 = "Ge din feedback här";
const feedbackModalCloseButton$3 = "Avbryt";
const feedbackModalSubmitButton$3 = "Skicka";
const deleteSchedulingPageTitle$3 = "Ta bort denna schemaläggningssida?";
const deleteSchedulingPageDescription$3 = "Efter bekräftelse kommer denna sida och dess anslutna schemaläggningslänkar att raderas och inaktiveras permanent. Denna åtgärd kan inte ångras.";
const deleteSchedulingPageConfirmButton$3 = "Ta bort sida";
const deleteSchedulingPageCancelButton$3 = "Avbryt";
const schedulerEditorTitle$3 = "Schemaläggningsredigerare";
const allSchedulingPages$3 = "Alla schemaläggningssidor";
const createAndManageSchedulingPages$3 = "Skapa och hantera dina schemaläggningssidor.";
const createNewSchedulingPageButtonText$3 = "Skapa ny";
const pageTitle$3 = "Sidrubrik";
const durationTitle$3 = "Varaktighet";
const loading$3 = "Laddar";
const required$3 = "Obligatorisk";
const optional$3 = "Valfritt";
const loadingPagesDescription$3 = "Vänta medan vi hämtar schemaläggningssidorna";
const noSchedulingPages$3 = "Inga schemaläggningssidor hittades";
const createFirstSchedulingPage$3 = "Kom igång genom att skapa din första schemaläggningssida";
const editSchedulingPageButtonText$3 = "Redigera";
const eventInfoTab$3 = "Händelseinfo";
const availabilityTab$3 = "Tillgänglighet";
const participantsTab$3 = "Deltagare";
const bookingOptionsTab$3 = "Bokningsalternativ";
const returnToCalendarView$3 = "Tillbaka till kalender";
const bookingFormTab$3 = "Bokningsformulär";
const communicationsTab$3 = "Kommunikation";
const pageStylesTab$3 = "Sidstilar";
const savingButtonText$3 = "Sparar";
const saveChangesButtonText$3 = "Spara ändringar";
const createButtonText$3 = "Skapa";
const timePeriod_day$3 = "dag";
const timePeriod_week$3 = "vecka";
const timePeriod_month$3 = "månad";
const timePeriod_year$3 = "år";
const timeDuration_minute$3 = "minut";
const timeDuration_hour$3 = "timme";
const eventCommunicationsTitle$3 = "Evenemangskommunikation";
const eventCommunicationsDescription$3 = "Ställ in automatiska bekräftelsemejl.";
const unsavedChangesLabel$3 = "Osparade ändringar";
const changesSavedLabel$3 = "Ändringar sparade";
const fixFormErrors$3 = "Vänligen korrigera formulärfelet.";
const nylasEditorTabs$3 = {
	bookingFormError: "Bokningsformulärfelet: ",
	bookingFormError_label: "Etikett krävs för fältet av typ {{type}}.",
	bookingFormError_option: "Tomt alternativ identifierat inom {{label}} av typ {{type}}.",
	formErrorTitle: "Formulärfel",
	updateConfigError: "Uppdateringsfel: ",
	deleteConfigError: "Ta bort konfigurationsfel: ",
	createConfigError: "Skapandefel: ",
	getConfigsError: "Hämta konfigurationer fel: "
};
const nylasEditorTabsGroup$3 = {
	eventTitleRequired: "Evenemangstitel krävs.",
	eventTimeRequired: "Evenemangstid krävs.",
	participantsRequired: "Deltagare krävs.",
	participantEmailRequired: "Deltagarens e-post krävs.",
	errorOccured: "Fel uppstod vid sparandet av ändringarna.",
	createGroupEventError: "Fel uppstod vid skapandet av gruppresultatet: ",
	updateGroupEventError: "Fel uppstod vid uppdateringen av gruppresultatet: ",
	deleteGroupEventError: "Fel uppstod vid borttagning av gruppresultatet: ",
	importGroupEventError: "Importgruppensergebnisfel: ",
	getGroupEventsError: "Fel uppstod vid hämtning av gruppresultat: "
};
const nylasListConfigurations$3 = {
	previewButtonText: "Förhandsgranska",
	copyLinkButtonText: "Kopiera länk",
	deleteButtonText: "Ta bort"
};
const nylasAdditionalParticipants$3 = {
	headerTitle: "Deltagare",
	headerSubTitle: "Lägg till personer i ditt team eller organisation för att delta i evenemanget.",
	organizerAsParticipant: "Deltagare",
	organizer: "Arrangör",
	participant: "Deltagare",
	addParticipant_first: "Lägg till en deltagare",
	addParticipant_next: "Lägg till en annan deltagare",
	tooltip: {
		includeOrganizer: "Inkludera arrangör",
		includeOrganizerDesc: "Arrangören (du) kommer att inkluderas i rotationsschemat.",
		excludeOrganizer: "Exkludera arrangör",
		excludeOrganizerDesc: "Arrangören (du) kommer inte att inkluderas i rotationsschemat."
	},
	error: "Vänligen lägg till minst en deltagare"
};
const nylasAvailabilityPicker$3 = {
	headerTitle: "Standard öppettider",
	headerSubTitle: "Ange när du regelbundet är tillgänglig för bokningar.",
	tooltip: {
		desc: "Detta är standardtillgängligheten för deltagare som inte har angett tillgänglighet på deltagarfliken."
	},
	selectTimezone: "Välj tidszon",
	unavailable: "Inte tillgänglig",
	days: {
		SUN: "SÖN",
		MON: "MÅN",
		TUE: "TIS",
		WED: "ONS",
		THU: "TOR",
		FRI: "FRE",
		SAT: "LÖR"
	},
	errors: {
		invalid: "Ogiltigt"
	}
};
const nylasBookingCalendarPicker$3 = {
	headerTitle: "Kalenderbokning",
	headerSubTitle: "Välj kalendern där du vill lägga till bokningar.",
	tooltip: {
		desc: "Kalendern används för att skapa händelser."
	},
	selectOptionLabel: "Välj ett alternativ",
	selectCalendarErrorMessage: "Vänligen välj en kalender"
};
const nylasBookingConfirmationRedirect$3 = {
	dropdownLabel: "När en bokning har bekräftats",
	tooltip: {
		desc: "Du kan antingen visa standardsidan för bekräftelse eller omdirigera användare till din egen bekräftelsesida."
	},
	redirectOption_default: "Visa standardsidan för bekräftelse",
	redirectOption_custom: "Omdirigera till anpassad URL"
};
const nylasBookingConfirmationType$3 = {
	dropdownLabel: "När en bokning begärs",
	tooltip: {
		desc: "Manuell godkännande av bokningar låter dig granska och antingen acceptera eller neka varje bokningsförfrågan."
	},
	bookingOption_booking: "Godkänn bokningar automatiskt",
	bookingOption_organizerConfirmation: "Godkänn bokningar manuellt"
};
const nylasBookingFormConfig$3 = {
	headerTitle: "Bokningsformulär",
	headerSubTitle: "Lägg till anpassade fält i bokningsformuläret.",
	dropdownButtonText: "Lägg till nytt fält",
	addOption: "Lägg till ett alternativ",
	allOptionsHeader: "ALLA ALTERNATIV",
	fieldInTitleError: "Detta fält används i evenemangstiteln och kan inte tas bort.",
	fieldInDescriptionError: "Detta fält används i evenemangsbeskrivningen och kan inte tas bort.",
	label: "Etikett",
	defaultValue: "Standardvärde",
	fieldType: {
		text: "Kort text",
		multi_line_text: "Lång text",
		email: "E-post",
		phone_number: "Telefonnummer",
		dropdown: "Rullgardinsmeny",
		radio_button: "Radioknapp",
		checkbox: "Kryssruta",
		date: "Datum",
		metadata: "Metadata",
		multi_select: "Flera urval"
	},
	fieldLabel: {
		your_name: "Ditt namn",
		your_email: "Din e-post",
		email: "Ytterligare e-post",
		phone_number: "Telefonnummer etikett",
		dropdown: "Rullgardinsmeny etikett",
		text: "Kort text etikett",
		multi_line_text: "Lång text etikett",
		radio_button: "Radioknapp etikett",
		checkbox: "Kryssruta etikett",
		date: "Datum etikett",
		metadata: "Metadata etikett",
		multi_select: "Flera urval etikett"
	}
};
const nylasBufferTime$3 = {
	headerTitle: "Buffertid",
	headerSubTitle: "Kräver tom buffertid före och efter ett evenemang.",
	tooltip: {
		desc: "Schemaläggaren bokar inte bufferttiden."
	},
	beforeBufferLabel: "Före evenemanget",
	afterBufferLabel: "Efter evenemanget",
	minutesShort: "min",
	previewHeader: "FÖRHANDSVISNING"
};
const nylasCalendarPicker$3 = {
	calendarPickerLabel: "Välj kalendrar som ska kontrolleras för tillgänglighet",
	selectAtLeastOneCalendar: "Vänligen välj minst en kalender för varje deltagare."
};
const nylasCancellationPolicy$3 = {
	cancellationPolicyLabel: "Meddelande om avbokningspolicy",
	tooltip: {
		desc: "Deltagarna får detta meddelande om de försöker avboka evenemanget. De ombeds ange en anledning till avbokningen."
	}
};
const nylasConfirmationEmail$3 = {
	headerTitle: "Bokning bekräftad{{organizerName}}",
	headerSubTitle: "Bekräftelsemail för bokning",
	editButtonText: "Redigera",
	error: {
		invalidImageUrl: "Ogiltig bild-URL."
	},
	confirmationEmail: {
		label: "Aktivera e-postmeddelanden",
		tooltip: {
			desc: "Tillåt Nylas att skicka e-postmeddelanden, inklusive bekräftelsemeddelanden och påminnelser om evenemang.",
			language: "Denna språk kommer att användas för e-postmeddelanden till arrangörerna."
		},
		language: "Välj språk"
	},
	nylasBranding: {
		label: "Visa Nylas-varumärke",
		tooltip: {
			desc: "Avmarkera detta för att dölja sidfoten i e-postkommunikationen."
		}
	},
	companyLogoUrl: {
		label: "Företagslogotyp-URL",
		tooltip: {
			desc: "Denna logotyp visas i bokningsbekräftelsemail. URL:en måste vara offentligt tillgänglig. Bilden kommer att skalas ner till en maximal storlek på 200px x 100px."
		}
	},
	emailMessage: {
		header: "E-postmeddelande",
		label: "Anpassad e-posttitel",
		tooltip: {
			desc: "En e-posttitel är en rubrik i e-postens innehåll. Detta ändrar inte ämnesraden."
		},
		additionalInfoLabel: "Ytterligare information",
		additionalInfoTooltip: "Schemaläggaren lägger till innehållet i rutan till e-postens innehåll.",
		additionalInfoPlaceholder: "Standardtext"
	},
	allHosts: "Alla värdar och gäster",
	immediatelyUponBooking: "Omedelbart efter bokning"
};
const nylasConnectedCalendars$3 = {
	headerTitle: "Anslutna kalendrar",
	headerSubTitle: "Välj kalendrarna som ska användas för att kontrollera din tillgänglighet.",
	tooltip: {
		desc: "Kontrollera tillgänglighet i en eller flera kalendrar. Om du väljer flera kalendrar för en deltagare måste deltagaren vara tillgänglig i alla sina kalendrar för att anses vara tillgänglig."
	},
	participantCalendarTitle: "{{participantName}}s anslutna kalendrar",
	selectAtLeastOneCalendar: "Vänligen välj minst en kalender för varje deltagare."
};
const nylasCustomBookingFlow$3 = {
	headerTitle: "Anpassat bokningsflöde"
};
const nylasCustomEventSlug$3 = {
	headerTitle: "Anpassad sidlänk",
	headerSubTitle: "Skapa en anpassad URL-länk för denna sida.",
	eventSlugLabel: "Sidlänk för URL",
	tooltip: {
		desc: "Ange en anpassad länk för din URL för att unikt identifiera din sida (endast bokstäver, siffror och bindestreck)."
	},
	copied: "Kopierad!"
};
const nylasCustomizeBookingSettings$3 = {
	headerTitle: "Ytterligare inställningar",
	headerSubTitle: "Bokningsinställningar för evenemanget.",
	tooltip: {
		desc: "Anpassa dina bokningsinställningar."
	},
	allowGuests: {
		label: "Tillåt gäster att bjuda in ytterligare gäster."
	},
	hideReschedule: {
		label: "Dölj alternativ för ombokning.",
		tooltip: {
			desc: "Dölj knappen 'Omboka' i bokningsbekräftelsen och e-postaviseringar."
		}
	},
	hideCancel: {
		label: "Dölj alternativ för avbokning",
		tooltip: {
			desc: "Dölj knappen 'Avboka' i bokningsbekräftelsen och e-postaviseringar."
		}
	}
};
const nylasEventDescription$3 = {
	headerTitle: "Evenemangsbeskrivning",
	addAdditionalFields: {
		buttonText: "Fyll i ytterligare fält automatiskt",
		tooltip: {
			desc: "Klicka på detta när du har lagt till alla fält du vill inkludera i beskrivningen. Viktigt: Vänligen ändra inte markeringarna '--- Additional Fields ---' och '--- End Additional Fields ---' för att säkerställa att allt fungerar korrekt."
		}
	},
	tooltip: {
		desc: "Evenemangsbeskrivningen visas i schemaläggarens redigeringsvy och i svarspayloaden när en bokning skapas."
	}
};
const nylasEventDuration$3 = {
	headerTitle: "Evenemangets varaktighet",
	error: {
		durationMustBeMultipleOf5: "Varaktigheten måste vara en multipel av 5",
		durationMustBeGreaterThan0: "Varaktigheten måste vara större än 0"
	}
};
const nylasEventInfo$3 = {
	headerTitle: "Evenemangsinformation"
};
const nylasEventLimits$3 = {
	headerTitle: "Begränsningar för evenemanget"
};
const nylasEventLocation$3 = {
	headerTitle: "Evenemangsmöte eller plats",
	tooltip: {
		desc: "Välj ett konferensalternativ eller lägg till en anpassad plats."
	},
	conferenceOptions: {
		none: "Ingen",
		zoom: "Zoom-möte",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "Anpassad plats"
	}
};
const nylasEventTitle$3 = {
	headerTitle: "Evenemangets titel",
	helpText_start: "Skapa ett dynamiskt mallbaserat event {{field}} genom att skriva",
	helpText_end: "och välja ett mallobjekt.",
	title: "titel",
	description: "beskrivning",
	tooltip: {
		desc: "Till exempel: Intervju med"
	},
	eventTitleRequired: "Evenemangets titel är obligatorisk",
	eventTitleTokenDescription: {
		invitee: "Namnet på huvudinbjudan.",
		inviteeEmail: "E-postadressen för huvudinbjudan.",
		duration: "Varaktigheten för evenemanget."
	}
};
const nylasLimitFutureBookings$3 = {
	headerTitle: "Begränsa framtida bokningar",
	tooltip: {
		desc: "Gränsen för hur långt in i framtiden bokningar kan göras."
	}
};
const nylasMinBookingNotice$3 = {
	headerTitle: "Minsta bokningsnotis",
	tooltip: {
		desc: "Den minsta tidsramen i framtiden som en ny bokning kan göras."
	}
};
const nylasMinCancellationNotice$3 = {
	headerTitle: "Minsta avbokningsnotis",
	tooltip: {
		desc: "Den minsta tidsramen som krävs för att avboka en bokning."
	}
};
const nylasPageName$3 = {
	headerTitle: "Sidnamn",
	headerSubTitle: "Ange namnet på schemaläggningssidan.",
	pageNameError: "Ange ett sidnamn",
	tooltip: {
		desc: "Som standard använder schemaläggningssidor ditt användarnamn som sidnamn. Sidnamnet visas i det övre vänstra hörnet av kalendervyn."
	}
};
const nylasPageStyling$3 = {
	headerTitle: "Sidstil och anpassning"
};
const nylasParticipantBookingCalendars$3 = {
	headerTitle: "Boka till denna kalender",
	headerSubTitle: "Välj kalendern där du vill lägga till bokningar.",
	participantBookingCalendarTitle: "{{participantName}}s bokningskalendrar",
	selectAtLeastOneCalendar: "Vänligen välj minst en kalender för varje deltagare."
};
const nylasParticipantCustomAvailability$3 = {
	headerTitle: "Deltagares öppettider",
	headerSubTitle: "Om inte inställt används standardöppettiderna för att beräkna deltagarens tillgänglighet.",
	participantOpenHoursTitle: "{{participantName}}s öppettider"
};
const nylasReminderEmails$3 = {
	headerTitle: "Kommande möte {{organizerName}}",
	headerSubTitle: "Påminnelse före händelsen",
	editButtonText: "Redigera",
	recipientOptions_all: "Alla värdar och gäster",
	recipientOptions_guest: "Alla gäster på evenemanget",
	recipientOptions_host: "Endast värd för evenemanget",
	beforeTheEvent: "före evenemanget",
	emailRecipients: {
		label: "E-postmottagare"
	},
	sendConfirmation: {
		label: "Skicka bekräftelsemail när",
		tooltip: {
			desc: "Mottagarna kommer att få ett påminnelsemail vid den angivna tiden före evenemanget."
		}
	},
	emailSubject: {
		label: "E-postämne",
		placeholder: "Kommande möte {{organizerName}}"
	},
	reminderMinutesValidationError: "Ange påminnelseminuter i multiplar av 5. Försök ",
	newReminderButtonText: "Ny påminnelse"
};
const nylasSchedulingMethod$3 = {
	headerTitle: "Schemaläggningsmetod",
	headerSubTitle: "Välj en schemaläggningsmetod för evenemanget.",
	tooltip: {
		standard: {
			label: "Standard",
			desc: "Tillåter 1:1-bokningar eller n:1-bokningar med ytterligare deltagare."
		},
		maxFairness: {
			label: "Rundgång - Maximera rättvisa",
			desc: "Rotera genom deltagarlistan och visa deltagaren med minst bokningar."
		},
		maxAvailability: {
			label: "Rundgång - Maximera tillgänglighet",
			desc: "Rotera genom deltagarlistan och prioritera deltagare med minst bokningar, samtidigt som så många tidsslotar som möjligt görs tillgängliga."
		}
	},
	schedulingMethodOptions_collective: "Standardbokning",
	schedulingMethodOptions_maxFairness: "Rundgång - Max rättvisa",
	schedulingMethodOptions_maxAvailability: "Rundgång - Max tillgänglighet"
};
const nylasTimeslotInterval$3 = {
	minutesShort: "min",
	lengthOfMeeting: "Möteslängd",
	headerTitle: "Inställningar för tidsluckor",
	timeslotInterval: {
		label: "Intervall för tidsluckor."
	},
	timeslotRounding: {
		label: "Typ av avrundning för tidsluckor",
		tooltip: {
			desc: "Intervall vid vilket tidsluckor visas."
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "Avrundning av intervall",
			desc: "Tidsluckor börjar vid tider som avrundas till intervallvärdet."
		},
		noRounding: {
			label: "Standard",
			desc: "Tidsluckor avrundas till närmaste kvart."
		}
	}
};
const nylasEventTimeslot$3 = {
	recurrenceOptions: {
		none: "Upprepas inte",
		daily: "Dagligen",
		weekly: "Varje vecka på {{dayOfWeek}}",
		monthly: "Månadsvis den {{dayOfMonth}}",
		monthOnDay: "Månadsvis den {{date}}",
		yearly: "Årligen den {{dateOfMonth}}",
		custom: "Anpassad"
	},
	recurrenceLabel: "Upprepa denna händelse",
	endDate: "Slutdatum",
	customRecurrence: {
		repeatEvery: "Upprepa varje",
		repeatOn: "Upprepa på",
		ends: "Slutar",
		endsOptions: {
			never: "Aldrig",
			after: "Efter",
			on: "På"
		},
		occurrences: "förekomster"
	},
	dateTimeLabel: "Datum och tid",
	errors: {
		invalidTimeRange: "Ogiltig tidsperiod",
		startTimeSameAsEndTime: "Starttid och sluttid kan inte vara samma",
		startTimeBeforeCurrentDate: "Starttid kan inte vara i det passade",
		invalid: "Ogiltigt"
	}
};
const nylasEventCapacity$3 = {
	headerTitle: "Deltagare",
	headerSubTitle: "Ställ in det maximala antalet deltagare för denna tidslucka.",
	tooltip: {
		desc: "Arrangören och deltagarna som är konfigurerade på schemaläggningssidan räknas inte som deltagare."
	},
	attendees: "deltagare"
};
const nylasSelectEventType$3 = {
	returnToAllSchedulingPages: "Tillbaka till alla schemaläggningssidor",
	createEventHeaderTitle: "Skapa ett evenemang",
	eventTypeHeaderTitle: "Evenemangstyp",
	noEventTypesEnabled: "Inga evenemangstyper aktiverade",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "Tillåter 1:1-bokningar."
		},
		collective: {
			label: "Standardbokning",
			desc: "Tillåter n:1-bokningar med ytterligare deltagare."
		},
		maxFairness: {
			label: "Rundgång - Maximera rättvisa",
			desc: "Rotera genom deltagarlistan och visa deltagaren med minst bokningar."
		},
		maxAvailability: {
			label: "Rundgång - Maximera tillgänglighet",
			desc: "Rotera genom deltagarlistan och prioritera deltagare med minst bokningar, samtidigt som så många tidsslotar som möjligt görs tillgängliga."
		},
		group: {
			label: "Grupp / Klass",
			desc: "Dessa är evenemang som vanligtvis har en arrangör och flera deltagare."
		}
	}
};
const pageSettingsButton$3 = "Sidinställningar";
const nylasEventCalendar$3 = {
	hideNonGroupEvents: {
		showLabel: "Filtrera händelser",
		tooltip: {
			desc: "Välj typ av händelser som ska visas i kalendern."
		},
		options: {
			all: "Alla",
			group: "Endast grupphändelser"
		}
	},
	createEventDetails: {
		headerTitle: "Evenemangsinformation",
		closeButtonTooltip: "Stäng",
		cancelButton: "Avbryt",
		createButton: "Skapa"
	},
	discardChanges: {
		headerTitle: "Vill du verkligen avbryta ändringarna?",
		cancelButton: "Avbryt",
		discardButton: "Avbryt"
	},
	unsavedChanges: "Osparade ändringar",
	editEventDetails: {
		headerTitle: "Evenemangsinformation",
		closeButtonTooltip: "Stäng",
		deleteButton: "Ta bort",
		saveButton: "Spara",
		pastEventTooltip: "Detta evenemang är i det passade och kan inte redigeras."
	},
	importEvent: {
		closeButtonTooltip: "Stäng",
		importButton: "Importera",
		participantsLabel: "Deltagare"
	},
	deleteEvent: {
		closeButtonTooltip: "Stäng",
		deleting: "Tar bort..."
	},
	editOptions: {
		headerTitle: "Alternativ",
		closeButtonTooltip: "Stäng",
		deleting: "Tar bort...",
		"import": "Importera",
		edit: "Redigera",
		deleteThis: "Ta bort detta evenemang",
		deleteAll: "Ta bort alla evenemang",
		importTooltip: "Tillåter dig att välja befintliga evenemang från en kalender och konfigurera dem som grupp-evenemang"
	},
	updateOptions: {
		updateThis: "Uppdatera detta evenemang",
		updateAll: "Uppdatera alla evenemang",
		updateFuture: "Uppdatera alla framtida evenemang"
	},
	deleteOptions: {
		deleteThis: "Ta bort",
		deleteFuture: "Ta bort detta och alla framtida evenemang",
		deleteAll: "Ta bort alla evenemang"
	}
};
const sv$1 = {
	noDateSelected: noDateSelected$3,
	rescheduleTitle: rescheduleTitle$3,
	allDay: allDay$3,
	today: today$3,
	spotsLeft: spotsLeft$3,
	search: search$3,
	selectOneOrMoreOptions: selectOneOrMoreOptions$3,
	days: days$3,
	time: time$3,
	months: months$3,
	multipleOptionsSelected: multipleOptionsSelected$3,
	selectAtLeastOneOption: selectAtLeastOneOption$3,
	nextButton: nextButton$3,
	selectedDayAndYear: selectedDayAndYear$3,
	selectedTime: selectedTime$3,
	name: name$3,
	namePlaceholder: namePlaceholder$3,
	email: email$3,
	emailPlaceholder: emailPlaceholder$3,
	guestEmail: guestEmail$3,
	guestEmailPlaceholder: guestEmailPlaceholder$3,
	addGuest: addGuest$3,
	addAnotherGuest: addAnotherGuest$3,
	backButton: backButton$3,
	bookNowButton: bookNowButton$3,
	bookingConfirmed: bookingConfirmed$3,
	bookingConfirmedDescription: bookingConfirmedDescription$3,
	bookingSent: bookingSent$3,
	bookingSentDescription: bookingSentDescription$3,
	bookingRescheduled: bookingRescheduled$3,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$3,
	cancelBookingButton: cancelBookingButton$3,
	rescheduleBookingButton: rescheduleBookingButton$3,
	rejectBookingButton: rejectBookingButton$3,
	confirmBookingButton: confirmBookingButton$3,
	bookingPendingTitle: bookingPendingTitle$3,
	bookingPendingnDescription: bookingPendingnDescription$3,
	confirmedEventCardTitle: confirmedEventCardTitle$3,
	confirmedEventCardDescription: confirmedEventCardDescription$3,
	cancelBookingTitle: cancelBookingTitle$3,
	cancelBookingMessage: cancelBookingMessage$3,
	reasonForCancellation: reasonForCancellation$3,
	goBackButton: goBackButton$3,
	bookingCancelledTitle: bookingCancelledTitle$3,
	bookingCancelledMessage: bookingCancelledMessage$3,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$3,
	closeButton: closeButton$3,
	closingButton: closingButton$3,
	fieldRequired: fieldRequired$3,
	invalidInputFormat: invalidInputFormat$3,
	createBookingErrorTitle: createBookingErrorTitle$3,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$3,
	cancelBookingErrorTitle: cancelBookingErrorTitle$3,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$3,
	getUISettingErrorTitle: getUISettingErrorTitle$3,
	rejectBookingErrorTitle: rejectBookingErrorTitle$3,
	confirmBookingErrorTitle: confirmBookingErrorTitle$3,
	genericErrorTitle: genericErrorTitle$3,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$3,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$3,
	publicConfigErrorMessage: publicConfigErrorMessage$3,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$2,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$3,
	cancellationErrorTitle: cancellationErrorTitle$3,
	cancellationErrorMessage: cancellationErrorMessage$3,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$3,
	cancelBokingFormError: cancelBokingFormError$3,
	feedbackFormTitle: feedbackFormTitle$3,
	feedbackFormDescription: feedbackFormDescription$3,
	feedbackMessageLabel: feedbackMessageLabel$3,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$3,
	feedbackModalCloseButton: feedbackModalCloseButton$3,
	feedbackModalSubmitButton: feedbackModalSubmitButton$3,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$3,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$3,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$3,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$3,
	schedulerEditorTitle: schedulerEditorTitle$3,
	allSchedulingPages: allSchedulingPages$3,
	createAndManageSchedulingPages: createAndManageSchedulingPages$3,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$3,
	pageTitle: pageTitle$3,
	durationTitle: durationTitle$3,
	loading: loading$3,
	required: required$3,
	optional: optional$3,
	loadingPagesDescription: loadingPagesDescription$3,
	noSchedulingPages: noSchedulingPages$3,
	createFirstSchedulingPage: createFirstSchedulingPage$3,
	editSchedulingPageButtonText: editSchedulingPageButtonText$3,
	eventInfoTab: eventInfoTab$3,
	availabilityTab: availabilityTab$3,
	participantsTab: participantsTab$3,
	bookingOptionsTab: bookingOptionsTab$3,
	returnToCalendarView: returnToCalendarView$3,
	bookingFormTab: bookingFormTab$3,
	communicationsTab: communicationsTab$3,
	pageStylesTab: pageStylesTab$3,
	savingButtonText: savingButtonText$3,
	saveChangesButtonText: saveChangesButtonText$3,
	createButtonText: createButtonText$3,
	timePeriod_day: timePeriod_day$3,
	timePeriod_week: timePeriod_week$3,
	timePeriod_month: timePeriod_month$3,
	timePeriod_year: timePeriod_year$3,
	timeDuration_minute: timeDuration_minute$3,
	timeDuration_hour: timeDuration_hour$3,
	eventCommunicationsTitle: eventCommunicationsTitle$3,
	eventCommunicationsDescription: eventCommunicationsDescription$3,
	unsavedChangesLabel: unsavedChangesLabel$3,
	changesSavedLabel: changesSavedLabel$3,
	fixFormErrors: fixFormErrors$3,
	nylasEditorTabs: nylasEditorTabs$3,
	nylasEditorTabsGroup: nylasEditorTabsGroup$3,
	nylasListConfigurations: nylasListConfigurations$3,
	nylasAdditionalParticipants: nylasAdditionalParticipants$3,
	nylasAvailabilityPicker: nylasAvailabilityPicker$3,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$3,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$3,
	nylasBookingConfirmationType: nylasBookingConfirmationType$3,
	nylasBookingFormConfig: nylasBookingFormConfig$3,
	nylasBufferTime: nylasBufferTime$3,
	nylasCalendarPicker: nylasCalendarPicker$3,
	nylasCancellationPolicy: nylasCancellationPolicy$3,
	nylasConfirmationEmail: nylasConfirmationEmail$3,
	nylasConnectedCalendars: nylasConnectedCalendars$3,
	nylasCustomBookingFlow: nylasCustomBookingFlow$3,
	nylasCustomEventSlug: nylasCustomEventSlug$3,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$3,
	nylasEventDescription: nylasEventDescription$3,
	nylasEventDuration: nylasEventDuration$3,
	nylasEventInfo: nylasEventInfo$3,
	nylasEventLimits: nylasEventLimits$3,
	nylasEventLocation: nylasEventLocation$3,
	nylasEventTitle: nylasEventTitle$3,
	nylasLimitFutureBookings: nylasLimitFutureBookings$3,
	nylasMinBookingNotice: nylasMinBookingNotice$3,
	nylasMinCancellationNotice: nylasMinCancellationNotice$3,
	nylasPageName: nylasPageName$3,
	nylasPageStyling: nylasPageStyling$3,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$3,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$3,
	nylasReminderEmails: nylasReminderEmails$3,
	nylasSchedulingMethod: nylasSchedulingMethod$3,
	nylasTimeslotInterval: nylasTimeslotInterval$3,
	nylasEventTimeslot: nylasEventTimeslot$3,
	nylasEventCapacity: nylasEventCapacity$3,
	nylasSelectEventType: nylasSelectEventType$3,
	pageSettingsButton: pageSettingsButton$3,
	nylasEventCalendar: nylasEventCalendar$3
};

const svTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$3,
  rescheduleTitle: rescheduleTitle$3,
  allDay: allDay$3,
  today: today$3,
  spotsLeft: spotsLeft$3,
  search: search$3,
  selectOneOrMoreOptions: selectOneOrMoreOptions$3,
  days: days$3,
  time: time$3,
  months: months$3,
  multipleOptionsSelected: multipleOptionsSelected$3,
  selectAtLeastOneOption: selectAtLeastOneOption$3,
  nextButton: nextButton$3,
  selectedDayAndYear: selectedDayAndYear$3,
  selectedTime: selectedTime$3,
  name: name$3,
  namePlaceholder: namePlaceholder$3,
  email: email$3,
  emailPlaceholder: emailPlaceholder$3,
  guestEmail: guestEmail$3,
  guestEmailPlaceholder: guestEmailPlaceholder$3,
  addGuest: addGuest$3,
  addAnotherGuest: addAnotherGuest$3,
  backButton: backButton$3,
  bookNowButton: bookNowButton$3,
  bookingConfirmed: bookingConfirmed$3,
  bookingConfirmedDescription: bookingConfirmedDescription$3,
  bookingSent: bookingSent$3,
  bookingSentDescription: bookingSentDescription$3,
  bookingRescheduled: bookingRescheduled$3,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$3,
  cancelBookingButton: cancelBookingButton$3,
  rescheduleBookingButton: rescheduleBookingButton$3,
  rejectBookingButton: rejectBookingButton$3,
  confirmBookingButton: confirmBookingButton$3,
  bookingPendingTitle: bookingPendingTitle$3,
  bookingPendingnDescription: bookingPendingnDescription$3,
  confirmedEventCardTitle: confirmedEventCardTitle$3,
  confirmedEventCardDescription: confirmedEventCardDescription$3,
  cancelBookingTitle: cancelBookingTitle$3,
  cancelBookingMessage: cancelBookingMessage$3,
  reasonForCancellation: reasonForCancellation$3,
  goBackButton: goBackButton$3,
  bookingCancelledTitle: bookingCancelledTitle$3,
  bookingCancelledMessage: bookingCancelledMessage$3,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$3,
  closeButton: closeButton$3,
  closingButton: closingButton$3,
  fieldRequired: fieldRequired$3,
  invalidInputFormat: invalidInputFormat$3,
  createBookingErrorTitle: createBookingErrorTitle$3,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$3,
  cancelBookingErrorTitle: cancelBookingErrorTitle$3,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$3,
  getUISettingErrorTitle: getUISettingErrorTitle$3,
  rejectBookingErrorTitle: rejectBookingErrorTitle$3,
  confirmBookingErrorTitle: confirmBookingErrorTitle$3,
  genericErrorTitle: genericErrorTitle$3,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$3,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$3,
  publicConfigErrorMessage: publicConfigErrorMessage$3,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$2,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$3,
  cancellationErrorTitle: cancellationErrorTitle$3,
  cancellationErrorMessage: cancellationErrorMessage$3,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$3,
  cancelBokingFormError: cancelBokingFormError$3,
  feedbackFormTitle: feedbackFormTitle$3,
  feedbackFormDescription: feedbackFormDescription$3,
  feedbackMessageLabel: feedbackMessageLabel$3,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$3,
  feedbackModalCloseButton: feedbackModalCloseButton$3,
  feedbackModalSubmitButton: feedbackModalSubmitButton$3,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$3,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$3,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$3,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$3,
  schedulerEditorTitle: schedulerEditorTitle$3,
  allSchedulingPages: allSchedulingPages$3,
  createAndManageSchedulingPages: createAndManageSchedulingPages$3,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$3,
  pageTitle: pageTitle$3,
  durationTitle: durationTitle$3,
  loading: loading$3,
  required: required$3,
  optional: optional$3,
  loadingPagesDescription: loadingPagesDescription$3,
  noSchedulingPages: noSchedulingPages$3,
  createFirstSchedulingPage: createFirstSchedulingPage$3,
  editSchedulingPageButtonText: editSchedulingPageButtonText$3,
  eventInfoTab: eventInfoTab$3,
  availabilityTab: availabilityTab$3,
  participantsTab: participantsTab$3,
  bookingOptionsTab: bookingOptionsTab$3,
  returnToCalendarView: returnToCalendarView$3,
  bookingFormTab: bookingFormTab$3,
  communicationsTab: communicationsTab$3,
  pageStylesTab: pageStylesTab$3,
  savingButtonText: savingButtonText$3,
  saveChangesButtonText: saveChangesButtonText$3,
  createButtonText: createButtonText$3,
  timePeriod_day: timePeriod_day$3,
  timePeriod_week: timePeriod_week$3,
  timePeriod_month: timePeriod_month$3,
  timePeriod_year: timePeriod_year$3,
  timeDuration_minute: timeDuration_minute$3,
  timeDuration_hour: timeDuration_hour$3,
  eventCommunicationsTitle: eventCommunicationsTitle$3,
  eventCommunicationsDescription: eventCommunicationsDescription$3,
  unsavedChangesLabel: unsavedChangesLabel$3,
  changesSavedLabel: changesSavedLabel$3,
  fixFormErrors: fixFormErrors$3,
  nylasEditorTabs: nylasEditorTabs$3,
  nylasEditorTabsGroup: nylasEditorTabsGroup$3,
  nylasListConfigurations: nylasListConfigurations$3,
  nylasAdditionalParticipants: nylasAdditionalParticipants$3,
  nylasAvailabilityPicker: nylasAvailabilityPicker$3,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$3,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$3,
  nylasBookingConfirmationType: nylasBookingConfirmationType$3,
  nylasBookingFormConfig: nylasBookingFormConfig$3,
  nylasBufferTime: nylasBufferTime$3,
  nylasCalendarPicker: nylasCalendarPicker$3,
  nylasCancellationPolicy: nylasCancellationPolicy$3,
  nylasConfirmationEmail: nylasConfirmationEmail$3,
  nylasConnectedCalendars: nylasConnectedCalendars$3,
  nylasCustomBookingFlow: nylasCustomBookingFlow$3,
  nylasCustomEventSlug: nylasCustomEventSlug$3,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$3,
  nylasEventDescription: nylasEventDescription$3,
  nylasEventDuration: nylasEventDuration$3,
  nylasEventInfo: nylasEventInfo$3,
  nylasEventLimits: nylasEventLimits$3,
  nylasEventLocation: nylasEventLocation$3,
  nylasEventTitle: nylasEventTitle$3,
  nylasLimitFutureBookings: nylasLimitFutureBookings$3,
  nylasMinBookingNotice: nylasMinBookingNotice$3,
  nylasMinCancellationNotice: nylasMinCancellationNotice$3,
  nylasPageName: nylasPageName$3,
  nylasPageStyling: nylasPageStyling$3,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$3,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$3,
  nylasReminderEmails: nylasReminderEmails$3,
  nylasSchedulingMethod: nylasSchedulingMethod$3,
  nylasTimeslotInterval: nylasTimeslotInterval$3,
  nylasEventTimeslot: nylasEventTimeslot$3,
  nylasEventCapacity: nylasEventCapacity$3,
  nylasSelectEventType: nylasSelectEventType$3,
  pageSettingsButton: pageSettingsButton$3,
  nylasEventCalendar: nylasEventCalendar$3,
  'default': sv$1
});

const noDateSelected$2 = "请选择日期";
const rescheduleTitle$2 = "选择另一个时间段重新安排您的会议";
const allDay$2 = "全天";
const today$2 = "今天";
const spotsLeft$2 = "{{count}} 剩余";
const search$2 = "搜索";
const selectOneOrMoreOptions$2 = "请选择一个或多个选项";
const days$2 = {
	sunday: "周日",
	monday: "周一",
	tuesday: "周二",
	wednesday: "周三",
	thursday: "周四",
	friday: "周五",
	saturday: "周六"
};
const time$2 = {
	hour: "小时",
	hours: "小时",
	minute: "分钟",
	minutes: "分钟",
	day: "天",
	days: "天",
	week: "周",
	weeks: "周",
	month: "月",
	months: "月",
	year: "年",
	years: "年"
};
const months$2 = {
	january: "一月",
	february: "二月",
	march: "三月",
	april: "四月",
	may: "五月",
	june: "六月",
	july: "七月",
	august: "八月",
	september: "九月",
	october: "十月",
	november: "十一月",
	december: "十二月"
};
const multipleOptionsSelected$2 = "多个选项已选择";
const selectAtLeastOneOption$2 = "请至少选择一个选项";
const nextButton$2 = "下一个";
const selectedDayAndYear$2 = "{{date}}";
const selectedTime$2 = "{{time}}";
const name$2 = "姓名";
const namePlaceholder$2 = "输入你的名字";
const email$2 = "电子邮件";
const emailPlaceholder$2 = "输入你的电子邮件";
const guestEmail$2 = "客人的电子邮件";
const guestEmailPlaceholder$2 = "输入客人的电子邮件";
const addGuest$2 = "添加客人";
const addAnotherGuest$2 = "添加另一个客人";
const backButton$2 = "返回";
const bookNowButton$2 = "立即预订";
const bookingConfirmed$2 = "预订已确认";
const bookingConfirmedDescription$2 = "您将很快收到一封确认电子邮件。";
const bookingSent$2 = "预订已发送";
const bookingSentDescription$2 = "预订确认后，您将收到一封电子邮件。";
const bookingRescheduled$2 = "预订已重新安排";
const bookingDateAndTimeHeader$2 = "预订日期和时间";
const cancelBookingButton$2 = "取消预订";
const rescheduleBookingButton$2 = "重新安排";
const rejectBookingButton$2 = "拒绝预订";
const confirmBookingButton$2 = "确认预订";
const bookingPendingTitle$2 = "预订待处理";
const bookingPendingnDescription$2 = "在下方管理您的预订。受邀者将收到一封电子邮件，通知他们请求状态。";
const confirmedEventCardTitle$2 = "您的预订已成功确认";
const confirmedEventCardDescription$2 = "确认邮件已发送至";
const cancelBookingTitle$2 = "取消预订？";
const cancelBookingMessage$2 = "您当前的时间段将对其他人开放。";
const reasonForCancellation$2 = "取消原因";
const goBackButton$2 = "返回";
const bookingCancelledTitle$2 = "您的预订已成功取消";
const bookingCancelledMessage$2 = "取消邮件已发送至";
const bookingCancelledMessage_theParticipants$2 = "参与者";
const closeButton$2 = "关闭";
const closingButton$2 = "关闭";
const fieldRequired$2 = "{{field}} 是必需的.";
const invalidInputFormat$2 = "{{field}} 格式无效.";
const createBookingErrorTitle$2 = "创建预订";
const getAvailabilityErrorTitle$2 = "获取可用性";
const cancelBookingErrorTitle$2 = "取消预订";
const rescheduleBookingErrorTitle$2 = "重新安排预订";
const getUISettingErrorTitle$2 = "获取UI设置";
const rejectBookingErrorTitle$2 = "拒绝预订";
const confirmBookingErrorTitle$2 = "确认预订";
const genericErrorTitle$2 = "出了点问题...";
const schedulingComponentErrorTitle$2 = "调度组件错误";
const sessionIdRequiredErrorMessage$2 = "私有配置需要 'sessionId'。";
const publicConfigErrorMessage$2 = "如果使用公共配置，请传递 configurationId 或 'slug' 和 'clientId' 的组合。";
const invalidTimeslotErrorTitle$1 = "无效的时间段！";
const invalidTimeslotErrorMessage$2 = "所选时间段无效";
const cancellationErrorTitle$2 = "取消错误";
const cancellationErrorMessage$2 = "请提供取消的原因。";
const minimumCancellationErrorMessage$2 = "您不能在活动开始前的{{minCancellationNotice}}分钟内取消预订";
const cancelBokingFormError$2 = "取消预订表单错误";
const feedbackFormTitle$2 = "分享您的反馈";
const feedbackFormDescription$2 = "为我们提供反馈并报告错误有助于为您创造更好的体验。";
const feedbackMessageLabel$2 = "请详细描述您正在评论的功能或遇到问题的地方。";
const feedbackMessagePlaceholder$2 = "在此处提供您的反馈";
const feedbackModalCloseButton$2 = "取消";
const feedbackModalSubmitButton$2 = "提交";
const deleteSchedulingPageTitle$2 = "删除此日程安排页面？";
const deleteSchedulingPageDescription$2 = "确认后，此页面及其关联的日程安排链接将被永久删除并停用。此操作无法撤消。";
const deleteSchedulingPageConfirmButton$2 = "删除页面";
const deleteSchedulingPageCancelButton$2 = "取消";
const schedulerEditorTitle$2 = "日程编辑器";
const allSchedulingPages$2 = "所有日程页面";
const createAndManageSchedulingPages$2 = "创建和管理您的日程页面。";
const createNewSchedulingPageButtonText$2 = "创建新的";
const pageTitle$2 = "页面标题";
const durationTitle$2 = "持续时间";
const loading$2 = "加载中";
const required$2 = "必需";
const optional$2 = "可选";
const loadingPagesDescription$2 = "请稍候，我们正在获取日程页面";
const noSchedulingPages$2 = "未找到日程页面";
const createFirstSchedulingPage$2 = "从创建第一个日程页面开始";
const editSchedulingPageButtonText$2 = "编辑";
const eventInfoTab$2 = "事件信息";
const availabilityTab$2 = "可用性";
const participantsTab$2 = "参与者";
const bookingOptionsTab$2 = "预订选项";
const returnToCalendarView$2 = "返回日历视图";
const bookingFormTab$2 = "预订表格";
const communicationsTab$2 = "通讯";
const pageStylesTab$2 = "页面样式";
const savingButtonText$2 = "保存中";
const saveChangesButtonText$2 = "保存更改";
const createButtonText$2 = "创建";
const timePeriod_day$2 = "天";
const timePeriod_week$2 = "周";
const timePeriod_month$2 = "月";
const timePeriod_year$2 = "年";
const timeDuration_minute$2 = "分钟";
const timeDuration_hour$2 = "小时";
const eventCommunicationsTitle$2 = "活动通信";
const eventCommunicationsDescription$2 = "设置自动确认电子邮件。";
const unsavedChangesLabel$2 = "未保存的更改";
const changesSavedLabel$2 = "更改已保存";
const fixFormErrors$2 = "请修复表单错误。";
const nylasEditorTabs$2 = {
	bookingFormError: "预订表单错误：",
	bookingFormError_label: "{{type}} 类型的字段需要标签。",
	bookingFormError_option: "{{label}} 类型的 {{type}} 字段中检测到空选项。",
	formErrorTitle: "表单错误",
	updateConfigError: "更新配置错误: ",
	createConfigError: "创建配置错误: ",
	deleteConfigError: "删除配置错误: ",
	getConfigsError: "获取配置错误: "
};
const nylasEditorTabsGroup$2 = {
	eventTitleRequired: "事件标题是必需的。",
	eventTimeRequired: "事件时间是必需的。",
	participantsRequired: "参与者是必需的。",
	participantEmailRequired: "参与者电子邮件是必需的。",
	errorOccured: "保存更改时出错。",
	createGroupEventError: "创建组结果错误: ",
	updateGroupEventError: "更新组结果错误: ",
	deleteGroupEventError: "删除组结果错误: ",
	importGroupEventError: "导入组结果错误: ",
	getGroupEventsError: "获取组结果错误: "
};
const nylasListConfigurations$2 = {
	previewButtonText: "预览",
	copyLinkButtonText: "复制链接",
	deleteButtonText: "删除"
};
const nylasAdditionalParticipants$2 = {
	headerTitle: "参与者",
	headerSubTitle: "添加您的团队或组织中的人员加入活动。",
	organizerAsParticipant: "参与者",
	organizer: "组织者",
	participant: "参与者",
	addParticipant_first: "添加参与者",
	addParticipant_next: "添加另一位参与者",
	tooltip: {
		includeOrganizer: "包括组织者",
		includeOrganizerDesc: "组织者（您）将包含在轮换中。",
		excludeOrganizer: "排除组织者",
		excludeOrganizerDesc: "组织者（您）将不包含在轮换中。"
	},
	error: "请至少添加一个参与者"
};
const nylasAvailabilityPicker$2 = {
	headerTitle: "默认开放时间",
	headerSubTitle: "设置您定期可用于活动预订的时间。",
	tooltip: {
		desc: "这是为未在参与者选项卡上设置可用性的参与者提供的默认可用时间。"
	},
	selectTimezone: "选择时区",
	unavailable: "不可用",
	days: {
		SUN: "周日",
		MON: "周一",
		TUE: "周二",
		WED: "周三",
		THU: "周四",
		FRI: "周五",
		SAT: "周六"
	},
	errors: {
		invalid: "无效"
	}
};
const nylasBookingCalendarPicker$2 = {
	headerTitle: "日历预订",
	headerSubTitle: "选择您希望添加活动预订的日历。",
	tooltip: {
		desc: "日历将用于创建事件。"
	},
	selectOptionLabel: "选择一个选项",
	selectCalendarErrorMessage: "请选择一个日历"
};
const nylasBookingConfirmationRedirect$2 = {
	dropdownLabel: "预订确认时",
	tooltip: {
		desc: "您可以显示默认确认页面或将用户重定向到您自己的确认页面。"
	},
	redirectOption_default: "显示默认确认页面",
	redirectOption_custom: "重定向到自定义 URL"
};
const nylasBookingConfirmationType$2 = {
	dropdownLabel: "预订请求时",
	tooltip: {
		desc: "手动接受预订允许您审核并接受或拒绝每个预订请求。"
	},
	bookingOption_booking: "自动接受预订",
	bookingOption_organizerConfirmation: "手动接受预订"
};
const nylasBookingFormConfig$2 = {
	headerTitle: "预订表格",
	headerSubTitle: "向预订表格添加自定义字段。",
	dropdownButtonText: "添加新字段",
	addOption: "添加选项",
	allOptionsHeader: "所有选项",
	fieldInTitleError: "该字段用于事件标题，无法删除。",
	fieldInDescriptionError: "该字段用于事件描述，无法删除。",
	label: "标签",
	defaultValue: "默认值",
	fieldType: {
		text: "短文本",
		multi_line_text: "长文本",
		email: "电子邮件",
		phone_number: "电话号码",
		dropdown: "下拉菜单",
		radio_button: "单选按钮",
		checkbox: "复选框",
		date: "日期",
		metadata: "元数据",
		multi_select: "多选"
	},
	fieldLabel: {
		your_name: "您的姓名",
		your_email: "您的邮箱",
		email: "额外的邮箱",
		phone_number: "电话号码标签",
		dropdown: "下拉菜单标签",
		text: "短文本标签",
		multi_line_text: "长文本标签",
		radio_button: "单选按钮标签",
		checkbox: "复选框标签",
		date: "日期标签",
		metadata: "元数据标签",
		multi_select: "多选标签"
	}
};
const nylasBufferTime$2 = {
	headerTitle: "缓冲时间",
	headerSubTitle: "要求在活动之前和之后的空闲缓冲时间。",
	tooltip: {
		desc: "调度器不会预订缓冲时间。"
	},
	beforeBufferLabel: "活动前",
	afterBufferLabel: "活动后",
	minutesShort: "分钟",
	previewHeader: "预览"
};
const nylasCalendarPicker$2 = {
	calendarPickerLabel: "选择要检查可用性的日历",
	selectAtLeastOneCalendar: "请为每个参与者至少选择一个日历。"
};
const nylasCancellationPolicy$2 = {
	cancellationPolicyLabel: "取消政策信息",
	tooltip: {
		desc: "如果试图取消活动，参与者将收到此消息。参与者需要提供取消原因。"
	}
};
const nylasConfirmationEmail$2 = {
	headerTitle: "预订已确认{{organizerName}}",
	headerSubTitle: "预订确认电子邮件",
	editButtonText: "编辑",
	error: {
		invalidImageUrl: "无效的图像 URL。"
	},
	confirmationEmail: {
		label: "启用电子邮件通知",
		tooltip: {
			desc: "允许 Nylas 发送电子邮件通知，包括确认消息和事件提醒。",
			language: "此语言将用于向组织者发送电子邮件通知。"
		},
		language: "选择语言"
	},
	nylasBranding: {
		label: "显示 Nylas 品牌",
		tooltip: {
			desc: "取消选中此选项以在电子邮件中隐藏页脚。"
		}
	},
	companyLogoUrl: {
		label: "公司标志 URL",
		tooltip: {
			desc: "此标志将出现在预订确认电子邮件中。URL 必须可公开访问。图像将缩小至最大尺寸 200px x 100px。"
		}
	},
	emailMessage: {
		header: "电子邮件信息",
		label: "自定义电子邮件标题",
		tooltip: {
			desc: "电子邮件标题是电子邮件正文中的标题。这不会更改主题行。"
		},
		additionalInfoLabel: "附加信息",
		additionalInfoTooltip: "调度器会将此框的内容添加到电子邮件正文中。",
		additionalInfoPlaceholder: "默认正文"
	},
	allHosts: "所有主办方和来宾",
	immediatelyUponBooking: "预订后立即"
};
const nylasConnectedCalendars$2 = {
	headerTitle: "已连接的日历",
	headerSubTitle: "选择用于检查您可用性的日历。",
	tooltip: {
		desc: "检查一个或多个日历的可用性。如果为参与者选择了多个日历，则参与者必须在其所有日历上可用才能被视为可用。"
	},
	participantCalendarTitle: "{{participantName}}的已连接日历",
	selectAtLeastOneCalendar: "请为每个参与者至少选择一个日历。"
};
const nylasCustomBookingFlow$2 = {
	headerTitle: "自定义预订流程"
};
const nylasCustomEventSlug$2 = {
	headerTitle: "自定义页面短链接",
	headerSubTitle: "为此页面创建自定义 URL 短链接。",
	eventSlugLabel: "页面 URL 短链接",
	tooltip: {
		desc: "为您的 URL 提供一个自定义短链接，以帮助唯一标识您的页面（仅限字母、数字和连字符）。"
	},
	copied: "已复制！"
};
const nylasCustomizeBookingSettings$2 = {
	headerTitle: "附加设置",
	headerSubTitle: "活动的预订设置。",
	tooltip: {
		desc: "自定义您的预订设置。"
	},
	allowGuests: {
		label: "允许客人邀请其他客人。"
	},
	hideReschedule: {
		label: "隐藏重新安排选项。",
		tooltip: {
			desc: "隐藏预订确认和电子邮件通知中的“重新安排”按钮。"
		}
	},
	hideCancel: {
		label: "隐藏取消选项",
		tooltip: {
			desc: "隐藏预订确认和电子邮件通知中的“取消”按钮。"
		}
	}
};
const nylasEventDescription$2 = {
	headerTitle: "活动描述",
	addAdditionalFields: {
		buttonText: "自动填充其他字段",
		tooltip: {
			desc: "添加完所有您想包含在描述中的字段后点击此处。重要提示：请不要修改'--- Additional Fields ---'和'--- End Additional Fields ---'标记，以确保一切正常运行。"
		}
	},
	tooltip: {
		desc: "活动描述显示在调度器编辑器的管理视图中，并在创建预订时包含在响应中。"
	}
};
const nylasEventDuration$2 = {
	headerTitle: "活动持续时间",
	error: {
		durationMustBeMultipleOf5: "持续时间必须是5的倍数",
		durationMustBeGreaterThan0: "持续时间必须大于0"
	}
};
const nylasEventInfo$2 = {
	headerTitle: "活动信息"
};
const nylasEventLimits$2 = {
	headerTitle: "活动限制"
};
const nylasEventLocation$2 = {
	headerTitle: "活动会议或地点",
	tooltip: {
		desc: "选择一个会议选项或添加一个自定义地点。"
	},
	conferenceOptions: {
		none: "无",
		zoom: "Zoom会议",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "自定义位置"
	}
};
const nylasEventTitle$2 = {
	headerTitle: "活动标题",
	helpText_start: "通过输入创建动态模板事件 {{field}}",
	helpText_end: "并选择模板项创建动态模板活动标题。",
	title: "标题",
	description: "描述",
	tooltip: {
		desc: "例如，与...面试"
	},
	eventTitleRequired: "活动标题是必需的",
	eventTitleTokenDescription: {
		invitee: "主催者の名前",
		inviteeEmail: "主催者のメールアドレス",
		duration: "イベントの長さ"
	}
};
const nylasLimitFutureBookings$2 = {
	headerTitle: "限制未来预订",
	tooltip: {
		desc: "限制可以进行预订的未来时间范围。"
	}
};
const nylasMinBookingNotice$2 = {
	headerTitle: "最小预订通知时间",
	tooltip: {
		desc: "可以进行新预订的最短时间。"
	}
};
const nylasMinCancellationNotice$2 = {
	headerTitle: "最小取消通知时间",
	tooltip: {
		desc: "取消预订所需的最短时间。"
	}
};
const nylasPageName$2 = {
	headerTitle: "页面名称",
	headerSubTitle: "设置日程安排页面的名称。",
	pageNameError: "请输入页面名称",
	tooltip: {
		desc: "默认情况下，日程安排页面使用您的用户名作为页面名称。页面名称显示在日历视图的左上角。"
	}
};
const nylasPageStyling$2 = {
	headerTitle: "页面样式和自定义"
};
const nylasParticipantBookingCalendars$2 = {
	headerTitle: "预订到此日历",
	headerSubTitle: "选择您希望添加活动预订的日历。",
	participantBookingCalendarTitle: "{{participantName}}的预订日历",
	selectAtLeastOneCalendar: "请为每个参与者至少选择一个日历。"
};
const nylasParticipantCustomAvailability$2 = {
	headerTitle: "参与者开放时间",
	headerSubTitle: "如果未设置，将使用默认开放时间来计算该参与者的可用性。",
	participantOpenHoursTitle: "{{participantName}}的开放时间"
};
const nylasReminderEmails$2 = {
	headerTitle: "即将举行的会议 {{organizerName}}",
	headerSubTitle: "活动前的提醒",
	editButtonText: "编辑",
	recipientOptions_all: "所有主办方和来宾",
	recipientOptions_guest: "所有活动来宾",
	recipientOptions_host: "仅活动主办方",
	beforeTheEvent: "活动前",
	emailRecipients: {
		label: "电子邮件接收者"
	},
	sendConfirmation: {
		label: "在以下时间发送确认电子邮件",
		tooltip: {
			desc: "接收者将在活动前的指定时间收到提醒邮件。"
		}
	},
	emailSubject: {
		label: "电子邮件主题",
		placeholder: "即将举行的会议 {{organizerName}}"
	},
	reminderMinutesValidationError: "请以5的倍数输入提醒时间（分钟）。尝试 ",
	newReminderButtonText: "新提醒"
};
const nylasSchedulingMethod$2 = {
	headerTitle: "日程安排方法",
	headerSubTitle: "为活动选择一种日程安排方法。",
	tooltip: {
		standard: {
			label: "标准",
			desc: "允许 1:1 预订或包含额外参与者的 n:1 预订。"
		},
		maxFairness: {
			label: "轮询 - 最大公平性",
			desc: "在所选参与者列表中轮询，显示最近预订最少的参与者。"
		},
		maxAvailability: {
			label: "轮询 - 最大可用性",
			desc: "在所选参与者列表中轮询，优先显示最近预订最少的参与者，并尽可能多地提供时间段。"
		}
	},
	schedulingMethodOptions_collective: "标准预订",
	schedulingMethodOptions_maxFairness: "轮询 - 最大公平性",
	schedulingMethodOptions_maxAvailability: "轮询 - 最大可用性"
};
const nylasTimeslotInterval$2 = {
	minutesShort: "分钟",
	lengthOfMeeting: "会议长度",
	headerTitle: "时间段设置",
	timeslotInterval: {
		label: "时间段间隔。"
	},
	timeslotRounding: {
		label: "时间段舍入类型",
		tooltip: {
			desc: "显示时间段的间隔。"
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "间隔舍入",
			desc: "时间段将从舍入到间隔值的时间开始。"
		},
		noRounding: {
			label: "默认",
			desc: "时间段将舍入到最近的15分钟。"
		}
	}
};
const nylasEventTimeslot$2 = {
	recurrenceOptions: {
		none: "不重复",
		daily: "每天",
		weekly: "每周 {{dayOfWeek}}",
		monthly: "每月 {{dayOfMonth}}",
		monthOnDay: "每月第 {{date}} 天",
		yearly: "每年 {{dateOfMonth}}",
		custom: "自定义"
	},
	recurrenceLabel: "重复此活动",
	endDate: "结束日期",
	customRecurrence: {
		repeatEvery: "每次重复",
		repeatOn: "重复日期",
		ends: "结束",
		endsOptions: {
			never: "从不",
			after: "之后",
			on: "日期"
		},
		occurrences: "次"
	},
	dateTimeLabel: "日期和时间",
	errors: {
		invalidTimeRange: "无效的时间范围",
		startTimeSameAsEndTime: "开始时间和结束时间不能相同",
		startTimeBeforeCurrentDate: "开始时间不能在当前日期之前",
		invalid: "无效"
	}
};
const nylasEventCapacity$2 = {
	headerTitle: "受邀者",
	headerSubTitle: "设置此时间段的最大受邀者数量。",
	tooltip: {
		desc: "在计划页面中配置的组织者和参与者不计为受邀者。"
	},
	attendees: "受邀者"
};
const nylasSelectEventType$2 = {
	returnToAllSchedulingPages: "返回所有日程安排页面",
	createEventHeaderTitle: "创建活动",
	eventTypeHeaderTitle: "活动类型",
	noEventTypesEnabled: "没有活动类型启用",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "允许 1:1 预订。"
		},
		collective: {
			label: "标准预订",
			desc: "允许 n:1 预订，包括额外参与者。"
		},
		maxFairness: {
			label: "轮询 - 最大公平性",
			desc: "轮询所选参与者列表，显示最近预订最少的参与者。"
		},
		maxAvailability: {
			label: "轮询 - 最大可用性",
			desc: "轮询所选参与者列表，优先显示最近预订最少的参与者，但尽可能多地提供时间段。"
		},
		group: {
			label: "组/班级",
			desc: "这些是通常具有一个组织者和多个参与者的活动。"
		}
	}
};
const pageSettingsButton$2 = "页面设置";
const nylasEventCalendar$2 = {
	hideNonGroupEvents: {
		showLabel: "过滤事件",
		tooltip: {
			desc: "选择要显示在日历中的事件类型。"
		},
		options: {
			all: "所有",
			group: "仅群组"
		}
	},
	createEventDetails: {
		headerTitle: "事件详情",
		closeButtonTooltip: "关闭",
		cancelButton: "取消",
		createButton: "创建"
	},
	discardChanges: {
		headerTitle: "确定要放弃未保存的更改吗？",
		cancelButton: "取消",
		discardButton: "放弃"
	},
	unsavedChanges: "未保存的更改",
	editEventDetails: {
		headerTitle: "事件详情",
		closeButtonTooltip: "关闭",
		deleteButton: "删除",
		saveButton: "保存",
		pastEventTooltip: "此事件已过去，无法编辑。"
	},
	importEvent: {
		closeButtonTooltip: "关闭",
		importButton: "导入",
		participantsLabel: "参与者"
	},
	deleteEvent: {
		closeButtonTooltip: "关闭",
		deleting: "删除中..."
	},
	editOptions: {
		headerTitle: "选项",
		closeButtonTooltip: "关闭",
		deleting: "删除中...",
		"import": "导入",
		edit: "编辑",
		deleteThis: "删除此事件",
		deleteAll: "删除所有事件",
		importTooltip: "允许您从日历中选择现有事件并将其配置为组事件"
	},
	updateOptions: {
		updateThis: "更新此事件",
		updateAll: "更新所有事件",
		updateFuture: "更新所有未来事件"
	},
	deleteOptions: {
		deleteThis: "删除",
		deleteFuture: "删除此事件和所有未来事件",
		deleteAll: "删除所有事件"
	}
};
const zhCn$1 = {
	noDateSelected: noDateSelected$2,
	rescheduleTitle: rescheduleTitle$2,
	allDay: allDay$2,
	today: today$2,
	spotsLeft: spotsLeft$2,
	search: search$2,
	selectOneOrMoreOptions: selectOneOrMoreOptions$2,
	days: days$2,
	time: time$2,
	months: months$2,
	multipleOptionsSelected: multipleOptionsSelected$2,
	selectAtLeastOneOption: selectAtLeastOneOption$2,
	nextButton: nextButton$2,
	selectedDayAndYear: selectedDayAndYear$2,
	selectedTime: selectedTime$2,
	name: name$2,
	namePlaceholder: namePlaceholder$2,
	email: email$2,
	emailPlaceholder: emailPlaceholder$2,
	guestEmail: guestEmail$2,
	guestEmailPlaceholder: guestEmailPlaceholder$2,
	addGuest: addGuest$2,
	addAnotherGuest: addAnotherGuest$2,
	backButton: backButton$2,
	bookNowButton: bookNowButton$2,
	bookingConfirmed: bookingConfirmed$2,
	bookingConfirmedDescription: bookingConfirmedDescription$2,
	bookingSent: bookingSent$2,
	bookingSentDescription: bookingSentDescription$2,
	bookingRescheduled: bookingRescheduled$2,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$2,
	cancelBookingButton: cancelBookingButton$2,
	rescheduleBookingButton: rescheduleBookingButton$2,
	rejectBookingButton: rejectBookingButton$2,
	confirmBookingButton: confirmBookingButton$2,
	bookingPendingTitle: bookingPendingTitle$2,
	bookingPendingnDescription: bookingPendingnDescription$2,
	confirmedEventCardTitle: confirmedEventCardTitle$2,
	confirmedEventCardDescription: confirmedEventCardDescription$2,
	cancelBookingTitle: cancelBookingTitle$2,
	cancelBookingMessage: cancelBookingMessage$2,
	reasonForCancellation: reasonForCancellation$2,
	goBackButton: goBackButton$2,
	bookingCancelledTitle: bookingCancelledTitle$2,
	bookingCancelledMessage: bookingCancelledMessage$2,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$2,
	closeButton: closeButton$2,
	closingButton: closingButton$2,
	fieldRequired: fieldRequired$2,
	invalidInputFormat: invalidInputFormat$2,
	createBookingErrorTitle: createBookingErrorTitle$2,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$2,
	cancelBookingErrorTitle: cancelBookingErrorTitle$2,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$2,
	getUISettingErrorTitle: getUISettingErrorTitle$2,
	rejectBookingErrorTitle: rejectBookingErrorTitle$2,
	confirmBookingErrorTitle: confirmBookingErrorTitle$2,
	genericErrorTitle: genericErrorTitle$2,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$2,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$2,
	publicConfigErrorMessage: publicConfigErrorMessage$2,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$1,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$2,
	cancellationErrorTitle: cancellationErrorTitle$2,
	cancellationErrorMessage: cancellationErrorMessage$2,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$2,
	cancelBokingFormError: cancelBokingFormError$2,
	feedbackFormTitle: feedbackFormTitle$2,
	feedbackFormDescription: feedbackFormDescription$2,
	feedbackMessageLabel: feedbackMessageLabel$2,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$2,
	feedbackModalCloseButton: feedbackModalCloseButton$2,
	feedbackModalSubmitButton: feedbackModalSubmitButton$2,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$2,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$2,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$2,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$2,
	schedulerEditorTitle: schedulerEditorTitle$2,
	allSchedulingPages: allSchedulingPages$2,
	createAndManageSchedulingPages: createAndManageSchedulingPages$2,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$2,
	pageTitle: pageTitle$2,
	durationTitle: durationTitle$2,
	loading: loading$2,
	required: required$2,
	optional: optional$2,
	loadingPagesDescription: loadingPagesDescription$2,
	noSchedulingPages: noSchedulingPages$2,
	createFirstSchedulingPage: createFirstSchedulingPage$2,
	editSchedulingPageButtonText: editSchedulingPageButtonText$2,
	eventInfoTab: eventInfoTab$2,
	availabilityTab: availabilityTab$2,
	participantsTab: participantsTab$2,
	bookingOptionsTab: bookingOptionsTab$2,
	returnToCalendarView: returnToCalendarView$2,
	bookingFormTab: bookingFormTab$2,
	communicationsTab: communicationsTab$2,
	pageStylesTab: pageStylesTab$2,
	savingButtonText: savingButtonText$2,
	saveChangesButtonText: saveChangesButtonText$2,
	createButtonText: createButtonText$2,
	timePeriod_day: timePeriod_day$2,
	timePeriod_week: timePeriod_week$2,
	timePeriod_month: timePeriod_month$2,
	timePeriod_year: timePeriod_year$2,
	timeDuration_minute: timeDuration_minute$2,
	timeDuration_hour: timeDuration_hour$2,
	eventCommunicationsTitle: eventCommunicationsTitle$2,
	eventCommunicationsDescription: eventCommunicationsDescription$2,
	unsavedChangesLabel: unsavedChangesLabel$2,
	changesSavedLabel: changesSavedLabel$2,
	fixFormErrors: fixFormErrors$2,
	nylasEditorTabs: nylasEditorTabs$2,
	nylasEditorTabsGroup: nylasEditorTabsGroup$2,
	nylasListConfigurations: nylasListConfigurations$2,
	nylasAdditionalParticipants: nylasAdditionalParticipants$2,
	nylasAvailabilityPicker: nylasAvailabilityPicker$2,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$2,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$2,
	nylasBookingConfirmationType: nylasBookingConfirmationType$2,
	nylasBookingFormConfig: nylasBookingFormConfig$2,
	nylasBufferTime: nylasBufferTime$2,
	nylasCalendarPicker: nylasCalendarPicker$2,
	nylasCancellationPolicy: nylasCancellationPolicy$2,
	nylasConfirmationEmail: nylasConfirmationEmail$2,
	nylasConnectedCalendars: nylasConnectedCalendars$2,
	nylasCustomBookingFlow: nylasCustomBookingFlow$2,
	nylasCustomEventSlug: nylasCustomEventSlug$2,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$2,
	nylasEventDescription: nylasEventDescription$2,
	nylasEventDuration: nylasEventDuration$2,
	nylasEventInfo: nylasEventInfo$2,
	nylasEventLimits: nylasEventLimits$2,
	nylasEventLocation: nylasEventLocation$2,
	nylasEventTitle: nylasEventTitle$2,
	nylasLimitFutureBookings: nylasLimitFutureBookings$2,
	nylasMinBookingNotice: nylasMinBookingNotice$2,
	nylasMinCancellationNotice: nylasMinCancellationNotice$2,
	nylasPageName: nylasPageName$2,
	nylasPageStyling: nylasPageStyling$2,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$2,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$2,
	nylasReminderEmails: nylasReminderEmails$2,
	nylasSchedulingMethod: nylasSchedulingMethod$2,
	nylasTimeslotInterval: nylasTimeslotInterval$2,
	nylasEventTimeslot: nylasEventTimeslot$2,
	nylasEventCapacity: nylasEventCapacity$2,
	nylasSelectEventType: nylasSelectEventType$2,
	pageSettingsButton: pageSettingsButton$2,
	nylasEventCalendar: nylasEventCalendar$2
};

const zhCnTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$2,
  rescheduleTitle: rescheduleTitle$2,
  allDay: allDay$2,
  today: today$2,
  spotsLeft: spotsLeft$2,
  search: search$2,
  selectOneOrMoreOptions: selectOneOrMoreOptions$2,
  days: days$2,
  time: time$2,
  months: months$2,
  multipleOptionsSelected: multipleOptionsSelected$2,
  selectAtLeastOneOption: selectAtLeastOneOption$2,
  nextButton: nextButton$2,
  selectedDayAndYear: selectedDayAndYear$2,
  selectedTime: selectedTime$2,
  name: name$2,
  namePlaceholder: namePlaceholder$2,
  email: email$2,
  emailPlaceholder: emailPlaceholder$2,
  guestEmail: guestEmail$2,
  guestEmailPlaceholder: guestEmailPlaceholder$2,
  addGuest: addGuest$2,
  addAnotherGuest: addAnotherGuest$2,
  backButton: backButton$2,
  bookNowButton: bookNowButton$2,
  bookingConfirmed: bookingConfirmed$2,
  bookingConfirmedDescription: bookingConfirmedDescription$2,
  bookingSent: bookingSent$2,
  bookingSentDescription: bookingSentDescription$2,
  bookingRescheduled: bookingRescheduled$2,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$2,
  cancelBookingButton: cancelBookingButton$2,
  rescheduleBookingButton: rescheduleBookingButton$2,
  rejectBookingButton: rejectBookingButton$2,
  confirmBookingButton: confirmBookingButton$2,
  bookingPendingTitle: bookingPendingTitle$2,
  bookingPendingnDescription: bookingPendingnDescription$2,
  confirmedEventCardTitle: confirmedEventCardTitle$2,
  confirmedEventCardDescription: confirmedEventCardDescription$2,
  cancelBookingTitle: cancelBookingTitle$2,
  cancelBookingMessage: cancelBookingMessage$2,
  reasonForCancellation: reasonForCancellation$2,
  goBackButton: goBackButton$2,
  bookingCancelledTitle: bookingCancelledTitle$2,
  bookingCancelledMessage: bookingCancelledMessage$2,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$2,
  closeButton: closeButton$2,
  closingButton: closingButton$2,
  fieldRequired: fieldRequired$2,
  invalidInputFormat: invalidInputFormat$2,
  createBookingErrorTitle: createBookingErrorTitle$2,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$2,
  cancelBookingErrorTitle: cancelBookingErrorTitle$2,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$2,
  getUISettingErrorTitle: getUISettingErrorTitle$2,
  rejectBookingErrorTitle: rejectBookingErrorTitle$2,
  confirmBookingErrorTitle: confirmBookingErrorTitle$2,
  genericErrorTitle: genericErrorTitle$2,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$2,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$2,
  publicConfigErrorMessage: publicConfigErrorMessage$2,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle$1,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$2,
  cancellationErrorTitle: cancellationErrorTitle$2,
  cancellationErrorMessage: cancellationErrorMessage$2,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$2,
  cancelBokingFormError: cancelBokingFormError$2,
  feedbackFormTitle: feedbackFormTitle$2,
  feedbackFormDescription: feedbackFormDescription$2,
  feedbackMessageLabel: feedbackMessageLabel$2,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$2,
  feedbackModalCloseButton: feedbackModalCloseButton$2,
  feedbackModalSubmitButton: feedbackModalSubmitButton$2,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$2,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$2,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$2,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$2,
  schedulerEditorTitle: schedulerEditorTitle$2,
  allSchedulingPages: allSchedulingPages$2,
  createAndManageSchedulingPages: createAndManageSchedulingPages$2,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$2,
  pageTitle: pageTitle$2,
  durationTitle: durationTitle$2,
  loading: loading$2,
  required: required$2,
  optional: optional$2,
  loadingPagesDescription: loadingPagesDescription$2,
  noSchedulingPages: noSchedulingPages$2,
  createFirstSchedulingPage: createFirstSchedulingPage$2,
  editSchedulingPageButtonText: editSchedulingPageButtonText$2,
  eventInfoTab: eventInfoTab$2,
  availabilityTab: availabilityTab$2,
  participantsTab: participantsTab$2,
  bookingOptionsTab: bookingOptionsTab$2,
  returnToCalendarView: returnToCalendarView$2,
  bookingFormTab: bookingFormTab$2,
  communicationsTab: communicationsTab$2,
  pageStylesTab: pageStylesTab$2,
  savingButtonText: savingButtonText$2,
  saveChangesButtonText: saveChangesButtonText$2,
  createButtonText: createButtonText$2,
  timePeriod_day: timePeriod_day$2,
  timePeriod_week: timePeriod_week$2,
  timePeriod_month: timePeriod_month$2,
  timePeriod_year: timePeriod_year$2,
  timeDuration_minute: timeDuration_minute$2,
  timeDuration_hour: timeDuration_hour$2,
  eventCommunicationsTitle: eventCommunicationsTitle$2,
  eventCommunicationsDescription: eventCommunicationsDescription$2,
  unsavedChangesLabel: unsavedChangesLabel$2,
  changesSavedLabel: changesSavedLabel$2,
  fixFormErrors: fixFormErrors$2,
  nylasEditorTabs: nylasEditorTabs$2,
  nylasEditorTabsGroup: nylasEditorTabsGroup$2,
  nylasListConfigurations: nylasListConfigurations$2,
  nylasAdditionalParticipants: nylasAdditionalParticipants$2,
  nylasAvailabilityPicker: nylasAvailabilityPicker$2,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$2,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$2,
  nylasBookingConfirmationType: nylasBookingConfirmationType$2,
  nylasBookingFormConfig: nylasBookingFormConfig$2,
  nylasBufferTime: nylasBufferTime$2,
  nylasCalendarPicker: nylasCalendarPicker$2,
  nylasCancellationPolicy: nylasCancellationPolicy$2,
  nylasConfirmationEmail: nylasConfirmationEmail$2,
  nylasConnectedCalendars: nylasConnectedCalendars$2,
  nylasCustomBookingFlow: nylasCustomBookingFlow$2,
  nylasCustomEventSlug: nylasCustomEventSlug$2,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$2,
  nylasEventDescription: nylasEventDescription$2,
  nylasEventDuration: nylasEventDuration$2,
  nylasEventInfo: nylasEventInfo$2,
  nylasEventLimits: nylasEventLimits$2,
  nylasEventLocation: nylasEventLocation$2,
  nylasEventTitle: nylasEventTitle$2,
  nylasLimitFutureBookings: nylasLimitFutureBookings$2,
  nylasMinBookingNotice: nylasMinBookingNotice$2,
  nylasMinCancellationNotice: nylasMinCancellationNotice$2,
  nylasPageName: nylasPageName$2,
  nylasPageStyling: nylasPageStyling$2,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$2,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$2,
  nylasReminderEmails: nylasReminderEmails$2,
  nylasSchedulingMethod: nylasSchedulingMethod$2,
  nylasTimeslotInterval: nylasTimeslotInterval$2,
  nylasEventTimeslot: nylasEventTimeslot$2,
  nylasEventCapacity: nylasEventCapacity$2,
  nylasSelectEventType: nylasSelectEventType$2,
  pageSettingsButton: pageSettingsButton$2,
  nylasEventCalendar: nylasEventCalendar$2,
  'default': zhCn$1
});

const noDateSelected$1 = "Geen datum geselecteerd";
const rescheduleTitle$1 = "Kies een ander tijdslot om je afspraak te verzetten";
const allDay$1 = "Alle dag";
const today$1 = "Vandaag";
const spotsLeft$1 = "{{count}} plaatsen over";
const search$1 = "Zoeken";
const selectOneOrMoreOptions$1 = "Selecteer minstens één optie";
const days$1 = {
	sunday: "ZO",
	monday: "MA",
	tuesday: "DI",
	wednesday: "WO",
	thursday: "DO",
	friday: "VR",
	saturday: "ZA"
};
const time$1 = {
	hour: "uur",
	hours: "uren",
	minute: "minuut",
	minutes: "minuten",
	day: "dag",
	days: "dagen",
	week: "week",
	weeks: "weken",
	month: "maand",
	months: "maanden",
	year: "jaar",
	years: "jaren"
};
const months$1 = {
	january: "Januari",
	february: "Februari",
	march: "Maart",
	april: "April",
	may: "Mei",
	june: "Juni",
	july: "Juli",
	august: "Augustus",
	september: "September",
	october: "Oktober",
	november: "November",
	december: "December"
};
const multipleOptionsSelected$1 = "Meerdere opties geselecteerd";
const selectAtLeastOneOption$1 = "Selecteer minstens één optie";
const nextButton$1 = "Volgende";
const selectedDayAndYear$1 = "{{date}}";
const selectedTime$1 = "{{time}}";
const name$1 = "Naam";
const namePlaceholder$1 = "Voer je naam in";
const email$1 = "E-mail";
const emailPlaceholder$1 = "Voer je e-mail in";
const guestEmail$1 = "E-mail van gast";
const guestEmailPlaceholder$1 = "Voer het e-mailadres van de gast in";
const addGuest$1 = "Gast toevoegen";
const addAnotherGuest$1 = "Nog een gast toevoegen";
const backButton$1 = "Terug";
const bookNowButton$1 = "Boek nu";
const bookingConfirmed$1 = "Boeking bevestigd";
const bookingConfirmedDescription$1 = "U ontvangt binnenkort een e-mailbevestiging.";
const bookingSent$1 = "Boeking verzonden";
const bookingSentDescription$1 = "U ontvangt een e-mail zodra de boeking is bevestigd.";
const bookingRescheduled$1 = "Boeking verplaatst";
const bookingDateAndTimeHeader$1 = "Boekingsdatum en -tijd";
const cancelBookingButton$1 = "Boeking annuleren";
const rescheduleBookingButton$1 = "Herplannen";
const rejectBookingButton$1 = "Boeking afwijzen";
const confirmBookingButton$1 = "Boeking bevestigen";
const bookingPendingTitle$1 = "Boeking in afwachting";
const bookingPendingnDescription$1 = "Beheer uw boeking hieronder. De genodigde ontvangt een e-mail over de status van de aanvraag.";
const confirmedEventCardTitle$1 = "Uw boeking is succesvol bevestigd";
const confirmedEventCardDescription$1 = "Een bevestigingsmail is verzonden naar";
const cancelBookingTitle$1 = "Boeking annuleren?";
const cancelBookingMessage$1 = "Uw huidige tijdslot zal beschikbaar worden voor anderen.";
const reasonForCancellation$1 = "Reden voor annulering";
const goBackButton$1 = "Ga terug";
const bookingCancelledTitle$1 = "Uw boeking is succesvol geannuleerd";
const bookingCancelledMessage$1 = "Er is een annuleringsmail verzonden naar";
const bookingCancelledMessage_theParticipants$1 = "deelnemers";
const closeButton$1 = "Sluiten";
const closingButton$1 = "Sluiten";
const fieldRequired$1 = "{{field}} is vereist.";
const invalidInputFormat$1 = "{{field}} heeft een ongeldig formaat.";
const createBookingErrorTitle$1 = "Boeking Maken";
const getAvailabilityErrorTitle$1 = "Beschikbaarheid Opvragen";
const cancelBookingErrorTitle$1 = "Boeking Annuleren";
const rescheduleBookingErrorTitle$1 = "Boeking Wijzigen";
const getUISettingErrorTitle$1 = "UI-instellingen Ophalen";
const rejectBookingErrorTitle$1 = "Boeking Afwijzen";
const confirmBookingErrorTitle$1 = "Boeking Bevestigen";
const genericErrorTitle$1 = "Er is iets misgegaan...";
const noSessionIdErrorTitle = "Geen sessie-ID!";
const schedulingComponentErrorTitle$1 = "Fout in planningscomponent";
const sessionIdRequiredErrorMessage$1 = "'sessionId' is vereist voor privéconfiguraties.";
const publicConfigErrorMessage$1 = "Als u een openbare configuratie gebruikt, geeft u een configurationId of een combinatie van 'slug' en 'clientId' door.";
const invalidTimeslotErrorMessage$1 = "Het geselecteerde tijdslot is ongeldig";
const cancellationErrorTitle$1 = "Annuleringsfout";
const cancellationErrorMessage$1 = "Geef een reden op voor de annulering.";
const minimumCancellationErrorMessage$1 = "U kunt de boeking niet annuleren binnen {{minCancellationNotice}} minuten voor het evenement";
const cancelBokingFormError$1 = "Fout in het annuleringsformulier";
const feedbackFormTitle$1 = "Deel uw feedback";
const feedbackFormDescription$1 = "Door ons uw feedback te geven en fouten te melden, helpt u ons een betere ervaring voor u te creëren.";
const feedbackMessageLabel$1 = "Geef ons een gedetailleerde beschrijving van de functie waarover u commentaar geeft of waar u een probleem heeft ondervonden.";
const feedbackMessagePlaceholder$1 = "Geef hier uw feedback";
const feedbackModalCloseButton$1 = "Sluiten";
const feedbackModalSubmitButton$1 = "Verzenden";
const deleteSchedulingPageTitle$1 = "Deze planningspagina verwijderen?";
const deleteSchedulingPageDescription$1 = "Na bevestiging worden deze pagina en de gekoppelde planningslinks permanent verwijderd en gedeactiveerd. Deze actie kan niet ongedaan worden gemaakt.";
const deleteSchedulingPageConfirmButton$1 = "Pagina verwijderen";
const deleteSchedulingPageCancelButton$1 = "Annuleren";
const schedulerEditorTitle$1 = "Planner Editor";
const allSchedulingPages$1 = "Alle planningspagina's";
const createAndManageSchedulingPages$1 = "Maak en beheer uw planningspagina's.";
const createNewSchedulingPageButtonText$1 = "Nieuwe maken";
const pageTitle$1 = "Paginatitel";
const durationTitle$1 = "Duur";
const loading$1 = "Bezig met laden";
const required$1 = "Vereist";
const optional$1 = "Optioneel";
const loadingPagesDescription$1 = "Even geduld terwijl we de planningspagina's ophalen";
const noSchedulingPages$1 = "Geen planningspagina's gevonden";
const createFirstSchedulingPage$1 = "Begin met het maken van uw eerste planningspagina";
const editSchedulingPageButtonText$1 = "Bewerken";
const eventInfoTab$1 = "Evenementinfo";
const availabilityTab$1 = "Beschikbaarheid";
const participantsTab$1 = "Deelnemers";
const bookingOptionsTab$1 = "Boekingsopties";
const returnToCalendarView$1 = "Terug naar de kalenderweergave";
const bookingFormTab$1 = "Boekingsformulier";
const communicationsTab$1 = "Communicatie";
const pageStylesTab$1 = "Paginastijlen";
const savingButtonText$1 = "Opslaan";
const saveChangesButtonText$1 = "Wijzigingen opslaan";
const createButtonText$1 = "Aanmaken";
const timePeriod_day$1 = "dag";
const timePeriod_week$1 = "week";
const timePeriod_month$1 = "maand";
const timePeriod_year$1 = "jaar";
const timeDuration_minute$1 = "minuut";
const timeDuration_hour$1 = "uur";
const eventCommunicationsTitle$1 = "Evenementcommunicatie";
const eventCommunicationsDescription$1 = "Stel automatische bevestigingsmails in.";
const unsavedChangesLabel$1 = "Niet-opgeslagen wijzigingen";
const changesSavedLabel$1 = "Wijzigingen opgeslagen";
const fixFormErrors$1 = "Corrigeer de formulierfouten.";
const nylasEditorTabs$1 = {
	bookingFormError: "Boekingsformulierfout: ",
	bookingFormError_label: "Label is vereist voor het veld van type {{type}}.",
	bookingFormError_option: "Lege optie gedetecteerd binnen {{label}} van type {{type}}.",
	formErrorTitle: "Formulierfout",
	updateConfigError: "Update config error: ",
	createConfigError: "Create config error: ",
	deleteConfigError: "Delete config error: ",
	getConfigsError: "Get configs error: "
};
const nylasEditorTabsGroup$1 = {
	eventTitleRequired: "Evenementtitel is vereist.",
	eventTimeRequired: "Evenementtijd is vereist.",
	participantsRequired: "Deelnemers zijn vereist.",
	participantEmailRequired: "Deelnemer-E-mail is vereist.",
	errorOccured: "Fout bij het opslaan van de wijzigingen.",
	createGroupEventError: "Fout bij het maken van het groepsereignis: ",
	updateGroupEventError: "Fout bij het bijwerken van het groepsereignis: ",
	deleteGroupEventError: "Fout bij het verwijderen van het groepsereignis: ",
	importGroupEventError: "Fout bij het importeren van het groepsereignis: ",
	getGroupEventsError: "Fout bij het ophalen van het groepsereignis: "
};
const nylasListConfigurations$1 = {
	previewButtonText: "Voorbeeld",
	copyLinkButtonText: "Kopieer link",
	deleteButtonText: "Verwijderen"
};
const nylasAdditionalParticipants$1 = {
	headerTitle: "Deelnemers",
	headerSubTitle: "Voeg mensen van uw team of organisatie toe aan het evenement.",
	organizerAsParticipant: "Deelnemer",
	organizer: "Organisator",
	participant: "Deelnemer",
	addParticipant_first: "Een deelnemer toevoegen",
	addParticipant_next: "Nog een deelnemer toevoegen",
	tooltip: {
		includeOrganizer: "Organisator opnemen",
		includeOrganizerDesc: "De organisator (u) wordt opgenomen in de beurtrolrotatie.",
		excludeOrganizer: "Organisator uitsluiten",
		excludeOrganizerDesc: "De organisator (u) wordt niet opgenomen in de beurtrolrotatie."
	},
	error: "Voeg minstens één deelnemer toe"
};
const nylasAvailabilityPicker$1 = {
	headerTitle: "Standaard openingstijden",
	headerSubTitle: "Stel in wanneer u regelmatig beschikbaar bent voor boekingen.",
	tooltip: {
		desc: "Dit is de standaard beschikbaarheid voor deelnemers die geen beschikbaarheid hebben ingesteld op het tabblad Deelnemers."
	},
	selectTimezone: "Selecteer tijdzone",
	unavailable: "Niet beschikbaar",
	days: {
		SUN: "ZON",
		MON: "MAA",
		TUE: "DIN",
		WED: "WOE",
		THU: "DON",
		FRI: "VRIJ",
		SAT: "ZAT"
	},
	errors: {
		invalid: "Ongeldig"
	}
};
const nylasBookingCalendarPicker$1 = {
	headerTitle: "Kalender boeken",
	headerSubTitle: "Selecteer de kalender waarin u boekingen wilt toevoegen.",
	tooltip: {
		desc: "De kalender wordt gebruikt om evenementen te maken."
	},
	selectOptionLabel: "Selecteer een optie",
	selectCalendarErrorMessage: "Selecteer een kalender"
};
const nylasBookingConfirmationRedirect$1 = {
	dropdownLabel: "Wanneer een boeking wordt bevestigd",
	tooltip: {
		desc: "U kunt de standaard bevestigingspagina weergeven of gebruikers omleiden naar uw eigen bevestigingspagina."
	},
	redirectOption_default: "Standaard bevestigingspagina weergeven",
	redirectOption_custom: "Omleiden naar aangepaste URL"
};
const nylasBookingConfirmationType$1 = {
	dropdownLabel: "Wanneer een boeking wordt aangevraagd",
	tooltip: {
		desc: "Handmatig accepteren van boekingen stelt u in staat om elke boekingsaanvraag te beoordelen en te accepteren of te weigeren."
	},
	bookingOption_booking: "Boekingen automatisch accepteren",
	bookingOption_organizerConfirmation: "Boekingen handmatig accepteren"
};
const nylasBookingFormConfig$1 = {
	headerTitle: "Boekingsformulier",
	headerSubTitle: "Voeg aangepaste velden toe aan het boekingsformulier.",
	dropdownButtonText: "Nieuw veld toevoegen",
	addOption: "Optie toevoegen",
	allOptionsHeader: "ALLE OPTIES",
	fieldInTitleError: "Dit veld wordt gebruikt in de evenementtitel en kan niet worden verwijderd.",
	fieldInDescriptionError: "Dit veld wordt gebruikt in de evenementbeschrijving en kan niet worden verwijderd.",
	label: "Label",
	defaultValue: "Standaardwaarde",
	fieldType: {
		text: "Korte tekst",
		multi_line_text: "Lange tekst",
		email: "E-mail",
		phone_number: "Telefoonnummer",
		dropdown: "Keuzelijst",
		radio_button: "Radioknop",
		checkbox: "Selectievakje",
		date: "Datum",
		metadata: "Metadata",
		multi_select: "Meervoudige selectie"
	},
	fieldLabel: {
		your_name: "Uw naam",
		your_email: "Uw e-mail",
		email: "Aanvullende e-mail",
		phone_number: "Telefoonnummer label",
		dropdown: "Dropdown label",
		text: "Korte tekst label",
		multi_line_text: "Lange tekst label",
		radio_button: "Radioknop label",
		checkbox: "Selectievakje label",
		date: "Datum label",
		metadata: "Metadata label",
		multi_select: "Meervoudige selectie label"
	}
};
const nylasBufferTime$1 = {
	headerTitle: "Buffertijd",
	headerSubTitle: "Vereist lege buffertijd vóór en na een evenement.",
	tooltip: {
		desc: "De planner boekt de buffertijd niet."
	},
	beforeBufferLabel: "Voor het evenement",
	afterBufferLabel: "Na het evenement",
	minutesShort: "min",
	previewHeader: "VOORBEELD"
};
const nylasCalendarPicker$1 = {
	calendarPickerLabel: "Selecteer agenda's die worden gecontroleerd op beschikbaarheid",
	selectAtLeastOneCalendar: "Selecteer minstens één agenda voor elke deelnemer."
};
const nylasCancellationPolicy$1 = {
	cancellationPolicyLabel: "Annuleringsbeleid bericht",
	tooltip: {
		desc: "Deelnemers ontvangen dit bericht als ze proberen het evenement te annuleren. Ze worden gevraagd een reden voor annulering op te geven."
	}
};
const nylasConfirmationEmail$1 = {
	headerTitle: "Boeking bevestigd{{organizerName}}",
	headerSubTitle: "Bevestigingsmail voor boeking",
	editButtonText: "Bewerken",
	error: {
		invalidImageUrl: "Ongeldige afbeelding URL."
	},
	confirmationEmail: {
		label: "E-mailmeldingen inschakelen",
		tooltip: {
			desc: "Sta Nylas toe e-mailmeldingen te verzenden, inclusief bevestigingsberichten en evenementherinneringen.",
			language: "Deze taal wordt gebruikt voor e-mailmeldingen aan de organisatoren."
		},
		language: "Taal selecteren"
	},
	nylasBranding: {
		label: "Nylas-branding tonen",
		tooltip: {
			desc: "Schakel dit uit om de voettekst in de e-mailcommunicatie te verbergen."
		}
	},
	companyLogoUrl: {
		label: "Bedrijfslogo-URL",
		tooltip: {
			desc: "Dit logo verschijnt in de bevestigingsmail voor boeking. De URL moet openbaar toegankelijk zijn. De afbeelding wordt verkleind tot een maximale grootte van 200px x 100px."
		}
	},
	emailMessage: {
		header: "E-mailbericht",
		label: "Aangepaste e-mailtitel",
		tooltip: {
			desc: "Een e-mailtitel is een kop in de e-mailtekst. Dit wijzigt de onderwerpregel niet."
		},
		additionalInfoLabel: "Aanvullende informatie",
		additionalInfoTooltip: "De planner voegt de inhoud van dit veld toe aan de e-mailtekst.",
		additionalInfoPlaceholder: "Standaardtekst"
	},
	allHosts: "Alle hosts en gasten",
	immediatelyUponBooking: "Direct na boeking"
};
const nylasConnectedCalendars$1 = {
	headerTitle: "Verbonden agenda's",
	headerSubTitle: "Selecteer de agenda's die worden gebruikt om uw beschikbaarheid te controleren.",
	tooltip: {
		desc: "Controleer beschikbaarheid in een of meer agenda's. Als u meerdere agenda's voor een deelnemer selecteert, moet de deelnemer in al zijn agenda's beschikbaar zijn om als beschikbaar te worden beschouwd."
	},
	participantCalendarTitle: "Verbonden agenda's van {{participantName}}",
	selectAtLeastOneCalendar: "Selecteer minstens één agenda voor elke deelnemer."
};
const nylasCustomBookingFlow$1 = {
	headerTitle: "Aangepaste boekingsflow"
};
const nylasCustomEventSlug$1 = {
	headerTitle: "Aangepaste pagina slug",
	headerSubTitle: "Maak een aangepaste URL-slug voor deze pagina.",
	eventSlugLabel: "Pagina-URL-slug",
	tooltip: {
		desc: "Geef een aangepaste slug op voor uw URL om uw pagina uniek te identificeren (alleen letters, cijfers en streepjes)."
	},
	copied: "Gekopieerd!"
};
const nylasCustomizeBookingSettings$1 = {
	headerTitle: "Aanvullende instellingen",
	headerSubTitle: "Boekingsinstellingen voor het evenement.",
	tooltip: {
		desc: "Pas uw boekingsinstellingen aan."
	},
	allowGuests: {
		label: "Sta gasten toe om extra gasten uit te nodigen."
	},
	hideReschedule: {
		label: "Optie voor herplanning verbergen.",
		tooltip: {
			desc: "Verberg de knop 'Herplannen' in de boekingsbevestiging en e-mailmeldingen."
		}
	},
	hideCancel: {
		label: "Optie voor annuleren verbergen",
		tooltip: {
			desc: "Verberg de knop 'Annuleren' in de boekingsbevestiging en e-mailmeldingen."
		}
	}
};
const nylasEventDescription$1 = {
	headerTitle: "Eventbeschrijving",
	addAdditionalFields: {
		buttonText: "Extra velden automatisch invullen",
		tooltip: {
			desc: "Klik hierop nadat u alle velden heeft toegevoegd die u in de beschrijving wilt opnemen. Belangrijk: Laat de markeringen '--- Additional Fields ---' en '--- End Additional Fields ---' ongewijzigd om ervoor te zorgen dat alles correct werkt."
		}
	},
	tooltip: {
		desc: "De eventbeschrijving wordt weergegeven in de beheerweergave van de planner en in het antwoord als een boeking wordt gemaakt."
	}
};
const nylasEventDuration$1 = {
	headerTitle: "Duur van het evenement",
	error: {
		durationMustBeMultipleOf5: "De duur moet een veelvoud van 5 zijn",
		durationMustBeGreaterThan0: "De duur moet groter zijn dan 0"
	}
};
const nylasEventInfo$1 = {
	headerTitle: "Eventinformatie"
};
const nylasEventLimits$1 = {
	headerTitle: "Eventlimieten"
};
const nylasEventLocation$1 = {
	headerTitle: "Evenementlocatie of vergadering",
	tooltip: {
		desc: "Kies een conferentieoptie of voeg een aangepaste locatie toe."
	},
	conferenceOptions: {
		none: "Geen",
		zoom: "Zoom-vergadering",
		google: "Google Meet",
		microsoft: "Microsoft Teams",
		custom: "Aangepaste locatie"
	}
};
const nylasEventTitle$1 = {
	headerTitle: "Eventtitel",
	helpText_start: "Maak een dynamische gebeurtenis met sjabloon {{field}} door te typen",
	helpText_end: "en een template-item te selecteren.",
	title: "titel",
	description: "beschrijving",
	tooltip: {
		desc: "Bijvoorbeeld: Interview met"
	},
	eventTitleRequired: "Eventtitel is vereist",
	eventTitleTokenDescription: {
		invitee: "De naam van de hoofdinzijer.",
		inviteeEmail: "De e-mailadres van de hoofdinzijer.",
		duration: "De duur van het evenement."
	}
};
const nylasLimitFutureBookings$1 = {
	headerTitle: "Beperk toekomstige boekingen",
	tooltip: {
		desc: "De limiet voor hoe ver in de toekomst boekingen kunnen worden gemaakt."
	}
};
const nylasMinBookingNotice$1 = {
	headerTitle: "Minimale boekingsmelding",
	tooltip: {
		desc: "De minimale hoeveelheid tijd in de toekomst waarin een nieuwe boeking kan worden gemaakt."
	}
};
const nylasMinCancellationNotice$1 = {
	headerTitle: "Minimale annuleringsmelding",
	tooltip: {
		desc: "De minimale hoeveelheid tijd die nodig is om een boeking te annuleren."
	}
};
const nylasPageName$1 = {
	headerTitle: "Paginanaam",
	headerSubTitle: "Stel de naam van de planningspagina in.",
	pageNameError: "Voer een paginanaam in",
	tooltip: {
		desc: "Standaard gebruiken planningspagina's uw gebruikersnaam als paginanaam. De paginanaam wordt weergegeven in de linkerbovenhoek van de kalenderweergave."
	}
};
const nylasPageStyling$1 = {
	headerTitle: "Pagina-opmaak en -aanpassing"
};
const nylasParticipantBookingCalendars$1 = {
	headerTitle: "Boeken naar deze agenda",
	headerSubTitle: "Selecteer de agenda waarin u boekingen voor evenementen wilt toevoegen.",
	participantBookingCalendarTitle: "{{participantName}}'s boekingsagenda's",
	selectAtLeastOneCalendar: "Selecteer minstens één agenda voor elke deelnemer."
};
const nylasParticipantCustomAvailability$1 = {
	headerTitle: "Beschikbaarheid van deelnemer",
	headerSubTitle: "Als deze niet is ingesteld, worden de standaard openingstijden gebruikt om de beschikbaarheid voor deze deelnemer te berekenen.",
	participantOpenHoursTitle: "{{participantName}}'s openingstijden"
};
const nylasReminderEmails$1 = {
	headerTitle: "Komende vergadering {{organizerName}}",
	headerSubTitle: "Herinnering vóór evenement",
	editButtonText: "Bewerken",
	recipientOptions_all: "Alle hosts en gasten",
	recipientOptions_guest: "Alle gasten van het evenement",
	recipientOptions_host: "Alleen evenementhost",
	beforeTheEvent: "voor het evenement",
	emailRecipients: {
		label: "E-mailontvangers"
	},
	sendConfirmation: {
		label: "Stuur een bevestigingsmail wanneer",
		tooltip: {
			desc: "De ontvangers ontvangen een herinneringsmail op het opgegeven tijdstip vóór het evenement."
		}
	},
	emailSubject: {
		label: "Onderwerp van de e-mail",
		placeholder: "Komende vergadering {{organizerName}}"
	},
	reminderMinutesValidationError: "Voer de herinneringsminuten in veelvouden van 5 in. Probeer ",
	newReminderButtonText: "Nieuwe herinnering"
};
const nylasSchedulingMethod$1 = {
	headerTitle: "Planningsmethode",
	headerSubTitle: "Selecteer een planningsmethode voor het evenement.",
	tooltip: {
		standard: {
			label: "Standaard",
			desc: "Staat 1:1 boekingen of n:1 boekingen toe met extra deelnemers."
		},
		maxFairness: {
			label: "Rondgang - Maximale eerlijkheid",
			desc: "Doorloopt de lijst met geselecteerde deelnemers en toont de deelnemer met de minste recente boekingen."
		},
		maxAvailability: {
			label: "Rondgang - Maximale beschikbaarheid",
			desc: "Doorloopt de lijst met geselecteerde deelnemers, prioriteert deelnemers met de minste boekingen, maar maakt zoveel mogelijk tijdslots beschikbaar."
		}
	},
	schedulingMethodOptions_collective: "Standaard boeking",
	schedulingMethodOptions_maxFairness: "Rondgang - Maximale eerlijkheid",
	schedulingMethodOptions_maxAvailability: "Rondgang - Maximale beschikbaarheid"
};
const nylasTimeslotInterval$1 = {
	minutesShort: "min",
	lengthOfMeeting: "Lengte van de vergadering",
	headerTitle: "Tijdslotinstellingen",
	timeslotInterval: {
		label: "Tijdslotinterval."
	},
	timeslotRounding: {
		label: "Type tijdslotafronding",
		tooltip: {
			desc: "Het interval waarop tijdslots worden weergegeven."
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "Intervalafronding",
			desc: "Tijdslots beginnen op tijden die zijn afgerond op de intervalwaarde."
		},
		noRounding: {
			label: "Standaard",
			desc: "Tijdslots worden afgerond op het dichtstbijzijnde kwartier."
		}
	}
};
const nylasEventTimeslot$1 = {
	recurrenceOptions: {
		none: "Herhaalt niet",
		daily: "Dagelijks",
		weekly: "Wekelijks elke {{dayOfWeek}}",
		monthly: "Maandelijks op {{dayOfMonth}}",
		monthOnDay: "Maandelijks op dag {{date}}",
		yearly: "Jaarlijks op {{dateOfMonth}}",
		custom: "Aangepast"
	},
	recurrenceLabel: "Herhaal dit evenement",
	endDate: "Einddatum",
	customRecurrence: {
		repeatEvery: "Herhaal elke",
		repeatOn: "Herhaal op",
		ends: "Eindigt",
		endsOptions: {
			never: "Nooit",
			after: "Na",
			on: "Op"
		},
		occurrences: "keer"
	},
	dateTimeLabel: "Datum en tijd",
	errors: {
		invalidTimeRange: "Ongeldige tijdsperiode",
		startTimeSameAsEndTime: "Starttijd en eindtijd kunnen niet dezelfde zijn",
		startTimeBeforeCurrentDate: "Starttijd kan niet in het verleden liggen",
		invalid: "Ongeldig"
	}
};
const nylasEventCapacity$1 = {
	headerTitle: "Genodigden",
	headerSubTitle: "Stel het maximale aantal genodigden in voor dit tijdslot van het evenement.",
	tooltip: {
		desc: "De organisator en deelnemers die zijn geconfigureerd op de planningspagina worden niet als genodigden geteld."
	},
	attendees: "genodigden"
};
const nylasSelectEventType$1 = {
	returnToAllSchedulingPages: "Terug naar alle planningspagina's",
	createEventHeaderTitle: "Evenement maken",
	eventTypeHeaderTitle: "Evenementtype",
	noEventTypesEnabled: "Geen evenementtypen ingeschakeld",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "Staat 1:1 boekingen toe."
		},
		collective: {
			label: "Standaard boeking",
			desc: "Staat n:1 boekingen toe met extra deelnemers."
		},
		maxFairness: {
			label: "Rondgang - Maximale eerlijkheid",
			desc: "Doorloopt de lijst met geselecteerde deelnemers en toont de deelnemer met de minste recente boekingen."
		},
		maxAvailability: {
			label: "Rondgang - Maximale beschikbaarheid",
			desc: "Doorloopt de lijst met geselecteerde deelnemers, prioriteert deelnemers met de minste boekingen, maar maakt zoveel mogelijk tijdslots beschikbaar."
		},
		group: {
			label: "Groep / Klasse",
			desc: "Dit zijn evenementen die meestal één organisator en meerdere deelnemers hebben."
		}
	}
};
const pageSettingsButton$1 = "Pagina-instellingen";
const nylasEventCalendar$1 = {
	hideNonGroupEvents: {
		showLabel: "Evenementen filteren",
		tooltip: {
			desc: "Selecteer het type evenement dat in de agenda wordt weergegeven."
		},
		options: {
			all: "Alle evenementen",
			group: "Alleen groepsevenementen"
		}
	},
	createEventDetails: {
		headerTitle: "Evenementdetails",
		closeButtonTooltip: "Sluiten",
		cancelButton: "Annuleren",
		createButton: "Maken"
	},
	discardChanges: {
		headerTitle: "Wilt u de wijzigingen annuleren?",
		cancelButton: "Annuleren",
		discardButton: "Annuleren"
	},
	unsavedChanges: "Ongewijzigde wijzigingen",
	editEventDetails: {
		headerTitle: "Evenementdetails",
		closeButtonTooltip: "Sluiten",
		deleteButton: "Verwijderen",
		saveButton: "Opslaan",
		pastEventTooltip: "Dit evenement is in het verleden en kan niet worden gewijzigd."
	},
	importEvent: {
		closeButtonTooltip: "Sluiten",
		importButton: "Importeren",
		participantsLabel: "Deelnemers"
	},
	deleteEvent: {
		closeButtonTooltip: "Sluiten",
		deleting: "Verwijderen..."
	},
	editOptions: {
		headerTitle: "Opties",
		closeButtonTooltip: "Sluiten",
		deleting: "Verwijderen...",
		"import": "Importeren",
		edit: "Bewerken",
		deleteThis: "Dit evenement verwijderen",
		deleteAll: "Alle evenementen verwijderen",
		importTooltip: "Staat toe om bestaande evenementen uit een agenda te importeren en deze als groepsevenementen te configureren"
	},
	updateOptions: {
		updateThis: "Dit evenement bijwerken",
		updateAll: "Alle evenementen bijwerken",
		updateFuture: "Alle toekomstige evenementen bijwerken"
	},
	deleteOptions: {
		deleteThis: "Verwijderen",
		deleteFuture: "Dit evenement en alle toekomstige evenementen verwijderen",
		deleteAll: "Alle evenementen verwijderen"
	}
};
const nl$1 = {
	noDateSelected: noDateSelected$1,
	rescheduleTitle: rescheduleTitle$1,
	allDay: allDay$1,
	today: today$1,
	spotsLeft: spotsLeft$1,
	search: search$1,
	selectOneOrMoreOptions: selectOneOrMoreOptions$1,
	days: days$1,
	time: time$1,
	months: months$1,
	multipleOptionsSelected: multipleOptionsSelected$1,
	selectAtLeastOneOption: selectAtLeastOneOption$1,
	nextButton: nextButton$1,
	selectedDayAndYear: selectedDayAndYear$1,
	selectedTime: selectedTime$1,
	name: name$1,
	namePlaceholder: namePlaceholder$1,
	email: email$1,
	emailPlaceholder: emailPlaceholder$1,
	guestEmail: guestEmail$1,
	guestEmailPlaceholder: guestEmailPlaceholder$1,
	addGuest: addGuest$1,
	addAnotherGuest: addAnotherGuest$1,
	backButton: backButton$1,
	bookNowButton: bookNowButton$1,
	bookingConfirmed: bookingConfirmed$1,
	bookingConfirmedDescription: bookingConfirmedDescription$1,
	bookingSent: bookingSent$1,
	bookingSentDescription: bookingSentDescription$1,
	bookingRescheduled: bookingRescheduled$1,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader$1,
	cancelBookingButton: cancelBookingButton$1,
	rescheduleBookingButton: rescheduleBookingButton$1,
	rejectBookingButton: rejectBookingButton$1,
	confirmBookingButton: confirmBookingButton$1,
	bookingPendingTitle: bookingPendingTitle$1,
	bookingPendingnDescription: bookingPendingnDescription$1,
	confirmedEventCardTitle: confirmedEventCardTitle$1,
	confirmedEventCardDescription: confirmedEventCardDescription$1,
	cancelBookingTitle: cancelBookingTitle$1,
	cancelBookingMessage: cancelBookingMessage$1,
	reasonForCancellation: reasonForCancellation$1,
	goBackButton: goBackButton$1,
	bookingCancelledTitle: bookingCancelledTitle$1,
	bookingCancelledMessage: bookingCancelledMessage$1,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$1,
	closeButton: closeButton$1,
	closingButton: closingButton$1,
	fieldRequired: fieldRequired$1,
	invalidInputFormat: invalidInputFormat$1,
	createBookingErrorTitle: createBookingErrorTitle$1,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle$1,
	cancelBookingErrorTitle: cancelBookingErrorTitle$1,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$1,
	getUISettingErrorTitle: getUISettingErrorTitle$1,
	rejectBookingErrorTitle: rejectBookingErrorTitle$1,
	confirmBookingErrorTitle: confirmBookingErrorTitle$1,
	genericErrorTitle: genericErrorTitle$1,
	noSessionIdErrorTitle: noSessionIdErrorTitle,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle$1,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$1,
	publicConfigErrorMessage: publicConfigErrorMessage$1,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$1,
	cancellationErrorTitle: cancellationErrorTitle$1,
	cancellationErrorMessage: cancellationErrorMessage$1,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage$1,
	cancelBokingFormError: cancelBokingFormError$1,
	feedbackFormTitle: feedbackFormTitle$1,
	feedbackFormDescription: feedbackFormDescription$1,
	feedbackMessageLabel: feedbackMessageLabel$1,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder$1,
	feedbackModalCloseButton: feedbackModalCloseButton$1,
	feedbackModalSubmitButton: feedbackModalSubmitButton$1,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle$1,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription$1,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$1,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$1,
	schedulerEditorTitle: schedulerEditorTitle$1,
	allSchedulingPages: allSchedulingPages$1,
	createAndManageSchedulingPages: createAndManageSchedulingPages$1,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$1,
	pageTitle: pageTitle$1,
	durationTitle: durationTitle$1,
	loading: loading$1,
	required: required$1,
	optional: optional$1,
	loadingPagesDescription: loadingPagesDescription$1,
	noSchedulingPages: noSchedulingPages$1,
	createFirstSchedulingPage: createFirstSchedulingPage$1,
	editSchedulingPageButtonText: editSchedulingPageButtonText$1,
	eventInfoTab: eventInfoTab$1,
	availabilityTab: availabilityTab$1,
	participantsTab: participantsTab$1,
	bookingOptionsTab: bookingOptionsTab$1,
	returnToCalendarView: returnToCalendarView$1,
	bookingFormTab: bookingFormTab$1,
	communicationsTab: communicationsTab$1,
	pageStylesTab: pageStylesTab$1,
	savingButtonText: savingButtonText$1,
	saveChangesButtonText: saveChangesButtonText$1,
	createButtonText: createButtonText$1,
	timePeriod_day: timePeriod_day$1,
	timePeriod_week: timePeriod_week$1,
	timePeriod_month: timePeriod_month$1,
	timePeriod_year: timePeriod_year$1,
	timeDuration_minute: timeDuration_minute$1,
	timeDuration_hour: timeDuration_hour$1,
	eventCommunicationsTitle: eventCommunicationsTitle$1,
	eventCommunicationsDescription: eventCommunicationsDescription$1,
	unsavedChangesLabel: unsavedChangesLabel$1,
	changesSavedLabel: changesSavedLabel$1,
	fixFormErrors: fixFormErrors$1,
	nylasEditorTabs: nylasEditorTabs$1,
	nylasEditorTabsGroup: nylasEditorTabsGroup$1,
	nylasListConfigurations: nylasListConfigurations$1,
	nylasAdditionalParticipants: nylasAdditionalParticipants$1,
	nylasAvailabilityPicker: nylasAvailabilityPicker$1,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker$1,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$1,
	nylasBookingConfirmationType: nylasBookingConfirmationType$1,
	nylasBookingFormConfig: nylasBookingFormConfig$1,
	nylasBufferTime: nylasBufferTime$1,
	nylasCalendarPicker: nylasCalendarPicker$1,
	nylasCancellationPolicy: nylasCancellationPolicy$1,
	nylasConfirmationEmail: nylasConfirmationEmail$1,
	nylasConnectedCalendars: nylasConnectedCalendars$1,
	nylasCustomBookingFlow: nylasCustomBookingFlow$1,
	nylasCustomEventSlug: nylasCustomEventSlug$1,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$1,
	nylasEventDescription: nylasEventDescription$1,
	nylasEventDuration: nylasEventDuration$1,
	nylasEventInfo: nylasEventInfo$1,
	nylasEventLimits: nylasEventLimits$1,
	nylasEventLocation: nylasEventLocation$1,
	nylasEventTitle: nylasEventTitle$1,
	nylasLimitFutureBookings: nylasLimitFutureBookings$1,
	nylasMinBookingNotice: nylasMinBookingNotice$1,
	nylasMinCancellationNotice: nylasMinCancellationNotice$1,
	nylasPageName: nylasPageName$1,
	nylasPageStyling: nylasPageStyling$1,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$1,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$1,
	nylasReminderEmails: nylasReminderEmails$1,
	nylasSchedulingMethod: nylasSchedulingMethod$1,
	nylasTimeslotInterval: nylasTimeslotInterval$1,
	nylasEventTimeslot: nylasEventTimeslot$1,
	nylasEventCapacity: nylasEventCapacity$1,
	nylasSelectEventType: nylasSelectEventType$1,
	pageSettingsButton: pageSettingsButton$1,
	nylasEventCalendar: nylasEventCalendar$1
};

const nlTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected$1,
  rescheduleTitle: rescheduleTitle$1,
  allDay: allDay$1,
  today: today$1,
  spotsLeft: spotsLeft$1,
  search: search$1,
  selectOneOrMoreOptions: selectOneOrMoreOptions$1,
  days: days$1,
  time: time$1,
  months: months$1,
  multipleOptionsSelected: multipleOptionsSelected$1,
  selectAtLeastOneOption: selectAtLeastOneOption$1,
  nextButton: nextButton$1,
  selectedDayAndYear: selectedDayAndYear$1,
  selectedTime: selectedTime$1,
  name: name$1,
  namePlaceholder: namePlaceholder$1,
  email: email$1,
  emailPlaceholder: emailPlaceholder$1,
  guestEmail: guestEmail$1,
  guestEmailPlaceholder: guestEmailPlaceholder$1,
  addGuest: addGuest$1,
  addAnotherGuest: addAnotherGuest$1,
  backButton: backButton$1,
  bookNowButton: bookNowButton$1,
  bookingConfirmed: bookingConfirmed$1,
  bookingConfirmedDescription: bookingConfirmedDescription$1,
  bookingSent: bookingSent$1,
  bookingSentDescription: bookingSentDescription$1,
  bookingRescheduled: bookingRescheduled$1,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader$1,
  cancelBookingButton: cancelBookingButton$1,
  rescheduleBookingButton: rescheduleBookingButton$1,
  rejectBookingButton: rejectBookingButton$1,
  confirmBookingButton: confirmBookingButton$1,
  bookingPendingTitle: bookingPendingTitle$1,
  bookingPendingnDescription: bookingPendingnDescription$1,
  confirmedEventCardTitle: confirmedEventCardTitle$1,
  confirmedEventCardDescription: confirmedEventCardDescription$1,
  cancelBookingTitle: cancelBookingTitle$1,
  cancelBookingMessage: cancelBookingMessage$1,
  reasonForCancellation: reasonForCancellation$1,
  goBackButton: goBackButton$1,
  bookingCancelledTitle: bookingCancelledTitle$1,
  bookingCancelledMessage: bookingCancelledMessage$1,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants$1,
  closeButton: closeButton$1,
  closingButton: closingButton$1,
  fieldRequired: fieldRequired$1,
  invalidInputFormat: invalidInputFormat$1,
  createBookingErrorTitle: createBookingErrorTitle$1,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle$1,
  cancelBookingErrorTitle: cancelBookingErrorTitle$1,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle$1,
  getUISettingErrorTitle: getUISettingErrorTitle$1,
  rejectBookingErrorTitle: rejectBookingErrorTitle$1,
  confirmBookingErrorTitle: confirmBookingErrorTitle$1,
  genericErrorTitle: genericErrorTitle$1,
  noSessionIdErrorTitle: noSessionIdErrorTitle,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle$1,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage$1,
  publicConfigErrorMessage: publicConfigErrorMessage$1,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage$1,
  cancellationErrorTitle: cancellationErrorTitle$1,
  cancellationErrorMessage: cancellationErrorMessage$1,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage$1,
  cancelBokingFormError: cancelBokingFormError$1,
  feedbackFormTitle: feedbackFormTitle$1,
  feedbackFormDescription: feedbackFormDescription$1,
  feedbackMessageLabel: feedbackMessageLabel$1,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder$1,
  feedbackModalCloseButton: feedbackModalCloseButton$1,
  feedbackModalSubmitButton: feedbackModalSubmitButton$1,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle$1,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription$1,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton$1,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton$1,
  schedulerEditorTitle: schedulerEditorTitle$1,
  allSchedulingPages: allSchedulingPages$1,
  createAndManageSchedulingPages: createAndManageSchedulingPages$1,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText$1,
  pageTitle: pageTitle$1,
  durationTitle: durationTitle$1,
  loading: loading$1,
  required: required$1,
  optional: optional$1,
  loadingPagesDescription: loadingPagesDescription$1,
  noSchedulingPages: noSchedulingPages$1,
  createFirstSchedulingPage: createFirstSchedulingPage$1,
  editSchedulingPageButtonText: editSchedulingPageButtonText$1,
  eventInfoTab: eventInfoTab$1,
  availabilityTab: availabilityTab$1,
  participantsTab: participantsTab$1,
  bookingOptionsTab: bookingOptionsTab$1,
  returnToCalendarView: returnToCalendarView$1,
  bookingFormTab: bookingFormTab$1,
  communicationsTab: communicationsTab$1,
  pageStylesTab: pageStylesTab$1,
  savingButtonText: savingButtonText$1,
  saveChangesButtonText: saveChangesButtonText$1,
  createButtonText: createButtonText$1,
  timePeriod_day: timePeriod_day$1,
  timePeriod_week: timePeriod_week$1,
  timePeriod_month: timePeriod_month$1,
  timePeriod_year: timePeriod_year$1,
  timeDuration_minute: timeDuration_minute$1,
  timeDuration_hour: timeDuration_hour$1,
  eventCommunicationsTitle: eventCommunicationsTitle$1,
  eventCommunicationsDescription: eventCommunicationsDescription$1,
  unsavedChangesLabel: unsavedChangesLabel$1,
  changesSavedLabel: changesSavedLabel$1,
  fixFormErrors: fixFormErrors$1,
  nylasEditorTabs: nylasEditorTabs$1,
  nylasEditorTabsGroup: nylasEditorTabsGroup$1,
  nylasListConfigurations: nylasListConfigurations$1,
  nylasAdditionalParticipants: nylasAdditionalParticipants$1,
  nylasAvailabilityPicker: nylasAvailabilityPicker$1,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker$1,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect$1,
  nylasBookingConfirmationType: nylasBookingConfirmationType$1,
  nylasBookingFormConfig: nylasBookingFormConfig$1,
  nylasBufferTime: nylasBufferTime$1,
  nylasCalendarPicker: nylasCalendarPicker$1,
  nylasCancellationPolicy: nylasCancellationPolicy$1,
  nylasConfirmationEmail: nylasConfirmationEmail$1,
  nylasConnectedCalendars: nylasConnectedCalendars$1,
  nylasCustomBookingFlow: nylasCustomBookingFlow$1,
  nylasCustomEventSlug: nylasCustomEventSlug$1,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings$1,
  nylasEventDescription: nylasEventDescription$1,
  nylasEventDuration: nylasEventDuration$1,
  nylasEventInfo: nylasEventInfo$1,
  nylasEventLimits: nylasEventLimits$1,
  nylasEventLocation: nylasEventLocation$1,
  nylasEventTitle: nylasEventTitle$1,
  nylasLimitFutureBookings: nylasLimitFutureBookings$1,
  nylasMinBookingNotice: nylasMinBookingNotice$1,
  nylasMinCancellationNotice: nylasMinCancellationNotice$1,
  nylasPageName: nylasPageName$1,
  nylasPageStyling: nylasPageStyling$1,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars$1,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability$1,
  nylasReminderEmails: nylasReminderEmails$1,
  nylasSchedulingMethod: nylasSchedulingMethod$1,
  nylasTimeslotInterval: nylasTimeslotInterval$1,
  nylasEventTimeslot: nylasEventTimeslot$1,
  nylasEventCapacity: nylasEventCapacity$1,
  nylasSelectEventType: nylasSelectEventType$1,
  pageSettingsButton: pageSettingsButton$1,
  nylasEventCalendar: nylasEventCalendar$1,
  'default': nl$1
});

const noDateSelected = "날짜가 선택되지 않았습니다";
const rescheduleTitle = "회의 일정을 변경할 다른 시간대를 선택하세요";
const allDay = "온 날";
const today = "오늘";
const spotsLeft = "{{count}} 스포트 남음";
const search = "검색";
const selectOneOrMoreOptions = "하나 이상의 옵션을 선택하세요";
const days = {
	sunday: "일",
	monday: "월",
	tuesday: "화",
	wednesday: "수",
	thursday: "목",
	friday: "금",
	saturday: "토"
};
const time = {
	hour: "시간",
	hours: "시간",
	minute: "분",
	minutes: "분",
	day: "일",
	days: "일",
	week: "주",
	weeks: "주",
	month: "월",
	months: "월",
	year: "년",
	years: "년"
};
const months = {
	january: "1월",
	february: "2월",
	march: "3월",
	april: "4월",
	may: "5월",
	june: "6월",
	july: "7월",
	august: "8월",
	september: "9월",
	october: "10월",
	november: "11월",
	december: "12월"
};
const multipleOptionsSelected = "여러 옵션이 선택되었습니다";
const selectAtLeastOneOption = "최소 하나의 옵션을 선택하세요";
const nextButton = "다음";
const selectedDayAndYear = "{{date}}";
const selectedTime = "{{time}}";
const name = "이름";
const namePlaceholder = "이름을 입력하세요";
const email = "이메일";
const emailPlaceholder = "이메일을 입력하세요";
const guestEmail = "게스트 이메일";
const guestEmailPlaceholder = "게스트 이메일을 입력하세요";
const addGuest = "게스트 추가";
const addAnotherGuest = "다른 게스트 추가";
const backButton = "뒤로";
const bookNowButton = "지금 예약";
const bookingConfirmed = "예약이 확인되었습니다";
const bookingConfirmedDescription = "곧 이메일 확인을 받게 됩니다.";
const bookingSent = "예약이 전송되었습니다";
const bookingSentDescription = "예약이 확인되면 이메일을 받게 됩니다.";
const bookingRescheduled = "예약이 재조정되었습니다";
const bookingDateAndTimeHeader = "예약 날짜 및 시간";
const cancelBookingButton = "예약 취소";
const rescheduleBookingButton = "재조정";
const rejectBookingButton = "예약 거부";
const confirmBookingButton = "예약 확인";
const bookingPendingTitle = "예약 대기 중";
const bookingPendingnDescription = "아래에서 예약을 관리하세요. 초대한 사람은 요청 상태를 알려주는 이메일을 받게 됩니다.";
const confirmedEventCardTitle = "예약이 성공적으로 확인되었습니다";
const confirmedEventCardDescription = "확인 이메일이 전송되었습니다:";
const cancelBookingTitle = "예약을 취소하시겠습니까?";
const cancelBookingMessage = "현재 시간대는 다른 사람이 이용할 수 있게 됩니다.";
const reasonForCancellation = "취소 사유";
const goBackButton = "뒤로가기";
const bookingCancelledTitle = "예약이 성공적으로 취소되었습니다";
const bookingCancelledMessage = "취소 이메일이 전송되었습니다:";
const bookingCancelledMessage_theParticipants = "참여자에게 전송되었습니다";
const closeButton = "닫기";
const closingButton = "닫는 중";
const fieldRequired = "{{field}}은(는) 필수 항목입니다.";
const invalidInputFormat = "{{field}}의 형식이 올바르지 않습니다.";
const createBookingErrorTitle = "예약 생성";
const getAvailabilityErrorTitle = "가능 여부 가져오기";
const cancelBookingErrorTitle = "예약 취소";
const rescheduleBookingErrorTitle = "예약 재조정";
const getUISettingErrorTitle = "UI 설정 가져오기";
const rejectBookingErrorTitle = "예약 거부";
const confirmBookingErrorTitle = "예약 확인";
const genericErrorTitle = "문제가 발생했습니다";
const schedulingComponentErrorTitle = "스케줄링 구성 요소 오류";
const sessionIdRequiredErrorMessage = "비공개 구성에 'sessionId'가 필요합니다.";
const publicConfigErrorMessage = "공개 구성을 사용하는 경우 configurationId 또는 'slug'와 'clientId'의 조합을 전달하십시오.";
const invalidTimeslotErrorTitle = "잘못된 시간대!";
const invalidTimeslotErrorMessage = "선택한 시간대가 유효하지 않습니다";
const cancellationErrorTitle = "취소 오류";
const cancellationErrorMessage = "취소 사유를 제공해주세요.";
const minimumCancellationErrorMessage = "이벤트 {{minCancellationNotice}}분 이내에는 예약을 취소할 수 없습니다";
const cancelBokingFormError = "예약 취소 양식 오류";
const feedbackFormTitle = "피드백 공유";
const feedbackFormDescription = "피드백을 제공하고 오류를 보고해주시면 더 나은 경험을 만드는 데 도움이 됩니다.";
const feedbackMessageLabel = "댓글을 남기고 싶은 기능에 대한 상세한 설명이나 문제가 발생한 부분을 알려주세요.";
const feedbackMessagePlaceholder = "여기에 피드백을 제공하세요";
const feedbackModalCloseButton = "취소";
const feedbackModalSubmitButton = "제출";
const deleteSchedulingPageTitle = "이 스케줄링 페이지를 삭제하시겠습니까?";
const deleteSchedulingPageDescription = "확인하면 이 페이지와 연결된 모든 스케줄링 링크가 영구적으로 삭제되고 비활성화됩니다. 이 작업은 되돌릴 수 없습니다.";
const deleteSchedulingPageConfirmButton = "페이지 삭제";
const deleteSchedulingPageCancelButton = "취소";
const schedulerEditorTitle = "스케줄러 편집기";
const allSchedulingPages = "모든 스케줄링 페이지";
const createAndManageSchedulingPages = "스케줄링 페이지를 생성하고 관리하세요.";
const createNewSchedulingPageButtonText = "새로 만들기";
const pageTitle = "페이지 제목";
const durationTitle = "기간";
const loading = "로딩 중";
const required = "필수";
const optional = "선택 사항";
const loadingPagesDescription = "스케줄링 페이지를 가져오는 중입니다. 잠시만 기다려 주세요.";
const noSchedulingPages = "스케줄링 페이지가 없습니다";
const createFirstSchedulingPage = "첫 번째 스케줄링 페이지 생성을 시작하세요";
const editSchedulingPageButtonText = "편집";
const eventInfoTab = "이벤트 정보";
const availabilityTab = "가능 여부";
const participantsTab = "참여자";
const bookingOptionsTab = "예약 옵션";
const returnToCalendarView = "캘린더로 돌아가기";
const bookingFormTab = "예약 양식";
const communicationsTab = "커뮤니케이션";
const pageStylesTab = "페이지 스타일";
const savingButtonText = "저장 중";
const saveChangesButtonText = "변경 사항 저장";
const createButtonText = "생성";
const timePeriod_day = "일";
const timePeriod_week = "주";
const timePeriod_month = "월";
const timePeriod_year = "년";
const timeDuration_minute = "분";
const timeDuration_hour = "시간";
const eventCommunicationsTitle = "이벤트 커뮤니케이션";
const eventCommunicationsDescription = "자동 확인 이메일을 설정하세요.";
const unsavedChangesLabel = "저장되지 않은 변경 사항";
const changesSavedLabel = "변경 사항 저장됨";
const fixFormErrors = "폼 오류를 수정하세요.";
const nylasEditorTabs = {
	bookingFormError: "예약 폼 오류: ",
	bookingFormError_label: "{{type}} 타입의 필드에는 라벨이 필요합니다.",
	bookingFormError_option: "{{label}} 타입의 {{type}} 타입의 빈 옵션이 발견되었습니다.",
	formErrorTitle: "폼 오류",
	updateConfigError: "업데이트 오류: ",
	deleteConfigError: "삭제 오류: ",
	createConfigError: "생성 오류: ",
	getConfigsError: "구성 가져오기 오류: "
};
const nylasEditorTabsGroup = {
	eventTitleRequired: "이벤트 제목이 필요합니다.",
	eventTimeRequired: "이벤트 시간이 필요합니다.",
	participantsRequired: "참여자가 필요합니다.",
	participantEmailRequired: "참여자 이메일이 필요합니다.",
	errorOccured: "변경 사항 저장 오류가 발생했습니다.",
	createGroupEventError: "그룹 이벤트 생성 오류: ",
	updateGroupEventError: "그룹 이벤트 업데이트 오류: ",
	deleteGroupEventError: "그룹 이벤트 삭제 오류: ",
	importGroupEventError: "그룹 이벤트 가져오기 오류: ",
	getGroupEventsError: "그룹 이벤트 가져오기 오류: "
};
const nylasListConfigurations = {
	previewButtonText: "미리보기",
	copyLinkButtonText: "링크 복사",
	deleteButtonText: "삭제"
};
const nylasAdditionalParticipants = {
	headerTitle: "참여자",
	headerSubTitle: "팀이나 조직의 사람들을 추가하여 이벤트에 참여시키세요.",
	organizerAsParticipant: "참여자",
	organizer: "주최자",
	participant: "참여자",
	addParticipant_first: "참여자 추가",
	addParticipant_next: "다른 참여자 추가",
	tooltip: {
		includeOrganizer: "주최자 포함",
		includeOrganizerDesc: "주최자(당신)가 라운드 로빈 순환에 포함됩니다.",
		excludeOrganizer: "주최자 제외",
		excludeOrganizerDesc: "주최자(당신)가 라운드 로빈 순환에 포함되지 않습니다."
	},
	error: "최소 한 명의 참여자를 추가하세요"
};
const nylasAvailabilityPicker = {
	headerTitle: "기본 영업 시간",
	headerSubTitle: "정기적으로 이벤트 예약이 가능한 시간을 설정하세요.",
	tooltip: {
		desc: "참여자가 '참여자' 탭에서 가능 여부를 설정하지 않은 경우 기본 가능 여부입니다."
	},
	selectTimezone: "시간대 선택",
	unavailable: "불가능",
	days: {
		SUN: "일",
		MON: "월",
		TUE: "화",
		WED: "수",
		THU: "목",
		FRI: "금",
		SAT: "토"
	},
	errors: {
		invalid: "유효하지 않음"
	}
};
const nylasBookingCalendarPicker = {
	headerTitle: "캘린더 예약",
	headerSubTitle: "이벤트 예약을 추가할 캘린더를 선택하세요.",
	tooltip: {
		desc: "캘린더는 이벤트를 생성하는 데 사용됩니다."
	},
	selectOptionLabel: "옵션 선택",
	selectCalendarErrorMessage: "캘린더를 선택해주세요"
};
const nylasBookingConfirmationRedirect = {
	dropdownLabel: "예약이 확인될 때",
	tooltip: {
		desc: "기본 확인 페이지를 표시하거나 사용자의 확인 페이지로 리디렉션할 수 있습니다."
	},
	redirectOption_default: "기본 확인 페이지 표시",
	redirectOption_custom: "사용자 지정 URL로 리디렉션"
};
const nylasBookingConfirmationType = {
	dropdownLabel: "예약이 요청될 때",
	tooltip: {
		desc: "수동으로 예약을 승인하면 각 예약 요청을 검토하고 승인 또는 거부할 수 있습니다."
	},
	bookingOption_booking: "자동으로 예약 승인",
	bookingOption_organizerConfirmation: "수동으로 예약 승인"
};
const nylasBookingFormConfig = {
	headerTitle: "예약 양식",
	headerSubTitle: "예약 양식에 사용자 지정 필드를 추가하세요.",
	dropdownButtonText: "새 필드 추가",
	addOption: "옵션 추가",
	allOptionsHeader: "모든 옵션",
	fieldInTitleError: "이 필드는 이벤트 제목에 사용되며 제거할 수 없습니다.",
	fieldInDescriptionError: "이 필드는 이벤트 설명에 사용되며 제거할 수 없습니다.",
	label: "라벨",
	defaultValue: "기본값",
	fieldType: {
		text: "짧은 텍스트",
		multi_line_text: "긴 텍스트",
		email: "이메일",
		phone_number: "전화번호",
		dropdown: "드롭다운",
		radio_button: "라디오 버튼",
		checkbox: "체크박스",
		date: "날짜",
		metadata: "메타데이터",
		multi_select: "다중 선택"
	},
	fieldLabel: {
		your_name: "이름",
		your_email: "이메일",
		email: "추가 이메일",
		phone_number: "전화번호 레이블",
		dropdown: "드롭다운 레이블",
		text: "짧은 텍스트 레이블",
		multi_line_text: "긴 텍스트 레이블",
		radio_button: "라디오 버튼 레이블",
		checkbox: "체크박스 레이블",
		date: "날짜 레이블",
		metadata: "메타데이터 레이블",
		multi_select: "다중 선택 레이블"
	}
};
const nylasBufferTime = {
	headerTitle: "버퍼 시간",
	headerSubTitle: "이벤트 전후에 빈 버퍼 시간을 요구하세요.",
	tooltip: {
		desc: "스케줄러는 버퍼 시간을 예약하지 않습니다."
	},
	beforeBufferLabel: "이벤트 전",
	afterBufferLabel: "이벤트 후",
	minutesShort: "분",
	previewHeader: "미리보기"
};
const nylasCalendarPicker = {
	calendarPickerLabel: "가능 여부를 확인할 캘린더 선택",
	selectAtLeastOneCalendar: "각 참여자에 대해 최소 하나의 캘린더를 선택하세요."
};
const nylasCancellationPolicy = {
	cancellationPolicyLabel: "취소 정책 메시지",
	tooltip: {
		desc: "참석자가 이벤트를 취소하려고 할 때 이 메시지를 받습니다. 참석자에게 취소 사유를 제공하도록 요청합니다."
	}
};
const nylasConfirmationEmail = {
	headerTitle: "예약 확인{{organizerName}}",
	headerSubTitle: "예약 확인 이메일",
	editButtonText: "편집",
	error: {
		invalidImageUrl: "이미지 URL이 유효하지 않습니다."
	},
	confirmationEmail: {
		label: "이메일 알림 활성화",
		tooltip: {
			desc: "Nylas가 확인 메시지와 이벤트 알림을 포함한 이메일 알림을 보낼 수 있도록 허용합니다.",
			language: "이 언어는 주최자에 대한 이메일 알림에 사용됩니다."
		},
		language: "언어 선택"
	},
	nylasBranding: {
		label: "Nylas 브랜딩 표시",
		tooltip: {
			desc: "이메일 커뮤니케이션의 바닥글을 숨기려면 선택을 해제하세요."
		}
	},
	companyLogoUrl: {
		label: "회사 로고 URL",
		tooltip: {
			desc: "이 로고는 예약 확인 이메일에 표시됩니다. URL은 공개적으로 접근 가능해야 합니다. 이미지는 최대 크기인 200px x 100px로 축소됩니다."
		}
	},
	emailMessage: {
		header: "이메일 메시지",
		label: "사용자 지정 이메일 제목",
		tooltip: {
			desc: "이메일 제목은 이메일 본문의 헤드라인입니다. 제목 줄은 변경되지 않습니다."
		},
		additionalInfoLabel: "추가 정보",
		additionalInfoTooltip: "스케줄러가 상자의 내용을 이메일 본문에 추가합니다.",
		additionalInfoPlaceholder: "기본 본문"
	},
	allHosts: "모든 호스트 및 게스트",
	immediatelyUponBooking: "예약 즉시"
};
const nylasConnectedCalendars = {
	headerTitle: "연결된 캘린더",
	headerSubTitle: "가능 여부 확인에 사용할 캘린더를 선택하세요.",
	tooltip: {
		desc: "하나 이상의 캘린더에서 가능 여부를 확인하세요. 참여자에 대해 여러 캘린더를 선택하면, 참여자가 모든 캘린더에서 가능해야 사용 가능으로 간주됩니다."
	},
	participantCalendarTitle: "{{participantName}}의 연결된 캘린더",
	selectAtLeastOneCalendar: "각 참여자에 대해 최소 하나의 캘린더를 선택하세요."
};
const nylasCustomBookingFlow = {
	headerTitle: "맞춤 예약 흐름"
};
const nylasCustomEventSlug = {
	headerTitle: "사용자 정의 페이지 슬러그",
	headerSubTitle: "이 페이지에 대한 사용자 정의 URL 슬러그를 만드세요.",
	eventSlugLabel: "페이지 URL 슬러그",
	tooltip: {
		desc: "URL에 대한 사용자 정의 슬러그를 제공하여 페이지를 고유하게 식별하세요 (문자, 숫자, 하이픈만 사용 가능)."
	},
	copied: "복사됨!"
};
const nylasCustomizeBookingSettings = {
	headerTitle: "추가 설정",
	headerSubTitle: "이벤트 예약 설정.",
	tooltip: {
		desc: "예약 설정을 사용자 지정하세요."
	},
	allowGuests: {
		label: "게스트가 추가 게스트를 초대할 수 있도록 허용"
	},
	hideReschedule: {
		label: "예약 재조정 옵션 숨기기",
		tooltip: {
			desc: "예약 확인 및 이메일 알림에서 '재조정' 버튼을 숨깁니다."
		}
	},
	hideCancel: {
		label: "취소 옵션 숨기기",
		tooltip: {
			desc: "예약 확인 및 이메일 알림에서 '취소' 버튼을 숨깁니다."
		}
	}
};
const nylasEventDescription = {
	headerTitle: "이벤트 설명",
	addAdditionalFields: {
		buttonText: "추가 필드 자동 채우기",
		tooltip: {
			desc: "설명에 포함하려는 모든 필드를 추가한 후 이 버튼을 클릭하세요. 중요: 모든 기능이 올바르게 작동하도록 '--- Additional Fields ---'와 '--- End Additional Fields ---' 표시를 수정하지 마세요."
		}
	},
	tooltip: {
		desc: "이벤트 설명은 스케줄러 편집기의 관리자 보기 및 예약 생성 시 응답 페이로드에 표시됩니다."
	}
};
const nylasEventDuration = {
	headerTitle: "이벤트 기간",
	error: {
		durationMustBeMultipleOf5: "기간은 5의 배수여야 합니다",
		durationMustBeGreaterThan0: "기간은 0보다 크거나 같아야 합니다"
	}
};
const nylasEventInfo = {
	headerTitle: "이벤트 정보"
};
const nylasEventLimits = {
	headerTitle: "이벤트 제한"
};
const nylasEventLocation = {
	headerTitle: "이벤트 회의 또는 위치",
	tooltip: {
		desc: "회의 옵션을 선택하거나 맞춤 위치를 추가하세요."
	},
	conferenceOptions: {
		none: "없음",
		zoom: "줌 미팅",
		google: "구글 미트",
		microsoft: "마이크로소프트 팀즈",
		custom: "사용자 지정 위치"
	}
};
const nylasEventTitle = {
	headerTitle: "이벤트 제목",
	helpText_start: "다이나믹 템플릿 이벤트 {{field}}을(를) 생성하려면 입력하세요",
	helpText_end: "및 템플릿 항목을 선택하세요.",
	title: "제목",
	description: "설명",
	tooltip: {
		desc: "예: 인터뷰 with"
	},
	eventTitleRequired: "이벤트 제목은 필수입니다",
	eventTitleTokenDescription: {
		invitee: "주최자의 이름",
		inviteeEmail: "주최자의 이메일",
		duration: "이벤트의 기간"
	}
};
const nylasLimitFutureBookings = {
	headerTitle: "미래 예약 제한",
	tooltip: {
		desc: "예약을 할 수 있는 미래의 최대 기간."
	}
};
const nylasMinBookingNotice = {
	headerTitle: "최소 예약 공지",
	tooltip: {
		desc: "새 예약을 할 수 있는 최소 시간."
	}
};
const nylasMinCancellationNotice = {
	headerTitle: "최소 취소 공지",
	tooltip: {
		desc: "예약을 취소하는 데 필요한 최소 시간."
	}
};
const nylasPageName = {
	headerTitle: "페이지 이름",
	headerSubTitle: "스케줄링 페이지 이름을 설정하세요.",
	pageNameError: "페이지 이름을 입력하세요",
	tooltip: {
		desc: "기본적으로 스케줄링 페이지는 사용자 이름을 페이지 이름으로 사용합니다. 페이지 이름은 캘린더 보기의 왼쪽 상단에 표시됩니다."
	}
};
const nylasPageStyling = {
	headerTitle: "페이지 스타일 및 맞춤화"
};
const nylasParticipantBookingCalendars = {
	headerTitle: "이 캘린더에 예약",
	headerSubTitle: "이벤트 예약을 추가할 캘린더를 선택하세요.",
	participantBookingCalendarTitle: "{{participantName}}의 예약 캘린더",
	selectAtLeastOneCalendar: "각 참여자에 대해 최소 하나의 캘린더를 선택하세요."
};
const nylasParticipantCustomAvailability = {
	headerTitle: "참여자 영업 시간",
	headerSubTitle: "설정되지 않은 경우 기본 영업 시간이 이 참여자의 가능 여부 계산에 사용됩니다.",
	participantOpenHoursTitle: "{{participantName}}의 영업 시간"
};
const nylasReminderEmails = {
	headerTitle: "다가오는 회의{{organizerName}}",
	headerSubTitle: "이벤트 전 알림",
	editButtonText: "편집",
	recipientOptions_all: "모든 호스트 및 게스트",
	recipientOptions_guest: "모든 이벤트 게스트",
	recipientOptions_host: "이벤트 호스트만",
	beforeTheEvent: "이벤트 전",
	emailRecipients: {
		label: "이메일 수신자"
	},
	sendConfirmation: {
		label: "예약 시 확인 이메일 전송",
		tooltip: {
			desc: "수신자는 이벤트 전 지정된 시간에 알림 이메일을 받게 됩니다."
		}
	},
	emailSubject: {
		label: "이메일 제목",
		placeholder: "다가오는 회의{{organizerName}}"
	},
	reminderMinutesValidationError: "리마인더 분을 5의 배수로 입력하세요. 시도해보세요 ",
	newReminderButtonText: "새 알림"
};
const nylasSchedulingMethod = {
	headerTitle: "스케줄링 방법",
	headerSubTitle: "이벤트의 스케줄링 방법을 선택하세요.",
	tooltip: {
		standard: {
			label: "표준",
			desc: "1:1 예약 또는 추가 참여자가 있는 n:1 예약을 허용합니다."
		},
		maxFairness: {
			label: "라운드 로빈 공정성 최대화",
			desc: "선택한 참여자 목록을 순환하며 최근 예약이 가장 적은 참여자를 표시합니다."
		},
		maxAvailability: {
			label: "라운드 로빈 가능성 최대화",
			desc: "선택한 참여자 목록을 순환하며 최근 예약이 가장 적은 참여자를 우선시하지만 가능한 많은 시간대를 제공합니다."
		}
	},
	schedulingMethodOptions_collective: "표준 예약",
	schedulingMethodOptions_maxFairness: "라운드 로빈 공정성 최대화",
	schedulingMethodOptions_maxAvailability: "라운드 로빈 가능성 최대화"
};
const nylasTimeslotInterval = {
	minutesShort: "분",
	lengthOfMeeting: "회의 시간",
	headerTitle: "시간대 설정",
	timeslotInterval: {
		label: "시간대 간격"
	},
	timeslotRounding: {
		label: "시간대 반올림 유형",
		tooltip: {
			desc: "시간대가 표시되는 간격."
		}
	},
	timeslotRoundingOptions: {
		rounding: {
			label: "간격 반올림",
			desc: "시간대는 간격 값으로 반올림된 시간에서 시작됩니다."
		},
		noRounding: {
			label: "기본값",
			desc: "시간대는 가장 가까운 15분 단위로 반올림됩니다."
		}
	}
};
const nylasEventTimeslot = {
	recurrenceOptions: {
		none: "반복하지 않음",
		daily: "매일",
		weekly: "매주 {{dayOfWeek}}",
		monthly: "매월 {{dayOfMonth}}",
		monthOnDay: "매월 {{date}}일에",
		yearly: "매년 {{dateOfMonth}}",
		custom: "사용자 정의"
	},
	recurrenceLabel: "이 이벤트 반복",
	endDate: "종료 날짜",
	customRecurrence: {
		repeatEvery: "반복 주기",
		repeatOn: "반복 날짜",
		ends: "종료",
		endsOptions: {
			never: "안함",
			after: "후",
			on: "날짜"
		},
		occurrences: "횟수"
	},
	dateTimeLabel: "날짜 및 시간",
	errors: {
		invalidTimeRange: "시간 범위가 유효하지 않습니다",
		startTimeSameAsEndTime: "시작 시간과 종료 시간은 같을 수 없습니다",
		startTimeBeforeCurrentDate: "시작 시간은 과거일 수 없습니다",
		invalid: "유효하지 않음"
	}
};
const nylasEventCapacity = {
	headerTitle: "초대자",
	headerSubTitle: "이 이벤트 시간 슬롯의 최대 초대자 수를 설정하세요.",
	tooltip: {
		desc: "일정 페이지에서 구성된 주최자 및 참가자는 초대자로 계산되지 않습니다."
	},
	attendees: "참석자"
};
const nylasSelectEventType = {
	returnToAllSchedulingPages: "모든 스케줄링 페이지로 돌아가기",
	createEventHeaderTitle: "이벤트 만들기",
	eventTypeHeaderTitle: "이벤트 유형",
	noEventTypesEnabled: "이벤트 유형이 활성화되지 않았습니다.",
	eventTypeOptions: {
		oneOnOne: {
			label: "1:1",
			desc: "1:1 예약을 허용합니다."
		},
		collective: {
			label: "표준 예약",
			desc: "추가 참여자가 있는 n:1 예약을 허용합니다."
		},
		maxFairness: {
			label: "라운드 로빈 공정성 최대화",
			desc: "선택한 참여자 목록을 순환하며 최근 예약이 가장 적은 참여자를 표시합니다."
		},
		maxAvailability: {
			label: "라운드 로빈 가능성 최대화",
			desc: "선택한 참여자 목록을 순환하며 최근 예약이 가장 적은 참여자를 우선시하지만 가능한 많은 시간대를 제공합니다."
		},
		group: {
			label: "그룹/클래스",
			desc: "이 이벤트는 일반적으로 하나의 주최자와 여러 참여자를 가지고 있습니다."
		}
	}
};
const pageSettingsButton = "페이지 설정";
const nylasEventCalendar = {
	hideNonGroupEvents: {
		showLabel: "이벤트 필터",
		tooltip: {
			desc: "캘린더에 표시할 이벤트 유형을 선택합니다."
		},
		options: {
			all: "모든 이벤트",
			group: "그룹 이벤트"
		}
	},
	createEventDetails: {
		headerTitle: "이벤트 세부 정보",
		closeButtonTooltip: "닫기",
		cancelButton: "취소",
		createButton: "만들기"
	},
	discardChanges: {
		headerTitle: "변경 사항을 취소하시겠습니까?",
		cancelButton: "취소",
		discardButton: "취소"
	},
	unsavedChanges: "변경 사항이 저장되지 않았습니다",
	editEventDetails: {
		headerTitle: "이벤트 세부 정보",
		closeButtonTooltip: "닫기",
		deleteButton: "삭제",
		saveButton: "저장",
		pastEventTooltip: "이 이벤트는 과거이며 편집할 수 없습니다."
	},
	importEvent: {
		closeButtonTooltip: "닫기",
		importButton: "가져오기",
		participantsLabel: "참여자"
	},
	deleteEvent: {
		closeButtonTooltip: "닫기",
		deleting: "삭제 중..."
	},
	editOptions: {
		headerTitle: "옵션",
		closeButtonTooltip: "닫기",
		deleting: "삭제 중...",
		"import": "가져오기",
		edit: "편집",
		deleteThis: "이 이벤트 삭제",
		deleteAll: "모든 이벤트 삭제",
		importTooltip: "기존 이벤트를 캘린더에서 선택하고 그룹 이벤트로 구성할 수 있습니다."
	},
	updateOptions: {
		updateThis: "이 이벤트 업데이트",
		updateAll: "모든 이벤트 업데이트",
		updateFuture: "모든 미래 이벤트 업데이트"
	},
	deleteOptions: {
		deleteThis: "삭제",
		deleteFuture: "이 이벤트와 모든 미래 이벤트 삭제",
		deleteAll: "모든 이벤트 삭제"
	}
};
const ko$1 = {
	noDateSelected: noDateSelected,
	rescheduleTitle: rescheduleTitle,
	allDay: allDay,
	today: today,
	spotsLeft: spotsLeft,
	search: search,
	selectOneOrMoreOptions: selectOneOrMoreOptions,
	days: days,
	time: time,
	months: months,
	multipleOptionsSelected: multipleOptionsSelected,
	selectAtLeastOneOption: selectAtLeastOneOption,
	nextButton: nextButton,
	selectedDayAndYear: selectedDayAndYear,
	selectedTime: selectedTime,
	name: name,
	namePlaceholder: namePlaceholder,
	email: email,
	emailPlaceholder: emailPlaceholder,
	guestEmail: guestEmail,
	guestEmailPlaceholder: guestEmailPlaceholder,
	addGuest: addGuest,
	addAnotherGuest: addAnotherGuest,
	backButton: backButton,
	bookNowButton: bookNowButton,
	bookingConfirmed: bookingConfirmed,
	bookingConfirmedDescription: bookingConfirmedDescription,
	bookingSent: bookingSent,
	bookingSentDescription: bookingSentDescription,
	bookingRescheduled: bookingRescheduled,
	bookingDateAndTimeHeader: bookingDateAndTimeHeader,
	cancelBookingButton: cancelBookingButton,
	rescheduleBookingButton: rescheduleBookingButton,
	rejectBookingButton: rejectBookingButton,
	confirmBookingButton: confirmBookingButton,
	bookingPendingTitle: bookingPendingTitle,
	bookingPendingnDescription: bookingPendingnDescription,
	confirmedEventCardTitle: confirmedEventCardTitle,
	confirmedEventCardDescription: confirmedEventCardDescription,
	cancelBookingTitle: cancelBookingTitle,
	cancelBookingMessage: cancelBookingMessage,
	reasonForCancellation: reasonForCancellation,
	goBackButton: goBackButton,
	bookingCancelledTitle: bookingCancelledTitle,
	bookingCancelledMessage: bookingCancelledMessage,
	bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants,
	closeButton: closeButton,
	closingButton: closingButton,
	fieldRequired: fieldRequired,
	invalidInputFormat: invalidInputFormat,
	createBookingErrorTitle: createBookingErrorTitle,
	getAvailabilityErrorTitle: getAvailabilityErrorTitle,
	cancelBookingErrorTitle: cancelBookingErrorTitle,
	rescheduleBookingErrorTitle: rescheduleBookingErrorTitle,
	getUISettingErrorTitle: getUISettingErrorTitle,
	rejectBookingErrorTitle: rejectBookingErrorTitle,
	confirmBookingErrorTitle: confirmBookingErrorTitle,
	genericErrorTitle: genericErrorTitle,
	schedulingComponentErrorTitle: schedulingComponentErrorTitle,
	sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage,
	publicConfigErrorMessage: publicConfigErrorMessage,
	invalidTimeslotErrorTitle: invalidTimeslotErrorTitle,
	invalidTimeslotErrorMessage: invalidTimeslotErrorMessage,
	cancellationErrorTitle: cancellationErrorTitle,
	cancellationErrorMessage: cancellationErrorMessage,
	minimumCancellationErrorMessage: minimumCancellationErrorMessage,
	cancelBokingFormError: cancelBokingFormError,
	feedbackFormTitle: feedbackFormTitle,
	feedbackFormDescription: feedbackFormDescription,
	feedbackMessageLabel: feedbackMessageLabel,
	feedbackMessagePlaceholder: feedbackMessagePlaceholder,
	feedbackModalCloseButton: feedbackModalCloseButton,
	feedbackModalSubmitButton: feedbackModalSubmitButton,
	deleteSchedulingPageTitle: deleteSchedulingPageTitle,
	deleteSchedulingPageDescription: deleteSchedulingPageDescription,
	deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton,
	deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton,
	schedulerEditorTitle: schedulerEditorTitle,
	allSchedulingPages: allSchedulingPages,
	createAndManageSchedulingPages: createAndManageSchedulingPages,
	createNewSchedulingPageButtonText: createNewSchedulingPageButtonText,
	pageTitle: pageTitle,
	durationTitle: durationTitle,
	loading: loading,
	required: required,
	optional: optional,
	loadingPagesDescription: loadingPagesDescription,
	noSchedulingPages: noSchedulingPages,
	createFirstSchedulingPage: createFirstSchedulingPage,
	editSchedulingPageButtonText: editSchedulingPageButtonText,
	eventInfoTab: eventInfoTab,
	availabilityTab: availabilityTab,
	participantsTab: participantsTab,
	bookingOptionsTab: bookingOptionsTab,
	returnToCalendarView: returnToCalendarView,
	bookingFormTab: bookingFormTab,
	communicationsTab: communicationsTab,
	pageStylesTab: pageStylesTab,
	savingButtonText: savingButtonText,
	saveChangesButtonText: saveChangesButtonText,
	createButtonText: createButtonText,
	timePeriod_day: timePeriod_day,
	timePeriod_week: timePeriod_week,
	timePeriod_month: timePeriod_month,
	timePeriod_year: timePeriod_year,
	timeDuration_minute: timeDuration_minute,
	timeDuration_hour: timeDuration_hour,
	eventCommunicationsTitle: eventCommunicationsTitle,
	eventCommunicationsDescription: eventCommunicationsDescription,
	unsavedChangesLabel: unsavedChangesLabel,
	changesSavedLabel: changesSavedLabel,
	fixFormErrors: fixFormErrors,
	nylasEditorTabs: nylasEditorTabs,
	nylasEditorTabsGroup: nylasEditorTabsGroup,
	nylasListConfigurations: nylasListConfigurations,
	nylasAdditionalParticipants: nylasAdditionalParticipants,
	nylasAvailabilityPicker: nylasAvailabilityPicker,
	nylasBookingCalendarPicker: nylasBookingCalendarPicker,
	nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect,
	nylasBookingConfirmationType: nylasBookingConfirmationType,
	nylasBookingFormConfig: nylasBookingFormConfig,
	nylasBufferTime: nylasBufferTime,
	nylasCalendarPicker: nylasCalendarPicker,
	nylasCancellationPolicy: nylasCancellationPolicy,
	nylasConfirmationEmail: nylasConfirmationEmail,
	nylasConnectedCalendars: nylasConnectedCalendars,
	nylasCustomBookingFlow: nylasCustomBookingFlow,
	nylasCustomEventSlug: nylasCustomEventSlug,
	nylasCustomizeBookingSettings: nylasCustomizeBookingSettings,
	nylasEventDescription: nylasEventDescription,
	nylasEventDuration: nylasEventDuration,
	nylasEventInfo: nylasEventInfo,
	nylasEventLimits: nylasEventLimits,
	nylasEventLocation: nylasEventLocation,
	nylasEventTitle: nylasEventTitle,
	nylasLimitFutureBookings: nylasLimitFutureBookings,
	nylasMinBookingNotice: nylasMinBookingNotice,
	nylasMinCancellationNotice: nylasMinCancellationNotice,
	nylasPageName: nylasPageName,
	nylasPageStyling: nylasPageStyling,
	nylasParticipantBookingCalendars: nylasParticipantBookingCalendars,
	nylasParticipantCustomAvailability: nylasParticipantCustomAvailability,
	nylasReminderEmails: nylasReminderEmails,
	nylasSchedulingMethod: nylasSchedulingMethod,
	nylasTimeslotInterval: nylasTimeslotInterval,
	nylasEventTimeslot: nylasEventTimeslot,
	nylasEventCapacity: nylasEventCapacity,
	nylasSelectEventType: nylasSelectEventType,
	pageSettingsButton: pageSettingsButton,
	nylasEventCalendar: nylasEventCalendar
};

const koTranslation = /*#__PURE__*/Object.freeze({
  __proto__: null,
  noDateSelected: noDateSelected,
  rescheduleTitle: rescheduleTitle,
  allDay: allDay,
  today: today,
  spotsLeft: spotsLeft,
  search: search,
  selectOneOrMoreOptions: selectOneOrMoreOptions,
  days: days,
  time: time,
  months: months,
  multipleOptionsSelected: multipleOptionsSelected,
  selectAtLeastOneOption: selectAtLeastOneOption,
  nextButton: nextButton,
  selectedDayAndYear: selectedDayAndYear,
  selectedTime: selectedTime,
  name: name,
  namePlaceholder: namePlaceholder,
  email: email,
  emailPlaceholder: emailPlaceholder,
  guestEmail: guestEmail,
  guestEmailPlaceholder: guestEmailPlaceholder,
  addGuest: addGuest,
  addAnotherGuest: addAnotherGuest,
  backButton: backButton,
  bookNowButton: bookNowButton,
  bookingConfirmed: bookingConfirmed,
  bookingConfirmedDescription: bookingConfirmedDescription,
  bookingSent: bookingSent,
  bookingSentDescription: bookingSentDescription,
  bookingRescheduled: bookingRescheduled,
  bookingDateAndTimeHeader: bookingDateAndTimeHeader,
  cancelBookingButton: cancelBookingButton,
  rescheduleBookingButton: rescheduleBookingButton,
  rejectBookingButton: rejectBookingButton,
  confirmBookingButton: confirmBookingButton,
  bookingPendingTitle: bookingPendingTitle,
  bookingPendingnDescription: bookingPendingnDescription,
  confirmedEventCardTitle: confirmedEventCardTitle,
  confirmedEventCardDescription: confirmedEventCardDescription,
  cancelBookingTitle: cancelBookingTitle,
  cancelBookingMessage: cancelBookingMessage,
  reasonForCancellation: reasonForCancellation,
  goBackButton: goBackButton,
  bookingCancelledTitle: bookingCancelledTitle,
  bookingCancelledMessage: bookingCancelledMessage,
  bookingCancelledMessage_theParticipants: bookingCancelledMessage_theParticipants,
  closeButton: closeButton,
  closingButton: closingButton,
  fieldRequired: fieldRequired,
  invalidInputFormat: invalidInputFormat,
  createBookingErrorTitle: createBookingErrorTitle,
  getAvailabilityErrorTitle: getAvailabilityErrorTitle,
  cancelBookingErrorTitle: cancelBookingErrorTitle,
  rescheduleBookingErrorTitle: rescheduleBookingErrorTitle,
  getUISettingErrorTitle: getUISettingErrorTitle,
  rejectBookingErrorTitle: rejectBookingErrorTitle,
  confirmBookingErrorTitle: confirmBookingErrorTitle,
  genericErrorTitle: genericErrorTitle,
  schedulingComponentErrorTitle: schedulingComponentErrorTitle,
  sessionIdRequiredErrorMessage: sessionIdRequiredErrorMessage,
  publicConfigErrorMessage: publicConfigErrorMessage,
  invalidTimeslotErrorTitle: invalidTimeslotErrorTitle,
  invalidTimeslotErrorMessage: invalidTimeslotErrorMessage,
  cancellationErrorTitle: cancellationErrorTitle,
  cancellationErrorMessage: cancellationErrorMessage,
  minimumCancellationErrorMessage: minimumCancellationErrorMessage,
  cancelBokingFormError: cancelBokingFormError,
  feedbackFormTitle: feedbackFormTitle,
  feedbackFormDescription: feedbackFormDescription,
  feedbackMessageLabel: feedbackMessageLabel,
  feedbackMessagePlaceholder: feedbackMessagePlaceholder,
  feedbackModalCloseButton: feedbackModalCloseButton,
  feedbackModalSubmitButton: feedbackModalSubmitButton,
  deleteSchedulingPageTitle: deleteSchedulingPageTitle,
  deleteSchedulingPageDescription: deleteSchedulingPageDescription,
  deleteSchedulingPageConfirmButton: deleteSchedulingPageConfirmButton,
  deleteSchedulingPageCancelButton: deleteSchedulingPageCancelButton,
  schedulerEditorTitle: schedulerEditorTitle,
  allSchedulingPages: allSchedulingPages,
  createAndManageSchedulingPages: createAndManageSchedulingPages,
  createNewSchedulingPageButtonText: createNewSchedulingPageButtonText,
  pageTitle: pageTitle,
  durationTitle: durationTitle,
  loading: loading,
  required: required,
  optional: optional,
  loadingPagesDescription: loadingPagesDescription,
  noSchedulingPages: noSchedulingPages,
  createFirstSchedulingPage: createFirstSchedulingPage,
  editSchedulingPageButtonText: editSchedulingPageButtonText,
  eventInfoTab: eventInfoTab,
  availabilityTab: availabilityTab,
  participantsTab: participantsTab,
  bookingOptionsTab: bookingOptionsTab,
  returnToCalendarView: returnToCalendarView,
  bookingFormTab: bookingFormTab,
  communicationsTab: communicationsTab,
  pageStylesTab: pageStylesTab,
  savingButtonText: savingButtonText,
  saveChangesButtonText: saveChangesButtonText,
  createButtonText: createButtonText,
  timePeriod_day: timePeriod_day,
  timePeriod_week: timePeriod_week,
  timePeriod_month: timePeriod_month,
  timePeriod_year: timePeriod_year,
  timeDuration_minute: timeDuration_minute,
  timeDuration_hour: timeDuration_hour,
  eventCommunicationsTitle: eventCommunicationsTitle,
  eventCommunicationsDescription: eventCommunicationsDescription,
  unsavedChangesLabel: unsavedChangesLabel,
  changesSavedLabel: changesSavedLabel,
  fixFormErrors: fixFormErrors,
  nylasEditorTabs: nylasEditorTabs,
  nylasEditorTabsGroup: nylasEditorTabsGroup,
  nylasListConfigurations: nylasListConfigurations,
  nylasAdditionalParticipants: nylasAdditionalParticipants,
  nylasAvailabilityPicker: nylasAvailabilityPicker,
  nylasBookingCalendarPicker: nylasBookingCalendarPicker,
  nylasBookingConfirmationRedirect: nylasBookingConfirmationRedirect,
  nylasBookingConfirmationType: nylasBookingConfirmationType,
  nylasBookingFormConfig: nylasBookingFormConfig,
  nylasBufferTime: nylasBufferTime,
  nylasCalendarPicker: nylasCalendarPicker,
  nylasCancellationPolicy: nylasCancellationPolicy,
  nylasConfirmationEmail: nylasConfirmationEmail,
  nylasConnectedCalendars: nylasConnectedCalendars,
  nylasCustomBookingFlow: nylasCustomBookingFlow,
  nylasCustomEventSlug: nylasCustomEventSlug,
  nylasCustomizeBookingSettings: nylasCustomizeBookingSettings,
  nylasEventDescription: nylasEventDescription,
  nylasEventDuration: nylasEventDuration,
  nylasEventInfo: nylasEventInfo,
  nylasEventLimits: nylasEventLimits,
  nylasEventLocation: nylasEventLocation,
  nylasEventTitle: nylasEventTitle,
  nylasLimitFutureBookings: nylasLimitFutureBookings,
  nylasMinBookingNotice: nylasMinBookingNotice,
  nylasMinCancellationNotice: nylasMinCancellationNotice,
  nylasPageName: nylasPageName,
  nylasPageStyling: nylasPageStyling,
  nylasParticipantBookingCalendars: nylasParticipantBookingCalendars,
  nylasParticipantCustomAvailability: nylasParticipantCustomAvailability,
  nylasReminderEmails: nylasReminderEmails,
  nylasSchedulingMethod: nylasSchedulingMethod,
  nylasTimeslotInterval: nylasTimeslotInterval,
  nylasEventTimeslot: nylasEventTimeslot,
  nylasEventCapacity: nylasEventCapacity,
  nylasSelectEventType: nylasSelectEventType,
  pageSettingsButton: pageSettingsButton,
  nylasEventCalendar: nylasEventCalendar,
  'default': ko$1
});

instance.init({
    lng: 'en',
    fallbackLng: 'en',
    keySeparator: '.',
    resources: {
        en: {
            translation: enTranslation,
        },
        fr: {
            translation: frTranslation,
        },
        es: {
            translation: esTranslation,
        },
        ja: {
            translation: jaTranslation,
        },
        de: {
            translation: deTranslation,
        },
        sv: {
            translation: svTranslation,
        },
        zh: {
            translation: zhCnTranslation,
        },
        nl: {
            translation: nlTranslation,
        },
        ko: {
            translation: koTranslation,
        },
    },
    interpolation: {
        escapeValue: false,
    },
});

var decode = {};

var decodeDataHtml = {};

// Generated using scripts/write-decode-map.ts
Object.defineProperty(decodeDataHtml, "__esModule", { value: true });
decodeDataHtml.default = new Uint16Array(
// prettier-ignore
"\u1d41<\xd5\u0131\u028a\u049d\u057b\u05d0\u0675\u06de\u07a2\u07d6\u080f\u0a4a\u0a91\u0da1\u0e6d\u0f09\u0f26\u10ca\u1228\u12e1\u1415\u149d\u14c3\u14df\u1525\0\0\0\0\0\0\u156b\u16cd\u198d\u1c12\u1ddd\u1f7e\u2060\u21b0\u228d\u23c0\u23fb\u2442\u2824\u2912\u2d08\u2e48\u2fce\u3016\u32ba\u3639\u37ac\u38fe\u3a28\u3a71\u3ae0\u3b2e\u0800EMabcfglmnoprstu\\bfms\x7f\x84\x8b\x90\x95\x98\xa6\xb3\xb9\xc8\xcflig\u803b\xc6\u40c6P\u803b&\u4026cute\u803b\xc1\u40c1reve;\u4102\u0100iyx}rc\u803b\xc2\u40c2;\u4410r;\uc000\ud835\udd04rave\u803b\xc0\u40c0pha;\u4391acr;\u4100d;\u6a53\u0100gp\x9d\xa1on;\u4104f;\uc000\ud835\udd38plyFunction;\u6061ing\u803b\xc5\u40c5\u0100cs\xbe\xc3r;\uc000\ud835\udc9cign;\u6254ilde\u803b\xc3\u40c3ml\u803b\xc4\u40c4\u0400aceforsu\xe5\xfb\xfe\u0117\u011c\u0122\u0127\u012a\u0100cr\xea\xf2kslash;\u6216\u0176\xf6\xf8;\u6ae7ed;\u6306y;\u4411\u0180crt\u0105\u010b\u0114ause;\u6235noullis;\u612ca;\u4392r;\uc000\ud835\udd05pf;\uc000\ud835\udd39eve;\u42d8c\xf2\u0113mpeq;\u624e\u0700HOacdefhilorsu\u014d\u0151\u0156\u0180\u019e\u01a2\u01b5\u01b7\u01ba\u01dc\u0215\u0273\u0278\u027ecy;\u4427PY\u803b\xa9\u40a9\u0180cpy\u015d\u0162\u017aute;\u4106\u0100;i\u0167\u0168\u62d2talDifferentialD;\u6145leys;\u612d\u0200aeio\u0189\u018e\u0194\u0198ron;\u410cdil\u803b\xc7\u40c7rc;\u4108nint;\u6230ot;\u410a\u0100dn\u01a7\u01adilla;\u40b8terDot;\u40b7\xf2\u017fi;\u43a7rcle\u0200DMPT\u01c7\u01cb\u01d1\u01d6ot;\u6299inus;\u6296lus;\u6295imes;\u6297o\u0100cs\u01e2\u01f8kwiseContourIntegral;\u6232eCurly\u0100DQ\u0203\u020foubleQuote;\u601duote;\u6019\u0200lnpu\u021e\u0228\u0247\u0255on\u0100;e\u0225\u0226\u6237;\u6a74\u0180git\u022f\u0236\u023aruent;\u6261nt;\u622fourIntegral;\u622e\u0100fr\u024c\u024e;\u6102oduct;\u6210nterClockwiseContourIntegral;\u6233oss;\u6a2fcr;\uc000\ud835\udc9ep\u0100;C\u0284\u0285\u62d3ap;\u624d\u0580DJSZacefios\u02a0\u02ac\u02b0\u02b4\u02b8\u02cb\u02d7\u02e1\u02e6\u0333\u048d\u0100;o\u0179\u02a5trahd;\u6911cy;\u4402cy;\u4405cy;\u440f\u0180grs\u02bf\u02c4\u02c7ger;\u6021r;\u61a1hv;\u6ae4\u0100ay\u02d0\u02d5ron;\u410e;\u4414l\u0100;t\u02dd\u02de\u6207a;\u4394r;\uc000\ud835\udd07\u0100af\u02eb\u0327\u0100cm\u02f0\u0322ritical\u0200ADGT\u0300\u0306\u0316\u031ccute;\u40b4o\u0174\u030b\u030d;\u42d9bleAcute;\u42ddrave;\u4060ilde;\u42dcond;\u62c4ferentialD;\u6146\u0470\u033d\0\0\0\u0342\u0354\0\u0405f;\uc000\ud835\udd3b\u0180;DE\u0348\u0349\u034d\u40a8ot;\u60dcqual;\u6250ble\u0300CDLRUV\u0363\u0372\u0382\u03cf\u03e2\u03f8ontourIntegra\xec\u0239o\u0274\u0379\0\0\u037b\xbb\u0349nArrow;\u61d3\u0100eo\u0387\u03a4ft\u0180ART\u0390\u0396\u03a1rrow;\u61d0ightArrow;\u61d4e\xe5\u02cang\u0100LR\u03ab\u03c4eft\u0100AR\u03b3\u03b9rrow;\u67f8ightArrow;\u67faightArrow;\u67f9ight\u0100AT\u03d8\u03derrow;\u61d2ee;\u62a8p\u0241\u03e9\0\0\u03efrrow;\u61d1ownArrow;\u61d5erticalBar;\u6225n\u0300ABLRTa\u0412\u042a\u0430\u045e\u047f\u037crrow\u0180;BU\u041d\u041e\u0422\u6193ar;\u6913pArrow;\u61f5reve;\u4311eft\u02d2\u043a\0\u0446\0\u0450ightVector;\u6950eeVector;\u695eector\u0100;B\u0459\u045a\u61bdar;\u6956ight\u01d4\u0467\0\u0471eeVector;\u695fector\u0100;B\u047a\u047b\u61c1ar;\u6957ee\u0100;A\u0486\u0487\u62a4rrow;\u61a7\u0100ct\u0492\u0497r;\uc000\ud835\udc9frok;\u4110\u0800NTacdfglmopqstux\u04bd\u04c0\u04c4\u04cb\u04de\u04e2\u04e7\u04ee\u04f5\u0521\u052f\u0536\u0552\u055d\u0560\u0565G;\u414aH\u803b\xd0\u40d0cute\u803b\xc9\u40c9\u0180aiy\u04d2\u04d7\u04dcron;\u411arc\u803b\xca\u40ca;\u442dot;\u4116r;\uc000\ud835\udd08rave\u803b\xc8\u40c8ement;\u6208\u0100ap\u04fa\u04fecr;\u4112ty\u0253\u0506\0\0\u0512mallSquare;\u65fberySmallSquare;\u65ab\u0100gp\u0526\u052aon;\u4118f;\uc000\ud835\udd3csilon;\u4395u\u0100ai\u053c\u0549l\u0100;T\u0542\u0543\u6a75ilde;\u6242librium;\u61cc\u0100ci\u0557\u055ar;\u6130m;\u6a73a;\u4397ml\u803b\xcb\u40cb\u0100ip\u056a\u056fsts;\u6203onentialE;\u6147\u0280cfios\u0585\u0588\u058d\u05b2\u05ccy;\u4424r;\uc000\ud835\udd09lled\u0253\u0597\0\0\u05a3mallSquare;\u65fcerySmallSquare;\u65aa\u0370\u05ba\0\u05bf\0\0\u05c4f;\uc000\ud835\udd3dAll;\u6200riertrf;\u6131c\xf2\u05cb\u0600JTabcdfgorst\u05e8\u05ec\u05ef\u05fa\u0600\u0612\u0616\u061b\u061d\u0623\u066c\u0672cy;\u4403\u803b>\u403emma\u0100;d\u05f7\u05f8\u4393;\u43dcreve;\u411e\u0180eiy\u0607\u060c\u0610dil;\u4122rc;\u411c;\u4413ot;\u4120r;\uc000\ud835\udd0a;\u62d9pf;\uc000\ud835\udd3eeater\u0300EFGLST\u0635\u0644\u064e\u0656\u065b\u0666qual\u0100;L\u063e\u063f\u6265ess;\u62dbullEqual;\u6267reater;\u6aa2ess;\u6277lantEqual;\u6a7eilde;\u6273cr;\uc000\ud835\udca2;\u626b\u0400Aacfiosu\u0685\u068b\u0696\u069b\u069e\u06aa\u06be\u06caRDcy;\u442a\u0100ct\u0690\u0694ek;\u42c7;\u405eirc;\u4124r;\u610clbertSpace;\u610b\u01f0\u06af\0\u06b2f;\u610dizontalLine;\u6500\u0100ct\u06c3\u06c5\xf2\u06a9rok;\u4126mp\u0144\u06d0\u06d8ownHum\xf0\u012fqual;\u624f\u0700EJOacdfgmnostu\u06fa\u06fe\u0703\u0707\u070e\u071a\u071e\u0721\u0728\u0744\u0778\u078b\u078f\u0795cy;\u4415lig;\u4132cy;\u4401cute\u803b\xcd\u40cd\u0100iy\u0713\u0718rc\u803b\xce\u40ce;\u4418ot;\u4130r;\u6111rave\u803b\xcc\u40cc\u0180;ap\u0720\u072f\u073f\u0100cg\u0734\u0737r;\u412ainaryI;\u6148lie\xf3\u03dd\u01f4\u0749\0\u0762\u0100;e\u074d\u074e\u622c\u0100gr\u0753\u0758ral;\u622bsection;\u62c2isible\u0100CT\u076c\u0772omma;\u6063imes;\u6062\u0180gpt\u077f\u0783\u0788on;\u412ef;\uc000\ud835\udd40a;\u4399cr;\u6110ilde;\u4128\u01eb\u079a\0\u079ecy;\u4406l\u803b\xcf\u40cf\u0280cfosu\u07ac\u07b7\u07bc\u07c2\u07d0\u0100iy\u07b1\u07b5rc;\u4134;\u4419r;\uc000\ud835\udd0dpf;\uc000\ud835\udd41\u01e3\u07c7\0\u07ccr;\uc000\ud835\udca5rcy;\u4408kcy;\u4404\u0380HJacfos\u07e4\u07e8\u07ec\u07f1\u07fd\u0802\u0808cy;\u4425cy;\u440cppa;\u439a\u0100ey\u07f6\u07fbdil;\u4136;\u441ar;\uc000\ud835\udd0epf;\uc000\ud835\udd42cr;\uc000\ud835\udca6\u0580JTaceflmost\u0825\u0829\u082c\u0850\u0863\u09b3\u09b8\u09c7\u09cd\u0a37\u0a47cy;\u4409\u803b<\u403c\u0280cmnpr\u0837\u083c\u0841\u0844\u084dute;\u4139bda;\u439bg;\u67ealacetrf;\u6112r;\u619e\u0180aey\u0857\u085c\u0861ron;\u413ddil;\u413b;\u441b\u0100fs\u0868\u0970t\u0500ACDFRTUVar\u087e\u08a9\u08b1\u08e0\u08e6\u08fc\u092f\u095b\u0390\u096a\u0100nr\u0883\u088fgleBracket;\u67e8row\u0180;BR\u0899\u089a\u089e\u6190ar;\u61e4ightArrow;\u61c6eiling;\u6308o\u01f5\u08b7\0\u08c3bleBracket;\u67e6n\u01d4\u08c8\0\u08d2eeVector;\u6961ector\u0100;B\u08db\u08dc\u61c3ar;\u6959loor;\u630aight\u0100AV\u08ef\u08f5rrow;\u6194ector;\u694e\u0100er\u0901\u0917e\u0180;AV\u0909\u090a\u0910\u62a3rrow;\u61a4ector;\u695aiangle\u0180;BE\u0924\u0925\u0929\u62b2ar;\u69cfqual;\u62b4p\u0180DTV\u0937\u0942\u094cownVector;\u6951eeVector;\u6960ector\u0100;B\u0956\u0957\u61bfar;\u6958ector\u0100;B\u0965\u0966\u61bcar;\u6952ight\xe1\u039cs\u0300EFGLST\u097e\u098b\u0995\u099d\u09a2\u09adqualGreater;\u62daullEqual;\u6266reater;\u6276ess;\u6aa1lantEqual;\u6a7dilde;\u6272r;\uc000\ud835\udd0f\u0100;e\u09bd\u09be\u62d8ftarrow;\u61daidot;\u413f\u0180npw\u09d4\u0a16\u0a1bg\u0200LRlr\u09de\u09f7\u0a02\u0a10eft\u0100AR\u09e6\u09ecrrow;\u67f5ightArrow;\u67f7ightArrow;\u67f6eft\u0100ar\u03b3\u0a0aight\xe1\u03bfight\xe1\u03caf;\uc000\ud835\udd43er\u0100LR\u0a22\u0a2ceftArrow;\u6199ightArrow;\u6198\u0180cht\u0a3e\u0a40\u0a42\xf2\u084c;\u61b0rok;\u4141;\u626a\u0400acefiosu\u0a5a\u0a5d\u0a60\u0a77\u0a7c\u0a85\u0a8b\u0a8ep;\u6905y;\u441c\u0100dl\u0a65\u0a6fiumSpace;\u605flintrf;\u6133r;\uc000\ud835\udd10nusPlus;\u6213pf;\uc000\ud835\udd44c\xf2\u0a76;\u439c\u0480Jacefostu\u0aa3\u0aa7\u0aad\u0ac0\u0b14\u0b19\u0d91\u0d97\u0d9ecy;\u440acute;\u4143\u0180aey\u0ab4\u0ab9\u0aberon;\u4147dil;\u4145;\u441d\u0180gsw\u0ac7\u0af0\u0b0eative\u0180MTV\u0ad3\u0adf\u0ae8ediumSpace;\u600bhi\u0100cn\u0ae6\u0ad8\xeb\u0ad9eryThi\xee\u0ad9ted\u0100GL\u0af8\u0b06reaterGreate\xf2\u0673essLes\xf3\u0a48Line;\u400ar;\uc000\ud835\udd11\u0200Bnpt\u0b22\u0b28\u0b37\u0b3areak;\u6060BreakingSpace;\u40a0f;\u6115\u0680;CDEGHLNPRSTV\u0b55\u0b56\u0b6a\u0b7c\u0ba1\u0beb\u0c04\u0c5e\u0c84\u0ca6\u0cd8\u0d61\u0d85\u6aec\u0100ou\u0b5b\u0b64ngruent;\u6262pCap;\u626doubleVerticalBar;\u6226\u0180lqx\u0b83\u0b8a\u0b9bement;\u6209ual\u0100;T\u0b92\u0b93\u6260ilde;\uc000\u2242\u0338ists;\u6204reater\u0380;EFGLST\u0bb6\u0bb7\u0bbd\u0bc9\u0bd3\u0bd8\u0be5\u626fqual;\u6271ullEqual;\uc000\u2267\u0338reater;\uc000\u226b\u0338ess;\u6279lantEqual;\uc000\u2a7e\u0338ilde;\u6275ump\u0144\u0bf2\u0bfdownHump;\uc000\u224e\u0338qual;\uc000\u224f\u0338e\u0100fs\u0c0a\u0c27tTriangle\u0180;BE\u0c1a\u0c1b\u0c21\u62eaar;\uc000\u29cf\u0338qual;\u62ecs\u0300;EGLST\u0c35\u0c36\u0c3c\u0c44\u0c4b\u0c58\u626equal;\u6270reater;\u6278ess;\uc000\u226a\u0338lantEqual;\uc000\u2a7d\u0338ilde;\u6274ested\u0100GL\u0c68\u0c79reaterGreater;\uc000\u2aa2\u0338essLess;\uc000\u2aa1\u0338recedes\u0180;ES\u0c92\u0c93\u0c9b\u6280qual;\uc000\u2aaf\u0338lantEqual;\u62e0\u0100ei\u0cab\u0cb9verseElement;\u620cghtTriangle\u0180;BE\u0ccb\u0ccc\u0cd2\u62ebar;\uc000\u29d0\u0338qual;\u62ed\u0100qu\u0cdd\u0d0cuareSu\u0100bp\u0ce8\u0cf9set\u0100;E\u0cf0\u0cf3\uc000\u228f\u0338qual;\u62e2erset\u0100;E\u0d03\u0d06\uc000\u2290\u0338qual;\u62e3\u0180bcp\u0d13\u0d24\u0d4eset\u0100;E\u0d1b\u0d1e\uc000\u2282\u20d2qual;\u6288ceeds\u0200;EST\u0d32\u0d33\u0d3b\u0d46\u6281qual;\uc000\u2ab0\u0338lantEqual;\u62e1ilde;\uc000\u227f\u0338erset\u0100;E\u0d58\u0d5b\uc000\u2283\u20d2qual;\u6289ilde\u0200;EFT\u0d6e\u0d6f\u0d75\u0d7f\u6241qual;\u6244ullEqual;\u6247ilde;\u6249erticalBar;\u6224cr;\uc000\ud835\udca9ilde\u803b\xd1\u40d1;\u439d\u0700Eacdfgmoprstuv\u0dbd\u0dc2\u0dc9\u0dd5\u0ddb\u0de0\u0de7\u0dfc\u0e02\u0e20\u0e22\u0e32\u0e3f\u0e44lig;\u4152cute\u803b\xd3\u40d3\u0100iy\u0dce\u0dd3rc\u803b\xd4\u40d4;\u441eblac;\u4150r;\uc000\ud835\udd12rave\u803b\xd2\u40d2\u0180aei\u0dee\u0df2\u0df6cr;\u414cga;\u43a9cron;\u439fpf;\uc000\ud835\udd46enCurly\u0100DQ\u0e0e\u0e1aoubleQuote;\u601cuote;\u6018;\u6a54\u0100cl\u0e27\u0e2cr;\uc000\ud835\udcaaash\u803b\xd8\u40d8i\u016c\u0e37\u0e3cde\u803b\xd5\u40d5es;\u6a37ml\u803b\xd6\u40d6er\u0100BP\u0e4b\u0e60\u0100ar\u0e50\u0e53r;\u603eac\u0100ek\u0e5a\u0e5c;\u63deet;\u63b4arenthesis;\u63dc\u0480acfhilors\u0e7f\u0e87\u0e8a\u0e8f\u0e92\u0e94\u0e9d\u0eb0\u0efcrtialD;\u6202y;\u441fr;\uc000\ud835\udd13i;\u43a6;\u43a0usMinus;\u40b1\u0100ip\u0ea2\u0eadncareplan\xe5\u069df;\u6119\u0200;eio\u0eb9\u0eba\u0ee0\u0ee4\u6abbcedes\u0200;EST\u0ec8\u0ec9\u0ecf\u0eda\u627aqual;\u6aaflantEqual;\u627cilde;\u627eme;\u6033\u0100dp\u0ee9\u0eeeuct;\u620fortion\u0100;a\u0225\u0ef9l;\u621d\u0100ci\u0f01\u0f06r;\uc000\ud835\udcab;\u43a8\u0200Ufos\u0f11\u0f16\u0f1b\u0f1fOT\u803b\"\u4022r;\uc000\ud835\udd14pf;\u611acr;\uc000\ud835\udcac\u0600BEacefhiorsu\u0f3e\u0f43\u0f47\u0f60\u0f73\u0fa7\u0faa\u0fad\u1096\u10a9\u10b4\u10bearr;\u6910G\u803b\xae\u40ae\u0180cnr\u0f4e\u0f53\u0f56ute;\u4154g;\u67ebr\u0100;t\u0f5c\u0f5d\u61a0l;\u6916\u0180aey\u0f67\u0f6c\u0f71ron;\u4158dil;\u4156;\u4420\u0100;v\u0f78\u0f79\u611cerse\u0100EU\u0f82\u0f99\u0100lq\u0f87\u0f8eement;\u620builibrium;\u61cbpEquilibrium;\u696fr\xbb\u0f79o;\u43a1ght\u0400ACDFTUVa\u0fc1\u0feb\u0ff3\u1022\u1028\u105b\u1087\u03d8\u0100nr\u0fc6\u0fd2gleBracket;\u67e9row\u0180;BL\u0fdc\u0fdd\u0fe1\u6192ar;\u61e5eftArrow;\u61c4eiling;\u6309o\u01f5\u0ff9\0\u1005bleBracket;\u67e7n\u01d4\u100a\0\u1014eeVector;\u695dector\u0100;B\u101d\u101e\u61c2ar;\u6955loor;\u630b\u0100er\u102d\u1043e\u0180;AV\u1035\u1036\u103c\u62a2rrow;\u61a6ector;\u695biangle\u0180;BE\u1050\u1051\u1055\u62b3ar;\u69d0qual;\u62b5p\u0180DTV\u1063\u106e\u1078ownVector;\u694feeVector;\u695cector\u0100;B\u1082\u1083\u61bear;\u6954ector\u0100;B\u1091\u1092\u61c0ar;\u6953\u0100pu\u109b\u109ef;\u611dndImplies;\u6970ightarrow;\u61db\u0100ch\u10b9\u10bcr;\u611b;\u61b1leDelayed;\u69f4\u0680HOacfhimoqstu\u10e4\u10f1\u10f7\u10fd\u1119\u111e\u1151\u1156\u1161\u1167\u11b5\u11bb\u11bf\u0100Cc\u10e9\u10eeHcy;\u4429y;\u4428FTcy;\u442ccute;\u415a\u0280;aeiy\u1108\u1109\u110e\u1113\u1117\u6abcron;\u4160dil;\u415erc;\u415c;\u4421r;\uc000\ud835\udd16ort\u0200DLRU\u112a\u1134\u113e\u1149ownArrow\xbb\u041eeftArrow\xbb\u089aightArrow\xbb\u0fddpArrow;\u6191gma;\u43a3allCircle;\u6218pf;\uc000\ud835\udd4a\u0272\u116d\0\0\u1170t;\u621aare\u0200;ISU\u117b\u117c\u1189\u11af\u65a1ntersection;\u6293u\u0100bp\u118f\u119eset\u0100;E\u1197\u1198\u628fqual;\u6291erset\u0100;E\u11a8\u11a9\u6290qual;\u6292nion;\u6294cr;\uc000\ud835\udcaear;\u62c6\u0200bcmp\u11c8\u11db\u1209\u120b\u0100;s\u11cd\u11ce\u62d0et\u0100;E\u11cd\u11d5qual;\u6286\u0100ch\u11e0\u1205eeds\u0200;EST\u11ed\u11ee\u11f4\u11ff\u627bqual;\u6ab0lantEqual;\u627dilde;\u627fTh\xe1\u0f8c;\u6211\u0180;es\u1212\u1213\u1223\u62d1rset\u0100;E\u121c\u121d\u6283qual;\u6287et\xbb\u1213\u0580HRSacfhiors\u123e\u1244\u1249\u1255\u125e\u1271\u1276\u129f\u12c2\u12c8\u12d1ORN\u803b\xde\u40deADE;\u6122\u0100Hc\u124e\u1252cy;\u440by;\u4426\u0100bu\u125a\u125c;\u4009;\u43a4\u0180aey\u1265\u126a\u126fron;\u4164dil;\u4162;\u4422r;\uc000\ud835\udd17\u0100ei\u127b\u1289\u01f2\u1280\0\u1287efore;\u6234a;\u4398\u0100cn\u128e\u1298kSpace;\uc000\u205f\u200aSpace;\u6009lde\u0200;EFT\u12ab\u12ac\u12b2\u12bc\u623cqual;\u6243ullEqual;\u6245ilde;\u6248pf;\uc000\ud835\udd4bipleDot;\u60db\u0100ct\u12d6\u12dbr;\uc000\ud835\udcafrok;\u4166\u0ae1\u12f7\u130e\u131a\u1326\0\u132c\u1331\0\0\0\0\0\u1338\u133d\u1377\u1385\0\u13ff\u1404\u140a\u1410\u0100cr\u12fb\u1301ute\u803b\xda\u40dar\u0100;o\u1307\u1308\u619fcir;\u6949r\u01e3\u1313\0\u1316y;\u440eve;\u416c\u0100iy\u131e\u1323rc\u803b\xdb\u40db;\u4423blac;\u4170r;\uc000\ud835\udd18rave\u803b\xd9\u40d9acr;\u416a\u0100di\u1341\u1369er\u0100BP\u1348\u135d\u0100ar\u134d\u1350r;\u405fac\u0100ek\u1357\u1359;\u63dfet;\u63b5arenthesis;\u63ddon\u0100;P\u1370\u1371\u62c3lus;\u628e\u0100gp\u137b\u137fon;\u4172f;\uc000\ud835\udd4c\u0400ADETadps\u1395\u13ae\u13b8\u13c4\u03e8\u13d2\u13d7\u13f3rrow\u0180;BD\u1150\u13a0\u13a4ar;\u6912ownArrow;\u61c5ownArrow;\u6195quilibrium;\u696eee\u0100;A\u13cb\u13cc\u62a5rrow;\u61a5own\xe1\u03f3er\u0100LR\u13de\u13e8eftArrow;\u6196ightArrow;\u6197i\u0100;l\u13f9\u13fa\u43d2on;\u43a5ing;\u416ecr;\uc000\ud835\udcb0ilde;\u4168ml\u803b\xdc\u40dc\u0480Dbcdefosv\u1427\u142c\u1430\u1433\u143e\u1485\u148a\u1490\u1496ash;\u62abar;\u6aeby;\u4412ash\u0100;l\u143b\u143c\u62a9;\u6ae6\u0100er\u1443\u1445;\u62c1\u0180bty\u144c\u1450\u147aar;\u6016\u0100;i\u144f\u1455cal\u0200BLST\u1461\u1465\u146a\u1474ar;\u6223ine;\u407ceparator;\u6758ilde;\u6240ThinSpace;\u600ar;\uc000\ud835\udd19pf;\uc000\ud835\udd4dcr;\uc000\ud835\udcb1dash;\u62aa\u0280cefos\u14a7\u14ac\u14b1\u14b6\u14bcirc;\u4174dge;\u62c0r;\uc000\ud835\udd1apf;\uc000\ud835\udd4ecr;\uc000\ud835\udcb2\u0200fios\u14cb\u14d0\u14d2\u14d8r;\uc000\ud835\udd1b;\u439epf;\uc000\ud835\udd4fcr;\uc000\ud835\udcb3\u0480AIUacfosu\u14f1\u14f5\u14f9\u14fd\u1504\u150f\u1514\u151a\u1520cy;\u442fcy;\u4407cy;\u442ecute\u803b\xdd\u40dd\u0100iy\u1509\u150drc;\u4176;\u442br;\uc000\ud835\udd1cpf;\uc000\ud835\udd50cr;\uc000\ud835\udcb4ml;\u4178\u0400Hacdefos\u1535\u1539\u153f\u154b\u154f\u155d\u1560\u1564cy;\u4416cute;\u4179\u0100ay\u1544\u1549ron;\u417d;\u4417ot;\u417b\u01f2\u1554\0\u155boWidt\xe8\u0ad9a;\u4396r;\u6128pf;\u6124cr;\uc000\ud835\udcb5\u0be1\u1583\u158a\u1590\0\u15b0\u15b6\u15bf\0\0\0\0\u15c6\u15db\u15eb\u165f\u166d\0\u1695\u169b\u16b2\u16b9\0\u16becute\u803b\xe1\u40e1reve;\u4103\u0300;Ediuy\u159c\u159d\u15a1\u15a3\u15a8\u15ad\u623e;\uc000\u223e\u0333;\u623frc\u803b\xe2\u40e2te\u80bb\xb4\u0306;\u4430lig\u803b\xe6\u40e6\u0100;r\xb2\u15ba;\uc000\ud835\udd1erave\u803b\xe0\u40e0\u0100ep\u15ca\u15d6\u0100fp\u15cf\u15d4sym;\u6135\xe8\u15d3ha;\u43b1\u0100ap\u15dfc\u0100cl\u15e4\u15e7r;\u4101g;\u6a3f\u0264\u15f0\0\0\u160a\u0280;adsv\u15fa\u15fb\u15ff\u1601\u1607\u6227nd;\u6a55;\u6a5clope;\u6a58;\u6a5a\u0380;elmrsz\u1618\u1619\u161b\u161e\u163f\u164f\u1659\u6220;\u69a4e\xbb\u1619sd\u0100;a\u1625\u1626\u6221\u0461\u1630\u1632\u1634\u1636\u1638\u163a\u163c\u163e;\u69a8;\u69a9;\u69aa;\u69ab;\u69ac;\u69ad;\u69ae;\u69aft\u0100;v\u1645\u1646\u621fb\u0100;d\u164c\u164d\u62be;\u699d\u0100pt\u1654\u1657h;\u6222\xbb\xb9arr;\u637c\u0100gp\u1663\u1667on;\u4105f;\uc000\ud835\udd52\u0380;Eaeiop\u12c1\u167b\u167d\u1682\u1684\u1687\u168a;\u6a70cir;\u6a6f;\u624ad;\u624bs;\u4027rox\u0100;e\u12c1\u1692\xf1\u1683ing\u803b\xe5\u40e5\u0180cty\u16a1\u16a6\u16a8r;\uc000\ud835\udcb6;\u402amp\u0100;e\u12c1\u16af\xf1\u0288ilde\u803b\xe3\u40e3ml\u803b\xe4\u40e4\u0100ci\u16c2\u16c8onin\xf4\u0272nt;\u6a11\u0800Nabcdefiklnoprsu\u16ed\u16f1\u1730\u173c\u1743\u1748\u1778\u177d\u17e0\u17e6\u1839\u1850\u170d\u193d\u1948\u1970ot;\u6aed\u0100cr\u16f6\u171ek\u0200ceps\u1700\u1705\u170d\u1713ong;\u624cpsilon;\u43f6rime;\u6035im\u0100;e\u171a\u171b\u623dq;\u62cd\u0176\u1722\u1726ee;\u62bded\u0100;g\u172c\u172d\u6305e\xbb\u172drk\u0100;t\u135c\u1737brk;\u63b6\u0100oy\u1701\u1741;\u4431quo;\u601e\u0280cmprt\u1753\u175b\u1761\u1764\u1768aus\u0100;e\u010a\u0109ptyv;\u69b0s\xe9\u170cno\xf5\u0113\u0180ahw\u176f\u1771\u1773;\u43b2;\u6136een;\u626cr;\uc000\ud835\udd1fg\u0380costuvw\u178d\u179d\u17b3\u17c1\u17d5\u17db\u17de\u0180aiu\u1794\u1796\u179a\xf0\u0760rc;\u65efp\xbb\u1371\u0180dpt\u17a4\u17a8\u17adot;\u6a00lus;\u6a01imes;\u6a02\u0271\u17b9\0\0\u17becup;\u6a06ar;\u6605riangle\u0100du\u17cd\u17d2own;\u65bdp;\u65b3plus;\u6a04e\xe5\u1444\xe5\u14adarow;\u690d\u0180ako\u17ed\u1826\u1835\u0100cn\u17f2\u1823k\u0180lst\u17fa\u05ab\u1802ozenge;\u69ebriangle\u0200;dlr\u1812\u1813\u1818\u181d\u65b4own;\u65beeft;\u65c2ight;\u65b8k;\u6423\u01b1\u182b\0\u1833\u01b2\u182f\0\u1831;\u6592;\u65914;\u6593ck;\u6588\u0100eo\u183e\u184d\u0100;q\u1843\u1846\uc000=\u20e5uiv;\uc000\u2261\u20e5t;\u6310\u0200ptwx\u1859\u185e\u1867\u186cf;\uc000\ud835\udd53\u0100;t\u13cb\u1863om\xbb\u13cctie;\u62c8\u0600DHUVbdhmptuv\u1885\u1896\u18aa\u18bb\u18d7\u18db\u18ec\u18ff\u1905\u190a\u1910\u1921\u0200LRlr\u188e\u1890\u1892\u1894;\u6557;\u6554;\u6556;\u6553\u0280;DUdu\u18a1\u18a2\u18a4\u18a6\u18a8\u6550;\u6566;\u6569;\u6564;\u6567\u0200LRlr\u18b3\u18b5\u18b7\u18b9;\u655d;\u655a;\u655c;\u6559\u0380;HLRhlr\u18ca\u18cb\u18cd\u18cf\u18d1\u18d3\u18d5\u6551;\u656c;\u6563;\u6560;\u656b;\u6562;\u655fox;\u69c9\u0200LRlr\u18e4\u18e6\u18e8\u18ea;\u6555;\u6552;\u6510;\u650c\u0280;DUdu\u06bd\u18f7\u18f9\u18fb\u18fd;\u6565;\u6568;\u652c;\u6534inus;\u629flus;\u629eimes;\u62a0\u0200LRlr\u1919\u191b\u191d\u191f;\u655b;\u6558;\u6518;\u6514\u0380;HLRhlr\u1930\u1931\u1933\u1935\u1937\u1939\u193b\u6502;\u656a;\u6561;\u655e;\u653c;\u6524;\u651c\u0100ev\u0123\u1942bar\u803b\xa6\u40a6\u0200ceio\u1951\u1956\u195a\u1960r;\uc000\ud835\udcb7mi;\u604fm\u0100;e\u171a\u171cl\u0180;bh\u1968\u1969\u196b\u405c;\u69c5sub;\u67c8\u016c\u1974\u197el\u0100;e\u1979\u197a\u6022t\xbb\u197ap\u0180;Ee\u012f\u1985\u1987;\u6aae\u0100;q\u06dc\u06db\u0ce1\u19a7\0\u19e8\u1a11\u1a15\u1a32\0\u1a37\u1a50\0\0\u1ab4\0\0\u1ac1\0\0\u1b21\u1b2e\u1b4d\u1b52\0\u1bfd\0\u1c0c\u0180cpr\u19ad\u19b2\u19ddute;\u4107\u0300;abcds\u19bf\u19c0\u19c4\u19ca\u19d5\u19d9\u6229nd;\u6a44rcup;\u6a49\u0100au\u19cf\u19d2p;\u6a4bp;\u6a47ot;\u6a40;\uc000\u2229\ufe00\u0100eo\u19e2\u19e5t;\u6041\xee\u0693\u0200aeiu\u19f0\u19fb\u1a01\u1a05\u01f0\u19f5\0\u19f8s;\u6a4don;\u410ddil\u803b\xe7\u40e7rc;\u4109ps\u0100;s\u1a0c\u1a0d\u6a4cm;\u6a50ot;\u410b\u0180dmn\u1a1b\u1a20\u1a26il\u80bb\xb8\u01adptyv;\u69b2t\u8100\xa2;e\u1a2d\u1a2e\u40a2r\xe4\u01b2r;\uc000\ud835\udd20\u0180cei\u1a3d\u1a40\u1a4dy;\u4447ck\u0100;m\u1a47\u1a48\u6713ark\xbb\u1a48;\u43c7r\u0380;Ecefms\u1a5f\u1a60\u1a62\u1a6b\u1aa4\u1aaa\u1aae\u65cb;\u69c3\u0180;el\u1a69\u1a6a\u1a6d\u42c6q;\u6257e\u0261\u1a74\0\0\u1a88rrow\u0100lr\u1a7c\u1a81eft;\u61baight;\u61bb\u0280RSacd\u1a92\u1a94\u1a96\u1a9a\u1a9f\xbb\u0f47;\u64c8st;\u629birc;\u629aash;\u629dnint;\u6a10id;\u6aefcir;\u69c2ubs\u0100;u\u1abb\u1abc\u6663it\xbb\u1abc\u02ec\u1ac7\u1ad4\u1afa\0\u1b0aon\u0100;e\u1acd\u1ace\u403a\u0100;q\xc7\xc6\u026d\u1ad9\0\0\u1ae2a\u0100;t\u1ade\u1adf\u402c;\u4040\u0180;fl\u1ae8\u1ae9\u1aeb\u6201\xee\u1160e\u0100mx\u1af1\u1af6ent\xbb\u1ae9e\xf3\u024d\u01e7\u1afe\0\u1b07\u0100;d\u12bb\u1b02ot;\u6a6dn\xf4\u0246\u0180fry\u1b10\u1b14\u1b17;\uc000\ud835\udd54o\xe4\u0254\u8100\xa9;s\u0155\u1b1dr;\u6117\u0100ao\u1b25\u1b29rr;\u61b5ss;\u6717\u0100cu\u1b32\u1b37r;\uc000\ud835\udcb8\u0100bp\u1b3c\u1b44\u0100;e\u1b41\u1b42\u6acf;\u6ad1\u0100;e\u1b49\u1b4a\u6ad0;\u6ad2dot;\u62ef\u0380delprvw\u1b60\u1b6c\u1b77\u1b82\u1bac\u1bd4\u1bf9arr\u0100lr\u1b68\u1b6a;\u6938;\u6935\u0270\u1b72\0\0\u1b75r;\u62dec;\u62dfarr\u0100;p\u1b7f\u1b80\u61b6;\u693d\u0300;bcdos\u1b8f\u1b90\u1b96\u1ba1\u1ba5\u1ba8\u622arcap;\u6a48\u0100au\u1b9b\u1b9ep;\u6a46p;\u6a4aot;\u628dr;\u6a45;\uc000\u222a\ufe00\u0200alrv\u1bb5\u1bbf\u1bde\u1be3rr\u0100;m\u1bbc\u1bbd\u61b7;\u693cy\u0180evw\u1bc7\u1bd4\u1bd8q\u0270\u1bce\0\0\u1bd2re\xe3\u1b73u\xe3\u1b75ee;\u62ceedge;\u62cfen\u803b\xa4\u40a4earrow\u0100lr\u1bee\u1bf3eft\xbb\u1b80ight\xbb\u1bbde\xe4\u1bdd\u0100ci\u1c01\u1c07onin\xf4\u01f7nt;\u6231lcty;\u632d\u0980AHabcdefhijlorstuwz\u1c38\u1c3b\u1c3f\u1c5d\u1c69\u1c75\u1c8a\u1c9e\u1cac\u1cb7\u1cfb\u1cff\u1d0d\u1d7b\u1d91\u1dab\u1dbb\u1dc6\u1dcdr\xf2\u0381ar;\u6965\u0200glrs\u1c48\u1c4d\u1c52\u1c54ger;\u6020eth;\u6138\xf2\u1133h\u0100;v\u1c5a\u1c5b\u6010\xbb\u090a\u016b\u1c61\u1c67arow;\u690fa\xe3\u0315\u0100ay\u1c6e\u1c73ron;\u410f;\u4434\u0180;ao\u0332\u1c7c\u1c84\u0100gr\u02bf\u1c81r;\u61catseq;\u6a77\u0180glm\u1c91\u1c94\u1c98\u803b\xb0\u40b0ta;\u43b4ptyv;\u69b1\u0100ir\u1ca3\u1ca8sht;\u697f;\uc000\ud835\udd21ar\u0100lr\u1cb3\u1cb5\xbb\u08dc\xbb\u101e\u0280aegsv\u1cc2\u0378\u1cd6\u1cdc\u1ce0m\u0180;os\u0326\u1cca\u1cd4nd\u0100;s\u0326\u1cd1uit;\u6666amma;\u43ddin;\u62f2\u0180;io\u1ce7\u1ce8\u1cf8\u40f7de\u8100\xf7;o\u1ce7\u1cf0ntimes;\u62c7n\xf8\u1cf7cy;\u4452c\u026f\u1d06\0\0\u1d0arn;\u631eop;\u630d\u0280lptuw\u1d18\u1d1d\u1d22\u1d49\u1d55lar;\u4024f;\uc000\ud835\udd55\u0280;emps\u030b\u1d2d\u1d37\u1d3d\u1d42q\u0100;d\u0352\u1d33ot;\u6251inus;\u6238lus;\u6214quare;\u62a1blebarwedg\xe5\xfan\u0180adh\u112e\u1d5d\u1d67ownarrow\xf3\u1c83arpoon\u0100lr\u1d72\u1d76ef\xf4\u1cb4igh\xf4\u1cb6\u0162\u1d7f\u1d85karo\xf7\u0f42\u026f\u1d8a\0\0\u1d8ern;\u631fop;\u630c\u0180cot\u1d98\u1da3\u1da6\u0100ry\u1d9d\u1da1;\uc000\ud835\udcb9;\u4455l;\u69f6rok;\u4111\u0100dr\u1db0\u1db4ot;\u62f1i\u0100;f\u1dba\u1816\u65bf\u0100ah\u1dc0\u1dc3r\xf2\u0429a\xf2\u0fa6angle;\u69a6\u0100ci\u1dd2\u1dd5y;\u445fgrarr;\u67ff\u0900Dacdefglmnopqrstux\u1e01\u1e09\u1e19\u1e38\u0578\u1e3c\u1e49\u1e61\u1e7e\u1ea5\u1eaf\u1ebd\u1ee1\u1f2a\u1f37\u1f44\u1f4e\u1f5a\u0100Do\u1e06\u1d34o\xf4\u1c89\u0100cs\u1e0e\u1e14ute\u803b\xe9\u40e9ter;\u6a6e\u0200aioy\u1e22\u1e27\u1e31\u1e36ron;\u411br\u0100;c\u1e2d\u1e2e\u6256\u803b\xea\u40ealon;\u6255;\u444dot;\u4117\u0100Dr\u1e41\u1e45ot;\u6252;\uc000\ud835\udd22\u0180;rs\u1e50\u1e51\u1e57\u6a9aave\u803b\xe8\u40e8\u0100;d\u1e5c\u1e5d\u6a96ot;\u6a98\u0200;ils\u1e6a\u1e6b\u1e72\u1e74\u6a99nters;\u63e7;\u6113\u0100;d\u1e79\u1e7a\u6a95ot;\u6a97\u0180aps\u1e85\u1e89\u1e97cr;\u4113ty\u0180;sv\u1e92\u1e93\u1e95\u6205et\xbb\u1e93p\u01001;\u1e9d\u1ea4\u0133\u1ea1\u1ea3;\u6004;\u6005\u6003\u0100gs\u1eaa\u1eac;\u414bp;\u6002\u0100gp\u1eb4\u1eb8on;\u4119f;\uc000\ud835\udd56\u0180als\u1ec4\u1ece\u1ed2r\u0100;s\u1eca\u1ecb\u62d5l;\u69e3us;\u6a71i\u0180;lv\u1eda\u1edb\u1edf\u43b5on\xbb\u1edb;\u43f5\u0200csuv\u1eea\u1ef3\u1f0b\u1f23\u0100io\u1eef\u1e31rc\xbb\u1e2e\u0269\u1ef9\0\0\u1efb\xed\u0548ant\u0100gl\u1f02\u1f06tr\xbb\u1e5dess\xbb\u1e7a\u0180aei\u1f12\u1f16\u1f1als;\u403dst;\u625fv\u0100;D\u0235\u1f20D;\u6a78parsl;\u69e5\u0100Da\u1f2f\u1f33ot;\u6253rr;\u6971\u0180cdi\u1f3e\u1f41\u1ef8r;\u612fo\xf4\u0352\u0100ah\u1f49\u1f4b;\u43b7\u803b\xf0\u40f0\u0100mr\u1f53\u1f57l\u803b\xeb\u40ebo;\u60ac\u0180cip\u1f61\u1f64\u1f67l;\u4021s\xf4\u056e\u0100eo\u1f6c\u1f74ctatio\xee\u0559nential\xe5\u0579\u09e1\u1f92\0\u1f9e\0\u1fa1\u1fa7\0\0\u1fc6\u1fcc\0\u1fd3\0\u1fe6\u1fea\u2000\0\u2008\u205allingdotse\xf1\u1e44y;\u4444male;\u6640\u0180ilr\u1fad\u1fb3\u1fc1lig;\u8000\ufb03\u0269\u1fb9\0\0\u1fbdg;\u8000\ufb00ig;\u8000\ufb04;\uc000\ud835\udd23lig;\u8000\ufb01lig;\uc000fj\u0180alt\u1fd9\u1fdc\u1fe1t;\u666dig;\u8000\ufb02ns;\u65b1of;\u4192\u01f0\u1fee\0\u1ff3f;\uc000\ud835\udd57\u0100ak\u05bf\u1ff7\u0100;v\u1ffc\u1ffd\u62d4;\u6ad9artint;\u6a0d\u0100ao\u200c\u2055\u0100cs\u2011\u2052\u03b1\u201a\u2030\u2038\u2045\u2048\0\u2050\u03b2\u2022\u2025\u2027\u202a\u202c\0\u202e\u803b\xbd\u40bd;\u6153\u803b\xbc\u40bc;\u6155;\u6159;\u615b\u01b3\u2034\0\u2036;\u6154;\u6156\u02b4\u203e\u2041\0\0\u2043\u803b\xbe\u40be;\u6157;\u615c5;\u6158\u01b6\u204c\0\u204e;\u615a;\u615d8;\u615el;\u6044wn;\u6322cr;\uc000\ud835\udcbb\u0880Eabcdefgijlnorstv\u2082\u2089\u209f\u20a5\u20b0\u20b4\u20f0\u20f5\u20fa\u20ff\u2103\u2112\u2138\u0317\u213e\u2152\u219e\u0100;l\u064d\u2087;\u6a8c\u0180cmp\u2090\u2095\u209dute;\u41f5ma\u0100;d\u209c\u1cda\u43b3;\u6a86reve;\u411f\u0100iy\u20aa\u20aerc;\u411d;\u4433ot;\u4121\u0200;lqs\u063e\u0642\u20bd\u20c9\u0180;qs\u063e\u064c\u20c4lan\xf4\u0665\u0200;cdl\u0665\u20d2\u20d5\u20e5c;\u6aa9ot\u0100;o\u20dc\u20dd\u6a80\u0100;l\u20e2\u20e3\u6a82;\u6a84\u0100;e\u20ea\u20ed\uc000\u22db\ufe00s;\u6a94r;\uc000\ud835\udd24\u0100;g\u0673\u061bmel;\u6137cy;\u4453\u0200;Eaj\u065a\u210c\u210e\u2110;\u6a92;\u6aa5;\u6aa4\u0200Eaes\u211b\u211d\u2129\u2134;\u6269p\u0100;p\u2123\u2124\u6a8arox\xbb\u2124\u0100;q\u212e\u212f\u6a88\u0100;q\u212e\u211bim;\u62e7pf;\uc000\ud835\udd58\u0100ci\u2143\u2146r;\u610am\u0180;el\u066b\u214e\u2150;\u6a8e;\u6a90\u8300>;cdlqr\u05ee\u2160\u216a\u216e\u2173\u2179\u0100ci\u2165\u2167;\u6aa7r;\u6a7aot;\u62d7Par;\u6995uest;\u6a7c\u0280adels\u2184\u216a\u2190\u0656\u219b\u01f0\u2189\0\u218epro\xf8\u209er;\u6978q\u0100lq\u063f\u2196les\xf3\u2088i\xed\u066b\u0100en\u21a3\u21adrtneqq;\uc000\u2269\ufe00\xc5\u21aa\u0500Aabcefkosy\u21c4\u21c7\u21f1\u21f5\u21fa\u2218\u221d\u222f\u2268\u227dr\xf2\u03a0\u0200ilmr\u21d0\u21d4\u21d7\u21dbrs\xf0\u1484f\xbb\u2024il\xf4\u06a9\u0100dr\u21e0\u21e4cy;\u444a\u0180;cw\u08f4\u21eb\u21efir;\u6948;\u61adar;\u610firc;\u4125\u0180alr\u2201\u220e\u2213rts\u0100;u\u2209\u220a\u6665it\xbb\u220alip;\u6026con;\u62b9r;\uc000\ud835\udd25s\u0100ew\u2223\u2229arow;\u6925arow;\u6926\u0280amopr\u223a\u223e\u2243\u225e\u2263rr;\u61fftht;\u623bk\u0100lr\u2249\u2253eftarrow;\u61a9ightarrow;\u61aaf;\uc000\ud835\udd59bar;\u6015\u0180clt\u226f\u2274\u2278r;\uc000\ud835\udcbdas\xe8\u21f4rok;\u4127\u0100bp\u2282\u2287ull;\u6043hen\xbb\u1c5b\u0ae1\u22a3\0\u22aa\0\u22b8\u22c5\u22ce\0\u22d5\u22f3\0\0\u22f8\u2322\u2367\u2362\u237f\0\u2386\u23aa\u23b4cute\u803b\xed\u40ed\u0180;iy\u0771\u22b0\u22b5rc\u803b\xee\u40ee;\u4438\u0100cx\u22bc\u22bfy;\u4435cl\u803b\xa1\u40a1\u0100fr\u039f\u22c9;\uc000\ud835\udd26rave\u803b\xec\u40ec\u0200;ino\u073e\u22dd\u22e9\u22ee\u0100in\u22e2\u22e6nt;\u6a0ct;\u622dfin;\u69dcta;\u6129lig;\u4133\u0180aop\u22fe\u231a\u231d\u0180cgt\u2305\u2308\u2317r;\u412b\u0180elp\u071f\u230f\u2313in\xe5\u078ear\xf4\u0720h;\u4131f;\u62b7ed;\u41b5\u0280;cfot\u04f4\u232c\u2331\u233d\u2341are;\u6105in\u0100;t\u2338\u2339\u621eie;\u69dddo\xf4\u2319\u0280;celp\u0757\u234c\u2350\u235b\u2361al;\u62ba\u0100gr\u2355\u2359er\xf3\u1563\xe3\u234darhk;\u6a17rod;\u6a3c\u0200cgpt\u236f\u2372\u2376\u237by;\u4451on;\u412ff;\uc000\ud835\udd5aa;\u43b9uest\u803b\xbf\u40bf\u0100ci\u238a\u238fr;\uc000\ud835\udcben\u0280;Edsv\u04f4\u239b\u239d\u23a1\u04f3;\u62f9ot;\u62f5\u0100;v\u23a6\u23a7\u62f4;\u62f3\u0100;i\u0777\u23aelde;\u4129\u01eb\u23b8\0\u23bccy;\u4456l\u803b\xef\u40ef\u0300cfmosu\u23cc\u23d7\u23dc\u23e1\u23e7\u23f5\u0100iy\u23d1\u23d5rc;\u4135;\u4439r;\uc000\ud835\udd27ath;\u4237pf;\uc000\ud835\udd5b\u01e3\u23ec\0\u23f1r;\uc000\ud835\udcbfrcy;\u4458kcy;\u4454\u0400acfghjos\u240b\u2416\u2422\u2427\u242d\u2431\u2435\u243bppa\u0100;v\u2413\u2414\u43ba;\u43f0\u0100ey\u241b\u2420dil;\u4137;\u443ar;\uc000\ud835\udd28reen;\u4138cy;\u4445cy;\u445cpf;\uc000\ud835\udd5ccr;\uc000\ud835\udcc0\u0b80ABEHabcdefghjlmnoprstuv\u2470\u2481\u2486\u248d\u2491\u250e\u253d\u255a\u2580\u264e\u265e\u2665\u2679\u267d\u269a\u26b2\u26d8\u275d\u2768\u278b\u27c0\u2801\u2812\u0180art\u2477\u247a\u247cr\xf2\u09c6\xf2\u0395ail;\u691barr;\u690e\u0100;g\u0994\u248b;\u6a8bar;\u6962\u0963\u24a5\0\u24aa\0\u24b1\0\0\0\0\0\u24b5\u24ba\0\u24c6\u24c8\u24cd\0\u24f9ute;\u413amptyv;\u69b4ra\xee\u084cbda;\u43bbg\u0180;dl\u088e\u24c1\u24c3;\u6991\xe5\u088e;\u6a85uo\u803b\xab\u40abr\u0400;bfhlpst\u0899\u24de\u24e6\u24e9\u24eb\u24ee\u24f1\u24f5\u0100;f\u089d\u24e3s;\u691fs;\u691d\xeb\u2252p;\u61abl;\u6939im;\u6973l;\u61a2\u0180;ae\u24ff\u2500\u2504\u6aabil;\u6919\u0100;s\u2509\u250a\u6aad;\uc000\u2aad\ufe00\u0180abr\u2515\u2519\u251drr;\u690crk;\u6772\u0100ak\u2522\u252cc\u0100ek\u2528\u252a;\u407b;\u405b\u0100es\u2531\u2533;\u698bl\u0100du\u2539\u253b;\u698f;\u698d\u0200aeuy\u2546\u254b\u2556\u2558ron;\u413e\u0100di\u2550\u2554il;\u413c\xec\u08b0\xe2\u2529;\u443b\u0200cqrs\u2563\u2566\u256d\u257da;\u6936uo\u0100;r\u0e19\u1746\u0100du\u2572\u2577har;\u6967shar;\u694bh;\u61b2\u0280;fgqs\u258b\u258c\u0989\u25f3\u25ff\u6264t\u0280ahlrt\u2598\u25a4\u25b7\u25c2\u25e8rrow\u0100;t\u0899\u25a1a\xe9\u24f6arpoon\u0100du\u25af\u25b4own\xbb\u045ap\xbb\u0966eftarrows;\u61c7ight\u0180ahs\u25cd\u25d6\u25derrow\u0100;s\u08f4\u08a7arpoon\xf3\u0f98quigarro\xf7\u21f0hreetimes;\u62cb\u0180;qs\u258b\u0993\u25falan\xf4\u09ac\u0280;cdgs\u09ac\u260a\u260d\u261d\u2628c;\u6aa8ot\u0100;o\u2614\u2615\u6a7f\u0100;r\u261a\u261b\u6a81;\u6a83\u0100;e\u2622\u2625\uc000\u22da\ufe00s;\u6a93\u0280adegs\u2633\u2639\u263d\u2649\u264bppro\xf8\u24c6ot;\u62d6q\u0100gq\u2643\u2645\xf4\u0989gt\xf2\u248c\xf4\u099bi\xed\u09b2\u0180ilr\u2655\u08e1\u265asht;\u697c;\uc000\ud835\udd29\u0100;E\u099c\u2663;\u6a91\u0161\u2669\u2676r\u0100du\u25b2\u266e\u0100;l\u0965\u2673;\u696alk;\u6584cy;\u4459\u0280;acht\u0a48\u2688\u268b\u2691\u2696r\xf2\u25c1orne\xf2\u1d08ard;\u696bri;\u65fa\u0100io\u269f\u26a4dot;\u4140ust\u0100;a\u26ac\u26ad\u63b0che\xbb\u26ad\u0200Eaes\u26bb\u26bd\u26c9\u26d4;\u6268p\u0100;p\u26c3\u26c4\u6a89rox\xbb\u26c4\u0100;q\u26ce\u26cf\u6a87\u0100;q\u26ce\u26bbim;\u62e6\u0400abnoptwz\u26e9\u26f4\u26f7\u271a\u272f\u2741\u2747\u2750\u0100nr\u26ee\u26f1g;\u67ecr;\u61fdr\xeb\u08c1g\u0180lmr\u26ff\u270d\u2714eft\u0100ar\u09e6\u2707ight\xe1\u09f2apsto;\u67fcight\xe1\u09fdparrow\u0100lr\u2725\u2729ef\xf4\u24edight;\u61ac\u0180afl\u2736\u2739\u273dr;\u6985;\uc000\ud835\udd5dus;\u6a2dimes;\u6a34\u0161\u274b\u274fst;\u6217\xe1\u134e\u0180;ef\u2757\u2758\u1800\u65cange\xbb\u2758ar\u0100;l\u2764\u2765\u4028t;\u6993\u0280achmt\u2773\u2776\u277c\u2785\u2787r\xf2\u08a8orne\xf2\u1d8car\u0100;d\u0f98\u2783;\u696d;\u600eri;\u62bf\u0300achiqt\u2798\u279d\u0a40\u27a2\u27ae\u27bbquo;\u6039r;\uc000\ud835\udcc1m\u0180;eg\u09b2\u27aa\u27ac;\u6a8d;\u6a8f\u0100bu\u252a\u27b3o\u0100;r\u0e1f\u27b9;\u601arok;\u4142\u8400<;cdhilqr\u082b\u27d2\u2639\u27dc\u27e0\u27e5\u27ea\u27f0\u0100ci\u27d7\u27d9;\u6aa6r;\u6a79re\xe5\u25f2mes;\u62c9arr;\u6976uest;\u6a7b\u0100Pi\u27f5\u27f9ar;\u6996\u0180;ef\u2800\u092d\u181b\u65c3r\u0100du\u2807\u280dshar;\u694ahar;\u6966\u0100en\u2817\u2821rtneqq;\uc000\u2268\ufe00\xc5\u281e\u0700Dacdefhilnopsu\u2840\u2845\u2882\u288e\u2893\u28a0\u28a5\u28a8\u28da\u28e2\u28e4\u0a83\u28f3\u2902Dot;\u623a\u0200clpr\u284e\u2852\u2863\u287dr\u803b\xaf\u40af\u0100et\u2857\u2859;\u6642\u0100;e\u285e\u285f\u6720se\xbb\u285f\u0100;s\u103b\u2868to\u0200;dlu\u103b\u2873\u2877\u287bow\xee\u048cef\xf4\u090f\xf0\u13d1ker;\u65ae\u0100oy\u2887\u288cmma;\u6a29;\u443cash;\u6014asuredangle\xbb\u1626r;\uc000\ud835\udd2ao;\u6127\u0180cdn\u28af\u28b4\u28c9ro\u803b\xb5\u40b5\u0200;acd\u1464\u28bd\u28c0\u28c4s\xf4\u16a7ir;\u6af0ot\u80bb\xb7\u01b5us\u0180;bd\u28d2\u1903\u28d3\u6212\u0100;u\u1d3c\u28d8;\u6a2a\u0163\u28de\u28e1p;\u6adb\xf2\u2212\xf0\u0a81\u0100dp\u28e9\u28eeels;\u62a7f;\uc000\ud835\udd5e\u0100ct\u28f8\u28fdr;\uc000\ud835\udcc2pos\xbb\u159d\u0180;lm\u2909\u290a\u290d\u43bctimap;\u62b8\u0c00GLRVabcdefghijlmoprstuvw\u2942\u2953\u297e\u2989\u2998\u29da\u29e9\u2a15\u2a1a\u2a58\u2a5d\u2a83\u2a95\u2aa4\u2aa8\u2b04\u2b07\u2b44\u2b7f\u2bae\u2c34\u2c67\u2c7c\u2ce9\u0100gt\u2947\u294b;\uc000\u22d9\u0338\u0100;v\u2950\u0bcf\uc000\u226b\u20d2\u0180elt\u295a\u2972\u2976ft\u0100ar\u2961\u2967rrow;\u61cdightarrow;\u61ce;\uc000\u22d8\u0338\u0100;v\u297b\u0c47\uc000\u226a\u20d2ightarrow;\u61cf\u0100Dd\u298e\u2993ash;\u62afash;\u62ae\u0280bcnpt\u29a3\u29a7\u29ac\u29b1\u29ccla\xbb\u02deute;\u4144g;\uc000\u2220\u20d2\u0280;Eiop\u0d84\u29bc\u29c0\u29c5\u29c8;\uc000\u2a70\u0338d;\uc000\u224b\u0338s;\u4149ro\xf8\u0d84ur\u0100;a\u29d3\u29d4\u666el\u0100;s\u29d3\u0b38\u01f3\u29df\0\u29e3p\u80bb\xa0\u0b37mp\u0100;e\u0bf9\u0c00\u0280aeouy\u29f4\u29fe\u2a03\u2a10\u2a13\u01f0\u29f9\0\u29fb;\u6a43on;\u4148dil;\u4146ng\u0100;d\u0d7e\u2a0aot;\uc000\u2a6d\u0338p;\u6a42;\u443dash;\u6013\u0380;Aadqsx\u0b92\u2a29\u2a2d\u2a3b\u2a41\u2a45\u2a50rr;\u61d7r\u0100hr\u2a33\u2a36k;\u6924\u0100;o\u13f2\u13f0ot;\uc000\u2250\u0338ui\xf6\u0b63\u0100ei\u2a4a\u2a4ear;\u6928\xed\u0b98ist\u0100;s\u0ba0\u0b9fr;\uc000\ud835\udd2b\u0200Eest\u0bc5\u2a66\u2a79\u2a7c\u0180;qs\u0bbc\u2a6d\u0be1\u0180;qs\u0bbc\u0bc5\u2a74lan\xf4\u0be2i\xed\u0bea\u0100;r\u0bb6\u2a81\xbb\u0bb7\u0180Aap\u2a8a\u2a8d\u2a91r\xf2\u2971rr;\u61aear;\u6af2\u0180;sv\u0f8d\u2a9c\u0f8c\u0100;d\u2aa1\u2aa2\u62fc;\u62facy;\u445a\u0380AEadest\u2ab7\u2aba\u2abe\u2ac2\u2ac5\u2af6\u2af9r\xf2\u2966;\uc000\u2266\u0338rr;\u619ar;\u6025\u0200;fqs\u0c3b\u2ace\u2ae3\u2aeft\u0100ar\u2ad4\u2ad9rro\xf7\u2ac1ightarro\xf7\u2a90\u0180;qs\u0c3b\u2aba\u2aealan\xf4\u0c55\u0100;s\u0c55\u2af4\xbb\u0c36i\xed\u0c5d\u0100;r\u0c35\u2afei\u0100;e\u0c1a\u0c25i\xe4\u0d90\u0100pt\u2b0c\u2b11f;\uc000\ud835\udd5f\u8180\xac;in\u2b19\u2b1a\u2b36\u40acn\u0200;Edv\u0b89\u2b24\u2b28\u2b2e;\uc000\u22f9\u0338ot;\uc000\u22f5\u0338\u01e1\u0b89\u2b33\u2b35;\u62f7;\u62f6i\u0100;v\u0cb8\u2b3c\u01e1\u0cb8\u2b41\u2b43;\u62fe;\u62fd\u0180aor\u2b4b\u2b63\u2b69r\u0200;ast\u0b7b\u2b55\u2b5a\u2b5flle\xec\u0b7bl;\uc000\u2afd\u20e5;\uc000\u2202\u0338lint;\u6a14\u0180;ce\u0c92\u2b70\u2b73u\xe5\u0ca5\u0100;c\u0c98\u2b78\u0100;e\u0c92\u2b7d\xf1\u0c98\u0200Aait\u2b88\u2b8b\u2b9d\u2ba7r\xf2\u2988rr\u0180;cw\u2b94\u2b95\u2b99\u619b;\uc000\u2933\u0338;\uc000\u219d\u0338ghtarrow\xbb\u2b95ri\u0100;e\u0ccb\u0cd6\u0380chimpqu\u2bbd\u2bcd\u2bd9\u2b04\u0b78\u2be4\u2bef\u0200;cer\u0d32\u2bc6\u0d37\u2bc9u\xe5\u0d45;\uc000\ud835\udcc3ort\u026d\u2b05\0\0\u2bd6ar\xe1\u2b56m\u0100;e\u0d6e\u2bdf\u0100;q\u0d74\u0d73su\u0100bp\u2beb\u2bed\xe5\u0cf8\xe5\u0d0b\u0180bcp\u2bf6\u2c11\u2c19\u0200;Ees\u2bff\u2c00\u0d22\u2c04\u6284;\uc000\u2ac5\u0338et\u0100;e\u0d1b\u2c0bq\u0100;q\u0d23\u2c00c\u0100;e\u0d32\u2c17\xf1\u0d38\u0200;Ees\u2c22\u2c23\u0d5f\u2c27\u6285;\uc000\u2ac6\u0338et\u0100;e\u0d58\u2c2eq\u0100;q\u0d60\u2c23\u0200gilr\u2c3d\u2c3f\u2c45\u2c47\xec\u0bd7lde\u803b\xf1\u40f1\xe7\u0c43iangle\u0100lr\u2c52\u2c5ceft\u0100;e\u0c1a\u2c5a\xf1\u0c26ight\u0100;e\u0ccb\u2c65\xf1\u0cd7\u0100;m\u2c6c\u2c6d\u43bd\u0180;es\u2c74\u2c75\u2c79\u4023ro;\u6116p;\u6007\u0480DHadgilrs\u2c8f\u2c94\u2c99\u2c9e\u2ca3\u2cb0\u2cb6\u2cd3\u2ce3ash;\u62adarr;\u6904p;\uc000\u224d\u20d2ash;\u62ac\u0100et\u2ca8\u2cac;\uc000\u2265\u20d2;\uc000>\u20d2nfin;\u69de\u0180Aet\u2cbd\u2cc1\u2cc5rr;\u6902;\uc000\u2264\u20d2\u0100;r\u2cca\u2ccd\uc000<\u20d2ie;\uc000\u22b4\u20d2\u0100At\u2cd8\u2cdcrr;\u6903rie;\uc000\u22b5\u20d2im;\uc000\u223c\u20d2\u0180Aan\u2cf0\u2cf4\u2d02rr;\u61d6r\u0100hr\u2cfa\u2cfdk;\u6923\u0100;o\u13e7\u13e5ear;\u6927\u1253\u1a95\0\0\0\0\0\0\0\0\0\0\0\0\0\u2d2d\0\u2d38\u2d48\u2d60\u2d65\u2d72\u2d84\u1b07\0\0\u2d8d\u2dab\0\u2dc8\u2dce\0\u2ddc\u2e19\u2e2b\u2e3e\u2e43\u0100cs\u2d31\u1a97ute\u803b\xf3\u40f3\u0100iy\u2d3c\u2d45r\u0100;c\u1a9e\u2d42\u803b\xf4\u40f4;\u443e\u0280abios\u1aa0\u2d52\u2d57\u01c8\u2d5alac;\u4151v;\u6a38old;\u69bclig;\u4153\u0100cr\u2d69\u2d6dir;\u69bf;\uc000\ud835\udd2c\u036f\u2d79\0\0\u2d7c\0\u2d82n;\u42dbave\u803b\xf2\u40f2;\u69c1\u0100bm\u2d88\u0df4ar;\u69b5\u0200acit\u2d95\u2d98\u2da5\u2da8r\xf2\u1a80\u0100ir\u2d9d\u2da0r;\u69beoss;\u69bbn\xe5\u0e52;\u69c0\u0180aei\u2db1\u2db5\u2db9cr;\u414dga;\u43c9\u0180cdn\u2dc0\u2dc5\u01cdron;\u43bf;\u69b6pf;\uc000\ud835\udd60\u0180ael\u2dd4\u2dd7\u01d2r;\u69b7rp;\u69b9\u0380;adiosv\u2dea\u2deb\u2dee\u2e08\u2e0d\u2e10\u2e16\u6228r\xf2\u1a86\u0200;efm\u2df7\u2df8\u2e02\u2e05\u6a5dr\u0100;o\u2dfe\u2dff\u6134f\xbb\u2dff\u803b\xaa\u40aa\u803b\xba\u40bagof;\u62b6r;\u6a56lope;\u6a57;\u6a5b\u0180clo\u2e1f\u2e21\u2e27\xf2\u2e01ash\u803b\xf8\u40f8l;\u6298i\u016c\u2e2f\u2e34de\u803b\xf5\u40f5es\u0100;a\u01db\u2e3as;\u6a36ml\u803b\xf6\u40f6bar;\u633d\u0ae1\u2e5e\0\u2e7d\0\u2e80\u2e9d\0\u2ea2\u2eb9\0\0\u2ecb\u0e9c\0\u2f13\0\0\u2f2b\u2fbc\0\u2fc8r\u0200;ast\u0403\u2e67\u2e72\u0e85\u8100\xb6;l\u2e6d\u2e6e\u40b6le\xec\u0403\u0269\u2e78\0\0\u2e7bm;\u6af3;\u6afdy;\u443fr\u0280cimpt\u2e8b\u2e8f\u2e93\u1865\u2e97nt;\u4025od;\u402eil;\u6030enk;\u6031r;\uc000\ud835\udd2d\u0180imo\u2ea8\u2eb0\u2eb4\u0100;v\u2ead\u2eae\u43c6;\u43d5ma\xf4\u0a76ne;\u660e\u0180;tv\u2ebf\u2ec0\u2ec8\u43c0chfork\xbb\u1ffd;\u43d6\u0100au\u2ecf\u2edfn\u0100ck\u2ed5\u2eddk\u0100;h\u21f4\u2edb;\u610e\xf6\u21f4s\u0480;abcdemst\u2ef3\u2ef4\u1908\u2ef9\u2efd\u2f04\u2f06\u2f0a\u2f0e\u402bcir;\u6a23ir;\u6a22\u0100ou\u1d40\u2f02;\u6a25;\u6a72n\u80bb\xb1\u0e9dim;\u6a26wo;\u6a27\u0180ipu\u2f19\u2f20\u2f25ntint;\u6a15f;\uc000\ud835\udd61nd\u803b\xa3\u40a3\u0500;Eaceinosu\u0ec8\u2f3f\u2f41\u2f44\u2f47\u2f81\u2f89\u2f92\u2f7e\u2fb6;\u6ab3p;\u6ab7u\xe5\u0ed9\u0100;c\u0ece\u2f4c\u0300;acens\u0ec8\u2f59\u2f5f\u2f66\u2f68\u2f7eppro\xf8\u2f43urlye\xf1\u0ed9\xf1\u0ece\u0180aes\u2f6f\u2f76\u2f7approx;\u6ab9qq;\u6ab5im;\u62e8i\xed\u0edfme\u0100;s\u2f88\u0eae\u6032\u0180Eas\u2f78\u2f90\u2f7a\xf0\u2f75\u0180dfp\u0eec\u2f99\u2faf\u0180als\u2fa0\u2fa5\u2faalar;\u632eine;\u6312urf;\u6313\u0100;t\u0efb\u2fb4\xef\u0efbrel;\u62b0\u0100ci\u2fc0\u2fc5r;\uc000\ud835\udcc5;\u43c8ncsp;\u6008\u0300fiopsu\u2fda\u22e2\u2fdf\u2fe5\u2feb\u2ff1r;\uc000\ud835\udd2epf;\uc000\ud835\udd62rime;\u6057cr;\uc000\ud835\udcc6\u0180aeo\u2ff8\u3009\u3013t\u0100ei\u2ffe\u3005rnion\xf3\u06b0nt;\u6a16st\u0100;e\u3010\u3011\u403f\xf1\u1f19\xf4\u0f14\u0a80ABHabcdefhilmnoprstux\u3040\u3051\u3055\u3059\u30e0\u310e\u312b\u3147\u3162\u3172\u318e\u3206\u3215\u3224\u3229\u3258\u326e\u3272\u3290\u32b0\u32b7\u0180art\u3047\u304a\u304cr\xf2\u10b3\xf2\u03ddail;\u691car\xf2\u1c65ar;\u6964\u0380cdenqrt\u3068\u3075\u3078\u307f\u308f\u3094\u30cc\u0100eu\u306d\u3071;\uc000\u223d\u0331te;\u4155i\xe3\u116emptyv;\u69b3g\u0200;del\u0fd1\u3089\u308b\u308d;\u6992;\u69a5\xe5\u0fd1uo\u803b\xbb\u40bbr\u0580;abcfhlpstw\u0fdc\u30ac\u30af\u30b7\u30b9\u30bc\u30be\u30c0\u30c3\u30c7\u30cap;\u6975\u0100;f\u0fe0\u30b4s;\u6920;\u6933s;\u691e\xeb\u225d\xf0\u272el;\u6945im;\u6974l;\u61a3;\u619d\u0100ai\u30d1\u30d5il;\u691ao\u0100;n\u30db\u30dc\u6236al\xf3\u0f1e\u0180abr\u30e7\u30ea\u30eer\xf2\u17e5rk;\u6773\u0100ak\u30f3\u30fdc\u0100ek\u30f9\u30fb;\u407d;\u405d\u0100es\u3102\u3104;\u698cl\u0100du\u310a\u310c;\u698e;\u6990\u0200aeuy\u3117\u311c\u3127\u3129ron;\u4159\u0100di\u3121\u3125il;\u4157\xec\u0ff2\xe2\u30fa;\u4440\u0200clqs\u3134\u3137\u313d\u3144a;\u6937dhar;\u6969uo\u0100;r\u020e\u020dh;\u61b3\u0180acg\u314e\u315f\u0f44l\u0200;ips\u0f78\u3158\u315b\u109cn\xe5\u10bbar\xf4\u0fa9t;\u65ad\u0180ilr\u3169\u1023\u316esht;\u697d;\uc000\ud835\udd2f\u0100ao\u3177\u3186r\u0100du\u317d\u317f\xbb\u047b\u0100;l\u1091\u3184;\u696c\u0100;v\u318b\u318c\u43c1;\u43f1\u0180gns\u3195\u31f9\u31fcht\u0300ahlrst\u31a4\u31b0\u31c2\u31d8\u31e4\u31eerrow\u0100;t\u0fdc\u31ada\xe9\u30c8arpoon\u0100du\u31bb\u31bfow\xee\u317ep\xbb\u1092eft\u0100ah\u31ca\u31d0rrow\xf3\u0feaarpoon\xf3\u0551ightarrows;\u61c9quigarro\xf7\u30cbhreetimes;\u62ccg;\u42daingdotse\xf1\u1f32\u0180ahm\u320d\u3210\u3213r\xf2\u0feaa\xf2\u0551;\u600foust\u0100;a\u321e\u321f\u63b1che\xbb\u321fmid;\u6aee\u0200abpt\u3232\u323d\u3240\u3252\u0100nr\u3237\u323ag;\u67edr;\u61fer\xeb\u1003\u0180afl\u3247\u324a\u324er;\u6986;\uc000\ud835\udd63us;\u6a2eimes;\u6a35\u0100ap\u325d\u3267r\u0100;g\u3263\u3264\u4029t;\u6994olint;\u6a12ar\xf2\u31e3\u0200achq\u327b\u3280\u10bc\u3285quo;\u603ar;\uc000\ud835\udcc7\u0100bu\u30fb\u328ao\u0100;r\u0214\u0213\u0180hir\u3297\u329b\u32a0re\xe5\u31f8mes;\u62cai\u0200;efl\u32aa\u1059\u1821\u32ab\u65b9tri;\u69celuhar;\u6968;\u611e\u0d61\u32d5\u32db\u32df\u332c\u3338\u3371\0\u337a\u33a4\0\0\u33ec\u33f0\0\u3428\u3448\u345a\u34ad\u34b1\u34ca\u34f1\0\u3616\0\0\u3633cute;\u415bqu\xef\u27ba\u0500;Eaceinpsy\u11ed\u32f3\u32f5\u32ff\u3302\u330b\u330f\u331f\u3326\u3329;\u6ab4\u01f0\u32fa\0\u32fc;\u6ab8on;\u4161u\xe5\u11fe\u0100;d\u11f3\u3307il;\u415frc;\u415d\u0180Eas\u3316\u3318\u331b;\u6ab6p;\u6abaim;\u62e9olint;\u6a13i\xed\u1204;\u4441ot\u0180;be\u3334\u1d47\u3335\u62c5;\u6a66\u0380Aacmstx\u3346\u334a\u3357\u335b\u335e\u3363\u336drr;\u61d8r\u0100hr\u3350\u3352\xeb\u2228\u0100;o\u0a36\u0a34t\u803b\xa7\u40a7i;\u403bwar;\u6929m\u0100in\u3369\xf0nu\xf3\xf1t;\u6736r\u0100;o\u3376\u2055\uc000\ud835\udd30\u0200acoy\u3382\u3386\u3391\u33a0rp;\u666f\u0100hy\u338b\u338fcy;\u4449;\u4448rt\u026d\u3399\0\0\u339ci\xe4\u1464ara\xec\u2e6f\u803b\xad\u40ad\u0100gm\u33a8\u33b4ma\u0180;fv\u33b1\u33b2\u33b2\u43c3;\u43c2\u0400;deglnpr\u12ab\u33c5\u33c9\u33ce\u33d6\u33de\u33e1\u33e6ot;\u6a6a\u0100;q\u12b1\u12b0\u0100;E\u33d3\u33d4\u6a9e;\u6aa0\u0100;E\u33db\u33dc\u6a9d;\u6a9fe;\u6246lus;\u6a24arr;\u6972ar\xf2\u113d\u0200aeit\u33f8\u3408\u340f\u3417\u0100ls\u33fd\u3404lsetm\xe9\u336ahp;\u6a33parsl;\u69e4\u0100dl\u1463\u3414e;\u6323\u0100;e\u341c\u341d\u6aaa\u0100;s\u3422\u3423\u6aac;\uc000\u2aac\ufe00\u0180flp\u342e\u3433\u3442tcy;\u444c\u0100;b\u3438\u3439\u402f\u0100;a\u343e\u343f\u69c4r;\u633ff;\uc000\ud835\udd64a\u0100dr\u344d\u0402es\u0100;u\u3454\u3455\u6660it\xbb\u3455\u0180csu\u3460\u3479\u349f\u0100au\u3465\u346fp\u0100;s\u1188\u346b;\uc000\u2293\ufe00p\u0100;s\u11b4\u3475;\uc000\u2294\ufe00u\u0100bp\u347f\u348f\u0180;es\u1197\u119c\u3486et\u0100;e\u1197\u348d\xf1\u119d\u0180;es\u11a8\u11ad\u3496et\u0100;e\u11a8\u349d\xf1\u11ae\u0180;af\u117b\u34a6\u05b0r\u0165\u34ab\u05b1\xbb\u117car\xf2\u1148\u0200cemt\u34b9\u34be\u34c2\u34c5r;\uc000\ud835\udcc8tm\xee\xf1i\xec\u3415ar\xe6\u11be\u0100ar\u34ce\u34d5r\u0100;f\u34d4\u17bf\u6606\u0100an\u34da\u34edight\u0100ep\u34e3\u34eapsilo\xee\u1ee0h\xe9\u2eafs\xbb\u2852\u0280bcmnp\u34fb\u355e\u1209\u358b\u358e\u0480;Edemnprs\u350e\u350f\u3511\u3515\u351e\u3523\u352c\u3531\u3536\u6282;\u6ac5ot;\u6abd\u0100;d\u11da\u351aot;\u6ac3ult;\u6ac1\u0100Ee\u3528\u352a;\u6acb;\u628alus;\u6abfarr;\u6979\u0180eiu\u353d\u3552\u3555t\u0180;en\u350e\u3545\u354bq\u0100;q\u11da\u350feq\u0100;q\u352b\u3528m;\u6ac7\u0100bp\u355a\u355c;\u6ad5;\u6ad3c\u0300;acens\u11ed\u356c\u3572\u3579\u357b\u3326ppro\xf8\u32faurlye\xf1\u11fe\xf1\u11f3\u0180aes\u3582\u3588\u331bppro\xf8\u331aq\xf1\u3317g;\u666a\u0680123;Edehlmnps\u35a9\u35ac\u35af\u121c\u35b2\u35b4\u35c0\u35c9\u35d5\u35da\u35df\u35e8\u35ed\u803b\xb9\u40b9\u803b\xb2\u40b2\u803b\xb3\u40b3;\u6ac6\u0100os\u35b9\u35bct;\u6abeub;\u6ad8\u0100;d\u1222\u35c5ot;\u6ac4s\u0100ou\u35cf\u35d2l;\u67c9b;\u6ad7arr;\u697bult;\u6ac2\u0100Ee\u35e4\u35e6;\u6acc;\u628blus;\u6ac0\u0180eiu\u35f4\u3609\u360ct\u0180;en\u121c\u35fc\u3602q\u0100;q\u1222\u35b2eq\u0100;q\u35e7\u35e4m;\u6ac8\u0100bp\u3611\u3613;\u6ad4;\u6ad6\u0180Aan\u361c\u3620\u362drr;\u61d9r\u0100hr\u3626\u3628\xeb\u222e\u0100;o\u0a2b\u0a29war;\u692alig\u803b\xdf\u40df\u0be1\u3651\u365d\u3660\u12ce\u3673\u3679\0\u367e\u36c2\0\0\0\0\0\u36db\u3703\0\u3709\u376c\0\0\0\u3787\u0272\u3656\0\0\u365bget;\u6316;\u43c4r\xeb\u0e5f\u0180aey\u3666\u366b\u3670ron;\u4165dil;\u4163;\u4442lrec;\u6315r;\uc000\ud835\udd31\u0200eiko\u3686\u369d\u36b5\u36bc\u01f2\u368b\0\u3691e\u01004f\u1284\u1281a\u0180;sv\u3698\u3699\u369b\u43b8ym;\u43d1\u0100cn\u36a2\u36b2k\u0100as\u36a8\u36aeppro\xf8\u12c1im\xbb\u12acs\xf0\u129e\u0100as\u36ba\u36ae\xf0\u12c1rn\u803b\xfe\u40fe\u01ec\u031f\u36c6\u22e7es\u8180\xd7;bd\u36cf\u36d0\u36d8\u40d7\u0100;a\u190f\u36d5r;\u6a31;\u6a30\u0180eps\u36e1\u36e3\u3700\xe1\u2a4d\u0200;bcf\u0486\u36ec\u36f0\u36f4ot;\u6336ir;\u6af1\u0100;o\u36f9\u36fc\uc000\ud835\udd65rk;\u6ada\xe1\u3362rime;\u6034\u0180aip\u370f\u3712\u3764d\xe5\u1248\u0380adempst\u3721\u374d\u3740\u3751\u3757\u375c\u375fngle\u0280;dlqr\u3730\u3731\u3736\u3740\u3742\u65b5own\xbb\u1dbbeft\u0100;e\u2800\u373e\xf1\u092e;\u625cight\u0100;e\u32aa\u374b\xf1\u105aot;\u65ecinus;\u6a3alus;\u6a39b;\u69cdime;\u6a3bezium;\u63e2\u0180cht\u3772\u377d\u3781\u0100ry\u3777\u377b;\uc000\ud835\udcc9;\u4446cy;\u445brok;\u4167\u0100io\u378b\u378ex\xf4\u1777head\u0100lr\u3797\u37a0eftarro\xf7\u084fightarrow\xbb\u0f5d\u0900AHabcdfghlmoprstuw\u37d0\u37d3\u37d7\u37e4\u37f0\u37fc\u380e\u381c\u3823\u3834\u3851\u385d\u386b\u38a9\u38cc\u38d2\u38ea\u38f6r\xf2\u03edar;\u6963\u0100cr\u37dc\u37e2ute\u803b\xfa\u40fa\xf2\u1150r\u01e3\u37ea\0\u37edy;\u445eve;\u416d\u0100iy\u37f5\u37farc\u803b\xfb\u40fb;\u4443\u0180abh\u3803\u3806\u380br\xf2\u13adlac;\u4171a\xf2\u13c3\u0100ir\u3813\u3818sht;\u697e;\uc000\ud835\udd32rave\u803b\xf9\u40f9\u0161\u3827\u3831r\u0100lr\u382c\u382e\xbb\u0957\xbb\u1083lk;\u6580\u0100ct\u3839\u384d\u026f\u383f\0\0\u384arn\u0100;e\u3845\u3846\u631cr\xbb\u3846op;\u630fri;\u65f8\u0100al\u3856\u385acr;\u416b\u80bb\xa8\u0349\u0100gp\u3862\u3866on;\u4173f;\uc000\ud835\udd66\u0300adhlsu\u114b\u3878\u387d\u1372\u3891\u38a0own\xe1\u13b3arpoon\u0100lr\u3888\u388cef\xf4\u382digh\xf4\u382fi\u0180;hl\u3899\u389a\u389c\u43c5\xbb\u13faon\xbb\u389aparrows;\u61c8\u0180cit\u38b0\u38c4\u38c8\u026f\u38b6\0\0\u38c1rn\u0100;e\u38bc\u38bd\u631dr\xbb\u38bdop;\u630eng;\u416fri;\u65f9cr;\uc000\ud835\udcca\u0180dir\u38d9\u38dd\u38e2ot;\u62f0lde;\u4169i\u0100;f\u3730\u38e8\xbb\u1813\u0100am\u38ef\u38f2r\xf2\u38a8l\u803b\xfc\u40fcangle;\u69a7\u0780ABDacdeflnoprsz\u391c\u391f\u3929\u392d\u39b5\u39b8\u39bd\u39df\u39e4\u39e8\u39f3\u39f9\u39fd\u3a01\u3a20r\xf2\u03f7ar\u0100;v\u3926\u3927\u6ae8;\u6ae9as\xe8\u03e1\u0100nr\u3932\u3937grt;\u699c\u0380eknprst\u34e3\u3946\u394b\u3952\u395d\u3964\u3996app\xe1\u2415othin\xe7\u1e96\u0180hir\u34eb\u2ec8\u3959op\xf4\u2fb5\u0100;h\u13b7\u3962\xef\u318d\u0100iu\u3969\u396dgm\xe1\u33b3\u0100bp\u3972\u3984setneq\u0100;q\u397d\u3980\uc000\u228a\ufe00;\uc000\u2acb\ufe00setneq\u0100;q\u398f\u3992\uc000\u228b\ufe00;\uc000\u2acc\ufe00\u0100hr\u399b\u399fet\xe1\u369ciangle\u0100lr\u39aa\u39afeft\xbb\u0925ight\xbb\u1051y;\u4432ash\xbb\u1036\u0180elr\u39c4\u39d2\u39d7\u0180;be\u2dea\u39cb\u39cfar;\u62bbq;\u625alip;\u62ee\u0100bt\u39dc\u1468a\xf2\u1469r;\uc000\ud835\udd33tr\xe9\u39aesu\u0100bp\u39ef\u39f1\xbb\u0d1c\xbb\u0d59pf;\uc000\ud835\udd67ro\xf0\u0efbtr\xe9\u39b4\u0100cu\u3a06\u3a0br;\uc000\ud835\udccb\u0100bp\u3a10\u3a18n\u0100Ee\u3980\u3a16\xbb\u397en\u0100Ee\u3992\u3a1e\xbb\u3990igzag;\u699a\u0380cefoprs\u3a36\u3a3b\u3a56\u3a5b\u3a54\u3a61\u3a6airc;\u4175\u0100di\u3a40\u3a51\u0100bg\u3a45\u3a49ar;\u6a5fe\u0100;q\u15fa\u3a4f;\u6259erp;\u6118r;\uc000\ud835\udd34pf;\uc000\ud835\udd68\u0100;e\u1479\u3a66at\xe8\u1479cr;\uc000\ud835\udccc\u0ae3\u178e\u3a87\0\u3a8b\0\u3a90\u3a9b\0\0\u3a9d\u3aa8\u3aab\u3aaf\0\0\u3ac3\u3ace\0\u3ad8\u17dc\u17dftr\xe9\u17d1r;\uc000\ud835\udd35\u0100Aa\u3a94\u3a97r\xf2\u03c3r\xf2\u09f6;\u43be\u0100Aa\u3aa1\u3aa4r\xf2\u03b8r\xf2\u09eba\xf0\u2713is;\u62fb\u0180dpt\u17a4\u3ab5\u3abe\u0100fl\u3aba\u17a9;\uc000\ud835\udd69im\xe5\u17b2\u0100Aa\u3ac7\u3acar\xf2\u03cer\xf2\u0a01\u0100cq\u3ad2\u17b8r;\uc000\ud835\udccd\u0100pt\u17d6\u3adcr\xe9\u17d4\u0400acefiosu\u3af0\u3afd\u3b08\u3b0c\u3b11\u3b15\u3b1b\u3b21c\u0100uy\u3af6\u3afbte\u803b\xfd\u40fd;\u444f\u0100iy\u3b02\u3b06rc;\u4177;\u444bn\u803b\xa5\u40a5r;\uc000\ud835\udd36cy;\u4457pf;\uc000\ud835\udd6acr;\uc000\ud835\udcce\u0100cm\u3b26\u3b29y;\u444el\u803b\xff\u40ff\u0500acdefhiosw\u3b42\u3b48\u3b54\u3b58\u3b64\u3b69\u3b6d\u3b74\u3b7a\u3b80cute;\u417a\u0100ay\u3b4d\u3b52ron;\u417e;\u4437ot;\u417c\u0100et\u3b5d\u3b61tr\xe6\u155fa;\u43b6r;\uc000\ud835\udd37cy;\u4436grarr;\u61ddpf;\uc000\ud835\udd6bcr;\uc000\ud835\udccf\u0100jn\u3b85\u3b87;\u600dj;\u600c"
    .split("")
    .map(function (c) { return c.charCodeAt(0); }));

var decodeDataXml = {};

// Generated using scripts/write-decode-map.ts
Object.defineProperty(decodeDataXml, "__esModule", { value: true });
decodeDataXml.default = new Uint16Array(
// prettier-ignore
"\u0200aglq\t\x15\x18\x1b\u026d\x0f\0\0\x12p;\u4026os;\u4027t;\u403et;\u403cuot;\u4022"
    .split("")
    .map(function (c) { return c.charCodeAt(0); }));

var decode_codepoint = {};

(function (exports) {
// Adapted from https://github.com/mathiasbynens/he/blob/36afe179392226cf1b6ccdb16ebbb7a5a844d93a/src/he.js#L106-L134
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceCodePoint = exports.fromCodePoint = void 0;
var decodeMap = new Map([
    [0, 65533],
    // C1 Unicode control character reference replacements
    [128, 8364],
    [130, 8218],
    [131, 402],
    [132, 8222],
    [133, 8230],
    [134, 8224],
    [135, 8225],
    [136, 710],
    [137, 8240],
    [138, 352],
    [139, 8249],
    [140, 338],
    [142, 381],
    [145, 8216],
    [146, 8217],
    [147, 8220],
    [148, 8221],
    [149, 8226],
    [150, 8211],
    [151, 8212],
    [152, 732],
    [153, 8482],
    [154, 353],
    [155, 8250],
    [156, 339],
    [158, 382],
    [159, 376],
]);
/**
 * Polyfill for `String.fromCodePoint`. It is used to create a string from a Unicode code point.
 */
exports.fromCodePoint = 
// eslint-disable-next-line @typescript-eslint/no-unnecessary-condition, node/no-unsupported-features/es-builtins
(_a = String.fromCodePoint) !== null && _a !== void 0 ? _a : function (codePoint) {
    var output = "";
    if (codePoint > 0xffff) {
        codePoint -= 0x10000;
        output += String.fromCharCode(((codePoint >>> 10) & 0x3ff) | 0xd800);
        codePoint = 0xdc00 | (codePoint & 0x3ff);
    }
    output += String.fromCharCode(codePoint);
    return output;
};
/**
 * Replace the given code point with a replacement character if it is a
 * surrogate or is outside the valid range. Otherwise return the code
 * point unchanged.
 */
function replaceCodePoint(codePoint) {
    var _a;
    if ((codePoint >= 0xd800 && codePoint <= 0xdfff) || codePoint > 0x10ffff) {
        return 0xfffd;
    }
    return (_a = decodeMap.get(codePoint)) !== null && _a !== void 0 ? _a : codePoint;
}
exports.replaceCodePoint = replaceCodePoint;
/**
 * Replace the code point if relevant, then convert it to a string.
 *
 * @deprecated Use `fromCodePoint(replaceCodePoint(codePoint))` instead.
 * @param codePoint The code point to decode.
 * @returns The decoded code point.
 */
function decodeCodePoint(codePoint) {
    return (0, exports.fromCodePoint)(replaceCodePoint(codePoint));
}
exports.default = decodeCodePoint;

}(decode_codepoint));

(function (exports) {
var __createBinding = (commonjsGlobal && commonjsGlobal.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (commonjsGlobal && commonjsGlobal.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (commonjsGlobal && commonjsGlobal.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (commonjsGlobal && commonjsGlobal.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeXML = exports.decodeHTMLStrict = exports.decodeHTMLAttribute = exports.decodeHTML = exports.determineBranch = exports.EntityDecoder = exports.DecodingMode = exports.BinTrieFlags = exports.fromCodePoint = exports.replaceCodePoint = exports.decodeCodePoint = exports.xmlDecodeTree = exports.htmlDecodeTree = void 0;
var decode_data_html_js_1 = __importDefault(decodeDataHtml);
exports.htmlDecodeTree = decode_data_html_js_1.default;
var decode_data_xml_js_1 = __importDefault(decodeDataXml);
exports.xmlDecodeTree = decode_data_xml_js_1.default;
var decode_codepoint_js_1 = __importStar(decode_codepoint);
exports.decodeCodePoint = decode_codepoint_js_1.default;
var decode_codepoint_js_2 = decode_codepoint;
Object.defineProperty(exports, "replaceCodePoint", { enumerable: true, get: function () { return decode_codepoint_js_2.replaceCodePoint; } });
Object.defineProperty(exports, "fromCodePoint", { enumerable: true, get: function () { return decode_codepoint_js_2.fromCodePoint; } });
var CharCodes;
(function (CharCodes) {
    CharCodes[CharCodes["NUM"] = 35] = "NUM";
    CharCodes[CharCodes["SEMI"] = 59] = "SEMI";
    CharCodes[CharCodes["EQUALS"] = 61] = "EQUALS";
    CharCodes[CharCodes["ZERO"] = 48] = "ZERO";
    CharCodes[CharCodes["NINE"] = 57] = "NINE";
    CharCodes[CharCodes["LOWER_A"] = 97] = "LOWER_A";
    CharCodes[CharCodes["LOWER_F"] = 102] = "LOWER_F";
    CharCodes[CharCodes["LOWER_X"] = 120] = "LOWER_X";
    CharCodes[CharCodes["LOWER_Z"] = 122] = "LOWER_Z";
    CharCodes[CharCodes["UPPER_A"] = 65] = "UPPER_A";
    CharCodes[CharCodes["UPPER_F"] = 70] = "UPPER_F";
    CharCodes[CharCodes["UPPER_Z"] = 90] = "UPPER_Z";
})(CharCodes || (CharCodes = {}));
/** Bit that needs to be set to convert an upper case ASCII character to lower case */
var TO_LOWER_BIT = 32;
var BinTrieFlags;
(function (BinTrieFlags) {
    BinTrieFlags[BinTrieFlags["VALUE_LENGTH"] = 49152] = "VALUE_LENGTH";
    BinTrieFlags[BinTrieFlags["BRANCH_LENGTH"] = 16256] = "BRANCH_LENGTH";
    BinTrieFlags[BinTrieFlags["JUMP_TABLE"] = 127] = "JUMP_TABLE";
})(BinTrieFlags = exports.BinTrieFlags || (exports.BinTrieFlags = {}));
function isNumber(code) {
    return code >= CharCodes.ZERO && code <= CharCodes.NINE;
}
function isHexadecimalCharacter(code) {
    return ((code >= CharCodes.UPPER_A && code <= CharCodes.UPPER_F) ||
        (code >= CharCodes.LOWER_A && code <= CharCodes.LOWER_F));
}
function isAsciiAlphaNumeric(code) {
    return ((code >= CharCodes.UPPER_A && code <= CharCodes.UPPER_Z) ||
        (code >= CharCodes.LOWER_A && code <= CharCodes.LOWER_Z) ||
        isNumber(code));
}
/**
 * Checks if the given character is a valid end character for an entity in an attribute.
 *
 * Attribute values that aren't terminated properly aren't parsed, and shouldn't lead to a parser error.
 * See the example in https://html.spec.whatwg.org/multipage/parsing.html#named-character-reference-state
 */
function isEntityInAttributeInvalidEnd(code) {
    return code === CharCodes.EQUALS || isAsciiAlphaNumeric(code);
}
var EntityDecoderState;
(function (EntityDecoderState) {
    EntityDecoderState[EntityDecoderState["EntityStart"] = 0] = "EntityStart";
    EntityDecoderState[EntityDecoderState["NumericStart"] = 1] = "NumericStart";
    EntityDecoderState[EntityDecoderState["NumericDecimal"] = 2] = "NumericDecimal";
    EntityDecoderState[EntityDecoderState["NumericHex"] = 3] = "NumericHex";
    EntityDecoderState[EntityDecoderState["NamedEntity"] = 4] = "NamedEntity";
})(EntityDecoderState || (EntityDecoderState = {}));
var DecodingMode;
(function (DecodingMode) {
    /** Entities in text nodes that can end with any character. */
    DecodingMode[DecodingMode["Legacy"] = 0] = "Legacy";
    /** Only allow entities terminated with a semicolon. */
    DecodingMode[DecodingMode["Strict"] = 1] = "Strict";
    /** Entities in attributes have limitations on ending characters. */
    DecodingMode[DecodingMode["Attribute"] = 2] = "Attribute";
})(DecodingMode = exports.DecodingMode || (exports.DecodingMode = {}));
/**
 * Token decoder with support of writing partial entities.
 */
var EntityDecoder = /** @class */ (function () {
    function EntityDecoder(
    /** The tree used to decode entities. */
    decodeTree, 
    /**
     * The function that is called when a codepoint is decoded.
     *
     * For multi-byte named entities, this will be called multiple times,
     * with the second codepoint, and the same `consumed` value.
     *
     * @param codepoint The decoded codepoint.
     * @param consumed The number of bytes consumed by the decoder.
     */
    emitCodePoint, 
    /** An object that is used to produce errors. */
    errors) {
        this.decodeTree = decodeTree;
        this.emitCodePoint = emitCodePoint;
        this.errors = errors;
        /** The current state of the decoder. */
        this.state = EntityDecoderState.EntityStart;
        /** Characters that were consumed while parsing an entity. */
        this.consumed = 1;
        /**
         * The result of the entity.
         *
         * Either the result index of a numeric entity, or the codepoint of a
         * numeric entity.
         */
        this.result = 0;
        /** The current index in the decode tree. */
        this.treeIndex = 0;
        /** The number of characters that were consumed in excess. */
        this.excess = 1;
        /** The mode in which the decoder is operating. */
        this.decodeMode = DecodingMode.Strict;
    }
    /** Resets the instance to make it reusable. */
    EntityDecoder.prototype.startEntity = function (decodeMode) {
        this.decodeMode = decodeMode;
        this.state = EntityDecoderState.EntityStart;
        this.result = 0;
        this.treeIndex = 0;
        this.excess = 1;
        this.consumed = 1;
    };
    /**
     * Write an entity to the decoder. This can be called multiple times with partial entities.
     * If the entity is incomplete, the decoder will return -1.
     *
     * Mirrors the implementation of `getDecoder`, but with the ability to stop decoding if the
     * entity is incomplete, and resume when the next string is written.
     *
     * @param string The string containing the entity (or a continuation of the entity).
     * @param offset The offset at which the entity begins. Should be 0 if this is not the first call.
     * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
     */
    EntityDecoder.prototype.write = function (str, offset) {
        switch (this.state) {
            case EntityDecoderState.EntityStart: {
                if (str.charCodeAt(offset) === CharCodes.NUM) {
                    this.state = EntityDecoderState.NumericStart;
                    this.consumed += 1;
                    return this.stateNumericStart(str, offset + 1);
                }
                this.state = EntityDecoderState.NamedEntity;
                return this.stateNamedEntity(str, offset);
            }
            case EntityDecoderState.NumericStart: {
                return this.stateNumericStart(str, offset);
            }
            case EntityDecoderState.NumericDecimal: {
                return this.stateNumericDecimal(str, offset);
            }
            case EntityDecoderState.NumericHex: {
                return this.stateNumericHex(str, offset);
            }
            case EntityDecoderState.NamedEntity: {
                return this.stateNamedEntity(str, offset);
            }
        }
    };
    /**
     * Switches between the numeric decimal and hexadecimal states.
     *
     * Equivalent to the `Numeric character reference state` in the HTML spec.
     *
     * @param str The string containing the entity (or a continuation of the entity).
     * @param offset The current offset.
     * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
     */
    EntityDecoder.prototype.stateNumericStart = function (str, offset) {
        if (offset >= str.length) {
            return -1;
        }
        if ((str.charCodeAt(offset) | TO_LOWER_BIT) === CharCodes.LOWER_X) {
            this.state = EntityDecoderState.NumericHex;
            this.consumed += 1;
            return this.stateNumericHex(str, offset + 1);
        }
        this.state = EntityDecoderState.NumericDecimal;
        return this.stateNumericDecimal(str, offset);
    };
    EntityDecoder.prototype.addToNumericResult = function (str, start, end, base) {
        if (start !== end) {
            var digitCount = end - start;
            this.result =
                this.result * Math.pow(base, digitCount) +
                    parseInt(str.substr(start, digitCount), base);
            this.consumed += digitCount;
        }
    };
    /**
     * Parses a hexadecimal numeric entity.
     *
     * Equivalent to the `Hexademical character reference state` in the HTML spec.
     *
     * @param str The string containing the entity (or a continuation of the entity).
     * @param offset The current offset.
     * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
     */
    EntityDecoder.prototype.stateNumericHex = function (str, offset) {
        var startIdx = offset;
        while (offset < str.length) {
            var char = str.charCodeAt(offset);
            if (isNumber(char) || isHexadecimalCharacter(char)) {
                offset += 1;
            }
            else {
                this.addToNumericResult(str, startIdx, offset, 16);
                return this.emitNumericEntity(char, 3);
            }
        }
        this.addToNumericResult(str, startIdx, offset, 16);
        return -1;
    };
    /**
     * Parses a decimal numeric entity.
     *
     * Equivalent to the `Decimal character reference state` in the HTML spec.
     *
     * @param str The string containing the entity (or a continuation of the entity).
     * @param offset The current offset.
     * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
     */
    EntityDecoder.prototype.stateNumericDecimal = function (str, offset) {
        var startIdx = offset;
        while (offset < str.length) {
            var char = str.charCodeAt(offset);
            if (isNumber(char)) {
                offset += 1;
            }
            else {
                this.addToNumericResult(str, startIdx, offset, 10);
                return this.emitNumericEntity(char, 2);
            }
        }
        this.addToNumericResult(str, startIdx, offset, 10);
        return -1;
    };
    /**
     * Validate and emit a numeric entity.
     *
     * Implements the logic from the `Hexademical character reference start
     * state` and `Numeric character reference end state` in the HTML spec.
     *
     * @param lastCp The last code point of the entity. Used to see if the
     *               entity was terminated with a semicolon.
     * @param expectedLength The minimum number of characters that should be
     *                       consumed. Used to validate that at least one digit
     *                       was consumed.
     * @returns The number of characters that were consumed.
     */
    EntityDecoder.prototype.emitNumericEntity = function (lastCp, expectedLength) {
        var _a;
        // Ensure we consumed at least one digit.
        if (this.consumed <= expectedLength) {
            (_a = this.errors) === null || _a === void 0 ? void 0 : _a.absenceOfDigitsInNumericCharacterReference(this.consumed);
            return 0;
        }
        // Figure out if this is a legit end of the entity
        if (lastCp === CharCodes.SEMI) {
            this.consumed += 1;
        }
        else if (this.decodeMode === DecodingMode.Strict) {
            return 0;
        }
        this.emitCodePoint((0, decode_codepoint_js_1.replaceCodePoint)(this.result), this.consumed);
        if (this.errors) {
            if (lastCp !== CharCodes.SEMI) {
                this.errors.missingSemicolonAfterCharacterReference();
            }
            this.errors.validateNumericCharacterReference(this.result);
        }
        return this.consumed;
    };
    /**
     * Parses a named entity.
     *
     * Equivalent to the `Named character reference state` in the HTML spec.
     *
     * @param str The string containing the entity (or a continuation of the entity).
     * @param offset The current offset.
     * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
     */
    EntityDecoder.prototype.stateNamedEntity = function (str, offset) {
        var decodeTree = this.decodeTree;
        var current = decodeTree[this.treeIndex];
        // The mask is the number of bytes of the value, including the current byte.
        var valueLength = (current & BinTrieFlags.VALUE_LENGTH) >> 14;
        for (; offset < str.length; offset++, this.excess++) {
            var char = str.charCodeAt(offset);
            this.treeIndex = determineBranch(decodeTree, current, this.treeIndex + Math.max(1, valueLength), char);
            if (this.treeIndex < 0) {
                return this.result === 0 ||
                    // If we are parsing an attribute
                    (this.decodeMode === DecodingMode.Attribute &&
                        // We shouldn't have consumed any characters after the entity,
                        (valueLength === 0 ||
                            // And there should be no invalid characters.
                            isEntityInAttributeInvalidEnd(char)))
                    ? 0
                    : this.emitNotTerminatedNamedEntity();
            }
            current = decodeTree[this.treeIndex];
            valueLength = (current & BinTrieFlags.VALUE_LENGTH) >> 14;
            // If the branch is a value, store it and continue
            if (valueLength !== 0) {
                // If the entity is terminated by a semicolon, we are done.
                if (char === CharCodes.SEMI) {
                    return this.emitNamedEntityData(this.treeIndex, valueLength, this.consumed + this.excess);
                }
                // If we encounter a non-terminated (legacy) entity while parsing strictly, then ignore it.
                if (this.decodeMode !== DecodingMode.Strict) {
                    this.result = this.treeIndex;
                    this.consumed += this.excess;
                    this.excess = 0;
                }
            }
        }
        return -1;
    };
    /**
     * Emit a named entity that was not terminated with a semicolon.
     *
     * @returns The number of characters consumed.
     */
    EntityDecoder.prototype.emitNotTerminatedNamedEntity = function () {
        var _a;
        var _b = this, result = _b.result, decodeTree = _b.decodeTree;
        var valueLength = (decodeTree[result] & BinTrieFlags.VALUE_LENGTH) >> 14;
        this.emitNamedEntityData(result, valueLength, this.consumed);
        (_a = this.errors) === null || _a === void 0 ? void 0 : _a.missingSemicolonAfterCharacterReference();
        return this.consumed;
    };
    /**
     * Emit a named entity.
     *
     * @param result The index of the entity in the decode tree.
     * @param valueLength The number of bytes in the entity.
     * @param consumed The number of characters consumed.
     *
     * @returns The number of characters consumed.
     */
    EntityDecoder.prototype.emitNamedEntityData = function (result, valueLength, consumed) {
        var decodeTree = this.decodeTree;
        this.emitCodePoint(valueLength === 1
            ? decodeTree[result] & ~BinTrieFlags.VALUE_LENGTH
            : decodeTree[result + 1], consumed);
        if (valueLength === 3) {
            // For multi-byte values, we need to emit the second byte.
            this.emitCodePoint(decodeTree[result + 2], consumed);
        }
        return consumed;
    };
    /**
     * Signal to the parser that the end of the input was reached.
     *
     * Remaining data will be emitted and relevant errors will be produced.
     *
     * @returns The number of characters consumed.
     */
    EntityDecoder.prototype.end = function () {
        var _a;
        switch (this.state) {
            case EntityDecoderState.NamedEntity: {
                // Emit a named entity if we have one.
                return this.result !== 0 &&
                    (this.decodeMode !== DecodingMode.Attribute ||
                        this.result === this.treeIndex)
                    ? this.emitNotTerminatedNamedEntity()
                    : 0;
            }
            // Otherwise, emit a numeric entity if we have one.
            case EntityDecoderState.NumericDecimal: {
                return this.emitNumericEntity(0, 2);
            }
            case EntityDecoderState.NumericHex: {
                return this.emitNumericEntity(0, 3);
            }
            case EntityDecoderState.NumericStart: {
                (_a = this.errors) === null || _a === void 0 ? void 0 : _a.absenceOfDigitsInNumericCharacterReference(this.consumed);
                return 0;
            }
            case EntityDecoderState.EntityStart: {
                // Return 0 if we have no entity.
                return 0;
            }
        }
    };
    return EntityDecoder;
}());
exports.EntityDecoder = EntityDecoder;
/**
 * Creates a function that decodes entities in a string.
 *
 * @param decodeTree The decode tree.
 * @returns A function that decodes entities in a string.
 */
function getDecoder(decodeTree) {
    var ret = "";
    var decoder = new EntityDecoder(decodeTree, function (str) { return (ret += (0, decode_codepoint_js_1.fromCodePoint)(str)); });
    return function decodeWithTrie(str, decodeMode) {
        var lastIndex = 0;
        var offset = 0;
        while ((offset = str.indexOf("&", offset)) >= 0) {
            ret += str.slice(lastIndex, offset);
            decoder.startEntity(decodeMode);
            var len = decoder.write(str, 
            // Skip the "&"
            offset + 1);
            if (len < 0) {
                lastIndex = offset + decoder.end();
                break;
            }
            lastIndex = offset + len;
            // If `len` is 0, skip the current `&` and continue.
            offset = len === 0 ? lastIndex + 1 : lastIndex;
        }
        var result = ret + str.slice(lastIndex);
        // Make sure we don't keep a reference to the final string.
        ret = "";
        return result;
    };
}
/**
 * Determines the branch of the current node that is taken given the current
 * character. This function is used to traverse the trie.
 *
 * @param decodeTree The trie.
 * @param current The current node.
 * @param nodeIdx The index right after the current node and its value.
 * @param char The current character.
 * @returns The index of the next node, or -1 if no branch is taken.
 */
function determineBranch(decodeTree, current, nodeIdx, char) {
    var branchCount = (current & BinTrieFlags.BRANCH_LENGTH) >> 7;
    var jumpOffset = current & BinTrieFlags.JUMP_TABLE;
    // Case 1: Single branch encoded in jump offset
    if (branchCount === 0) {
        return jumpOffset !== 0 && char === jumpOffset ? nodeIdx : -1;
    }
    // Case 2: Multiple branches encoded in jump table
    if (jumpOffset) {
        var value = char - jumpOffset;
        return value < 0 || value >= branchCount
            ? -1
            : decodeTree[nodeIdx + value] - 1;
    }
    // Case 3: Multiple branches encoded in dictionary
    // Binary search for the character.
    var lo = nodeIdx;
    var hi = lo + branchCount - 1;
    while (lo <= hi) {
        var mid = (lo + hi) >>> 1;
        var midVal = decodeTree[mid];
        if (midVal < char) {
            lo = mid + 1;
        }
        else if (midVal > char) {
            hi = mid - 1;
        }
        else {
            return decodeTree[mid + branchCount];
        }
    }
    return -1;
}
exports.determineBranch = determineBranch;
var htmlDecoder = getDecoder(decode_data_html_js_1.default);
var xmlDecoder = getDecoder(decode_data_xml_js_1.default);
/**
 * Decodes an HTML string.
 *
 * @param str The string to decode.
 * @param mode The decoding mode.
 * @returns The decoded string.
 */
function decodeHTML(str, mode) {
    if (mode === void 0) { mode = DecodingMode.Legacy; }
    return htmlDecoder(str, mode);
}
exports.decodeHTML = decodeHTML;
/**
 * Decodes an HTML string in an attribute.
 *
 * @param str The string to decode.
 * @returns The decoded string.
 */
function decodeHTMLAttribute(str) {
    return htmlDecoder(str, DecodingMode.Attribute);
}
exports.decodeHTMLAttribute = decodeHTMLAttribute;
/**
 * Decodes an HTML string, requiring all entities to be terminated by a semicolon.
 *
 * @param str The string to decode.
 * @returns The decoded string.
 */
function decodeHTMLStrict(str) {
    return htmlDecoder(str, DecodingMode.Strict);
}
exports.decodeHTMLStrict = decodeHTMLStrict;
/**
 * Decodes an XML string, requiring all entities to be terminated by a semicolon.
 *
 * @param str The string to decode.
 * @returns The decoded string.
 */
function decodeXML(str) {
    return xmlDecoder(str, DecodingMode.Strict);
}
exports.decodeXML = decodeXML;

}(decode));

var CharCodes;
(function (CharCodes) {
    CharCodes[CharCodes["Tab"] = 9] = "Tab";
    CharCodes[CharCodes["NewLine"] = 10] = "NewLine";
    CharCodes[CharCodes["FormFeed"] = 12] = "FormFeed";
    CharCodes[CharCodes["CarriageReturn"] = 13] = "CarriageReturn";
    CharCodes[CharCodes["Space"] = 32] = "Space";
    CharCodes[CharCodes["ExclamationMark"] = 33] = "ExclamationMark";
    CharCodes[CharCodes["Number"] = 35] = "Number";
    CharCodes[CharCodes["Amp"] = 38] = "Amp";
    CharCodes[CharCodes["SingleQuote"] = 39] = "SingleQuote";
    CharCodes[CharCodes["DoubleQuote"] = 34] = "DoubleQuote";
    CharCodes[CharCodes["Dash"] = 45] = "Dash";
    CharCodes[CharCodes["Slash"] = 47] = "Slash";
    CharCodes[CharCodes["Zero"] = 48] = "Zero";
    CharCodes[CharCodes["Nine"] = 57] = "Nine";
    CharCodes[CharCodes["Semi"] = 59] = "Semi";
    CharCodes[CharCodes["Lt"] = 60] = "Lt";
    CharCodes[CharCodes["Eq"] = 61] = "Eq";
    CharCodes[CharCodes["Gt"] = 62] = "Gt";
    CharCodes[CharCodes["Questionmark"] = 63] = "Questionmark";
    CharCodes[CharCodes["UpperA"] = 65] = "UpperA";
    CharCodes[CharCodes["LowerA"] = 97] = "LowerA";
    CharCodes[CharCodes["UpperF"] = 70] = "UpperF";
    CharCodes[CharCodes["LowerF"] = 102] = "LowerF";
    CharCodes[CharCodes["UpperZ"] = 90] = "UpperZ";
    CharCodes[CharCodes["LowerZ"] = 122] = "LowerZ";
    CharCodes[CharCodes["LowerX"] = 120] = "LowerX";
    CharCodes[CharCodes["OpeningSquareBracket"] = 91] = "OpeningSquareBracket";
})(CharCodes || (CharCodes = {}));
/** All the states the tokenizer can be in. */
var State;
(function (State) {
    State[State["Text"] = 1] = "Text";
    State[State["BeforeTagName"] = 2] = "BeforeTagName";
    State[State["InTagName"] = 3] = "InTagName";
    State[State["InSelfClosingTag"] = 4] = "InSelfClosingTag";
    State[State["BeforeClosingTagName"] = 5] = "BeforeClosingTagName";
    State[State["InClosingTagName"] = 6] = "InClosingTagName";
    State[State["AfterClosingTagName"] = 7] = "AfterClosingTagName";
    // Attributes
    State[State["BeforeAttributeName"] = 8] = "BeforeAttributeName";
    State[State["InAttributeName"] = 9] = "InAttributeName";
    State[State["AfterAttributeName"] = 10] = "AfterAttributeName";
    State[State["BeforeAttributeValue"] = 11] = "BeforeAttributeValue";
    State[State["InAttributeValueDq"] = 12] = "InAttributeValueDq";
    State[State["InAttributeValueSq"] = 13] = "InAttributeValueSq";
    State[State["InAttributeValueNq"] = 14] = "InAttributeValueNq";
    // Declarations
    State[State["BeforeDeclaration"] = 15] = "BeforeDeclaration";
    State[State["InDeclaration"] = 16] = "InDeclaration";
    // Processing instructions
    State[State["InProcessingInstruction"] = 17] = "InProcessingInstruction";
    // Comments & CDATA
    State[State["BeforeComment"] = 18] = "BeforeComment";
    State[State["CDATASequence"] = 19] = "CDATASequence";
    State[State["InSpecialComment"] = 20] = "InSpecialComment";
    State[State["InCommentLike"] = 21] = "InCommentLike";
    // Special tags
    State[State["BeforeSpecialS"] = 22] = "BeforeSpecialS";
    State[State["SpecialStartSequence"] = 23] = "SpecialStartSequence";
    State[State["InSpecialTag"] = 24] = "InSpecialTag";
    State[State["BeforeEntity"] = 25] = "BeforeEntity";
    State[State["BeforeNumericEntity"] = 26] = "BeforeNumericEntity";
    State[State["InNamedEntity"] = 27] = "InNamedEntity";
    State[State["InNumericEntity"] = 28] = "InNumericEntity";
    State[State["InHexEntity"] = 29] = "InHexEntity";
})(State || (State = {}));
function isWhitespace(c) {
    return (c === CharCodes.Space ||
        c === CharCodes.NewLine ||
        c === CharCodes.Tab ||
        c === CharCodes.FormFeed ||
        c === CharCodes.CarriageReturn);
}
function isEndOfTagSection(c) {
    return c === CharCodes.Slash || c === CharCodes.Gt || isWhitespace(c);
}
function isNumber(c) {
    return c >= CharCodes.Zero && c <= CharCodes.Nine;
}
function isASCIIAlpha(c) {
    return ((c >= CharCodes.LowerA && c <= CharCodes.LowerZ) ||
        (c >= CharCodes.UpperA && c <= CharCodes.UpperZ));
}
function isHexDigit(c) {
    return ((c >= CharCodes.UpperA && c <= CharCodes.UpperF) ||
        (c >= CharCodes.LowerA && c <= CharCodes.LowerF));
}
var QuoteType;
(function (QuoteType) {
    QuoteType[QuoteType["NoValue"] = 0] = "NoValue";
    QuoteType[QuoteType["Unquoted"] = 1] = "Unquoted";
    QuoteType[QuoteType["Single"] = 2] = "Single";
    QuoteType[QuoteType["Double"] = 3] = "Double";
})(QuoteType || (QuoteType = {}));
/**
 * Sequences used to match longer strings.
 *
 * We don't have `Script`, `Style`, or `Title` here. Instead, we re-use the *End
 * sequences with an increased offset.
 */
const Sequences = {
    Cdata: new Uint8Array([0x43, 0x44, 0x41, 0x54, 0x41, 0x5b]),
    CdataEnd: new Uint8Array([0x5d, 0x5d, 0x3e]),
    CommentEnd: new Uint8Array([0x2d, 0x2d, 0x3e]),
    ScriptEnd: new Uint8Array([0x3c, 0x2f, 0x73, 0x63, 0x72, 0x69, 0x70, 0x74]),
    StyleEnd: new Uint8Array([0x3c, 0x2f, 0x73, 0x74, 0x79, 0x6c, 0x65]),
    TitleEnd: new Uint8Array([0x3c, 0x2f, 0x74, 0x69, 0x74, 0x6c, 0x65]), // `</title`
};
class Tokenizer {
    constructor({ xmlMode = false, decodeEntities = true, }, cbs) {
        this.cbs = cbs;
        /** The current state the tokenizer is in. */
        this.state = State.Text;
        /** The read buffer. */
        this.buffer = "";
        /** The beginning of the section that is currently being read. */
        this.sectionStart = 0;
        /** The index within the buffer that we are currently looking at. */
        this.index = 0;
        /** Some behavior, eg. when decoding entities, is done while we are in another state. This keeps track of the other state type. */
        this.baseState = State.Text;
        /** For special parsing behavior inside of script and style tags. */
        this.isSpecial = false;
        /** Indicates whether the tokenizer has been paused. */
        this.running = true;
        /** The offset of the current buffer. */
        this.offset = 0;
        this.currentSequence = undefined;
        this.sequenceIndex = 0;
        this.trieIndex = 0;
        this.trieCurrent = 0;
        /** For named entities, the index of the value. For numeric entities, the code point. */
        this.entityResult = 0;
        this.entityExcess = 0;
        this.xmlMode = xmlMode;
        this.decodeEntities = decodeEntities;
        this.entityTrie = xmlMode ? decode.xmlDecodeTree : decode.htmlDecodeTree;
    }
    reset() {
        this.state = State.Text;
        this.buffer = "";
        this.sectionStart = 0;
        this.index = 0;
        this.baseState = State.Text;
        this.currentSequence = undefined;
        this.running = true;
        this.offset = 0;
    }
    write(chunk) {
        this.offset += this.buffer.length;
        this.buffer = chunk;
        this.parse();
    }
    end() {
        if (this.running)
            this.finish();
    }
    pause() {
        this.running = false;
    }
    resume() {
        this.running = true;
        if (this.index < this.buffer.length + this.offset) {
            this.parse();
        }
    }
    /**
     * The current index within all of the written data.
     */
    getIndex() {
        return this.index;
    }
    /**
     * The start of the current section.
     */
    getSectionStart() {
        return this.sectionStart;
    }
    stateText(c) {
        if (c === CharCodes.Lt ||
            (!this.decodeEntities && this.fastForwardTo(CharCodes.Lt))) {
            if (this.index > this.sectionStart) {
                this.cbs.ontext(this.sectionStart, this.index);
            }
            this.state = State.BeforeTagName;
            this.sectionStart = this.index;
        }
        else if (this.decodeEntities && c === CharCodes.Amp) {
            this.state = State.BeforeEntity;
        }
    }
    stateSpecialStartSequence(c) {
        const isEnd = this.sequenceIndex === this.currentSequence.length;
        const isMatch = isEnd
            ? // If we are at the end of the sequence, make sure the tag name has ended
                isEndOfTagSection(c)
            : // Otherwise, do a case-insensitive comparison
                (c | 0x20) === this.currentSequence[this.sequenceIndex];
        if (!isMatch) {
            this.isSpecial = false;
        }
        else if (!isEnd) {
            this.sequenceIndex++;
            return;
        }
        this.sequenceIndex = 0;
        this.state = State.InTagName;
        this.stateInTagName(c);
    }
    /** Look for an end tag. For <title> tags, also decode entities. */
    stateInSpecialTag(c) {
        if (this.sequenceIndex === this.currentSequence.length) {
            if (c === CharCodes.Gt || isWhitespace(c)) {
                const endOfText = this.index - this.currentSequence.length;
                if (this.sectionStart < endOfText) {
                    // Spoof the index so that reported locations match up.
                    const actualIndex = this.index;
                    this.index = endOfText;
                    this.cbs.ontext(this.sectionStart, endOfText);
                    this.index = actualIndex;
                }
                this.isSpecial = false;
                this.sectionStart = endOfText + 2; // Skip over the `</`
                this.stateInClosingTagName(c);
                return; // We are done; skip the rest of the function.
            }
            this.sequenceIndex = 0;
        }
        if ((c | 0x20) === this.currentSequence[this.sequenceIndex]) {
            this.sequenceIndex += 1;
        }
        else if (this.sequenceIndex === 0) {
            if (this.currentSequence === Sequences.TitleEnd) {
                // We have to parse entities in <title> tags.
                if (this.decodeEntities && c === CharCodes.Amp) {
                    this.state = State.BeforeEntity;
                }
            }
            else if (this.fastForwardTo(CharCodes.Lt)) {
                // Outside of <title> tags, we can fast-forward.
                this.sequenceIndex = 1;
            }
        }
        else {
            // If we see a `<`, set the sequence index to 1; useful for eg. `<</script>`.
            this.sequenceIndex = Number(c === CharCodes.Lt);
        }
    }
    stateCDATASequence(c) {
        if (c === Sequences.Cdata[this.sequenceIndex]) {
            if (++this.sequenceIndex === Sequences.Cdata.length) {
                this.state = State.InCommentLike;
                this.currentSequence = Sequences.CdataEnd;
                this.sequenceIndex = 0;
                this.sectionStart = this.index + 1;
            }
        }
        else {
            this.sequenceIndex = 0;
            this.state = State.InDeclaration;
            this.stateInDeclaration(c); // Reconsume the character
        }
    }
    /**
     * When we wait for one specific character, we can speed things up
     * by skipping through the buffer until we find it.
     *
     * @returns Whether the character was found.
     */
    fastForwardTo(c) {
        while (++this.index < this.buffer.length + this.offset) {
            if (this.buffer.charCodeAt(this.index - this.offset) === c) {
                return true;
            }
        }
        /*
         * We increment the index at the end of the `parse` loop,
         * so set it to `buffer.length - 1` here.
         *
         * TODO: Refactor `parse` to increment index before calling states.
         */
        this.index = this.buffer.length + this.offset - 1;
        return false;
    }
    /**
     * Comments and CDATA end with `-->` and `]]>`.
     *
     * Their common qualities are:
     * - Their end sequences have a distinct character they start with.
     * - That character is then repeated, so we have to check multiple repeats.
     * - All characters but the start character of the sequence can be skipped.
     */
    stateInCommentLike(c) {
        if (c === this.currentSequence[this.sequenceIndex]) {
            if (++this.sequenceIndex === this.currentSequence.length) {
                if (this.currentSequence === Sequences.CdataEnd) {
                    this.cbs.oncdata(this.sectionStart, this.index, 2);
                }
                else {
                    this.cbs.oncomment(this.sectionStart, this.index, 2);
                }
                this.sequenceIndex = 0;
                this.sectionStart = this.index + 1;
                this.state = State.Text;
            }
        }
        else if (this.sequenceIndex === 0) {
            // Fast-forward to the first character of the sequence
            if (this.fastForwardTo(this.currentSequence[0])) {
                this.sequenceIndex = 1;
            }
        }
        else if (c !== this.currentSequence[this.sequenceIndex - 1]) {
            // Allow long sequences, eg. --->, ]]]>
            this.sequenceIndex = 0;
        }
    }
    /**
     * HTML only allows ASCII alpha characters (a-z and A-Z) at the beginning of a tag name.
     *
     * XML allows a lot more characters here (@see https://www.w3.org/TR/REC-xml/#NT-NameStartChar).
     * We allow anything that wouldn't end the tag.
     */
    isTagStartChar(c) {
        return this.xmlMode ? !isEndOfTagSection(c) : isASCIIAlpha(c);
    }
    startSpecial(sequence, offset) {
        this.isSpecial = true;
        this.currentSequence = sequence;
        this.sequenceIndex = offset;
        this.state = State.SpecialStartSequence;
    }
    stateBeforeTagName(c) {
        if (c === CharCodes.ExclamationMark) {
            this.state = State.BeforeDeclaration;
            this.sectionStart = this.index + 1;
        }
        else if (c === CharCodes.Questionmark) {
            this.state = State.InProcessingInstruction;
            this.sectionStart = this.index + 1;
        }
        else if (this.isTagStartChar(c)) {
            const lower = c | 0x20;
            this.sectionStart = this.index;
            if (!this.xmlMode && lower === Sequences.TitleEnd[2]) {
                this.startSpecial(Sequences.TitleEnd, 3);
            }
            else {
                this.state =
                    !this.xmlMode && lower === Sequences.ScriptEnd[2]
                        ? State.BeforeSpecialS
                        : State.InTagName;
            }
        }
        else if (c === CharCodes.Slash) {
            this.state = State.BeforeClosingTagName;
        }
        else {
            this.state = State.Text;
            this.stateText(c);
        }
    }
    stateInTagName(c) {
        if (isEndOfTagSection(c)) {
            this.cbs.onopentagname(this.sectionStart, this.index);
            this.sectionStart = -1;
            this.state = State.BeforeAttributeName;
            this.stateBeforeAttributeName(c);
        }
    }
    stateBeforeClosingTagName(c) {
        if (isWhitespace(c)) ;
        else if (c === CharCodes.Gt) {
            this.state = State.Text;
        }
        else {
            this.state = this.isTagStartChar(c)
                ? State.InClosingTagName
                : State.InSpecialComment;
            this.sectionStart = this.index;
        }
    }
    stateInClosingTagName(c) {
        if (c === CharCodes.Gt || isWhitespace(c)) {
            this.cbs.onclosetag(this.sectionStart, this.index);
            this.sectionStart = -1;
            this.state = State.AfterClosingTagName;
            this.stateAfterClosingTagName(c);
        }
    }
    stateAfterClosingTagName(c) {
        // Skip everything until ">"
        if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
            this.state = State.Text;
            this.baseState = State.Text;
            this.sectionStart = this.index + 1;
        }
    }
    stateBeforeAttributeName(c) {
        if (c === CharCodes.Gt) {
            this.cbs.onopentagend(this.index);
            if (this.isSpecial) {
                this.state = State.InSpecialTag;
                this.sequenceIndex = 0;
            }
            else {
                this.state = State.Text;
            }
            this.baseState = this.state;
            this.sectionStart = this.index + 1;
        }
        else if (c === CharCodes.Slash) {
            this.state = State.InSelfClosingTag;
        }
        else if (!isWhitespace(c)) {
            this.state = State.InAttributeName;
            this.sectionStart = this.index;
        }
    }
    stateInSelfClosingTag(c) {
        if (c === CharCodes.Gt) {
            this.cbs.onselfclosingtag(this.index);
            this.state = State.Text;
            this.baseState = State.Text;
            this.sectionStart = this.index + 1;
            this.isSpecial = false; // Reset special state, in case of self-closing special tags
        }
        else if (!isWhitespace(c)) {
            this.state = State.BeforeAttributeName;
            this.stateBeforeAttributeName(c);
        }
    }
    stateInAttributeName(c) {
        if (c === CharCodes.Eq || isEndOfTagSection(c)) {
            this.cbs.onattribname(this.sectionStart, this.index);
            this.sectionStart = -1;
            this.state = State.AfterAttributeName;
            this.stateAfterAttributeName(c);
        }
    }
    stateAfterAttributeName(c) {
        if (c === CharCodes.Eq) {
            this.state = State.BeforeAttributeValue;
        }
        else if (c === CharCodes.Slash || c === CharCodes.Gt) {
            this.cbs.onattribend(QuoteType.NoValue, this.index);
            this.state = State.BeforeAttributeName;
            this.stateBeforeAttributeName(c);
        }
        else if (!isWhitespace(c)) {
            this.cbs.onattribend(QuoteType.NoValue, this.index);
            this.state = State.InAttributeName;
            this.sectionStart = this.index;
        }
    }
    stateBeforeAttributeValue(c) {
        if (c === CharCodes.DoubleQuote) {
            this.state = State.InAttributeValueDq;
            this.sectionStart = this.index + 1;
        }
        else if (c === CharCodes.SingleQuote) {
            this.state = State.InAttributeValueSq;
            this.sectionStart = this.index + 1;
        }
        else if (!isWhitespace(c)) {
            this.sectionStart = this.index;
            this.state = State.InAttributeValueNq;
            this.stateInAttributeValueNoQuotes(c); // Reconsume token
        }
    }
    handleInAttributeValue(c, quote) {
        if (c === quote ||
            (!this.decodeEntities && this.fastForwardTo(quote))) {
            this.cbs.onattribdata(this.sectionStart, this.index);
            this.sectionStart = -1;
            this.cbs.onattribend(quote === CharCodes.DoubleQuote
                ? QuoteType.Double
                : QuoteType.Single, this.index);
            this.state = State.BeforeAttributeName;
        }
        else if (this.decodeEntities && c === CharCodes.Amp) {
            this.baseState = this.state;
            this.state = State.BeforeEntity;
        }
    }
    stateInAttributeValueDoubleQuotes(c) {
        this.handleInAttributeValue(c, CharCodes.DoubleQuote);
    }
    stateInAttributeValueSingleQuotes(c) {
        this.handleInAttributeValue(c, CharCodes.SingleQuote);
    }
    stateInAttributeValueNoQuotes(c) {
        if (isWhitespace(c) || c === CharCodes.Gt) {
            this.cbs.onattribdata(this.sectionStart, this.index);
            this.sectionStart = -1;
            this.cbs.onattribend(QuoteType.Unquoted, this.index);
            this.state = State.BeforeAttributeName;
            this.stateBeforeAttributeName(c);
        }
        else if (this.decodeEntities && c === CharCodes.Amp) {
            this.baseState = this.state;
            this.state = State.BeforeEntity;
        }
    }
    stateBeforeDeclaration(c) {
        if (c === CharCodes.OpeningSquareBracket) {
            this.state = State.CDATASequence;
            this.sequenceIndex = 0;
        }
        else {
            this.state =
                c === CharCodes.Dash
                    ? State.BeforeComment
                    : State.InDeclaration;
        }
    }
    stateInDeclaration(c) {
        if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
            this.cbs.ondeclaration(this.sectionStart, this.index);
            this.state = State.Text;
            this.sectionStart = this.index + 1;
        }
    }
    stateInProcessingInstruction(c) {
        if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
            this.cbs.onprocessinginstruction(this.sectionStart, this.index);
            this.state = State.Text;
            this.sectionStart = this.index + 1;
        }
    }
    stateBeforeComment(c) {
        if (c === CharCodes.Dash) {
            this.state = State.InCommentLike;
            this.currentSequence = Sequences.CommentEnd;
            // Allow short comments (eg. <!-->)
            this.sequenceIndex = 2;
            this.sectionStart = this.index + 1;
        }
        else {
            this.state = State.InDeclaration;
        }
    }
    stateInSpecialComment(c) {
        if (c === CharCodes.Gt || this.fastForwardTo(CharCodes.Gt)) {
            this.cbs.oncomment(this.sectionStart, this.index, 0);
            this.state = State.Text;
            this.sectionStart = this.index + 1;
        }
    }
    stateBeforeSpecialS(c) {
        const lower = c | 0x20;
        if (lower === Sequences.ScriptEnd[3]) {
            this.startSpecial(Sequences.ScriptEnd, 4);
        }
        else if (lower === Sequences.StyleEnd[3]) {
            this.startSpecial(Sequences.StyleEnd, 4);
        }
        else {
            this.state = State.InTagName;
            this.stateInTagName(c); // Consume the token again
        }
    }
    stateBeforeEntity(c) {
        // Start excess with 1 to include the '&'
        this.entityExcess = 1;
        this.entityResult = 0;
        if (c === CharCodes.Number) {
            this.state = State.BeforeNumericEntity;
        }
        else if (c === CharCodes.Amp) ;
        else {
            this.trieIndex = 0;
            this.trieCurrent = this.entityTrie[0];
            this.state = State.InNamedEntity;
            this.stateInNamedEntity(c);
        }
    }
    stateInNamedEntity(c) {
        this.entityExcess += 1;
        this.trieIndex = decode.determineBranch(this.entityTrie, this.trieCurrent, this.trieIndex + 1, c);
        if (this.trieIndex < 0) {
            this.emitNamedEntity();
            this.index--;
            return;
        }
        this.trieCurrent = this.entityTrie[this.trieIndex];
        const masked = this.trieCurrent & decode.BinTrieFlags.VALUE_LENGTH;
        // If the branch is a value, store it and continue
        if (masked) {
            // The mask is the number of bytes of the value, including the current byte.
            const valueLength = (masked >> 14) - 1;
            // If we have a legacy entity while parsing strictly, just skip the number of bytes
            if (!this.allowLegacyEntity() && c !== CharCodes.Semi) {
                this.trieIndex += valueLength;
            }
            else {
                // Add 1 as we have already incremented the excess
                const entityStart = this.index - this.entityExcess + 1;
                if (entityStart > this.sectionStart) {
                    this.emitPartial(this.sectionStart, entityStart);
                }
                // If this is a surrogate pair, consume the next two bytes
                this.entityResult = this.trieIndex;
                this.trieIndex += valueLength;
                this.entityExcess = 0;
                this.sectionStart = this.index + 1;
                if (valueLength === 0) {
                    this.emitNamedEntity();
                }
            }
        }
    }
    emitNamedEntity() {
        this.state = this.baseState;
        if (this.entityResult === 0) {
            return;
        }
        const valueLength = (this.entityTrie[this.entityResult] & decode.BinTrieFlags.VALUE_LENGTH) >>
            14;
        switch (valueLength) {
            case 1: {
                this.emitCodePoint(this.entityTrie[this.entityResult] &
                    ~decode.BinTrieFlags.VALUE_LENGTH);
                break;
            }
            case 2: {
                this.emitCodePoint(this.entityTrie[this.entityResult + 1]);
                break;
            }
            case 3: {
                this.emitCodePoint(this.entityTrie[this.entityResult + 1]);
                this.emitCodePoint(this.entityTrie[this.entityResult + 2]);
            }
        }
    }
    stateBeforeNumericEntity(c) {
        if ((c | 0x20) === CharCodes.LowerX) {
            this.entityExcess++;
            this.state = State.InHexEntity;
        }
        else {
            this.state = State.InNumericEntity;
            this.stateInNumericEntity(c);
        }
    }
    emitNumericEntity(strict) {
        const entityStart = this.index - this.entityExcess - 1;
        const numberStart = entityStart + 2 + Number(this.state === State.InHexEntity);
        if (numberStart !== this.index) {
            // Emit leading data if any
            if (entityStart > this.sectionStart) {
                this.emitPartial(this.sectionStart, entityStart);
            }
            this.sectionStart = this.index + Number(strict);
            this.emitCodePoint(decode.replaceCodePoint(this.entityResult));
        }
        this.state = this.baseState;
    }
    stateInNumericEntity(c) {
        if (c === CharCodes.Semi) {
            this.emitNumericEntity(true);
        }
        else if (isNumber(c)) {
            this.entityResult = this.entityResult * 10 + (c - CharCodes.Zero);
            this.entityExcess++;
        }
        else {
            if (this.allowLegacyEntity()) {
                this.emitNumericEntity(false);
            }
            else {
                this.state = this.baseState;
            }
            this.index--;
        }
    }
    stateInHexEntity(c) {
        if (c === CharCodes.Semi) {
            this.emitNumericEntity(true);
        }
        else if (isNumber(c)) {
            this.entityResult = this.entityResult * 16 + (c - CharCodes.Zero);
            this.entityExcess++;
        }
        else if (isHexDigit(c)) {
            this.entityResult =
                this.entityResult * 16 + ((c | 0x20) - CharCodes.LowerA + 10);
            this.entityExcess++;
        }
        else {
            if (this.allowLegacyEntity()) {
                this.emitNumericEntity(false);
            }
            else {
                this.state = this.baseState;
            }
            this.index--;
        }
    }
    allowLegacyEntity() {
        return (!this.xmlMode &&
            (this.baseState === State.Text ||
                this.baseState === State.InSpecialTag));
    }
    /**
     * Remove data that has already been consumed from the buffer.
     */
    cleanup() {
        // If we are inside of text or attributes, emit what we already have.
        if (this.running && this.sectionStart !== this.index) {
            if (this.state === State.Text ||
                (this.state === State.InSpecialTag && this.sequenceIndex === 0)) {
                this.cbs.ontext(this.sectionStart, this.index);
                this.sectionStart = this.index;
            }
            else if (this.state === State.InAttributeValueDq ||
                this.state === State.InAttributeValueSq ||
                this.state === State.InAttributeValueNq) {
                this.cbs.onattribdata(this.sectionStart, this.index);
                this.sectionStart = this.index;
            }
        }
    }
    shouldContinue() {
        return this.index < this.buffer.length + this.offset && this.running;
    }
    /**
     * Iterates through the buffer, calling the function corresponding to the current state.
     *
     * States that are more likely to be hit are higher up, as a performance improvement.
     */
    parse() {
        while (this.shouldContinue()) {
            const c = this.buffer.charCodeAt(this.index - this.offset);
            switch (this.state) {
                case State.Text: {
                    this.stateText(c);
                    break;
                }
                case State.SpecialStartSequence: {
                    this.stateSpecialStartSequence(c);
                    break;
                }
                case State.InSpecialTag: {
                    this.stateInSpecialTag(c);
                    break;
                }
                case State.CDATASequence: {
                    this.stateCDATASequence(c);
                    break;
                }
                case State.InAttributeValueDq: {
                    this.stateInAttributeValueDoubleQuotes(c);
                    break;
                }
                case State.InAttributeName: {
                    this.stateInAttributeName(c);
                    break;
                }
                case State.InCommentLike: {
                    this.stateInCommentLike(c);
                    break;
                }
                case State.InSpecialComment: {
                    this.stateInSpecialComment(c);
                    break;
                }
                case State.BeforeAttributeName: {
                    this.stateBeforeAttributeName(c);
                    break;
                }
                case State.InTagName: {
                    this.stateInTagName(c);
                    break;
                }
                case State.InClosingTagName: {
                    this.stateInClosingTagName(c);
                    break;
                }
                case State.BeforeTagName: {
                    this.stateBeforeTagName(c);
                    break;
                }
                case State.AfterAttributeName: {
                    this.stateAfterAttributeName(c);
                    break;
                }
                case State.InAttributeValueSq: {
                    this.stateInAttributeValueSingleQuotes(c);
                    break;
                }
                case State.BeforeAttributeValue: {
                    this.stateBeforeAttributeValue(c);
                    break;
                }
                case State.BeforeClosingTagName: {
                    this.stateBeforeClosingTagName(c);
                    break;
                }
                case State.AfterClosingTagName: {
                    this.stateAfterClosingTagName(c);
                    break;
                }
                case State.BeforeSpecialS: {
                    this.stateBeforeSpecialS(c);
                    break;
                }
                case State.InAttributeValueNq: {
                    this.stateInAttributeValueNoQuotes(c);
                    break;
                }
                case State.InSelfClosingTag: {
                    this.stateInSelfClosingTag(c);
                    break;
                }
                case State.InDeclaration: {
                    this.stateInDeclaration(c);
                    break;
                }
                case State.BeforeDeclaration: {
                    this.stateBeforeDeclaration(c);
                    break;
                }
                case State.BeforeComment: {
                    this.stateBeforeComment(c);
                    break;
                }
                case State.InProcessingInstruction: {
                    this.stateInProcessingInstruction(c);
                    break;
                }
                case State.InNamedEntity: {
                    this.stateInNamedEntity(c);
                    break;
                }
                case State.BeforeEntity: {
                    this.stateBeforeEntity(c);
                    break;
                }
                case State.InHexEntity: {
                    this.stateInHexEntity(c);
                    break;
                }
                case State.InNumericEntity: {
                    this.stateInNumericEntity(c);
                    break;
                }
                default: {
                    // `this._state === State.BeforeNumericEntity`
                    this.stateBeforeNumericEntity(c);
                }
            }
            this.index++;
        }
        this.cleanup();
    }
    finish() {
        if (this.state === State.InNamedEntity) {
            this.emitNamedEntity();
        }
        // If there is remaining data, emit it in a reasonable way
        if (this.sectionStart < this.index) {
            this.handleTrailingData();
        }
        this.cbs.onend();
    }
    /** Handle any trailing data. */
    handleTrailingData() {
        const endIndex = this.buffer.length + this.offset;
        if (this.state === State.InCommentLike) {
            if (this.currentSequence === Sequences.CdataEnd) {
                this.cbs.oncdata(this.sectionStart, endIndex, 0);
            }
            else {
                this.cbs.oncomment(this.sectionStart, endIndex, 0);
            }
        }
        else if (this.state === State.InNumericEntity &&
            this.allowLegacyEntity()) {
            this.emitNumericEntity(false);
            // All trailing data will have been consumed
        }
        else if (this.state === State.InHexEntity &&
            this.allowLegacyEntity()) {
            this.emitNumericEntity(false);
            // All trailing data will have been consumed
        }
        else if (this.state === State.InTagName ||
            this.state === State.BeforeAttributeName ||
            this.state === State.BeforeAttributeValue ||
            this.state === State.AfterAttributeName ||
            this.state === State.InAttributeName ||
            this.state === State.InAttributeValueSq ||
            this.state === State.InAttributeValueDq ||
            this.state === State.InAttributeValueNq ||
            this.state === State.InClosingTagName) ;
        else {
            this.cbs.ontext(this.sectionStart, endIndex);
        }
    }
    emitPartial(start, endIndex) {
        if (this.baseState !== State.Text &&
            this.baseState !== State.InSpecialTag) {
            this.cbs.onattribdata(start, endIndex);
        }
        else {
            this.cbs.ontext(start, endIndex);
        }
    }
    emitCodePoint(cp) {
        if (this.baseState !== State.Text &&
            this.baseState !== State.InSpecialTag) {
            this.cbs.onattribentity(cp);
        }
        else {
            this.cbs.ontextentity(cp);
        }
    }
}

const formTags = new Set([
    "input",
    "option",
    "optgroup",
    "select",
    "button",
    "datalist",
    "textarea",
]);
const pTag = new Set(["p"]);
const tableSectionTags = new Set(["thead", "tbody"]);
const ddtTags = new Set(["dd", "dt"]);
const rtpTags = new Set(["rt", "rp"]);
const openImpliesClose = new Map([
    ["tr", new Set(["tr", "th", "td"])],
    ["th", new Set(["th"])],
    ["td", new Set(["thead", "th", "td"])],
    ["body", new Set(["head", "link", "script"])],
    ["li", new Set(["li"])],
    ["p", pTag],
    ["h1", pTag],
    ["h2", pTag],
    ["h3", pTag],
    ["h4", pTag],
    ["h5", pTag],
    ["h6", pTag],
    ["select", formTags],
    ["input", formTags],
    ["output", formTags],
    ["button", formTags],
    ["datalist", formTags],
    ["textarea", formTags],
    ["option", new Set(["option"])],
    ["optgroup", new Set(["optgroup", "option"])],
    ["dd", ddtTags],
    ["dt", ddtTags],
    ["address", pTag],
    ["article", pTag],
    ["aside", pTag],
    ["blockquote", pTag],
    ["details", pTag],
    ["div", pTag],
    ["dl", pTag],
    ["fieldset", pTag],
    ["figcaption", pTag],
    ["figure", pTag],
    ["footer", pTag],
    ["form", pTag],
    ["header", pTag],
    ["hr", pTag],
    ["main", pTag],
    ["nav", pTag],
    ["ol", pTag],
    ["pre", pTag],
    ["section", pTag],
    ["table", pTag],
    ["ul", pTag],
    ["rt", rtpTags],
    ["rp", rtpTags],
    ["tbody", tableSectionTags],
    ["tfoot", tableSectionTags],
]);
const voidElements = new Set([
    "area",
    "base",
    "basefont",
    "br",
    "col",
    "command",
    "embed",
    "frame",
    "hr",
    "img",
    "input",
    "isindex",
    "keygen",
    "link",
    "meta",
    "param",
    "source",
    "track",
    "wbr",
]);
const foreignContextElements = new Set(["math", "svg"]);
const htmlIntegrationElements = new Set([
    "mi",
    "mo",
    "mn",
    "ms",
    "mtext",
    "annotation-xml",
    "foreignobject",
    "desc",
    "title",
]);
const reNameEnd = /\s|\//;
class Parser$2 {
    constructor(cbs, options = {}) {
        var _a, _b, _c, _d, _e;
        this.options = options;
        /** The start index of the last event. */
        this.startIndex = 0;
        /** The end index of the last event. */
        this.endIndex = 0;
        /**
         * Store the start index of the current open tag,
         * so we can update the start index for attributes.
         */
        this.openTagStart = 0;
        this.tagname = "";
        this.attribname = "";
        this.attribvalue = "";
        this.attribs = null;
        this.stack = [];
        this.foreignContext = [];
        this.buffers = [];
        this.bufferOffset = 0;
        /** The index of the last written buffer. Used when resuming after a `pause()`. */
        this.writeIndex = 0;
        /** Indicates whether the parser has finished running / `.end` has been called. */
        this.ended = false;
        this.cbs = cbs !== null && cbs !== void 0 ? cbs : {};
        this.lowerCaseTagNames = (_a = options.lowerCaseTags) !== null && _a !== void 0 ? _a : !options.xmlMode;
        this.lowerCaseAttributeNames =
            (_b = options.lowerCaseAttributeNames) !== null && _b !== void 0 ? _b : !options.xmlMode;
        this.tokenizer = new ((_c = options.Tokenizer) !== null && _c !== void 0 ? _c : Tokenizer)(this.options, this);
        (_e = (_d = this.cbs).onparserinit) === null || _e === void 0 ? void 0 : _e.call(_d, this);
    }
    // Tokenizer event handlers
    /** @internal */
    ontext(start, endIndex) {
        var _a, _b;
        const data = this.getSlice(start, endIndex);
        this.endIndex = endIndex - 1;
        (_b = (_a = this.cbs).ontext) === null || _b === void 0 ? void 0 : _b.call(_a, data);
        this.startIndex = endIndex;
    }
    /** @internal */
    ontextentity(cp) {
        var _a, _b;
        /*
         * Entities can be emitted on the character, or directly after.
         * We use the section start here to get accurate indices.
         */
        const index = this.tokenizer.getSectionStart();
        this.endIndex = index - 1;
        (_b = (_a = this.cbs).ontext) === null || _b === void 0 ? void 0 : _b.call(_a, decode.fromCodePoint(cp));
        this.startIndex = index;
    }
    isVoidElement(name) {
        return !this.options.xmlMode && voidElements.has(name);
    }
    /** @internal */
    onopentagname(start, endIndex) {
        this.endIndex = endIndex;
        let name = this.getSlice(start, endIndex);
        if (this.lowerCaseTagNames) {
            name = name.toLowerCase();
        }
        this.emitOpenTag(name);
    }
    emitOpenTag(name) {
        var _a, _b, _c, _d;
        this.openTagStart = this.startIndex;
        this.tagname = name;
        const impliesClose = !this.options.xmlMode && openImpliesClose.get(name);
        if (impliesClose) {
            while (this.stack.length > 0 &&
                impliesClose.has(this.stack[this.stack.length - 1])) {
                const element = this.stack.pop();
                (_b = (_a = this.cbs).onclosetag) === null || _b === void 0 ? void 0 : _b.call(_a, element, true);
            }
        }
        if (!this.isVoidElement(name)) {
            this.stack.push(name);
            if (foreignContextElements.has(name)) {
                this.foreignContext.push(true);
            }
            else if (htmlIntegrationElements.has(name)) {
                this.foreignContext.push(false);
            }
        }
        (_d = (_c = this.cbs).onopentagname) === null || _d === void 0 ? void 0 : _d.call(_c, name);
        if (this.cbs.onopentag)
            this.attribs = {};
    }
    endOpenTag(isImplied) {
        var _a, _b;
        this.startIndex = this.openTagStart;
        if (this.attribs) {
            (_b = (_a = this.cbs).onopentag) === null || _b === void 0 ? void 0 : _b.call(_a, this.tagname, this.attribs, isImplied);
            this.attribs = null;
        }
        if (this.cbs.onclosetag && this.isVoidElement(this.tagname)) {
            this.cbs.onclosetag(this.tagname, true);
        }
        this.tagname = "";
    }
    /** @internal */
    onopentagend(endIndex) {
        this.endIndex = endIndex;
        this.endOpenTag(false);
        // Set `startIndex` for next node
        this.startIndex = endIndex + 1;
    }
    /** @internal */
    onclosetag(start, endIndex) {
        var _a, _b, _c, _d, _e, _f;
        this.endIndex = endIndex;
        let name = this.getSlice(start, endIndex);
        if (this.lowerCaseTagNames) {
            name = name.toLowerCase();
        }
        if (foreignContextElements.has(name) ||
            htmlIntegrationElements.has(name)) {
            this.foreignContext.pop();
        }
        if (!this.isVoidElement(name)) {
            const pos = this.stack.lastIndexOf(name);
            if (pos !== -1) {
                if (this.cbs.onclosetag) {
                    let count = this.stack.length - pos;
                    while (count--) {
                        // We know the stack has sufficient elements.
                        this.cbs.onclosetag(this.stack.pop(), count !== 0);
                    }
                }
                else
                    this.stack.length = pos;
            }
            else if (!this.options.xmlMode && name === "p") {
                // Implicit open before close
                this.emitOpenTag("p");
                this.closeCurrentTag(true);
            }
        }
        else if (!this.options.xmlMode && name === "br") {
            // We can't use `emitOpenTag` for implicit open, as `br` would be implicitly closed.
            (_b = (_a = this.cbs).onopentagname) === null || _b === void 0 ? void 0 : _b.call(_a, "br");
            (_d = (_c = this.cbs).onopentag) === null || _d === void 0 ? void 0 : _d.call(_c, "br", {}, true);
            (_f = (_e = this.cbs).onclosetag) === null || _f === void 0 ? void 0 : _f.call(_e, "br", false);
        }
        // Set `startIndex` for next node
        this.startIndex = endIndex + 1;
    }
    /** @internal */
    onselfclosingtag(endIndex) {
        this.endIndex = endIndex;
        if (this.options.xmlMode ||
            this.options.recognizeSelfClosing ||
            this.foreignContext[this.foreignContext.length - 1]) {
            this.closeCurrentTag(false);
            // Set `startIndex` for next node
            this.startIndex = endIndex + 1;
        }
        else {
            // Ignore the fact that the tag is self-closing.
            this.onopentagend(endIndex);
        }
    }
    closeCurrentTag(isOpenImplied) {
        var _a, _b;
        const name = this.tagname;
        this.endOpenTag(isOpenImplied);
        // Self-closing tags will be on the top of the stack
        if (this.stack[this.stack.length - 1] === name) {
            // If the opening tag isn't implied, the closing tag has to be implied.
            (_b = (_a = this.cbs).onclosetag) === null || _b === void 0 ? void 0 : _b.call(_a, name, !isOpenImplied);
            this.stack.pop();
        }
    }
    /** @internal */
    onattribname(start, endIndex) {
        this.startIndex = start;
        const name = this.getSlice(start, endIndex);
        this.attribname = this.lowerCaseAttributeNames
            ? name.toLowerCase()
            : name;
    }
    /** @internal */
    onattribdata(start, endIndex) {
        this.attribvalue += this.getSlice(start, endIndex);
    }
    /** @internal */
    onattribentity(cp) {
        this.attribvalue += decode.fromCodePoint(cp);
    }
    /** @internal */
    onattribend(quote, endIndex) {
        var _a, _b;
        this.endIndex = endIndex;
        (_b = (_a = this.cbs).onattribute) === null || _b === void 0 ? void 0 : _b.call(_a, this.attribname, this.attribvalue, quote === QuoteType.Double
            ? '"'
            : quote === QuoteType.Single
                ? "'"
                : quote === QuoteType.NoValue
                    ? undefined
                    : null);
        if (this.attribs &&
            !Object.prototype.hasOwnProperty.call(this.attribs, this.attribname)) {
            this.attribs[this.attribname] = this.attribvalue;
        }
        this.attribvalue = "";
    }
    getInstructionName(value) {
        const index = value.search(reNameEnd);
        let name = index < 0 ? value : value.substr(0, index);
        if (this.lowerCaseTagNames) {
            name = name.toLowerCase();
        }
        return name;
    }
    /** @internal */
    ondeclaration(start, endIndex) {
        this.endIndex = endIndex;
        const value = this.getSlice(start, endIndex);
        if (this.cbs.onprocessinginstruction) {
            const name = this.getInstructionName(value);
            this.cbs.onprocessinginstruction(`!${name}`, `!${value}`);
        }
        // Set `startIndex` for next node
        this.startIndex = endIndex + 1;
    }
    /** @internal */
    onprocessinginstruction(start, endIndex) {
        this.endIndex = endIndex;
        const value = this.getSlice(start, endIndex);
        if (this.cbs.onprocessinginstruction) {
            const name = this.getInstructionName(value);
            this.cbs.onprocessinginstruction(`?${name}`, `?${value}`);
        }
        // Set `startIndex` for next node
        this.startIndex = endIndex + 1;
    }
    /** @internal */
    oncomment(start, endIndex, offset) {
        var _a, _b, _c, _d;
        this.endIndex = endIndex;
        (_b = (_a = this.cbs).oncomment) === null || _b === void 0 ? void 0 : _b.call(_a, this.getSlice(start, endIndex - offset));
        (_d = (_c = this.cbs).oncommentend) === null || _d === void 0 ? void 0 : _d.call(_c);
        // Set `startIndex` for next node
        this.startIndex = endIndex + 1;
    }
    /** @internal */
    oncdata(start, endIndex, offset) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        this.endIndex = endIndex;
        const value = this.getSlice(start, endIndex - offset);
        if (this.options.xmlMode || this.options.recognizeCDATA) {
            (_b = (_a = this.cbs).oncdatastart) === null || _b === void 0 ? void 0 : _b.call(_a);
            (_d = (_c = this.cbs).ontext) === null || _d === void 0 ? void 0 : _d.call(_c, value);
            (_f = (_e = this.cbs).oncdataend) === null || _f === void 0 ? void 0 : _f.call(_e);
        }
        else {
            (_h = (_g = this.cbs).oncomment) === null || _h === void 0 ? void 0 : _h.call(_g, `[CDATA[${value}]]`);
            (_k = (_j = this.cbs).oncommentend) === null || _k === void 0 ? void 0 : _k.call(_j);
        }
        // Set `startIndex` for next node
        this.startIndex = endIndex + 1;
    }
    /** @internal */
    onend() {
        var _a, _b;
        if (this.cbs.onclosetag) {
            // Set the end index for all remaining tags
            this.endIndex = this.startIndex;
            for (let index = this.stack.length; index > 0; this.cbs.onclosetag(this.stack[--index], true))
                ;
        }
        (_b = (_a = this.cbs).onend) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    /**
     * Resets the parser to a blank state, ready to parse a new HTML document
     */
    reset() {
        var _a, _b, _c, _d;
        (_b = (_a = this.cbs).onreset) === null || _b === void 0 ? void 0 : _b.call(_a);
        this.tokenizer.reset();
        this.tagname = "";
        this.attribname = "";
        this.attribs = null;
        this.stack.length = 0;
        this.startIndex = 0;
        this.endIndex = 0;
        (_d = (_c = this.cbs).onparserinit) === null || _d === void 0 ? void 0 : _d.call(_c, this);
        this.buffers.length = 0;
        this.bufferOffset = 0;
        this.writeIndex = 0;
        this.ended = false;
    }
    /**
     * Resets the parser, then parses a complete document and
     * pushes it to the handler.
     *
     * @param data Document to parse.
     */
    parseComplete(data) {
        this.reset();
        this.end(data);
    }
    getSlice(start, end) {
        while (start - this.bufferOffset >= this.buffers[0].length) {
            this.shiftBuffer();
        }
        let slice = this.buffers[0].slice(start - this.bufferOffset, end - this.bufferOffset);
        while (end - this.bufferOffset > this.buffers[0].length) {
            this.shiftBuffer();
            slice += this.buffers[0].slice(0, end - this.bufferOffset);
        }
        return slice;
    }
    shiftBuffer() {
        this.bufferOffset += this.buffers[0].length;
        this.writeIndex--;
        this.buffers.shift();
    }
    /**
     * Parses a chunk of data and calls the corresponding callbacks.
     *
     * @param chunk Chunk to parse.
     */
    write(chunk) {
        var _a, _b;
        if (this.ended) {
            (_b = (_a = this.cbs).onerror) === null || _b === void 0 ? void 0 : _b.call(_a, new Error(".write() after done!"));
            return;
        }
        this.buffers.push(chunk);
        if (this.tokenizer.running) {
            this.tokenizer.write(chunk);
            this.writeIndex++;
        }
    }
    /**
     * Parses the end of the buffer and clears the stack, calls onend.
     *
     * @param chunk Optional final chunk to parse.
     */
    end(chunk) {
        var _a, _b;
        if (this.ended) {
            (_b = (_a = this.cbs).onerror) === null || _b === void 0 ? void 0 : _b.call(_a, new Error(".end() after done!"));
            return;
        }
        if (chunk)
            this.write(chunk);
        this.ended = true;
        this.tokenizer.end();
    }
    /**
     * Pauses parsing. The parser won't emit events until `resume` is called.
     */
    pause() {
        this.tokenizer.pause();
    }
    /**
     * Resumes parsing after `pause` was called.
     */
    resume() {
        this.tokenizer.resume();
        while (this.tokenizer.running &&
            this.writeIndex < this.buffers.length) {
            this.tokenizer.write(this.buffers[this.writeIndex++]);
        }
        if (this.ended)
            this.tokenizer.end();
    }
    /**
     * Alias of `write`, for backwards compatibility.
     *
     * @param chunk Chunk to parse.
     * @deprecated
     */
    parseChunk(chunk) {
        this.write(chunk);
    }
    /**
     * Alias of `end`, for backwards compatibility.
     *
     * @param chunk Optional final chunk to parse.
     * @deprecated
     */
    done(chunk) {
        this.end(chunk);
    }
}

/** Types of elements found in htmlparser2's DOM */
var ElementType;
(function (ElementType) {
    /** Type for the root element of a document */
    ElementType["Root"] = "root";
    /** Type for Text */
    ElementType["Text"] = "text";
    /** Type for <? ... ?> */
    ElementType["Directive"] = "directive";
    /** Type for <!-- ... --> */
    ElementType["Comment"] = "comment";
    /** Type for <script> tags */
    ElementType["Script"] = "script";
    /** Type for <style> tags */
    ElementType["Style"] = "style";
    /** Type for Any tag */
    ElementType["Tag"] = "tag";
    /** Type for <![CDATA[ ... ]]> */
    ElementType["CDATA"] = "cdata";
    /** Type for <!doctype ...> */
    ElementType["Doctype"] = "doctype";
})(ElementType || (ElementType = {}));
/**
 * Tests whether an element is a tag or not.
 *
 * @param elem Element to test
 */
function isTag$1(elem) {
    return (elem.type === ElementType.Tag ||
        elem.type === ElementType.Script ||
        elem.type === ElementType.Style);
}
// Exports for backwards compatibility
/** Type for the root element of a document */
const Root$7 = ElementType.Root;
/** Type for Text */
const Text$1 = ElementType.Text;
/** Type for <? ... ?> */
const Directive = ElementType.Directive;
/** Type for <!-- ... --> */
const Comment$6 = ElementType.Comment;
/** Type for <script> tags */
const Script = ElementType.Script;
/** Type for <style> tags */
const Style = ElementType.Style;
/** Type for Any tag */
const Tag = ElementType.Tag;
/** Type for <![CDATA[ ... ]]> */
const CDATA$1 = ElementType.CDATA;
/** Type for <!doctype ...> */
const Doctype = ElementType.Doctype;

const index$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  get ElementType () { return ElementType; },
  isTag: isTag$1,
  Root: Root$7,
  Text: Text$1,
  Directive: Directive,
  Comment: Comment$6,
  Script: Script,
  Style: Style,
  Tag: Tag,
  CDATA: CDATA$1,
  Doctype: Doctype
});

/**
 * This object will be used as the prototype for Nodes when creating a
 * DOM-Level-1-compliant structure.
 */
class Node$5 {
    constructor() {
        /** Parent of the node */
        this.parent = null;
        /** Previous sibling */
        this.prev = null;
        /** Next sibling */
        this.next = null;
        /** The start index of the node. Requires `withStartIndices` on the handler to be `true. */
        this.startIndex = null;
        /** The end index of the node. Requires `withEndIndices` on the handler to be `true. */
        this.endIndex = null;
    }
    // Read-write aliases for properties
    /**
     * Same as {@link parent}.
     * [DOM spec](https://dom.spec.whatwg.org)-compatible alias.
     */
    get parentNode() {
        return this.parent;
    }
    set parentNode(parent) {
        this.parent = parent;
    }
    /**
     * Same as {@link prev}.
     * [DOM spec](https://dom.spec.whatwg.org)-compatible alias.
     */
    get previousSibling() {
        return this.prev;
    }
    set previousSibling(prev) {
        this.prev = prev;
    }
    /**
     * Same as {@link next}.
     * [DOM spec](https://dom.spec.whatwg.org)-compatible alias.
     */
    get nextSibling() {
        return this.next;
    }
    set nextSibling(next) {
        this.next = next;
    }
    /**
     * Clone this node, and optionally its children.
     *
     * @param recursive Clone child nodes as well.
     * @returns A clone of the node.
     */
    cloneNode(recursive = false) {
        return cloneNode$1(this, recursive);
    }
}
/**
 * A node that contains some data.
 */
class DataNode extends Node$5 {
    /**
     * @param data The content of the data node
     */
    constructor(data) {
        super();
        this.data = data;
    }
    /**
     * Same as {@link data}.
     * [DOM spec](https://dom.spec.whatwg.org)-compatible alias.
     */
    get nodeValue() {
        return this.data;
    }
    set nodeValue(data) {
        this.data = data;
    }
}
/**
 * Text within the document.
 */
class Text extends DataNode {
    constructor() {
        super(...arguments);
        this.type = ElementType.Text;
    }
    get nodeType() {
        return 3;
    }
}
/**
 * Comments within the document.
 */
class Comment$5 extends DataNode {
    constructor() {
        super(...arguments);
        this.type = ElementType.Comment;
    }
    get nodeType() {
        return 8;
    }
}
/**
 * Processing instructions, including doc types.
 */
class ProcessingInstruction extends DataNode {
    constructor(name, data) {
        super(data);
        this.name = name;
        this.type = ElementType.Directive;
    }
    get nodeType() {
        return 1;
    }
}
/**
 * A `Node` that can have children.
 */
class NodeWithChildren extends Node$5 {
    /**
     * @param children Children of the node. Only certain node types can have children.
     */
    constructor(children) {
        super();
        this.children = children;
    }
    // Aliases
    /** First child of the node. */
    get firstChild() {
        var _a;
        return (_a = this.children[0]) !== null && _a !== void 0 ? _a : null;
    }
    /** Last child of the node. */
    get lastChild() {
        return this.children.length > 0
            ? this.children[this.children.length - 1]
            : null;
    }
    /**
     * Same as {@link children}.
     * [DOM spec](https://dom.spec.whatwg.org)-compatible alias.
     */
    get childNodes() {
        return this.children;
    }
    set childNodes(children) {
        this.children = children;
    }
}
class CDATA extends NodeWithChildren {
    constructor() {
        super(...arguments);
        this.type = ElementType.CDATA;
    }
    get nodeType() {
        return 4;
    }
}
/**
 * The root node of the document.
 */
class Document$4 extends NodeWithChildren {
    constructor() {
        super(...arguments);
        this.type = ElementType.Root;
    }
    get nodeType() {
        return 9;
    }
}
/**
 * An element within the DOM.
 */
class Element extends NodeWithChildren {
    /**
     * @param name Name of the tag, eg. `div`, `span`.
     * @param attribs Object mapping attribute names to attribute values.
     * @param children Children of the node.
     */
    constructor(name, attribs, children = [], type = name === "script"
        ? ElementType.Script
        : name === "style"
            ? ElementType.Style
            : ElementType.Tag) {
        super(children);
        this.name = name;
        this.attribs = attribs;
        this.type = type;
    }
    get nodeType() {
        return 1;
    }
    // DOM Level 1 aliases
    /**
     * Same as {@link name}.
     * [DOM spec](https://dom.spec.whatwg.org)-compatible alias.
     */
    get tagName() {
        return this.name;
    }
    set tagName(name) {
        this.name = name;
    }
    get attributes() {
        return Object.keys(this.attribs).map((name) => {
            var _a, _b;
            return ({
                name,
                value: this.attribs[name],
                namespace: (_a = this["x-attribsNamespace"]) === null || _a === void 0 ? void 0 : _a[name],
                prefix: (_b = this["x-attribsPrefix"]) === null || _b === void 0 ? void 0 : _b[name],
            });
        });
    }
}
/**
 * @param node Node to check.
 * @returns `true` if the node is a `Element`, `false` otherwise.
 */
function isTag(node) {
    return isTag$1(node);
}
/**
 * @param node Node to check.
 * @returns `true` if the node has the type `CDATA`, `false` otherwise.
 */
function isCDATA(node) {
    return node.type === ElementType.CDATA;
}
/**
 * @param node Node to check.
 * @returns `true` if the node has the type `Text`, `false` otherwise.
 */
function isText(node) {
    return node.type === ElementType.Text;
}
/**
 * @param node Node to check.
 * @returns `true` if the node has the type `Comment`, `false` otherwise.
 */
function isComment(node) {
    return node.type === ElementType.Comment;
}
/**
 * @param node Node to check.
 * @returns `true` if the node has the type `ProcessingInstruction`, `false` otherwise.
 */
function isDirective(node) {
    return node.type === ElementType.Directive;
}
/**
 * @param node Node to check.
 * @returns `true` if the node has the type `ProcessingInstruction`, `false` otherwise.
 */
function isDocument(node) {
    return node.type === ElementType.Root;
}
/**
 * @param node Node to check.
 * @returns `true` if the node has children, `false` otherwise.
 */
function hasChildren(node) {
    return Object.prototype.hasOwnProperty.call(node, "children");
}
/**
 * Clone a node, and optionally its children.
 *
 * @param recursive Clone child nodes as well.
 * @returns A clone of the node.
 */
function cloneNode$1(node, recursive = false) {
    let result;
    if (isText(node)) {
        result = new Text(node.data);
    }
    else if (isComment(node)) {
        result = new Comment$5(node.data);
    }
    else if (isTag(node)) {
        const children = recursive ? cloneChildren(node.children) : [];
        const clone = new Element(node.name, { ...node.attribs }, children);
        children.forEach((child) => (child.parent = clone));
        if (node.namespace != null) {
            clone.namespace = node.namespace;
        }
        if (node["x-attribsNamespace"]) {
            clone["x-attribsNamespace"] = { ...node["x-attribsNamespace"] };
        }
        if (node["x-attribsPrefix"]) {
            clone["x-attribsPrefix"] = { ...node["x-attribsPrefix"] };
        }
        result = clone;
    }
    else if (isCDATA(node)) {
        const children = recursive ? cloneChildren(node.children) : [];
        const clone = new CDATA(children);
        children.forEach((child) => (child.parent = clone));
        result = clone;
    }
    else if (isDocument(node)) {
        const children = recursive ? cloneChildren(node.children) : [];
        const clone = new Document$4(children);
        children.forEach((child) => (child.parent = clone));
        if (node["x-mode"]) {
            clone["x-mode"] = node["x-mode"];
        }
        result = clone;
    }
    else if (isDirective(node)) {
        const instruction = new ProcessingInstruction(node.name, node.data);
        if (node["x-name"] != null) {
            instruction["x-name"] = node["x-name"];
            instruction["x-publicId"] = node["x-publicId"];
            instruction["x-systemId"] = node["x-systemId"];
        }
        result = instruction;
    }
    else {
        throw new Error(`Not implemented yet: ${node.type}`);
    }
    result.startIndex = node.startIndex;
    result.endIndex = node.endIndex;
    if (node.sourceCodeLocation != null) {
        result.sourceCodeLocation = node.sourceCodeLocation;
    }
    return result;
}
function cloneChildren(childs) {
    const children = childs.map((child) => cloneNode$1(child, true));
    for (let i = 1; i < children.length; i++) {
        children[i].prev = children[i - 1];
        children[i - 1].next = children[i];
    }
    return children;
}

// Default options
const defaultOpts = {
    withStartIndices: false,
    withEndIndices: false,
    xmlMode: false,
};
class DomHandler {
    /**
     * @param callback Called once parsing has completed.
     * @param options Settings for the handler.
     * @param elementCB Callback whenever a tag is closed.
     */
    constructor(callback, options, elementCB) {
        /** The elements of the DOM */
        this.dom = [];
        /** The root element for the DOM */
        this.root = new Document$4(this.dom);
        /** Indicated whether parsing has been completed. */
        this.done = false;
        /** Stack of open tags. */
        this.tagStack = [this.root];
        /** A data node that is still being written to. */
        this.lastNode = null;
        /** Reference to the parser instance. Used for location information. */
        this.parser = null;
        // Make it possible to skip arguments, for backwards-compatibility
        if (typeof options === "function") {
            elementCB = options;
            options = defaultOpts;
        }
        if (typeof callback === "object") {
            options = callback;
            callback = undefined;
        }
        this.callback = callback !== null && callback !== void 0 ? callback : null;
        this.options = options !== null && options !== void 0 ? options : defaultOpts;
        this.elementCB = elementCB !== null && elementCB !== void 0 ? elementCB : null;
    }
    onparserinit(parser) {
        this.parser = parser;
    }
    // Resets the handler back to starting state
    onreset() {
        this.dom = [];
        this.root = new Document$4(this.dom);
        this.done = false;
        this.tagStack = [this.root];
        this.lastNode = null;
        this.parser = null;
    }
    // Signals the handler that parsing is done
    onend() {
        if (this.done)
            return;
        this.done = true;
        this.parser = null;
        this.handleCallback(null);
    }
    onerror(error) {
        this.handleCallback(error);
    }
    onclosetag() {
        this.lastNode = null;
        const elem = this.tagStack.pop();
        if (this.options.withEndIndices) {
            elem.endIndex = this.parser.endIndex;
        }
        if (this.elementCB)
            this.elementCB(elem);
    }
    onopentag(name, attribs) {
        const type = this.options.xmlMode ? ElementType.Tag : undefined;
        const element = new Element(name, attribs, undefined, type);
        this.addNode(element);
        this.tagStack.push(element);
    }
    ontext(data) {
        const { lastNode } = this;
        if (lastNode && lastNode.type === ElementType.Text) {
            lastNode.data += data;
            if (this.options.withEndIndices) {
                lastNode.endIndex = this.parser.endIndex;
            }
        }
        else {
            const node = new Text(data);
            this.addNode(node);
            this.lastNode = node;
        }
    }
    oncomment(data) {
        if (this.lastNode && this.lastNode.type === ElementType.Comment) {
            this.lastNode.data += data;
            return;
        }
        const node = new Comment$5(data);
        this.addNode(node);
        this.lastNode = node;
    }
    oncommentend() {
        this.lastNode = null;
    }
    oncdatastart() {
        const text = new Text("");
        const node = new CDATA([text]);
        this.addNode(node);
        text.parent = node;
        this.lastNode = text;
    }
    oncdataend() {
        this.lastNode = null;
    }
    onprocessinginstruction(name, data) {
        const node = new ProcessingInstruction(name, data);
        this.addNode(node);
    }
    handleCallback(error) {
        if (typeof this.callback === "function") {
            this.callback(error, this.dom);
        }
        else if (error) {
            throw error;
        }
    }
    addNode(node) {
        const parent = this.tagStack[this.tagStack.length - 1];
        const previousSibling = parent.children[parent.children.length - 1];
        if (this.options.withStartIndices) {
            node.startIndex = this.parser.startIndex;
        }
        if (this.options.withEndIndices) {
            node.endIndex = this.parser.endIndex;
        }
        parent.children.push(node);
        if (previousSibling) {
            node.prev = previousSibling;
            previousSibling.next = node;
        }
        node.parent = parent;
        this.lastNode = null;
    }
}

const xmlReplacer = /["&'<>$\x80-\uFFFF]/g;
const xmlCodeMap = new Map([
    [34, "&quot;"],
    [38, "&amp;"],
    [39, "&apos;"],
    [60, "&lt;"],
    [62, "&gt;"],
]);
// For compatibility with node < 4, we wrap `codePointAt`
const getCodePoint = 
// eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
String.prototype.codePointAt != null
    ? (str, index) => str.codePointAt(index)
    : // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        (c, index) => (c.charCodeAt(index) & 0xfc00) === 0xd800
            ? (c.charCodeAt(index) - 0xd800) * 0x400 +
                c.charCodeAt(index + 1) -
                0xdc00 +
                0x10000
            : c.charCodeAt(index);
/**
 * Encodes all non-ASCII characters, as well as characters not valid in XML
 * documents using XML entities.
 *
 * If a character has no equivalent entity, a
 * numeric hexadecimal reference (eg. `&#xfc;`) will be used.
 */
function encodeXML(str) {
    let ret = "";
    let lastIdx = 0;
    let match;
    while ((match = xmlReplacer.exec(str)) !== null) {
        const i = match.index;
        const char = str.charCodeAt(i);
        const next = xmlCodeMap.get(char);
        if (next !== undefined) {
            ret += str.substring(lastIdx, i) + next;
            lastIdx = i + 1;
        }
        else {
            ret += `${str.substring(lastIdx, i)}&#x${getCodePoint(str, i).toString(16)};`;
            // Increase by 1 if we have a surrogate pair
            lastIdx = xmlReplacer.lastIndex += Number((char & 0xfc00) === 0xd800);
        }
    }
    return ret + str.substr(lastIdx);
}
/**
 * Creates a function that escapes all characters matched by the given regular
 * expression using the given map of characters to escape to their entities.
 *
 * @param regex Regular expression to match characters to escape.
 * @param map Map of characters to escape to their entities.
 *
 * @returns Function that escapes all characters matched by the given regular
 * expression using the given map of characters to escape to their entities.
 */
function getEscaper(regex, map) {
    return function escape(data) {
        let match;
        let lastIdx = 0;
        let result = "";
        while ((match = regex.exec(data))) {
            if (lastIdx !== match.index) {
                result += data.substring(lastIdx, match.index);
            }
            // We know that this character will be in the map.
            result += map.get(match[0].charCodeAt(0));
            // Every match will be of length 1
            lastIdx = match.index + 1;
        }
        return result + data.substring(lastIdx);
    };
}
/**
 * Encodes all characters that have to be escaped in HTML attributes,
 * following {@link https://html.spec.whatwg.org/multipage/parsing.html#escapingString}.
 *
 * @param data String to escape.
 */
const escapeAttribute = getEscaper(/["&\u00A0]/g, new Map([
    [34, "&quot;"],
    [38, "&amp;"],
    [160, "&nbsp;"],
]));
/**
 * Encodes all characters that have to be escaped in HTML text,
 * following {@link https://html.spec.whatwg.org/multipage/parsing.html#escapingString}.
 *
 * @param data String to escape.
 */
const escapeText = getEscaper(/[&<>\u00A0]/g, new Map([
    [38, "&amp;"],
    [60, "&lt;"],
    [62, "&gt;"],
    [160, "&nbsp;"],
]));

const elementNames = new Map([
    "altGlyph",
    "altGlyphDef",
    "altGlyphItem",
    "animateColor",
    "animateMotion",
    "animateTransform",
    "clipPath",
    "feBlend",
    "feColorMatrix",
    "feComponentTransfer",
    "feComposite",
    "feConvolveMatrix",
    "feDiffuseLighting",
    "feDisplacementMap",
    "feDistantLight",
    "feDropShadow",
    "feFlood",
    "feFuncA",
    "feFuncB",
    "feFuncG",
    "feFuncR",
    "feGaussianBlur",
    "feImage",
    "feMerge",
    "feMergeNode",
    "feMorphology",
    "feOffset",
    "fePointLight",
    "feSpecularLighting",
    "feSpotLight",
    "feTile",
    "feTurbulence",
    "foreignObject",
    "glyphRef",
    "linearGradient",
    "radialGradient",
    "textPath",
].map((val) => [val.toLowerCase(), val]));
const attributeNames = new Map([
    "definitionURL",
    "attributeName",
    "attributeType",
    "baseFrequency",
    "baseProfile",
    "calcMode",
    "clipPathUnits",
    "diffuseConstant",
    "edgeMode",
    "filterUnits",
    "glyphRef",
    "gradientTransform",
    "gradientUnits",
    "kernelMatrix",
    "kernelUnitLength",
    "keyPoints",
    "keySplines",
    "keyTimes",
    "lengthAdjust",
    "limitingConeAngle",
    "markerHeight",
    "markerUnits",
    "markerWidth",
    "maskContentUnits",
    "maskUnits",
    "numOctaves",
    "pathLength",
    "patternContentUnits",
    "patternTransform",
    "patternUnits",
    "pointsAtX",
    "pointsAtY",
    "pointsAtZ",
    "preserveAlpha",
    "preserveAspectRatio",
    "primitiveUnits",
    "refX",
    "refY",
    "repeatCount",
    "repeatDur",
    "requiredExtensions",
    "requiredFeatures",
    "specularConstant",
    "specularExponent",
    "spreadMethod",
    "startOffset",
    "stdDeviation",
    "stitchTiles",
    "surfaceScale",
    "systemLanguage",
    "tableValues",
    "targetX",
    "targetY",
    "textLength",
    "viewBox",
    "viewTarget",
    "xChannelSelector",
    "yChannelSelector",
    "zoomAndPan",
].map((val) => [val.toLowerCase(), val]));

/*
 * Module dependencies
 */
const unencodedElements = new Set([
    "style",
    "script",
    "xmp",
    "iframe",
    "noembed",
    "noframes",
    "plaintext",
    "noscript",
]);
function replaceQuotes(value) {
    return value.replace(/"/g, "&quot;");
}
/**
 * Format attributes
 */
function formatAttributes(attributes, opts) {
    var _a;
    if (!attributes)
        return;
    const encode = ((_a = opts.encodeEntities) !== null && _a !== void 0 ? _a : opts.decodeEntities) === false
        ? replaceQuotes
        : opts.xmlMode || opts.encodeEntities !== "utf8"
            ? encodeXML
            : escapeAttribute;
    return Object.keys(attributes)
        .map((key) => {
        var _a, _b;
        const value = (_a = attributes[key]) !== null && _a !== void 0 ? _a : "";
        if (opts.xmlMode === "foreign") {
            /* Fix up mixed-case attribute names */
            key = (_b = attributeNames.get(key)) !== null && _b !== void 0 ? _b : key;
        }
        if (!opts.emptyAttrs && !opts.xmlMode && value === "") {
            return key;
        }
        return `${key}="${encode(value)}"`;
    })
        .join(" ");
}
/**
 * Self-enclosing tags
 */
const singleTag = new Set([
    "area",
    "base",
    "basefont",
    "br",
    "col",
    "command",
    "embed",
    "frame",
    "hr",
    "img",
    "input",
    "isindex",
    "keygen",
    "link",
    "meta",
    "param",
    "source",
    "track",
    "wbr",
]);
/**
 * Renders a DOM node or an array of DOM nodes to a string.
 *
 * Can be thought of as the equivalent of the `outerHTML` of the passed node(s).
 *
 * @param node Node to be rendered.
 * @param options Changes serialization behavior
 */
function render(node, options = {}) {
    const nodes = "length" in node ? node : [node];
    let output = "";
    for (let i = 0; i < nodes.length; i++) {
        output += renderNode(nodes[i], options);
    }
    return output;
}
function renderNode(node, options) {
    switch (node.type) {
        case Root$7:
            return render(node.children, options);
        // @ts-expect-error We don't use `Doctype` yet
        case Doctype:
        case Directive:
            return renderDirective(node);
        case Comment$6:
            return renderComment(node);
        case CDATA$1:
            return renderCdata(node);
        case Script:
        case Style:
        case Tag:
            return renderTag(node, options);
        case Text$1:
            return renderText(node, options);
    }
}
const foreignModeIntegrationPoints = new Set([
    "mi",
    "mo",
    "mn",
    "ms",
    "mtext",
    "annotation-xml",
    "foreignObject",
    "desc",
    "title",
]);
const foreignElements = new Set(["svg", "math"]);
function renderTag(elem, opts) {
    var _a;
    // Handle SVG / MathML in HTML
    if (opts.xmlMode === "foreign") {
        /* Fix up mixed-case element names */
        elem.name = (_a = elementNames.get(elem.name)) !== null && _a !== void 0 ? _a : elem.name;
        /* Exit foreign mode at integration points */
        if (elem.parent &&
            foreignModeIntegrationPoints.has(elem.parent.name)) {
            opts = { ...opts, xmlMode: false };
        }
    }
    if (!opts.xmlMode && foreignElements.has(elem.name)) {
        opts = { ...opts, xmlMode: "foreign" };
    }
    let tag = `<${elem.name}`;
    const attribs = formatAttributes(elem.attribs, opts);
    if (attribs) {
        tag += ` ${attribs}`;
    }
    if (elem.children.length === 0 &&
        (opts.xmlMode
            ? // In XML mode or foreign mode, and user hasn't explicitly turned off self-closing tags
                opts.selfClosingTags !== false
            : // User explicitly asked for self-closing tags, even in HTML mode
                opts.selfClosingTags && singleTag.has(elem.name))) {
        if (!opts.xmlMode)
            tag += " ";
        tag += "/>";
    }
    else {
        tag += ">";
        if (elem.children.length > 0) {
            tag += render(elem.children, opts);
        }
        if (opts.xmlMode || !singleTag.has(elem.name)) {
            tag += `</${elem.name}>`;
        }
    }
    return tag;
}
function renderDirective(elem) {
    return `<${elem.data}>`;
}
function renderText(elem, opts) {
    var _a;
    let data = elem.data || "";
    // If entities weren't decoded, no need to encode them back
    if (((_a = opts.encodeEntities) !== null && _a !== void 0 ? _a : opts.decodeEntities) !== false &&
        !(!opts.xmlMode &&
            elem.parent &&
            unencodedElements.has(elem.parent.name))) {
        data =
            opts.xmlMode || opts.encodeEntities !== "utf8"
                ? encodeXML(data)
                : escapeText(data);
    }
    return data;
}
function renderCdata(elem) {
    return `<![CDATA[${elem.children[0].data}]]>`;
}
function renderComment(elem) {
    return `<!--${elem.data}-->`;
}

/**
 * @category Stringify
 * @deprecated Use the `dom-serializer` module directly.
 * @param node Node to get the outer HTML of.
 * @param options Options for serialization.
 * @returns `node`'s outer HTML.
 */
function getOuterHTML(node, options) {
    return render(node, options);
}
/**
 * @category Stringify
 * @deprecated Use the `dom-serializer` module directly.
 * @param node Node to get the inner HTML of.
 * @param options Options for serialization.
 * @returns `node`'s inner HTML.
 */
function getInnerHTML(node, options) {
    return hasChildren(node)
        ? node.children.map((node) => getOuterHTML(node, options)).join("")
        : "";
}
/**
 * Get a node's inner text. Same as `textContent`, but inserts newlines for `<br>` tags. Ignores comments.
 *
 * @category Stringify
 * @deprecated Use `textContent` instead.
 * @param node Node to get the inner text of.
 * @returns `node`'s inner text.
 */
function getText(node) {
    if (Array.isArray(node))
        return node.map(getText).join("");
    if (isTag(node))
        return node.name === "br" ? "\n" : getText(node.children);
    if (isCDATA(node))
        return getText(node.children);
    if (isText(node))
        return node.data;
    return "";
}
/**
 * Get a node's text content. Ignores comments.
 *
 * @category Stringify
 * @param node Node to get the text content of.
 * @returns `node`'s text content.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/Node/textContent}
 */
function textContent(node) {
    if (Array.isArray(node))
        return node.map(textContent).join("");
    if (hasChildren(node) && !isComment(node)) {
        return textContent(node.children);
    }
    if (isText(node))
        return node.data;
    return "";
}
/**
 * Get a node's inner text, ignoring `<script>` and `<style>` tags. Ignores comments.
 *
 * @category Stringify
 * @param node Node to get the inner text of.
 * @returns `node`'s inner text.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/Node/innerText}
 */
function innerText(node) {
    if (Array.isArray(node))
        return node.map(innerText).join("");
    if (hasChildren(node) && (node.type === ElementType.Tag || isCDATA(node))) {
        return innerText(node.children);
    }
    if (isText(node))
        return node.data;
    return "";
}

/**
 * Get a node's children.
 *
 * @category Traversal
 * @param elem Node to get the children of.
 * @returns `elem`'s children, or an empty array.
 */
function getChildren(elem) {
    return hasChildren(elem) ? elem.children : [];
}
/**
 * Get a node's parent.
 *
 * @category Traversal
 * @param elem Node to get the parent of.
 * @returns `elem`'s parent node, or `null` if `elem` is a root node.
 */
function getParent(elem) {
    return elem.parent || null;
}
/**
 * Gets an elements siblings, including the element itself.
 *
 * Attempts to get the children through the element's parent first. If we don't
 * have a parent (the element is a root node), we walk the element's `prev` &
 * `next` to get all remaining nodes.
 *
 * @category Traversal
 * @param elem Element to get the siblings of.
 * @returns `elem`'s siblings, including `elem`.
 */
function getSiblings(elem) {
    const parent = getParent(elem);
    if (parent != null)
        return getChildren(parent);
    const siblings = [elem];
    let { prev, next } = elem;
    while (prev != null) {
        siblings.unshift(prev);
        ({ prev } = prev);
    }
    while (next != null) {
        siblings.push(next);
        ({ next } = next);
    }
    return siblings;
}
/**
 * Gets an attribute from an element.
 *
 * @category Traversal
 * @param elem Element to check.
 * @param name Attribute name to retrieve.
 * @returns The element's attribute value, or `undefined`.
 */
function getAttributeValue(elem, name) {
    var _a;
    return (_a = elem.attribs) === null || _a === void 0 ? void 0 : _a[name];
}
/**
 * Checks whether an element has an attribute.
 *
 * @category Traversal
 * @param elem Element to check.
 * @param name Attribute name to look for.
 * @returns Returns whether `elem` has the attribute `name`.
 */
function hasAttrib(elem, name) {
    return (elem.attribs != null &&
        Object.prototype.hasOwnProperty.call(elem.attribs, name) &&
        elem.attribs[name] != null);
}
/**
 * Get the tag name of an element.
 *
 * @category Traversal
 * @param elem The element to get the name for.
 * @returns The tag name of `elem`.
 */
function getName(elem) {
    return elem.name;
}
/**
 * Returns the next element sibling of a node.
 *
 * @category Traversal
 * @param elem The element to get the next sibling of.
 * @returns `elem`'s next sibling that is a tag, or `null` if there is no next
 * sibling.
 */
function nextElementSibling(elem) {
    let { next } = elem;
    while (next !== null && !isTag(next))
        ({ next } = next);
    return next;
}
/**
 * Returns the previous element sibling of a node.
 *
 * @category Traversal
 * @param elem The element to get the previous sibling of.
 * @returns `elem`'s previous sibling that is a tag, or `null` if there is no
 * previous sibling.
 */
function prevElementSibling(elem) {
    let { prev } = elem;
    while (prev !== null && !isTag(prev))
        ({ prev } = prev);
    return prev;
}

/**
 * Remove an element from the dom
 *
 * @category Manipulation
 * @param elem The element to be removed
 */
function removeElement(elem) {
    if (elem.prev)
        elem.prev.next = elem.next;
    if (elem.next)
        elem.next.prev = elem.prev;
    if (elem.parent) {
        const childs = elem.parent.children;
        const childsIndex = childs.lastIndexOf(elem);
        if (childsIndex >= 0) {
            childs.splice(childsIndex, 1);
        }
    }
    elem.next = null;
    elem.prev = null;
    elem.parent = null;
}
/**
 * Replace an element in the dom
 *
 * @category Manipulation
 * @param elem The element to be replaced
 * @param replacement The element to be added
 */
function replaceElement(elem, replacement) {
    const prev = (replacement.prev = elem.prev);
    if (prev) {
        prev.next = replacement;
    }
    const next = (replacement.next = elem.next);
    if (next) {
        next.prev = replacement;
    }
    const parent = (replacement.parent = elem.parent);
    if (parent) {
        const childs = parent.children;
        childs[childs.lastIndexOf(elem)] = replacement;
        elem.parent = null;
    }
}
/**
 * Append a child to an element.
 *
 * @category Manipulation
 * @param parent The element to append to.
 * @param child The element to be added as a child.
 */
function appendChild(parent, child) {
    removeElement(child);
    child.next = null;
    child.parent = parent;
    if (parent.children.push(child) > 1) {
        const sibling = parent.children[parent.children.length - 2];
        sibling.next = child;
        child.prev = sibling;
    }
    else {
        child.prev = null;
    }
}
/**
 * Append an element after another.
 *
 * @category Manipulation
 * @param elem The element to append after.
 * @param next The element be added.
 */
function append(elem, next) {
    removeElement(next);
    const { parent } = elem;
    const currNext = elem.next;
    next.next = currNext;
    next.prev = elem;
    elem.next = next;
    next.parent = parent;
    if (currNext) {
        currNext.prev = next;
        if (parent) {
            const childs = parent.children;
            childs.splice(childs.lastIndexOf(currNext), 0, next);
        }
    }
    else if (parent) {
        parent.children.push(next);
    }
}
/**
 * Prepend a child to an element.
 *
 * @category Manipulation
 * @param parent The element to prepend before.
 * @param child The element to be added as a child.
 */
function prependChild(parent, child) {
    removeElement(child);
    child.parent = parent;
    child.prev = null;
    if (parent.children.unshift(child) !== 1) {
        const sibling = parent.children[1];
        sibling.prev = child;
        child.next = sibling;
    }
    else {
        child.next = null;
    }
}
/**
 * Prepend an element before another.
 *
 * @category Manipulation
 * @param elem The element to prepend before.
 * @param prev The element be added.
 */
function prepend(elem, prev) {
    removeElement(prev);
    const { parent } = elem;
    if (parent) {
        const childs = parent.children;
        childs.splice(childs.indexOf(elem), 0, prev);
    }
    if (elem.prev) {
        elem.prev.next = prev;
    }
    prev.parent = parent;
    prev.prev = elem.prev;
    prev.next = elem;
    elem.prev = prev;
}

/**
 * Search a node and its children for nodes passing a test function. If `node` is not an array, it will be wrapped in one.
 *
 * @category Querying
 * @param test Function to test nodes on.
 * @param node Node to search. Will be included in the result set if it matches.
 * @param recurse Also consider child nodes.
 * @param limit Maximum number of nodes to return.
 * @returns All nodes passing `test`.
 */
function filter$1(test, node, recurse = true, limit = Infinity) {
    return find(test, Array.isArray(node) ? node : [node], recurse, limit);
}
/**
 * Search an array of nodes and their children for nodes passing a test function.
 *
 * @category Querying
 * @param test Function to test nodes on.
 * @param nodes Array of nodes to search.
 * @param recurse Also consider child nodes.
 * @param limit Maximum number of nodes to return.
 * @returns All nodes passing `test`.
 */
function find(test, nodes, recurse, limit) {
    const result = [];
    /** Stack of the arrays we are looking at. */
    const nodeStack = [nodes];
    /** Stack of the indices within the arrays. */
    const indexStack = [0];
    for (;;) {
        // First, check if the current array has any more elements to look at.
        if (indexStack[0] >= nodeStack[0].length) {
            // If we have no more arrays to look at, we are done.
            if (indexStack.length === 1) {
                return result;
            }
            // Otherwise, remove the current array from the stack.
            nodeStack.shift();
            indexStack.shift();
            // Loop back to the start to continue with the next array.
            continue;
        }
        const elem = nodeStack[0][indexStack[0]++];
        if (test(elem)) {
            result.push(elem);
            if (--limit <= 0)
                return result;
        }
        if (recurse && hasChildren(elem) && elem.children.length > 0) {
            /*
             * Add the children to the stack. We are depth-first, so this is
             * the next array we look at.
             */
            indexStack.unshift(0);
            nodeStack.unshift(elem.children);
        }
    }
}
/**
 * Finds the first element inside of an array that matches a test function. This is an alias for `Array.prototype.find`.
 *
 * @category Querying
 * @param test Function to test nodes on.
 * @param nodes Array of nodes to search.
 * @returns The first node in the array that passes `test`.
 * @deprecated Use `Array.prototype.find` directly.
 */
function findOneChild(test, nodes) {
    return nodes.find(test);
}
/**
 * Finds one element in a tree that passes a test.
 *
 * @category Querying
 * @param test Function to test nodes on.
 * @param nodes Node or array of nodes to search.
 * @param recurse Also consider child nodes.
 * @returns The first node that passes `test`.
 */
function findOne(test, nodes, recurse = true) {
    let elem = null;
    for (let i = 0; i < nodes.length && !elem; i++) {
        const node = nodes[i];
        if (!isTag(node)) {
            continue;
        }
        else if (test(node)) {
            elem = node;
        }
        else if (recurse && node.children.length > 0) {
            elem = findOne(test, node.children, true);
        }
    }
    return elem;
}
/**
 * Checks if a tree of nodes contains at least one node passing a test.
 *
 * @category Querying
 * @param test Function to test nodes on.
 * @param nodes Array of nodes to search.
 * @returns Whether a tree of nodes contains at least one node passing the test.
 */
function existsOne(test, nodes) {
    return nodes.some((checked) => isTag(checked) &&
        (test(checked) || existsOne(test, checked.children)));
}
/**
 * Search an array of nodes and their children for elements passing a test function.
 *
 * Same as `find`, but limited to elements and with less options, leading to reduced complexity.
 *
 * @category Querying
 * @param test Function to test nodes on.
 * @param nodes Array of nodes to search.
 * @returns All nodes passing `test`.
 */
function findAll(test, nodes) {
    const result = [];
    const nodeStack = [nodes];
    const indexStack = [0];
    for (;;) {
        if (indexStack[0] >= nodeStack[0].length) {
            if (nodeStack.length === 1) {
                return result;
            }
            // Otherwise, remove the current array from the stack.
            nodeStack.shift();
            indexStack.shift();
            // Loop back to the start to continue with the next array.
            continue;
        }
        const elem = nodeStack[0][indexStack[0]++];
        if (!isTag(elem))
            continue;
        if (test(elem))
            result.push(elem);
        if (elem.children.length > 0) {
            indexStack.unshift(0);
            nodeStack.unshift(elem.children);
        }
    }
}

/**
 * A map of functions to check nodes against.
 */
const Checks = {
    tag_name(name) {
        if (typeof name === "function") {
            return (elem) => isTag(elem) && name(elem.name);
        }
        else if (name === "*") {
            return isTag;
        }
        return (elem) => isTag(elem) && elem.name === name;
    },
    tag_type(type) {
        if (typeof type === "function") {
            return (elem) => type(elem.type);
        }
        return (elem) => elem.type === type;
    },
    tag_contains(data) {
        if (typeof data === "function") {
            return (elem) => isText(elem) && data(elem.data);
        }
        return (elem) => isText(elem) && elem.data === data;
    },
};
/**
 * Returns a function to check whether a node has an attribute with a particular
 * value.
 *
 * @param attrib Attribute to check.
 * @param value Attribute value to look for.
 * @returns A function to check whether the a node has an attribute with a
 *   particular value.
 */
function getAttribCheck(attrib, value) {
    if (typeof value === "function") {
        return (elem) => isTag(elem) && value(elem.attribs[attrib]);
    }
    return (elem) => isTag(elem) && elem.attribs[attrib] === value;
}
/**
 * Returns a function that returns `true` if either of the input functions
 * returns `true` for a node.
 *
 * @param a First function to combine.
 * @param b Second function to combine.
 * @returns A function taking a node and returning `true` if either of the input
 *   functions returns `true` for the node.
 */
function combineFuncs(a, b) {
    return (elem) => a(elem) || b(elem);
}
/**
 * Returns a function that executes all checks in `options` and returns `true`
 * if any of them match a node.
 *
 * @param options An object describing nodes to look for.
 * @returns A function that executes all checks in `options` and returns `true`
 *   if any of them match a node.
 */
function compileTest(options) {
    const funcs = Object.keys(options).map((key) => {
        const value = options[key];
        return Object.prototype.hasOwnProperty.call(Checks, key)
            ? Checks[key](value)
            : getAttribCheck(key, value);
    });
    return funcs.length === 0 ? null : funcs.reduce(combineFuncs);
}
/**
 * Checks whether a node matches the description in `options`.
 *
 * @category Legacy Query Functions
 * @param options An object describing nodes to look for.
 * @param node The element to test.
 * @returns Whether the element matches the description in `options`.
 */
function testElement(options, node) {
    const test = compileTest(options);
    return test ? test(node) : true;
}
/**
 * Returns all nodes that match `options`.
 *
 * @category Legacy Query Functions
 * @param options An object describing nodes to look for.
 * @param nodes Nodes to search through.
 * @param recurse Also consider child nodes.
 * @param limit Maximum number of nodes to return.
 * @returns All nodes that match `options`.
 */
function getElements(options, nodes, recurse, limit = Infinity) {
    const test = compileTest(options);
    return test ? filter$1(test, nodes, recurse, limit) : [];
}
/**
 * Returns the node with the supplied ID.
 *
 * @category Legacy Query Functions
 * @param id The unique ID attribute value to look for.
 * @param nodes Nodes to search through.
 * @param recurse Also consider child nodes.
 * @returns The node with the supplied ID.
 */
function getElementById(id, nodes, recurse = true) {
    if (!Array.isArray(nodes))
        nodes = [nodes];
    return findOne(getAttribCheck("id", id), nodes, recurse);
}
/**
 * Returns all nodes with the supplied `tagName`.
 *
 * @category Legacy Query Functions
 * @param tagName Tag name to search for.
 * @param nodes Nodes to search through.
 * @param recurse Also consider child nodes.
 * @param limit Maximum number of nodes to return.
 * @returns All nodes with the supplied `tagName`.
 */
function getElementsByTagName(tagName, nodes, recurse = true, limit = Infinity) {
    return filter$1(Checks["tag_name"](tagName), nodes, recurse, limit);
}
/**
 * Returns all nodes with the supplied `type`.
 *
 * @category Legacy Query Functions
 * @param type Element type to look for.
 * @param nodes Nodes to search through.
 * @param recurse Also consider child nodes.
 * @param limit Maximum number of nodes to return.
 * @returns All nodes with the supplied `type`.
 */
function getElementsByTagType(type, nodes, recurse = true, limit = Infinity) {
    return filter$1(Checks["tag_type"](type), nodes, recurse, limit);
}

/**
 * Given an array of nodes, remove any member that is contained by another
 * member.
 *
 * @category Helpers
 * @param nodes Nodes to filter.
 * @returns Remaining nodes that aren't contained by other nodes.
 */
function removeSubsets(nodes) {
    let idx = nodes.length;
    /*
     * Check if each node (or one of its ancestors) is already contained in the
     * array.
     */
    while (--idx >= 0) {
        const node = nodes[idx];
        /*
         * Remove the node if it is not unique.
         * We are going through the array from the end, so we only
         * have to check nodes that preceed the node under consideration in the array.
         */
        if (idx > 0 && nodes.lastIndexOf(node, idx - 1) >= 0) {
            nodes.splice(idx, 1);
            continue;
        }
        for (let ancestor = node.parent; ancestor; ancestor = ancestor.parent) {
            if (nodes.includes(ancestor)) {
                nodes.splice(idx, 1);
                break;
            }
        }
    }
    return nodes;
}
/**
 * @category Helpers
 * @see {@link http://dom.spec.whatwg.org/#dom-node-comparedocumentposition}
 */
var DocumentPosition;
(function (DocumentPosition) {
    DocumentPosition[DocumentPosition["DISCONNECTED"] = 1] = "DISCONNECTED";
    DocumentPosition[DocumentPosition["PRECEDING"] = 2] = "PRECEDING";
    DocumentPosition[DocumentPosition["FOLLOWING"] = 4] = "FOLLOWING";
    DocumentPosition[DocumentPosition["CONTAINS"] = 8] = "CONTAINS";
    DocumentPosition[DocumentPosition["CONTAINED_BY"] = 16] = "CONTAINED_BY";
})(DocumentPosition || (DocumentPosition = {}));
/**
 * Compare the position of one node against another node in any other document,
 * returning a bitmask with the values from {@link DocumentPosition}.
 *
 * Document order:
 * > There is an ordering, document order, defined on all the nodes in the
 * > document corresponding to the order in which the first character of the
 * > XML representation of each node occurs in the XML representation of the
 * > document after expansion of general entities. Thus, the document element
 * > node will be the first node. Element nodes occur before their children.
 * > Thus, document order orders element nodes in order of the occurrence of
 * > their start-tag in the XML (after expansion of entities). The attribute
 * > nodes of an element occur after the element and before its children. The
 * > relative order of attribute nodes is implementation-dependent.
 *
 * Source:
 * http://www.w3.org/TR/DOM-Level-3-Core/glossary.html#dt-document-order
 *
 * @category Helpers
 * @param nodeA The first node to use in the comparison
 * @param nodeB The second node to use in the comparison
 * @returns A bitmask describing the input nodes' relative position.
 *
 * See http://dom.spec.whatwg.org/#dom-node-comparedocumentposition for
 * a description of these values.
 */
function compareDocumentPosition(nodeA, nodeB) {
    const aParents = [];
    const bParents = [];
    if (nodeA === nodeB) {
        return 0;
    }
    let current = hasChildren(nodeA) ? nodeA : nodeA.parent;
    while (current) {
        aParents.unshift(current);
        current = current.parent;
    }
    current = hasChildren(nodeB) ? nodeB : nodeB.parent;
    while (current) {
        bParents.unshift(current);
        current = current.parent;
    }
    const maxIdx = Math.min(aParents.length, bParents.length);
    let idx = 0;
    while (idx < maxIdx && aParents[idx] === bParents[idx]) {
        idx++;
    }
    if (idx === 0) {
        return DocumentPosition.DISCONNECTED;
    }
    const sharedParent = aParents[idx - 1];
    const siblings = sharedParent.children;
    const aSibling = aParents[idx];
    const bSibling = bParents[idx];
    if (siblings.indexOf(aSibling) > siblings.indexOf(bSibling)) {
        if (sharedParent === nodeB) {
            return DocumentPosition.FOLLOWING | DocumentPosition.CONTAINED_BY;
        }
        return DocumentPosition.FOLLOWING;
    }
    if (sharedParent === nodeA) {
        return DocumentPosition.PRECEDING | DocumentPosition.CONTAINS;
    }
    return DocumentPosition.PRECEDING;
}
/**
 * Sort an array of nodes based on their relative position in the document,
 * removing any duplicate nodes. If the array contains nodes that do not belong
 * to the same document, sort order is unspecified.
 *
 * @category Helpers
 * @param nodes Array of DOM nodes.
 * @returns Collection of unique nodes, sorted in document order.
 */
function uniqueSort(nodes) {
    nodes = nodes.filter((node, i, arr) => !arr.includes(node, i + 1));
    nodes.sort((a, b) => {
        const relative = compareDocumentPosition(a, b);
        if (relative & DocumentPosition.PRECEDING) {
            return -1;
        }
        else if (relative & DocumentPosition.FOLLOWING) {
            return 1;
        }
        return 0;
    });
    return nodes;
}

/**
 * Get the feed object from the root of a DOM tree.
 *
 * @category Feeds
 * @param doc - The DOM to to extract the feed from.
 * @returns The feed.
 */
function getFeed(doc) {
    const feedRoot = getOneElement(isValidFeed, doc);
    return !feedRoot
        ? null
        : feedRoot.name === "feed"
            ? getAtomFeed(feedRoot)
            : getRssFeed(feedRoot);
}
/**
 * Parse an Atom feed.
 *
 * @param feedRoot The root of the feed.
 * @returns The parsed feed.
 */
function getAtomFeed(feedRoot) {
    var _a;
    const childs = feedRoot.children;
    const feed = {
        type: "atom",
        items: getElementsByTagName("entry", childs).map((item) => {
            var _a;
            const { children } = item;
            const entry = { media: getMediaElements(children) };
            addConditionally(entry, "id", "id", children);
            addConditionally(entry, "title", "title", children);
            const href = (_a = getOneElement("link", children)) === null || _a === void 0 ? void 0 : _a.attribs["href"];
            if (href) {
                entry.link = href;
            }
            const description = fetch("summary", children) || fetch("content", children);
            if (description) {
                entry.description = description;
            }
            const pubDate = fetch("updated", children);
            if (pubDate) {
                entry.pubDate = new Date(pubDate);
            }
            return entry;
        }),
    };
    addConditionally(feed, "id", "id", childs);
    addConditionally(feed, "title", "title", childs);
    const href = (_a = getOneElement("link", childs)) === null || _a === void 0 ? void 0 : _a.attribs["href"];
    if (href) {
        feed.link = href;
    }
    addConditionally(feed, "description", "subtitle", childs);
    const updated = fetch("updated", childs);
    if (updated) {
        feed.updated = new Date(updated);
    }
    addConditionally(feed, "author", "email", childs, true);
    return feed;
}
/**
 * Parse a RSS feed.
 *
 * @param feedRoot The root of the feed.
 * @returns The parsed feed.
 */
function getRssFeed(feedRoot) {
    var _a, _b;
    const childs = (_b = (_a = getOneElement("channel", feedRoot.children)) === null || _a === void 0 ? void 0 : _a.children) !== null && _b !== void 0 ? _b : [];
    const feed = {
        type: feedRoot.name.substr(0, 3),
        id: "",
        items: getElementsByTagName("item", feedRoot.children).map((item) => {
            const { children } = item;
            const entry = { media: getMediaElements(children) };
            addConditionally(entry, "id", "guid", children);
            addConditionally(entry, "title", "title", children);
            addConditionally(entry, "link", "link", children);
            addConditionally(entry, "description", "description", children);
            const pubDate = fetch("pubDate", children) || fetch("dc:date", children);
            if (pubDate)
                entry.pubDate = new Date(pubDate);
            return entry;
        }),
    };
    addConditionally(feed, "title", "title", childs);
    addConditionally(feed, "link", "link", childs);
    addConditionally(feed, "description", "description", childs);
    const updated = fetch("lastBuildDate", childs);
    if (updated) {
        feed.updated = new Date(updated);
    }
    addConditionally(feed, "author", "managingEditor", childs, true);
    return feed;
}
const MEDIA_KEYS_STRING = ["url", "type", "lang"];
const MEDIA_KEYS_INT = [
    "fileSize",
    "bitrate",
    "framerate",
    "samplingrate",
    "channels",
    "duration",
    "height",
    "width",
];
/**
 * Get all media elements of a feed item.
 *
 * @param where Nodes to search in.
 * @returns Media elements.
 */
function getMediaElements(where) {
    return getElementsByTagName("media:content", where).map((elem) => {
        const { attribs } = elem;
        const media = {
            medium: attribs["medium"],
            isDefault: !!attribs["isDefault"],
        };
        for (const attrib of MEDIA_KEYS_STRING) {
            if (attribs[attrib]) {
                media[attrib] = attribs[attrib];
            }
        }
        for (const attrib of MEDIA_KEYS_INT) {
            if (attribs[attrib]) {
                media[attrib] = parseInt(attribs[attrib], 10);
            }
        }
        if (attribs["expression"]) {
            media.expression = attribs["expression"];
        }
        return media;
    });
}
/**
 * Get one element by tag name.
 *
 * @param tagName Tag name to look for
 * @param node Node to search in
 * @returns The element or null
 */
function getOneElement(tagName, node) {
    return getElementsByTagName(tagName, node, true, 1)[0];
}
/**
 * Get the text content of an element with a certain tag name.
 *
 * @param tagName Tag name to look for.
 * @param where Node to search in.
 * @param recurse Whether to recurse into child nodes.
 * @returns The text content of the element.
 */
function fetch(tagName, where, recurse = false) {
    return textContent(getElementsByTagName(tagName, where, recurse, 1)).trim();
}
/**
 * Adds a property to an object if it has a value.
 *
 * @param obj Object to be extended
 * @param prop Property name
 * @param tagName Tag name that contains the conditionally added property
 * @param where Element to search for the property
 * @param recurse Whether to recurse into child nodes.
 */
function addConditionally(obj, prop, tagName, where, recurse = false) {
    const val = fetch(tagName, where, recurse);
    if (val)
        obj[prop] = val;
}
/**
 * Checks if an element is a feed root node.
 *
 * @param value The name of the element to check.
 * @returns Whether an element is a feed root node.
 */
function isValidFeed(value) {
    return value === "rss" || value === "feed" || value === "rdf:RDF";
}

const index = /*#__PURE__*/Object.freeze({
  __proto__: null,
  isTag: isTag,
  isCDATA: isCDATA,
  isText: isText,
  isComment: isComment,
  isDocument: isDocument,
  hasChildren: hasChildren,
  getOuterHTML: getOuterHTML,
  getInnerHTML: getInnerHTML,
  getText: getText,
  textContent: textContent,
  innerText: innerText,
  getChildren: getChildren,
  getParent: getParent,
  getSiblings: getSiblings,
  getAttributeValue: getAttributeValue,
  hasAttrib: hasAttrib,
  getName: getName,
  nextElementSibling: nextElementSibling,
  prevElementSibling: prevElementSibling,
  removeElement: removeElement,
  replaceElement: replaceElement,
  appendChild: appendChild,
  append: append,
  prependChild: prependChild,
  prepend: prepend,
  filter: filter$1,
  find: find,
  findOneChild: findOneChild,
  findOne: findOne,
  existsOne: existsOne,
  findAll: findAll,
  testElement: testElement,
  getElements: getElements,
  getElementById: getElementById,
  getElementsByTagName: getElementsByTagName,
  getElementsByTagType: getElementsByTagType,
  removeSubsets: removeSubsets,
  get DocumentPosition () { return DocumentPosition; },
  compareDocumentPosition: compareDocumentPosition,
  uniqueSort: uniqueSort,
  getFeed: getFeed
});

// Helper methods
/**
 * Parses the data, returns the resulting document.
 *
 * @param data The data that should be parsed.
 * @param options Optional options for the parser and DOM builder.
 */
function parseDocument(data, options) {
    const handler = new DomHandler(undefined, options);
    new Parser$2(handler, options).end(data);
    return handler.root;
}
/**
 * Parses data, returns an array of the root nodes.
 *
 * Note that the root nodes still have a `Document` node as their parent.
 * Use `parseDocument` to get the `Document` node instead.
 *
 * @param data The data that should be parsed.
 * @param options Optional options for the parser and DOM builder.
 * @deprecated Use `parseDocument` instead.
 */
function parseDOM(data, options) {
    return parseDocument(data, options).children;
}
/**
 * Creates a parser instance, with an attached DOM handler.
 *
 * @param callback A callback that will be called once parsing has been completed.
 * @param options Optional options for the parser and DOM builder.
 * @param elementCallback An optional callback that will be called every time a tag has been completed inside of the DOM.
 */
function createDomStream(callback, options, elementCallback) {
    const handler = new DomHandler(callback, options, elementCallback);
    return new Parser$2(handler, options);
}
const parseFeedDefaultOptions = { xmlMode: true };
/**
 * Parse a feed.
 *
 * @param feed The feed that should be parsed, as a string.
 * @param options Optionally, options for parsing. When using this, you should set `xmlMode` to `true`.
 */
function parseFeed(feed, options = parseFeedDefaultOptions) {
    return getFeed(parseDOM(feed, options));
}

const esm = /*#__PURE__*/Object.freeze({
  __proto__: null,
  parseDocument: parseDocument,
  parseDOM: parseDOM,
  createDomStream: createDomStream,
  parseFeed: parseFeed,
  Parser: Parser$2,
  DomHandler: DomHandler,
  DefaultHandler: DomHandler,
  Tokenizer: Tokenizer,
  ElementType: index$1,
  getFeed: getFeed,
  DomUtils: index
});

const require$$0$1 = /*@__PURE__*/getAugmentedNamespace(esm);

var escapeStringRegexp$1 = string => {
	if (typeof string !== 'string') {
		throw new TypeError('Expected a string');
	}

	// Escape characters with special meaning either inside or outside character sets.
	// Use a simple backslash escape when it’s always valid, and a \unnnn escape when the simpler form would be disallowed by Unicode patterns’ stricter grammar.
	return string
		.replace(/[|\\{}()[\]^$+*?.]/g, '\\$&')
		.replace(/-/g, '\\x2d');
};

/*!
 * is-plain-object <https://github.com/jonschlinkert/is-plain-object>
 *
 * Copyright (c) 2014-2017, Jon Schlinkert.
 * Released under the MIT License.
 */

function isObject$1(o) {
  return Object.prototype.toString.call(o) === '[object Object]';
}

function isPlainObject$1(o) {
  var ctor,prot;

  if (isObject$1(o) === false) return false;

  // If has modified constructor
  ctor = o.constructor;
  if (ctor === undefined) return true;

  // If has modified prototype
  prot = ctor.prototype;
  if (isObject$1(prot) === false) return false;

  // If constructor does not have an Object-specific method
  if (prot.hasOwnProperty('isPrototypeOf') === false) {
    return false;
  }

  // Most likely a plain Object
  return true;
}

const isPlainObject$2 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  isPlainObject: isPlainObject$1
});

const require$$2$1 = /*@__PURE__*/getAugmentedNamespace(isPlainObject$2);

var isMergeableObject = function isMergeableObject(value) {
	return isNonNullObject(value)
		&& !isSpecial(value)
};

function isNonNullObject(value) {
	return !!value && typeof value === 'object'
}

function isSpecial(value) {
	var stringValue = Object.prototype.toString.call(value);

	return stringValue === '[object RegExp]'
		|| stringValue === '[object Date]'
		|| isReactElement(value)
}

// see https://github.com/facebook/react/blob/b5ac963fb791d1298e7f396236383bc955f916c1/src/isomorphic/classic/element/ReactElement.js#L21-L25
var canUseSymbol = typeof Symbol === 'function' && Symbol.for;
var REACT_ELEMENT_TYPE = canUseSymbol ? Symbol.for('react.element') : 0xeac7;

function isReactElement(value) {
	return value.$$typeof === REACT_ELEMENT_TYPE
}

function emptyTarget(val) {
	return Array.isArray(val) ? [] : {}
}

function cloneUnlessOtherwiseSpecified(value, options) {
	return (options.clone !== false && options.isMergeableObject(value))
		? deepmerge$1(emptyTarget(value), value, options)
		: value
}

function defaultArrayMerge(target, source, options) {
	return target.concat(source).map(function(element) {
		return cloneUnlessOtherwiseSpecified(element, options)
	})
}

function getMergeFunction(key, options) {
	if (!options.customMerge) {
		return deepmerge$1
	}
	var customMerge = options.customMerge(key);
	return typeof customMerge === 'function' ? customMerge : deepmerge$1
}

function getEnumerableOwnPropertySymbols(target) {
	return Object.getOwnPropertySymbols
		? Object.getOwnPropertySymbols(target).filter(function(symbol) {
			return Object.propertyIsEnumerable.call(target, symbol)
		})
		: []
}

function getKeys(target) {
	return Object.keys(target).concat(getEnumerableOwnPropertySymbols(target))
}

function propertyIsOnObject(object, property) {
	try {
		return property in object
	} catch(_) {
		return false
	}
}

// Protects from prototype poisoning and unexpected merging up the prototype chain.
function propertyIsUnsafe(target, key) {
	return propertyIsOnObject(target, key) // Properties are safe to merge if they don't exist in the target yet,
		&& !(Object.hasOwnProperty.call(target, key) // unsafe if they exist up the prototype chain,
			&& Object.propertyIsEnumerable.call(target, key)) // and also unsafe if they're nonenumerable.
}

function mergeObject(target, source, options) {
	var destination = {};
	if (options.isMergeableObject(target)) {
		getKeys(target).forEach(function(key) {
			destination[key] = cloneUnlessOtherwiseSpecified(target[key], options);
		});
	}
	getKeys(source).forEach(function(key) {
		if (propertyIsUnsafe(target, key)) {
			return
		}

		if (propertyIsOnObject(target, key) && options.isMergeableObject(source[key])) {
			destination[key] = getMergeFunction(key, options)(target[key], source[key], options);
		} else {
			destination[key] = cloneUnlessOtherwiseSpecified(source[key], options);
		}
	});
	return destination
}

function deepmerge$1(target, source, options) {
	options = options || {};
	options.arrayMerge = options.arrayMerge || defaultArrayMerge;
	options.isMergeableObject = options.isMergeableObject || isMergeableObject;
	// cloneUnlessOtherwiseSpecified is added to `options` so that custom arrayMerge()
	// implementations can use it. The caller may not replace it.
	options.cloneUnlessOtherwiseSpecified = cloneUnlessOtherwiseSpecified;

	var sourceIsArray = Array.isArray(source);
	var targetIsArray = Array.isArray(target);
	var sourceAndTargetTypesMatch = sourceIsArray === targetIsArray;

	if (!sourceAndTargetTypesMatch) {
		return cloneUnlessOtherwiseSpecified(source, options)
	} else if (sourceIsArray) {
		return options.arrayMerge(target, source, options)
	} else {
		return mergeObject(target, source, options)
	}
}

deepmerge$1.all = function deepmergeAll(array, options) {
	if (!Array.isArray(array)) {
		throw new Error('first argument should be an array')
	}

	return array.reduce(function(prev, next) {
		return deepmerge$1(prev, next, options)
	}, {})
};

var deepmerge_1 = deepmerge$1;

var cjs = deepmerge_1;

var parseSrcset$1 = {exports: {}};

/**
 * Srcset Parser
 *
 * By Alex Bell |  MIT License
 *
 * JS Parser for the string value that appears in markup <img srcset="here">
 *
 * @returns Array [{url: _, d: _, w: _, h:_}, ...]
 *
 * Based super duper closely on the reference algorithm at:
 * https://html.spec.whatwg.org/multipage/embedded-content.html#parse-a-srcset-attribute
 *
 * Most comments are copied in directly from the spec
 * (except for comments in parens).
 */

(function (module) {
(function (root, factory) {
	if (module.exports) {
		// Node. Does not work with strict CommonJS, but
		// only CommonJS-like environments that support module.exports,
		// like Node.
		module.exports = factory();
	} else {
		// Browser globals (root is window)
		root.parseSrcset = factory();
	}
}(commonjsGlobal, function () {

	// 1. Let input be the value passed to this algorithm.
	return function (input) {

		// UTILITY FUNCTIONS

		// Manual is faster than RegEx
		// http://bjorn.tipling.com/state-and-regular-expressions-in-javascript
		// http://jsperf.com/whitespace-character/5
		function isSpace(c) {
			return (c === "\u0020" || // space
			c === "\u0009" || // horizontal tab
			c === "\u000A" || // new line
			c === "\u000C" || // form feed
			c === "\u000D");  // carriage return
		}

		function collectCharacters(regEx) {
			var chars,
				match = regEx.exec(input.substring(pos));
			if (match) {
				chars = match[ 0 ];
				pos += chars.length;
				return chars;
			}
		}

		var inputLength = input.length,

			// (Don't use \s, to avoid matching non-breaking space)
			regexLeadingSpaces = /^[ \t\n\r\u000c]+/,
			regexLeadingCommasOrSpaces = /^[, \t\n\r\u000c]+/,
			regexLeadingNotSpaces = /^[^ \t\n\r\u000c]+/,
			regexTrailingCommas = /[,]+$/,
			regexNonNegativeInteger = /^\d+$/,

			// ( Positive or negative or unsigned integers or decimals, without or without exponents.
			// Must include at least one digit.
			// According to spec tests any decimal point must be followed by a digit.
			// No leading plus sign is allowed.)
			// https://html.spec.whatwg.org/multipage/infrastructure.html#valid-floating-point-number
			regexFloatingPoint = /^-?(?:[0-9]+|[0-9]*\.[0-9]+)(?:[eE][+-]?[0-9]+)?$/,

			url,
			descriptors,
			currentDescriptor,
			state,
			c,

			// 2. Let position be a pointer into input, initially pointing at the start
			//    of the string.
			pos = 0,

			// 3. Let candidates be an initially empty source set.
			candidates = [];

		// 4. Splitting loop: Collect a sequence of characters that are space
		//    characters or U+002C COMMA characters. If any U+002C COMMA characters
		//    were collected, that is a parse error.
		while (true) {
			collectCharacters(regexLeadingCommasOrSpaces);

			// 5. If position is past the end of input, return candidates and abort these steps.
			if (pos >= inputLength) {
				return candidates; // (we're done, this is the sole return path)
			}

			// 6. Collect a sequence of characters that are not space characters,
			//    and let that be url.
			url = collectCharacters(regexLeadingNotSpaces);

			// 7. Let descriptors be a new empty list.
			descriptors = [];

			// 8. If url ends with a U+002C COMMA character (,), follow these substeps:
			//		(1). Remove all trailing U+002C COMMA characters from url. If this removed
			//         more than one character, that is a parse error.
			if (url.slice(-1) === ",") {
				url = url.replace(regexTrailingCommas, "");
				// (Jump ahead to step 9 to skip tokenization and just push the candidate).
				parseDescriptors();

				//	Otherwise, follow these substeps:
			} else {
				tokenize();
			} // (close else of step 8)

			// 16. Return to the step labeled splitting loop.
		} // (Close of big while loop.)

		/**
		 * Tokenizes descriptor properties prior to parsing
		 * Returns undefined.
		 */
		function tokenize() {

			// 8.1. Descriptor tokeniser: Skip whitespace
			collectCharacters(regexLeadingSpaces);

			// 8.2. Let current descriptor be the empty string.
			currentDescriptor = "";

			// 8.3. Let state be in descriptor.
			state = "in descriptor";

			while (true) {

				// 8.4. Let c be the character at position.
				c = input.charAt(pos);

				//  Do the following depending on the value of state.
				//  For the purpose of this step, "EOF" is a special character representing
				//  that position is past the end of input.

				// In descriptor
				if (state === "in descriptor") {
					// Do the following, depending on the value of c:

					// Space character
					// If current descriptor is not empty, append current descriptor to
					// descriptors and let current descriptor be the empty string.
					// Set state to after descriptor.
					if (isSpace(c)) {
						if (currentDescriptor) {
							descriptors.push(currentDescriptor);
							currentDescriptor = "";
							state = "after descriptor";
						}

						// U+002C COMMA (,)
						// Advance position to the next character in input. If current descriptor
						// is not empty, append current descriptor to descriptors. Jump to the step
						// labeled descriptor parser.
					} else if (c === ",") {
						pos += 1;
						if (currentDescriptor) {
							descriptors.push(currentDescriptor);
						}
						parseDescriptors();
						return;

						// U+0028 LEFT PARENTHESIS (()
						// Append c to current descriptor. Set state to in parens.
					} else if (c === "\u0028") {
						currentDescriptor = currentDescriptor + c;
						state = "in parens";

						// EOF
						// If current descriptor is not empty, append current descriptor to
						// descriptors. Jump to the step labeled descriptor parser.
					} else if (c === "") {
						if (currentDescriptor) {
							descriptors.push(currentDescriptor);
						}
						parseDescriptors();
						return;

						// Anything else
						// Append c to current descriptor.
					} else {
						currentDescriptor = currentDescriptor + c;
					}
					// (end "in descriptor"

					// In parens
				} else if (state === "in parens") {

					// U+0029 RIGHT PARENTHESIS ())
					// Append c to current descriptor. Set state to in descriptor.
					if (c === ")") {
						currentDescriptor = currentDescriptor + c;
						state = "in descriptor";

						// EOF
						// Append current descriptor to descriptors. Jump to the step labeled
						// descriptor parser.
					} else if (c === "") {
						descriptors.push(currentDescriptor);
						parseDescriptors();
						return;

						// Anything else
						// Append c to current descriptor.
					} else {
						currentDescriptor = currentDescriptor + c;
					}

					// After descriptor
				} else if (state === "after descriptor") {

					// Do the following, depending on the value of c:
					// Space character: Stay in this state.
					if (isSpace(c)) ; else if (c === "") {
						parseDescriptors();
						return;

						// Anything else
						// Set state to in descriptor. Set position to the previous character in input.
					} else {
						state = "in descriptor";
						pos -= 1;

					}
				}

				// Advance position to the next character in input.
				pos += 1;

				// Repeat this step.
			} // (close while true loop)
		}

		/**
		 * Adds descriptor properties to a candidate, pushes to the candidates array
		 * @return undefined
		 */
		// Declared outside of the while loop so that it's only created once.
		function parseDescriptors() {

			// 9. Descriptor parser: Let error be no.
			var pError = false,

				// 10. Let width be absent.
				// 11. Let density be absent.
				// 12. Let future-compat-h be absent. (We're implementing it now as h)
				w, d, h, i,
				candidate = {},
				desc, lastChar, value, intVal, floatVal;

			// 13. For each descriptor in descriptors, run the appropriate set of steps
			// from the following list:
			for (i = 0 ; i < descriptors.length; i++) {
				desc = descriptors[ i ];

				lastChar = desc[ desc.length - 1 ];
				value = desc.substring(0, desc.length - 1);
				intVal = parseInt(value, 10);
				floatVal = parseFloat(value);

				// If the descriptor consists of a valid non-negative integer followed by
				// a U+0077 LATIN SMALL LETTER W character
				if (regexNonNegativeInteger.test(value) && (lastChar === "w")) {

					// If width and density are not both absent, then let error be yes.
					if (w || d) {pError = true;}

					// Apply the rules for parsing non-negative integers to the descriptor.
					// If the result is zero, let error be yes.
					// Otherwise, let width be the result.
					if (intVal === 0) {pError = true;} else {w = intVal;}

					// If the descriptor consists of a valid floating-point number followed by
					// a U+0078 LATIN SMALL LETTER X character
				} else if (regexFloatingPoint.test(value) && (lastChar === "x")) {

					// If width, density and future-compat-h are not all absent, then let error
					// be yes.
					if (w || d || h) {pError = true;}

					// Apply the rules for parsing floating-point number values to the descriptor.
					// If the result is less than zero, let error be yes. Otherwise, let density
					// be the result.
					if (floatVal < 0) {pError = true;} else {d = floatVal;}

					// If the descriptor consists of a valid non-negative integer followed by
					// a U+0068 LATIN SMALL LETTER H character
				} else if (regexNonNegativeInteger.test(value) && (lastChar === "h")) {

					// If height and density are not both absent, then let error be yes.
					if (h || d) {pError = true;}

					// Apply the rules for parsing non-negative integers to the descriptor.
					// If the result is zero, let error be yes. Otherwise, let future-compat-h
					// be the result.
					if (intVal === 0) {pError = true;} else {h = intVal;}

					// Anything else, Let error be yes.
				} else {pError = true;}
			} // (close step 13 for loop)

			// 15. If error is still no, then append a new image source to candidates whose
			// URL is url, associated with a width width if not absent and a pixel
			// density density if not absent. Otherwise, there is a parse error.
			if (!pError) {
				candidate.url = url;
				if (w) { candidate.w = w;}
				if (d) { candidate.d = d;}
				if (h) { candidate.h = h;}
				candidates.push(candidate);
			} else if (console && console.log) {
				console.log("Invalid srcset descriptor found in '" +
					input + "' at '" + desc + "'.");
			}
		} // (close parseDescriptors fn)

	}
}));
}(parseSrcset$1));

// for now just expose the builtin process global from node.js
var process = commonjsGlobal.process;

var picocolors_browser = {exports: {}};

var x=String;
var create=function() {return {isColorSupported:false,reset:x,bold:x,dim:x,italic:x,underline:x,inverse:x,hidden:x,strikethrough:x,black:x,red:x,green:x,yellow:x,blue:x,magenta:x,cyan:x,white:x,gray:x,bgBlack:x,bgRed:x,bgGreen:x,bgYellow:x,bgBlue:x,bgMagenta:x,bgCyan:x,bgWhite:x,blackBright:x,redBright:x,greenBright:x,yellowBright:x,blueBright:x,magentaBright:x,cyanBright:x,whiteBright:x,bgBlackBright:x,bgRedBright:x,bgGreenBright:x,bgYellowBright:x,bgBlueBright:x,bgMagentaBright:x,bgCyanBright:x,bgWhiteBright:x}};
picocolors_browser.exports=create();
picocolors_browser.exports.createColors = create;

const _nodeResolve_empty = {};

const _nodeResolve_empty$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  'default': _nodeResolve_empty
});

const require$$2 = /*@__PURE__*/getAugmentedNamespace(_nodeResolve_empty$1);

let pico = picocolors_browser.exports;

let terminalHighlight$1 = require$$2;

class CssSyntaxError$3 extends Error {
  constructor(message, line, column, source, file, plugin) {
    super(message);
    this.name = 'CssSyntaxError';
    this.reason = message;

    if (file) {
      this.file = file;
    }
    if (source) {
      this.source = source;
    }
    if (plugin) {
      this.plugin = plugin;
    }
    if (typeof line !== 'undefined' && typeof column !== 'undefined') {
      if (typeof line === 'number') {
        this.line = line;
        this.column = column;
      } else {
        this.line = line.line;
        this.column = line.column;
        this.endLine = column.line;
        this.endColumn = column.column;
      }
    }

    this.setMessage();

    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, CssSyntaxError$3);
    }
  }

  setMessage() {
    this.message = this.plugin ? this.plugin + ': ' : '';
    this.message += this.file ? this.file : '<css input>';
    if (typeof this.line !== 'undefined') {
      this.message += ':' + this.line + ':' + this.column;
    }
    this.message += ': ' + this.reason;
  }

  showSourceCode(color) {
    if (!this.source) return ''

    let css = this.source;
    if (color == null) color = pico.isColorSupported;

    let aside = text => text;
    let mark = text => text;
    let highlight = text => text;
    if (color) {
      let { bold, gray, red } = pico.createColors(true);
      mark = text => bold(red(text));
      aside = text => gray(text);
      if (terminalHighlight$1) {
        highlight = text => terminalHighlight$1(text);
      }
    }

    let lines = css.split(/\r?\n/);
    let start = Math.max(this.line - 3, 0);
    let end = Math.min(this.line + 2, lines.length);
    let maxWidth = String(end).length;

    return lines
      .slice(start, end)
      .map((line, index) => {
        let number = start + 1 + index;
        let gutter = ' ' + (' ' + number).slice(-maxWidth) + ' | ';
        if (number === this.line) {
          if (line.length > 160) {
            let padding = 20;
            let subLineStart = Math.max(0, this.column - padding);
            let subLineEnd = Math.max(
              this.column + padding,
              this.endColumn + padding
            );
            let subLine = line.slice(subLineStart, subLineEnd);

            let spacing =
              aside(gutter.replace(/\d/g, ' ')) +
              line
                .slice(0, Math.min(this.column - 1, padding - 1))
                .replace(/[^\t]/g, ' ');

            return (
              mark('>') +
              aside(gutter) +
              highlight(subLine) +
              '\n ' +
              spacing +
              mark('^')
            )
          }

          let spacing =
            aside(gutter.replace(/\d/g, ' ')) +
            line.slice(0, this.column - 1).replace(/[^\t]/g, ' ');

          return (
            mark('>') +
            aside(gutter) +
            highlight(line) +
            '\n ' +
            spacing +
            mark('^')
          )
        }

        return ' ' + aside(gutter) + highlight(line)
      })
      .join('\n')
  }

  toString() {
    let code = this.showSourceCode();
    if (code) {
      code = '\n\n' + code + '\n';
    }
    return this.name + ': ' + this.message + code
  }
}

var cssSyntaxError = CssSyntaxError$3;
CssSyntaxError$3.default = CssSyntaxError$3;

const DEFAULT_RAW = {
  after: '\n',
  beforeClose: '\n',
  beforeComment: '\n',
  beforeDecl: '\n',
  beforeOpen: ' ',
  beforeRule: '\n',
  colon: ': ',
  commentLeft: ' ',
  commentRight: ' ',
  emptyBody: '',
  indent: '    ',
  semicolon: false
};

function capitalize(str) {
  return str[0].toUpperCase() + str.slice(1)
}

class Stringifier$2 {
  constructor(builder) {
    this.builder = builder;
  }

  atrule(node, semicolon) {
    let name = '@' + node.name;
    let params = node.params ? this.rawValue(node, 'params') : '';

    if (typeof node.raws.afterName !== 'undefined') {
      name += node.raws.afterName;
    } else if (params) {
      name += ' ';
    }

    if (node.nodes) {
      this.block(node, name + params);
    } else {
      let end = (node.raws.between || '') + (semicolon ? ';' : '');
      this.builder(name + params + end, node);
    }
  }

  beforeAfter(node, detect) {
    let value;
    if (node.type === 'decl') {
      value = this.raw(node, null, 'beforeDecl');
    } else if (node.type === 'comment') {
      value = this.raw(node, null, 'beforeComment');
    } else if (detect === 'before') {
      value = this.raw(node, null, 'beforeRule');
    } else {
      value = this.raw(node, null, 'beforeClose');
    }

    let buf = node.parent;
    let depth = 0;
    while (buf && buf.type !== 'root') {
      depth += 1;
      buf = buf.parent;
    }

    if (value.includes('\n')) {
      let indent = this.raw(node, null, 'indent');
      if (indent.length) {
        for (let step = 0; step < depth; step++) value += indent;
      }
    }

    return value
  }

  block(node, start) {
    let between = this.raw(node, 'between', 'beforeOpen');
    this.builder(start + between + '{', node, 'start');

    let after;
    if (node.nodes && node.nodes.length) {
      this.body(node);
      after = this.raw(node, 'after');
    } else {
      after = this.raw(node, 'after', 'emptyBody');
    }

    if (after) this.builder(after);
    this.builder('}', node, 'end');
  }

  body(node) {
    let last = node.nodes.length - 1;
    while (last > 0) {
      if (node.nodes[last].type !== 'comment') break
      last -= 1;
    }

    let semicolon = this.raw(node, 'semicolon');
    for (let i = 0; i < node.nodes.length; i++) {
      let child = node.nodes[i];
      let before = this.raw(child, 'before');
      if (before) this.builder(before);
      this.stringify(child, last !== i || semicolon);
    }
  }

  comment(node) {
    let left = this.raw(node, 'left', 'commentLeft');
    let right = this.raw(node, 'right', 'commentRight');
    this.builder('/*' + left + node.text + right + '*/', node);
  }

  decl(node, semicolon) {
    let between = this.raw(node, 'between', 'colon');
    let string = node.prop + between + this.rawValue(node, 'value');

    if (node.important) {
      string += node.raws.important || ' !important';
    }

    if (semicolon) string += ';';
    this.builder(string, node);
  }

  document(node) {
    this.body(node);
  }

  raw(node, own, detect) {
    let value;
    if (!detect) detect = own;

    // Already had
    if (own) {
      value = node.raws[own];
      if (typeof value !== 'undefined') return value
    }

    let parent = node.parent;

    if (detect === 'before') {
      // Hack for first rule in CSS
      if (!parent || (parent.type === 'root' && parent.first === node)) {
        return ''
      }

      // `root` nodes in `document` should use only their own raws
      if (parent && parent.type === 'document') {
        return ''
      }
    }

    // Floating child without parent
    if (!parent) return DEFAULT_RAW[detect]

    // Detect style by other nodes
    let root = node.root();
    if (!root.rawCache) root.rawCache = {};
    if (typeof root.rawCache[detect] !== 'undefined') {
      return root.rawCache[detect]
    }

    if (detect === 'before' || detect === 'after') {
      return this.beforeAfter(node, detect)
    } else {
      let method = 'raw' + capitalize(detect);
      if (this[method]) {
        value = this[method](root, node);
      } else {
        root.walk(i => {
          value = i.raws[own];
          if (typeof value !== 'undefined') return false
        });
      }
    }

    if (typeof value === 'undefined') value = DEFAULT_RAW[detect];

    root.rawCache[detect] = value;
    return value
  }

  rawBeforeClose(root) {
    let value;
    root.walk(i => {
      if (i.nodes && i.nodes.length > 0) {
        if (typeof i.raws.after !== 'undefined') {
          value = i.raws.after;
          if (value.includes('\n')) {
            value = value.replace(/[^\n]+$/, '');
          }
          return false
        }
      }
    });
    if (value) value = value.replace(/\S/g, '');
    return value
  }

  rawBeforeComment(root, node) {
    let value;
    root.walkComments(i => {
      if (typeof i.raws.before !== 'undefined') {
        value = i.raws.before;
        if (value.includes('\n')) {
          value = value.replace(/[^\n]+$/, '');
        }
        return false
      }
    });
    if (typeof value === 'undefined') {
      value = this.raw(node, null, 'beforeDecl');
    } else if (value) {
      value = value.replace(/\S/g, '');
    }
    return value
  }

  rawBeforeDecl(root, node) {
    let value;
    root.walkDecls(i => {
      if (typeof i.raws.before !== 'undefined') {
        value = i.raws.before;
        if (value.includes('\n')) {
          value = value.replace(/[^\n]+$/, '');
        }
        return false
      }
    });
    if (typeof value === 'undefined') {
      value = this.raw(node, null, 'beforeRule');
    } else if (value) {
      value = value.replace(/\S/g, '');
    }
    return value
  }

  rawBeforeOpen(root) {
    let value;
    root.walk(i => {
      if (i.type !== 'decl') {
        value = i.raws.between;
        if (typeof value !== 'undefined') return false
      }
    });
    return value
  }

  rawBeforeRule(root) {
    let value;
    root.walk(i => {
      if (i.nodes && (i.parent !== root || root.first !== i)) {
        if (typeof i.raws.before !== 'undefined') {
          value = i.raws.before;
          if (value.includes('\n')) {
            value = value.replace(/[^\n]+$/, '');
          }
          return false
        }
      }
    });
    if (value) value = value.replace(/\S/g, '');
    return value
  }

  rawColon(root) {
    let value;
    root.walkDecls(i => {
      if (typeof i.raws.between !== 'undefined') {
        value = i.raws.between.replace(/[^\s:]/g, '');
        return false
      }
    });
    return value
  }

  rawEmptyBody(root) {
    let value;
    root.walk(i => {
      if (i.nodes && i.nodes.length === 0) {
        value = i.raws.after;
        if (typeof value !== 'undefined') return false
      }
    });
    return value
  }

  rawIndent(root) {
    if (root.raws.indent) return root.raws.indent
    let value;
    root.walk(i => {
      let p = i.parent;
      if (p && p !== root && p.parent && p.parent === root) {
        if (typeof i.raws.before !== 'undefined') {
          let parts = i.raws.before.split('\n');
          value = parts[parts.length - 1];
          value = value.replace(/\S/g, '');
          return false
        }
      }
    });
    return value
  }

  rawSemicolon(root) {
    let value;
    root.walk(i => {
      if (i.nodes && i.nodes.length && i.last.type === 'decl') {
        value = i.raws.semicolon;
        if (typeof value !== 'undefined') return false
      }
    });
    return value
  }

  rawValue(node, prop) {
    let value = node[prop];
    let raw = node.raws[prop];
    if (raw && raw.value === value) {
      return raw.raw
    }

    return value
  }

  root(node) {
    this.body(node);
    if (node.raws.after) this.builder(node.raws.after);
  }

  rule(node) {
    this.block(node, this.rawValue(node, 'selector'));
    if (node.raws.ownSemicolon) {
      this.builder(node.raws.ownSemicolon, node, 'end');
    }
  }

  stringify(node, semicolon) {
    /* c8 ignore start */
    if (!this[node.type]) {
      throw new Error(
        'Unknown AST node type ' +
          node.type +
          '. ' +
          'Maybe you need to change PostCSS stringifier.'
      )
    }
    /* c8 ignore stop */
    this[node.type](node, semicolon);
  }
}

var stringifier = Stringifier$2;
Stringifier$2.default = Stringifier$2;

let Stringifier$1 = stringifier;

function stringify$4(node, builder) {
  let str = new Stringifier$1(builder);
  str.stringify(node);
}

var stringify_1 = stringify$4;
stringify$4.default = stringify$4;

var symbols = {};

symbols.isClean = Symbol('isClean');

symbols.my = Symbol('my');

let CssSyntaxError$2 = cssSyntaxError;
let Stringifier = stringifier;
let stringify$3 = stringify_1;
let { isClean: isClean$2, my: my$2 } = symbols;

function cloneNode(obj, parent) {
  let cloned = new obj.constructor();

  for (let i in obj) {
    if (!Object.prototype.hasOwnProperty.call(obj, i)) {
      /* c8 ignore next 2 */
      continue
    }
    if (i === 'proxyCache') continue
    let value = obj[i];
    let type = typeof value;

    if (i === 'parent' && type === 'object') {
      if (parent) cloned[i] = parent;
    } else if (i === 'source') {
      cloned[i] = value;
    } else if (Array.isArray(value)) {
      cloned[i] = value.map(j => cloneNode(j, cloned));
    } else {
      if (type === 'object' && value !== null) value = cloneNode(value);
      cloned[i] = value;
    }
  }

  return cloned
}

function sourceOffset(inputCSS, position) {
  // Not all custom syntaxes support `offset` in `source.start` and `source.end`
  if (
    position &&
    typeof position.offset !== 'undefined'
  ) {
    return position.offset;
  }

  let column = 1;
  let line = 1;
  let offset = 0;

  for (let i = 0; i < inputCSS.length; i++) {
    if (line === position.line && column === position.column) {
      offset = i;
      break
    }

    if (inputCSS[i] === '\n') {
      column = 1;
      line += 1;
    } else {
      column += 1;
    }
  }

  return offset
}

class Node$4 {
  get proxyOf() {
    return this
  }

  constructor(defaults = {}) {
    this.raws = {};
    this[isClean$2] = false;
    this[my$2] = true;

    for (let name in defaults) {
      if (name === 'nodes') {
        this.nodes = [];
        for (let node of defaults[name]) {
          if (typeof node.clone === 'function') {
            this.append(node.clone());
          } else {
            this.append(node);
          }
        }
      } else {
        this[name] = defaults[name];
      }
    }
  }

  addToError(error) {
    error.postcssNode = this;
    if (error.stack && this.source && /\n\s{4}at /.test(error.stack)) {
      let s = this.source;
      error.stack = error.stack.replace(
        /\n\s{4}at /,
        `$&${s.input.from}:${s.start.line}:${s.start.column}$&`
      );
    }
    return error
  }

  after(add) {
    this.parent.insertAfter(this, add);
    return this
  }

  assign(overrides = {}) {
    for (let name in overrides) {
      this[name] = overrides[name];
    }
    return this
  }

  before(add) {
    this.parent.insertBefore(this, add);
    return this
  }

  cleanRaws(keepBetween) {
    delete this.raws.before;
    delete this.raws.after;
    if (!keepBetween) delete this.raws.between;
  }

  clone(overrides = {}) {
    let cloned = cloneNode(this);
    for (let name in overrides) {
      cloned[name] = overrides[name];
    }
    return cloned
  }

  cloneAfter(overrides = {}) {
    let cloned = this.clone(overrides);
    this.parent.insertAfter(this, cloned);
    return cloned
  }

  cloneBefore(overrides = {}) {
    let cloned = this.clone(overrides);
    this.parent.insertBefore(this, cloned);
    return cloned
  }

  error(message, opts = {}) {
    if (this.source) {
      let { end, start } = this.rangeBy(opts);
      return this.source.input.error(
        message,
        { column: start.column, line: start.line },
        { column: end.column, line: end.line },
        opts
      )
    }
    return new CssSyntaxError$2(message)
  }

  getProxyProcessor() {
    return {
      get(node, prop) {
        if (prop === 'proxyOf') {
          return node
        } else if (prop === 'root') {
          return () => node.root().toProxy()
        } else {
          return node[prop]
        }
      },

      set(node, prop, value) {
        if (node[prop] === value) return true
        node[prop] = value;
        if (
          prop === 'prop' ||
          prop === 'value' ||
          prop === 'name' ||
          prop === 'params' ||
          prop === 'important' ||
          /* c8 ignore next */
          prop === 'text'
        ) {
          node.markDirty();
        }
        return true
      }
    }
  }

  /* c8 ignore next 3 */
  markClean() {
    this[isClean$2] = true;
  }

  markDirty() {
    if (this[isClean$2]) {
      this[isClean$2] = false;
      let next = this;
      while ((next = next.parent)) {
        next[isClean$2] = false;
      }
    }
  }

  next() {
    if (!this.parent) return undefined
    let index = this.parent.index(this);
    return this.parent.nodes[index + 1]
  }

  positionBy(opts) {
    let pos = this.source.start;
    if (opts.index) {
      pos = this.positionInside(opts.index);
    } else if (opts.word) {
      let inputString = ('document' in this.source.input)
        ? this.source.input.document
        : this.source.input.css;
      let stringRepresentation = inputString.slice(
        sourceOffset(inputString, this.source.start),
        sourceOffset(inputString, this.source.end)
      );
      let index = stringRepresentation.indexOf(opts.word);
      if (index !== -1) pos = this.positionInside(index);
    }
    return pos
  }

  positionInside(index) {
    let column = this.source.start.column;
    let line = this.source.start.line;
    let inputString = ('document' in this.source.input)
      ? this.source.input.document
      : this.source.input.css;
    let offset = sourceOffset(inputString, this.source.start);
    let end = offset + index;

    for (let i = offset; i < end; i++) {
      if (inputString[i] === '\n') {
        column = 1;
        line += 1;
      } else {
        column += 1;
      }
    }

    return { column, line }
  }

  prev() {
    if (!this.parent) return undefined
    let index = this.parent.index(this);
    return this.parent.nodes[index - 1]
  }

  rangeBy(opts) {
    let start = {
      column: this.source.start.column,
      line: this.source.start.line
    };
    let end = this.source.end
      ? {
          column: this.source.end.column + 1,
          line: this.source.end.line
        }
      : {
          column: start.column + 1,
          line: start.line
        };

    if (opts.word) {
      let inputString = ('document' in this.source.input)
        ? this.source.input.document
        : this.source.input.css;
      let stringRepresentation = inputString.slice(
        sourceOffset(inputString, this.source.start),
        sourceOffset(inputString, this.source.end)
      );
      let index = stringRepresentation.indexOf(opts.word);
      if (index !== -1) {
        start = this.positionInside(index);
        end = this.positionInside(
          index + opts.word.length,
        );
      }
    } else {
      if (opts.start) {
        start = {
          column: opts.start.column,
          line: opts.start.line
        };
      } else if (opts.index) {
        start = this.positionInside(opts.index);
      }

      if (opts.end) {
        end = {
          column: opts.end.column,
          line: opts.end.line
        };
      } else if (typeof opts.endIndex === 'number') {
        end = this.positionInside(opts.endIndex);
      } else if (opts.index) {
        end = this.positionInside(opts.index + 1);
      }
    }

    if (
      end.line < start.line ||
      (end.line === start.line && end.column <= start.column)
    ) {
      end = { column: start.column + 1, line: start.line };
    }

    return { end, start }
  }

  raw(prop, defaultType) {
    let str = new Stringifier();
    return str.raw(this, prop, defaultType)
  }

  remove() {
    if (this.parent) {
      this.parent.removeChild(this);
    }
    this.parent = undefined;
    return this
  }

  replaceWith(...nodes) {
    if (this.parent) {
      let bookmark = this;
      let foundSelf = false;
      for (let node of nodes) {
        if (node === this) {
          foundSelf = true;
        } else if (foundSelf) {
          this.parent.insertAfter(bookmark, node);
          bookmark = node;
        } else {
          this.parent.insertBefore(bookmark, node);
        }
      }

      if (!foundSelf) {
        this.remove();
      }
    }

    return this
  }

  root() {
    let result = this;
    while (result.parent && result.parent.type !== 'document') {
      result = result.parent;
    }
    return result
  }

  toJSON(_, inputs) {
    let fixed = {};
    let emitInputs = inputs == null;
    inputs = inputs || new Map();
    let inputsNextIndex = 0;

    for (let name in this) {
      if (!Object.prototype.hasOwnProperty.call(this, name)) {
        /* c8 ignore next 2 */
        continue
      }
      if (name === 'parent' || name === 'proxyCache') continue
      let value = this[name];

      if (Array.isArray(value)) {
        fixed[name] = value.map(i => {
          if (typeof i === 'object' && i.toJSON) {
            return i.toJSON(null, inputs)
          } else {
            return i
          }
        });
      } else if (typeof value === 'object' && value.toJSON) {
        fixed[name] = value.toJSON(null, inputs);
      } else if (name === 'source') {
        let inputId = inputs.get(value.input);
        if (inputId == null) {
          inputId = inputsNextIndex;
          inputs.set(value.input, inputsNextIndex);
          inputsNextIndex++;
        }
        fixed[name] = {
          end: value.end,
          inputId,
          start: value.start
        };
      } else {
        fixed[name] = value;
      }
    }

    if (emitInputs) {
      fixed.inputs = [...inputs.keys()].map(input => input.toJSON());
    }

    return fixed
  }

  toProxy() {
    if (!this.proxyCache) {
      this.proxyCache = new Proxy(this, this.getProxyProcessor());
    }
    return this.proxyCache
  }

  toString(stringifier = stringify$3) {
    if (stringifier.stringify) stringifier = stringifier.stringify;
    let result = '';
    stringifier(this, i => {
      result += i;
    });
    return result
  }

  warn(result, text, opts) {
    let data = { node: this };
    for (let i in opts) data[i] = opts[i];
    return result.warn(text, data)
  }
}

var node_1 = Node$4;
Node$4.default = Node$4;

let Node$3 = node_1;

class Comment$4 extends Node$3 {
  constructor(defaults) {
    super(defaults);
    this.type = 'comment';
  }
}

var comment = Comment$4;
Comment$4.default = Comment$4;

let Node$2 = node_1;

class Declaration$4 extends Node$2 {
  get variable() {
    return this.prop.startsWith('--') || this.prop[0] === '$'
  }

  constructor(defaults) {
    if (
      defaults &&
      typeof defaults.value !== 'undefined' &&
      typeof defaults.value !== 'string'
    ) {
      defaults = { ...defaults, value: String(defaults.value) };
    }
    super(defaults);
    this.type = 'decl';
  }
}

var declaration = Declaration$4;
Declaration$4.default = Declaration$4;

let Comment$3 = comment;
let Declaration$3 = declaration;
let Node$1 = node_1;
let { isClean: isClean$1, my: my$1 } = symbols;

let AtRule$4, parse$4, Root$6, Rule$4;

function cleanSource(nodes) {
  return nodes.map(i => {
    if (i.nodes) i.nodes = cleanSource(i.nodes);
    delete i.source;
    return i
  })
}

function markTreeDirty(node) {
  node[isClean$1] = false;
  if (node.proxyOf.nodes) {
    for (let i of node.proxyOf.nodes) {
      markTreeDirty(i);
    }
  }
}

class Container$7 extends Node$1 {
  get first() {
    if (!this.proxyOf.nodes) return undefined
    return this.proxyOf.nodes[0]
  }

  get last() {
    if (!this.proxyOf.nodes) return undefined
    return this.proxyOf.nodes[this.proxyOf.nodes.length - 1]
  }

  append(...children) {
    for (let child of children) {
      let nodes = this.normalize(child, this.last);
      for (let node of nodes) this.proxyOf.nodes.push(node);
    }

    this.markDirty();

    return this
  }

  cleanRaws(keepBetween) {
    super.cleanRaws(keepBetween);
    if (this.nodes) {
      for (let node of this.nodes) node.cleanRaws(keepBetween);
    }
  }

  each(callback) {
    if (!this.proxyOf.nodes) return undefined
    let iterator = this.getIterator();

    let index, result;
    while (this.indexes[iterator] < this.proxyOf.nodes.length) {
      index = this.indexes[iterator];
      result = callback(this.proxyOf.nodes[index], index);
      if (result === false) break

      this.indexes[iterator] += 1;
    }

    delete this.indexes[iterator];
    return result
  }

  every(condition) {
    return this.nodes.every(condition)
  }

  getIterator() {
    if (!this.lastEach) this.lastEach = 0;
    if (!this.indexes) this.indexes = {};

    this.lastEach += 1;
    let iterator = this.lastEach;
    this.indexes[iterator] = 0;

    return iterator
  }

  getProxyProcessor() {
    return {
      get(node, prop) {
        if (prop === 'proxyOf') {
          return node
        } else if (!node[prop]) {
          return node[prop]
        } else if (
          prop === 'each' ||
          (typeof prop === 'string' && prop.startsWith('walk'))
        ) {
          return (...args) => {
            return node[prop](
              ...args.map(i => {
                if (typeof i === 'function') {
                  return (child, index) => i(child.toProxy(), index)
                } else {
                  return i
                }
              })
            )
          }
        } else if (prop === 'every' || prop === 'some') {
          return cb => {
            return node[prop]((child, ...other) =>
              cb(child.toProxy(), ...other)
            )
          }
        } else if (prop === 'root') {
          return () => node.root().toProxy()
        } else if (prop === 'nodes') {
          return node.nodes.map(i => i.toProxy())
        } else if (prop === 'first' || prop === 'last') {
          return node[prop].toProxy()
        } else {
          return node[prop]
        }
      },

      set(node, prop, value) {
        if (node[prop] === value) return true
        node[prop] = value;
        if (prop === 'name' || prop === 'params' || prop === 'selector') {
          node.markDirty();
        }
        return true
      }
    }
  }

  index(child) {
    if (typeof child === 'number') return child
    if (child.proxyOf) child = child.proxyOf;
    return this.proxyOf.nodes.indexOf(child)
  }

  insertAfter(exist, add) {
    let existIndex = this.index(exist);
    let nodes = this.normalize(add, this.proxyOf.nodes[existIndex]).reverse();
    existIndex = this.index(exist);
    for (let node of nodes) this.proxyOf.nodes.splice(existIndex + 1, 0, node);

    let index;
    for (let id in this.indexes) {
      index = this.indexes[id];
      if (existIndex < index) {
        this.indexes[id] = index + nodes.length;
      }
    }

    this.markDirty();

    return this
  }

  insertBefore(exist, add) {
    let existIndex = this.index(exist);
    let type = existIndex === 0 ? 'prepend' : false;
    let nodes = this.normalize(
      add,
      this.proxyOf.nodes[existIndex],
      type
    ).reverse();
    existIndex = this.index(exist);
    for (let node of nodes) this.proxyOf.nodes.splice(existIndex, 0, node);

    let index;
    for (let id in this.indexes) {
      index = this.indexes[id];
      if (existIndex <= index) {
        this.indexes[id] = index + nodes.length;
      }
    }

    this.markDirty();

    return this
  }

  normalize(nodes, sample) {
    if (typeof nodes === 'string') {
      nodes = cleanSource(parse$4(nodes).nodes);
    } else if (typeof nodes === 'undefined') {
      nodes = [];
    } else if (Array.isArray(nodes)) {
      nodes = nodes.slice(0);
      for (let i of nodes) {
        if (i.parent) i.parent.removeChild(i, 'ignore');
      }
    } else if (nodes.type === 'root' && this.type !== 'document') {
      nodes = nodes.nodes.slice(0);
      for (let i of nodes) {
        if (i.parent) i.parent.removeChild(i, 'ignore');
      }
    } else if (nodes.type) {
      nodes = [nodes];
    } else if (nodes.prop) {
      if (typeof nodes.value === 'undefined') {
        throw new Error('Value field is missed in node creation')
      } else if (typeof nodes.value !== 'string') {
        nodes.value = String(nodes.value);
      }
      nodes = [new Declaration$3(nodes)];
    } else if (nodes.selector || nodes.selectors) {
      nodes = [new Rule$4(nodes)];
    } else if (nodes.name) {
      nodes = [new AtRule$4(nodes)];
    } else if (nodes.text) {
      nodes = [new Comment$3(nodes)];
    } else {
      throw new Error('Unknown node type in node creation')
    }

    let processed = nodes.map(i => {
      /* c8 ignore next */
      if (!i[my$1]) Container$7.rebuild(i);
      i = i.proxyOf;
      if (i.parent) i.parent.removeChild(i);
      if (i[isClean$1]) markTreeDirty(i);

      if (!i.raws) i.raws = {};
      if (typeof i.raws.before === 'undefined') {
        if (sample && typeof sample.raws.before !== 'undefined') {
          i.raws.before = sample.raws.before.replace(/\S/g, '');
        }
      }
      i.parent = this.proxyOf;
      return i
    });

    return processed
  }

  prepend(...children) {
    children = children.reverse();
    for (let child of children) {
      let nodes = this.normalize(child, this.first, 'prepend').reverse();
      for (let node of nodes) this.proxyOf.nodes.unshift(node);
      for (let id in this.indexes) {
        this.indexes[id] = this.indexes[id] + nodes.length;
      }
    }

    this.markDirty();

    return this
  }

  push(child) {
    child.parent = this;
    this.proxyOf.nodes.push(child);
    return this
  }

  removeAll() {
    for (let node of this.proxyOf.nodes) node.parent = undefined;
    this.proxyOf.nodes = [];

    this.markDirty();

    return this
  }

  removeChild(child) {
    child = this.index(child);
    this.proxyOf.nodes[child].parent = undefined;
    this.proxyOf.nodes.splice(child, 1);

    let index;
    for (let id in this.indexes) {
      index = this.indexes[id];
      if (index >= child) {
        this.indexes[id] = index - 1;
      }
    }

    this.markDirty();

    return this
  }

  replaceValues(pattern, opts, callback) {
    if (!callback) {
      callback = opts;
      opts = {};
    }

    this.walkDecls(decl => {
      if (opts.props && !opts.props.includes(decl.prop)) return
      if (opts.fast && !decl.value.includes(opts.fast)) return

      decl.value = decl.value.replace(pattern, callback);
    });

    this.markDirty();

    return this
  }

  some(condition) {
    return this.nodes.some(condition)
  }

  walk(callback) {
    return this.each((child, i) => {
      let result;
      try {
        result = callback(child, i);
      } catch (e) {
        throw child.addToError(e)
      }
      if (result !== false && child.walk) {
        result = child.walk(callback);
      }

      return result
    })
  }

  walkAtRules(name, callback) {
    if (!callback) {
      callback = name;
      return this.walk((child, i) => {
        if (child.type === 'atrule') {
          return callback(child, i)
        }
      })
    }
    if (name instanceof RegExp) {
      return this.walk((child, i) => {
        if (child.type === 'atrule' && name.test(child.name)) {
          return callback(child, i)
        }
      })
    }
    return this.walk((child, i) => {
      if (child.type === 'atrule' && child.name === name) {
        return callback(child, i)
      }
    })
  }

  walkComments(callback) {
    return this.walk((child, i) => {
      if (child.type === 'comment') {
        return callback(child, i)
      }
    })
  }

  walkDecls(prop, callback) {
    if (!callback) {
      callback = prop;
      return this.walk((child, i) => {
        if (child.type === 'decl') {
          return callback(child, i)
        }
      })
    }
    if (prop instanceof RegExp) {
      return this.walk((child, i) => {
        if (child.type === 'decl' && prop.test(child.prop)) {
          return callback(child, i)
        }
      })
    }
    return this.walk((child, i) => {
      if (child.type === 'decl' && child.prop === prop) {
        return callback(child, i)
      }
    })
  }

  walkRules(selector, callback) {
    if (!callback) {
      callback = selector;

      return this.walk((child, i) => {
        if (child.type === 'rule') {
          return callback(child, i)
        }
      })
    }
    if (selector instanceof RegExp) {
      return this.walk((child, i) => {
        if (child.type === 'rule' && selector.test(child.selector)) {
          return callback(child, i)
        }
      })
    }
    return this.walk((child, i) => {
      if (child.type === 'rule' && child.selector === selector) {
        return callback(child, i)
      }
    })
  }
}

Container$7.registerParse = dependant => {
  parse$4 = dependant;
};

Container$7.registerRule = dependant => {
  Rule$4 = dependant;
};

Container$7.registerAtRule = dependant => {
  AtRule$4 = dependant;
};

Container$7.registerRoot = dependant => {
  Root$6 = dependant;
};

var container = Container$7;
Container$7.default = Container$7;

/* c8 ignore start */
Container$7.rebuild = node => {
  if (node.type === 'atrule') {
    Object.setPrototypeOf(node, AtRule$4.prototype);
  } else if (node.type === 'rule') {
    Object.setPrototypeOf(node, Rule$4.prototype);
  } else if (node.type === 'decl') {
    Object.setPrototypeOf(node, Declaration$3.prototype);
  } else if (node.type === 'comment') {
    Object.setPrototypeOf(node, Comment$3.prototype);
  } else if (node.type === 'root') {
    Object.setPrototypeOf(node, Root$6.prototype);
  }

  node[my$1] = true;

  if (node.nodes) {
    node.nodes.forEach(child => {
      Container$7.rebuild(child);
    });
  }
};

let Container$6 = container;

class AtRule$3 extends Container$6 {
  constructor(defaults) {
    super(defaults);
    this.type = 'atrule';
  }

  append(...children) {
    if (!this.proxyOf.nodes) this.nodes = [];
    return super.append(...children)
  }

  prepend(...children) {
    if (!this.proxyOf.nodes) this.nodes = [];
    return super.prepend(...children)
  }
}

var atRule = AtRule$3;
AtRule$3.default = AtRule$3;

Container$6.registerAtRule(AtRule$3);

let Container$5 = container;

let LazyResult$4, Processor$3;

class Document$3 extends Container$5 {
  constructor(defaults) {
    // type needs to be passed to super, otherwise child roots won't be normalized correctly
    super({ type: 'document', ...defaults });

    if (!this.nodes) {
      this.nodes = [];
    }
  }

  toResult(opts = {}) {
    let lazy = new LazyResult$4(new Processor$3(), this, opts);

    return lazy.stringify()
  }
}

Document$3.registerLazyResult = dependant => {
  LazyResult$4 = dependant;
};

Document$3.registerProcessor = dependant => {
  Processor$3 = dependant;
};

var document = Document$3;
Document$3.default = Document$3;

// This alphabet uses `A-Za-z0-9_-` symbols.
// The order of characters is optimized for better gzip and brotli compression.
// References to the same file (works both for gzip and brotli):
// `'use`, `andom`, and `rict'`
// References to the brotli default dictionary:
// `-26T`, `1983`, `40px`, `75px`, `bush`, `jack`, `mind`, `very`, and `wolf`
let urlAlphabet =
  'useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict';

let customAlphabet = (alphabet, defaultSize = 21) => {
  return (size = defaultSize) => {
    let id = '';
    // A compact alternative for `for (var i = 0; i < step; i++)`.
    let i = size | 0;
    while (i--) {
      // `| 0` is more compact and faster than `Math.floor()`.
      id += alphabet[(Math.random() * alphabet.length) | 0];
    }
    return id
  }
};

let nanoid$1 = (size = 21) => {
  let id = '';
  // A compact alternative for `for (var i = 0; i < step; i++)`.
  let i = size | 0;
  while (i--) {
    // `| 0` is more compact and faster than `Math.floor()`.
    id += urlAlphabet[(Math.random() * 64) | 0];
  }
  return id
};

const nonSecure = /*#__PURE__*/Object.freeze({
  __proto__: null,
  nanoid: nanoid$1,
  customAlphabet: customAlphabet
});

const require$$0 = /*@__PURE__*/getAugmentedNamespace(nonSecure);

let { existsSync, readFileSync } = require$$2;
let { dirname: dirname$1, join } = require$$2;
let { SourceMapConsumer: SourceMapConsumer$2, SourceMapGenerator: SourceMapGenerator$2 } = require$$2;

function fromBase64(str) {
  if (Buffer) {
    return Buffer.from(str, 'base64').toString()
  } else {
    /* c8 ignore next 2 */
    return window.atob(str)
  }
}

class PreviousMap$2 {
  constructor(css, opts) {
    if (opts.map === false) return
    this.loadAnnotation(css);
    this.inline = this.startWith(this.annotation, 'data:');

    let prev = opts.map ? opts.map.prev : undefined;
    let text = this.loadMap(opts.from, prev);
    if (!this.mapFile && opts.from) {
      this.mapFile = opts.from;
    }
    if (this.mapFile) this.root = dirname$1(this.mapFile);
    if (text) this.text = text;
  }

  consumer() {
    if (!this.consumerCache) {
      this.consumerCache = new SourceMapConsumer$2(this.text);
    }
    return this.consumerCache
  }

  decodeInline(text) {
    let baseCharsetUri = /^data:application\/json;charset=utf-?8;base64,/;
    let baseUri = /^data:application\/json;base64,/;
    let charsetUri = /^data:application\/json;charset=utf-?8,/;
    let uri = /^data:application\/json,/;

    let uriMatch = text.match(charsetUri) || text.match(uri);
    if (uriMatch) {
      return decodeURIComponent(text.substr(uriMatch[0].length))
    }

    let baseUriMatch = text.match(baseCharsetUri) || text.match(baseUri);
    if (baseUriMatch) {
      return fromBase64(text.substr(baseUriMatch[0].length))
    }

    let encoding = text.match(/data:application\/json;([^,]+),/)[1];
    throw new Error('Unsupported source map encoding ' + encoding)
  }

  getAnnotationURL(sourceMapString) {
    return sourceMapString.replace(/^\/\*\s*# sourceMappingURL=/, '').trim()
  }

  isMap(map) {
    if (typeof map !== 'object') return false
    return (
      typeof map.mappings === 'string' ||
      typeof map._mappings === 'string' ||
      Array.isArray(map.sections)
    )
  }

  loadAnnotation(css) {
    let comments = css.match(/\/\*\s*# sourceMappingURL=/g);
    if (!comments) return

    // sourceMappingURLs from comments, strings, etc.
    let start = css.lastIndexOf(comments.pop());
    let end = css.indexOf('*/', start);

    if (start > -1 && end > -1) {
      // Locate the last sourceMappingURL to avoid pickin
      this.annotation = this.getAnnotationURL(css.substring(start, end));
    }
  }

  loadFile(path) {
    this.root = dirname$1(path);
    if (existsSync(path)) {
      this.mapFile = path;
      return readFileSync(path, 'utf-8').toString().trim()
    }
  }

  loadMap(file, prev) {
    if (prev === false) return false

    if (prev) {
      if (typeof prev === 'string') {
        return prev
      } else if (typeof prev === 'function') {
        let prevPath = prev(file);
        if (prevPath) {
          let map = this.loadFile(prevPath);
          if (!map) {
            throw new Error(
              'Unable to load previous source map: ' + prevPath.toString()
            )
          }
          return map
        }
      } else if (prev instanceof SourceMapConsumer$2) {
        return SourceMapGenerator$2.fromSourceMap(prev).toString()
      } else if (prev instanceof SourceMapGenerator$2) {
        return prev.toString()
      } else if (this.isMap(prev)) {
        return JSON.stringify(prev)
      } else {
        throw new Error(
          'Unsupported previous source map format: ' + prev.toString()
        )
      }
    } else if (this.inline) {
      return this.decodeInline(this.annotation)
    } else if (this.annotation) {
      let map = this.annotation;
      if (file) map = join(dirname$1(file), map);
      return this.loadFile(map)
    }
  }

  startWith(string, start) {
    if (!string) return false
    return string.substr(0, start.length) === start
  }

  withContent() {
    return !!(
      this.consumer().sourcesContent &&
      this.consumer().sourcesContent.length > 0
    )
  }
}

var previousMap = PreviousMap$2;
PreviousMap$2.default = PreviousMap$2;

let { nanoid } = require$$0;
let { isAbsolute, resolve: resolve$1 } = require$$2;
let { SourceMapConsumer: SourceMapConsumer$1, SourceMapGenerator: SourceMapGenerator$1 } = require$$2;
let { fileURLToPath, pathToFileURL: pathToFileURL$1 } = require$$2;

let CssSyntaxError$1 = cssSyntaxError;
let PreviousMap$1 = previousMap;
let terminalHighlight = require$$2;

let fromOffsetCache = Symbol('fromOffsetCache');

let sourceMapAvailable$1 = Boolean(SourceMapConsumer$1 && SourceMapGenerator$1);
let pathAvailable$1 = Boolean(resolve$1 && isAbsolute);

class Input$4 {
  get from() {
    return this.file || this.id
  }

  constructor(css, opts = {}) {
    if (
      css === null ||
      typeof css === 'undefined' ||
      (typeof css === 'object' && !css.toString)
    ) {
      throw new Error(`PostCSS received ${css} instead of CSS string`)
    }

    this.css = css.toString();

    if (this.css[0] === '\uFEFF' || this.css[0] === '\uFFFE') {
      this.hasBOM = true;
      this.css = this.css.slice(1);
    } else {
      this.hasBOM = false;
    }

    this.document = this.css;
    if (opts.document) this.document = opts.document.toString();

    if (opts.from) {
      if (
        !pathAvailable$1 ||
        /^\w+:\/\//.test(opts.from) ||
        isAbsolute(opts.from)
      ) {
        this.file = opts.from;
      } else {
        this.file = resolve$1(opts.from);
      }
    }

    if (pathAvailable$1 && sourceMapAvailable$1) {
      let map = new PreviousMap$1(this.css, opts);
      if (map.text) {
        this.map = map;
        let file = map.consumer().file;
        if (!this.file && file) this.file = this.mapResolve(file);
      }
    }

    if (!this.file) {
      this.id = '<input css ' + nanoid(6) + '>';
    }
    if (this.map) this.map.file = this.from;
  }

  error(message, line, column, opts = {}) {
    let endColumn, endLine, result;

    if (line && typeof line === 'object') {
      let start = line;
      let end = column;
      if (typeof start.offset === 'number') {
        let pos = this.fromOffset(start.offset);
        line = pos.line;
        column = pos.col;
      } else {
        line = start.line;
        column = start.column;
      }
      if (typeof end.offset === 'number') {
        let pos = this.fromOffset(end.offset);
        endLine = pos.line;
        endColumn = pos.col;
      } else {
        endLine = end.line;
        endColumn = end.column;
      }
    } else if (!column) {
      let pos = this.fromOffset(line);
      line = pos.line;
      column = pos.col;
    }

    let origin = this.origin(line, column, endLine, endColumn);
    if (origin) {
      result = new CssSyntaxError$1(
        message,
        origin.endLine === undefined
          ? origin.line
          : { column: origin.column, line: origin.line },
        origin.endLine === undefined
          ? origin.column
          : { column: origin.endColumn, line: origin.endLine },
        origin.source,
        origin.file,
        opts.plugin
      );
    } else {
      result = new CssSyntaxError$1(
        message,
        endLine === undefined ? line : { column, line },
        endLine === undefined ? column : { column: endColumn, line: endLine },
        this.css,
        this.file,
        opts.plugin
      );
    }

    result.input = { column, endColumn, endLine, line, source: this.css };
    if (this.file) {
      if (pathToFileURL$1) {
        result.input.url = pathToFileURL$1(this.file).toString();
      }
      result.input.file = this.file;
    }

    return result
  }

  fromOffset(offset) {
    let lastLine, lineToIndex;
    if (!this[fromOffsetCache]) {
      let lines = this.css.split('\n');
      lineToIndex = new Array(lines.length);
      let prevIndex = 0;

      for (let i = 0, l = lines.length; i < l; i++) {
        lineToIndex[i] = prevIndex;
        prevIndex += lines[i].length + 1;
      }

      this[fromOffsetCache] = lineToIndex;
    } else {
      lineToIndex = this[fromOffsetCache];
    }
    lastLine = lineToIndex[lineToIndex.length - 1];

    let min = 0;
    if (offset >= lastLine) {
      min = lineToIndex.length - 1;
    } else {
      let max = lineToIndex.length - 2;
      let mid;
      while (min < max) {
        mid = min + ((max - min) >> 1);
        if (offset < lineToIndex[mid]) {
          max = mid - 1;
        } else if (offset >= lineToIndex[mid + 1]) {
          min = mid + 1;
        } else {
          min = mid;
          break
        }
      }
    }
    return {
      col: offset - lineToIndex[min] + 1,
      line: min + 1
    }
  }

  mapResolve(file) {
    if (/^\w+:\/\//.test(file)) {
      return file
    }
    return resolve$1(this.map.consumer().sourceRoot || this.map.root || '.', file)
  }

  origin(line, column, endLine, endColumn) {
    if (!this.map) return false
    let consumer = this.map.consumer();

    let from = consumer.originalPositionFor({ column, line });
    if (!from.source) return false

    let to;
    if (typeof endLine === 'number') {
      to = consumer.originalPositionFor({ column: endColumn, line: endLine });
    }

    let fromUrl;

    if (isAbsolute(from.source)) {
      fromUrl = pathToFileURL$1(from.source);
    } else {
      fromUrl = new URL(
        from.source,
        this.map.consumer().sourceRoot || pathToFileURL$1(this.map.mapFile)
      );
    }

    let result = {
      column: from.column,
      endColumn: to && to.column,
      endLine: to && to.line,
      line: from.line,
      url: fromUrl.toString()
    };

    if (fromUrl.protocol === 'file:') {
      if (fileURLToPath) {
        result.file = fileURLToPath(fromUrl);
      } else {
        /* c8 ignore next 2 */
        throw new Error(`file: protocol is not available in this PostCSS build`)
      }
    }

    let source = consumer.sourceContentFor(from.source);
    if (source) result.source = source;

    return result
  }

  toJSON() {
    let json = {};
    for (let name of ['hasBOM', 'css', 'file', 'id']) {
      if (this[name] != null) {
        json[name] = this[name];
      }
    }
    if (this.map) {
      json.map = { ...this.map };
      if (json.map.consumerCache) {
        json.map.consumerCache = undefined;
      }
    }
    return json
  }
}

var input = Input$4;
Input$4.default = Input$4;

if (terminalHighlight && terminalHighlight.registerInput) {
  terminalHighlight.registerInput(Input$4);
}

let Container$4 = container;

let LazyResult$3, Processor$2;

class Root$5 extends Container$4 {
  constructor(defaults) {
    super(defaults);
    this.type = 'root';
    if (!this.nodes) this.nodes = [];
  }

  normalize(child, sample, type) {
    let nodes = super.normalize(child);

    if (sample) {
      if (type === 'prepend') {
        if (this.nodes.length > 1) {
          sample.raws.before = this.nodes[1].raws.before;
        } else {
          delete sample.raws.before;
        }
      } else if (this.first !== sample) {
        for (let node of nodes) {
          node.raws.before = sample.raws.before;
        }
      }
    }

    return nodes
  }

  removeChild(child, ignore) {
    let index = this.index(child);

    if (!ignore && index === 0 && this.nodes.length > 1) {
      this.nodes[1].raws.before = this.nodes[index].raws.before;
    }

    return super.removeChild(child)
  }

  toResult(opts = {}) {
    let lazy = new LazyResult$3(new Processor$2(), this, opts);
    return lazy.stringify()
  }
}

Root$5.registerLazyResult = dependant => {
  LazyResult$3 = dependant;
};

Root$5.registerProcessor = dependant => {
  Processor$2 = dependant;
};

var root = Root$5;
Root$5.default = Root$5;

Container$4.registerRoot(Root$5);

let list$2 = {
  comma(string) {
    return list$2.split(string, [','], true)
  },

  space(string) {
    let spaces = [' ', '\n', '\t'];
    return list$2.split(string, spaces)
  },

  split(string, separators, last) {
    let array = [];
    let current = '';
    let split = false;

    let func = 0;
    let inQuote = false;
    let prevQuote = '';
    let escape = false;

    for (let letter of string) {
      if (escape) {
        escape = false;
      } else if (letter === '\\') {
        escape = true;
      } else if (inQuote) {
        if (letter === prevQuote) {
          inQuote = false;
        }
      } else if (letter === '"' || letter === "'") {
        inQuote = true;
        prevQuote = letter;
      } else if (letter === '(') {
        func += 1;
      } else if (letter === ')') {
        if (func > 0) func -= 1;
      } else if (func === 0) {
        if (separators.includes(letter)) split = true;
      }

      if (split) {
        if (current !== '') array.push(current.trim());
        current = '';
        split = false;
      } else {
        current += letter;
      }
    }

    if (last || current !== '') array.push(current.trim());
    return array
  }
};

var list_1 = list$2;
list$2.default = list$2;

let Container$3 = container;
let list$1 = list_1;

class Rule$3 extends Container$3 {
  get selectors() {
    return list$1.comma(this.selector)
  }

  set selectors(values) {
    let match = this.selector ? this.selector.match(/,\s*/) : null;
    let sep = match ? match[0] : ',' + this.raw('between', 'beforeOpen');
    this.selector = values.join(sep);
  }

  constructor(defaults) {
    super(defaults);
    this.type = 'rule';
    if (!this.nodes) this.nodes = [];
  }
}

var rule = Rule$3;
Rule$3.default = Rule$3;

Container$3.registerRule(Rule$3);

let AtRule$2 = atRule;
let Comment$2 = comment;
let Declaration$2 = declaration;
let Input$3 = input;
let PreviousMap = previousMap;
let Root$4 = root;
let Rule$2 = rule;

function fromJSON$1(json, inputs) {
  if (Array.isArray(json)) return json.map(n => fromJSON$1(n))

  let { inputs: ownInputs, ...defaults } = json;
  if (ownInputs) {
    inputs = [];
    for (let input of ownInputs) {
      let inputHydrated = { ...input, __proto__: Input$3.prototype };
      if (inputHydrated.map) {
        inputHydrated.map = {
          ...inputHydrated.map,
          __proto__: PreviousMap.prototype
        };
      }
      inputs.push(inputHydrated);
    }
  }
  if (defaults.nodes) {
    defaults.nodes = json.nodes.map(n => fromJSON$1(n, inputs));
  }
  if (defaults.source) {
    let { inputId, ...source } = defaults.source;
    defaults.source = source;
    if (inputId != null) {
      defaults.source.input = inputs[inputId];
    }
  }
  if (defaults.type === 'root') {
    return new Root$4(defaults)
  } else if (defaults.type === 'decl') {
    return new Declaration$2(defaults)
  } else if (defaults.type === 'rule') {
    return new Rule$2(defaults)
  } else if (defaults.type === 'comment') {
    return new Comment$2(defaults)
  } else if (defaults.type === 'atrule') {
    return new AtRule$2(defaults)
  } else {
    throw new Error('Unknown node type: ' + json.type)
  }
}

var fromJSON_1 = fromJSON$1;
fromJSON$1.default = fromJSON$1;

let { dirname, relative, resolve, sep } = require$$2;
let { SourceMapConsumer, SourceMapGenerator } = require$$2;
let { pathToFileURL } = require$$2;

let Input$2 = input;

let sourceMapAvailable = Boolean(SourceMapConsumer && SourceMapGenerator);
let pathAvailable = Boolean(dirname && resolve && relative && sep);

class MapGenerator$2 {
  constructor(stringify, root, opts, cssString) {
    this.stringify = stringify;
    this.mapOpts = opts.map || {};
    this.root = root;
    this.opts = opts;
    this.css = cssString;
    this.originalCSS = cssString;
    this.usesFileUrls = !this.mapOpts.from && this.mapOpts.absolute;

    this.memoizedFileURLs = new Map();
    this.memoizedPaths = new Map();
    this.memoizedURLs = new Map();
  }

  addAnnotation() {
    let content;

    if (this.isInline()) {
      content =
        'data:application/json;base64,' + this.toBase64(this.map.toString());
    } else if (typeof this.mapOpts.annotation === 'string') {
      content = this.mapOpts.annotation;
    } else if (typeof this.mapOpts.annotation === 'function') {
      content = this.mapOpts.annotation(this.opts.to, this.root);
    } else {
      content = this.outputFile() + '.map';
    }
    let eol = '\n';
    if (this.css.includes('\r\n')) eol = '\r\n';

    this.css += eol + '/*# sourceMappingURL=' + content + ' */';
  }

  applyPrevMaps() {
    for (let prev of this.previous()) {
      let from = this.toUrl(this.path(prev.file));
      let root = prev.root || dirname(prev.file);
      let map;

      if (this.mapOpts.sourcesContent === false) {
        map = new SourceMapConsumer(prev.text);
        if (map.sourcesContent) {
          map.sourcesContent = null;
        }
      } else {
        map = prev.consumer();
      }

      this.map.applySourceMap(map, from, this.toUrl(this.path(root)));
    }
  }

  clearAnnotation() {
    if (this.mapOpts.annotation === false) return

    if (this.root) {
      let node;
      for (let i = this.root.nodes.length - 1; i >= 0; i--) {
        node = this.root.nodes[i];
        if (node.type !== 'comment') continue
        if (node.text.startsWith('# sourceMappingURL=')) {
          this.root.removeChild(i);
        }
      }
    } else if (this.css) {
      this.css = this.css.replace(/\n*\/\*#[\S\s]*?\*\/$/gm, '');
    }
  }

  generate() {
    this.clearAnnotation();
    if (pathAvailable && sourceMapAvailable && this.isMap()) {
      return this.generateMap()
    } else {
      let result = '';
      this.stringify(this.root, i => {
        result += i;
      });
      return [result]
    }
  }

  generateMap() {
    if (this.root) {
      this.generateString();
    } else if (this.previous().length === 1) {
      let prev = this.previous()[0].consumer();
      prev.file = this.outputFile();
      this.map = SourceMapGenerator.fromSourceMap(prev, {
        ignoreInvalidMapping: true
      });
    } else {
      this.map = new SourceMapGenerator({
        file: this.outputFile(),
        ignoreInvalidMapping: true
      });
      this.map.addMapping({
        generated: { column: 0, line: 1 },
        original: { column: 0, line: 1 },
        source: this.opts.from
          ? this.toUrl(this.path(this.opts.from))
          : '<no source>'
      });
    }

    if (this.isSourcesContent()) this.setSourcesContent();
    if (this.root && this.previous().length > 0) this.applyPrevMaps();
    if (this.isAnnotation()) this.addAnnotation();

    if (this.isInline()) {
      return [this.css]
    } else {
      return [this.css, this.map]
    }
  }

  generateString() {
    this.css = '';
    this.map = new SourceMapGenerator({
      file: this.outputFile(),
      ignoreInvalidMapping: true
    });

    let line = 1;
    let column = 1;

    let noSource = '<no source>';
    let mapping = {
      generated: { column: 0, line: 0 },
      original: { column: 0, line: 0 },
      source: ''
    };

    let last, lines;
    this.stringify(this.root, (str, node, type) => {
      this.css += str;

      if (node && type !== 'end') {
        mapping.generated.line = line;
        mapping.generated.column = column - 1;
        if (node.source && node.source.start) {
          mapping.source = this.sourcePath(node);
          mapping.original.line = node.source.start.line;
          mapping.original.column = node.source.start.column - 1;
          this.map.addMapping(mapping);
        } else {
          mapping.source = noSource;
          mapping.original.line = 1;
          mapping.original.column = 0;
          this.map.addMapping(mapping);
        }
      }

      lines = str.match(/\n/g);
      if (lines) {
        line += lines.length;
        last = str.lastIndexOf('\n');
        column = str.length - last;
      } else {
        column += str.length;
      }

      if (node && type !== 'start') {
        let p = node.parent || { raws: {} };
        let childless =
          node.type === 'decl' || (node.type === 'atrule' && !node.nodes);
        if (!childless || node !== p.last || p.raws.semicolon) {
          if (node.source && node.source.end) {
            mapping.source = this.sourcePath(node);
            mapping.original.line = node.source.end.line;
            mapping.original.column = node.source.end.column - 1;
            mapping.generated.line = line;
            mapping.generated.column = column - 2;
            this.map.addMapping(mapping);
          } else {
            mapping.source = noSource;
            mapping.original.line = 1;
            mapping.original.column = 0;
            mapping.generated.line = line;
            mapping.generated.column = column - 1;
            this.map.addMapping(mapping);
          }
        }
      }
    });
  }

  isAnnotation() {
    if (this.isInline()) {
      return true
    }
    if (typeof this.mapOpts.annotation !== 'undefined') {
      return this.mapOpts.annotation
    }
    if (this.previous().length) {
      return this.previous().some(i => i.annotation)
    }
    return true
  }

  isInline() {
    if (typeof this.mapOpts.inline !== 'undefined') {
      return this.mapOpts.inline
    }

    let annotation = this.mapOpts.annotation;
    if (typeof annotation !== 'undefined' && annotation !== true) {
      return false
    }

    if (this.previous().length) {
      return this.previous().some(i => i.inline)
    }
    return true
  }

  isMap() {
    if (typeof this.opts.map !== 'undefined') {
      return !!this.opts.map
    }
    return this.previous().length > 0
  }

  isSourcesContent() {
    if (typeof this.mapOpts.sourcesContent !== 'undefined') {
      return this.mapOpts.sourcesContent
    }
    if (this.previous().length) {
      return this.previous().some(i => i.withContent())
    }
    return true
  }

  outputFile() {
    if (this.opts.to) {
      return this.path(this.opts.to)
    } else if (this.opts.from) {
      return this.path(this.opts.from)
    } else {
      return 'to.css'
    }
  }

  path(file) {
    if (this.mapOpts.absolute) return file
    if (file.charCodeAt(0) === 60 /* `<` */) return file
    if (/^\w+:\/\//.test(file)) return file
    let cached = this.memoizedPaths.get(file);
    if (cached) return cached

    let from = this.opts.to ? dirname(this.opts.to) : '.';

    if (typeof this.mapOpts.annotation === 'string') {
      from = dirname(resolve(from, this.mapOpts.annotation));
    }

    let path = relative(from, file);
    this.memoizedPaths.set(file, path);

    return path
  }

  previous() {
    if (!this.previousMaps) {
      this.previousMaps = [];
      if (this.root) {
        this.root.walk(node => {
          if (node.source && node.source.input.map) {
            let map = node.source.input.map;
            if (!this.previousMaps.includes(map)) {
              this.previousMaps.push(map);
            }
          }
        });
      } else {
        let input = new Input$2(this.originalCSS, this.opts);
        if (input.map) this.previousMaps.push(input.map);
      }
    }

    return this.previousMaps
  }

  setSourcesContent() {
    let already = {};
    if (this.root) {
      this.root.walk(node => {
        if (node.source) {
          let from = node.source.input.from;
          if (from && !already[from]) {
            already[from] = true;
            let fromUrl = this.usesFileUrls
              ? this.toFileUrl(from)
              : this.toUrl(this.path(from));
            this.map.setSourceContent(fromUrl, node.source.input.css);
          }
        }
      });
    } else if (this.css) {
      let from = this.opts.from
        ? this.toUrl(this.path(this.opts.from))
        : '<no source>';
      this.map.setSourceContent(from, this.css);
    }
  }

  sourcePath(node) {
    if (this.mapOpts.from) {
      return this.toUrl(this.mapOpts.from)
    } else if (this.usesFileUrls) {
      return this.toFileUrl(node.source.input.from)
    } else {
      return this.toUrl(this.path(node.source.input.from))
    }
  }

  toBase64(str) {
    if (Buffer) {
      return Buffer.from(str).toString('base64')
    } else {
      return window.btoa(unescape(encodeURIComponent(str)))
    }
  }

  toFileUrl(path) {
    let cached = this.memoizedFileURLs.get(path);
    if (cached) return cached

    if (pathToFileURL) {
      let fileURL = pathToFileURL(path).toString();
      this.memoizedFileURLs.set(path, fileURL);

      return fileURL
    } else {
      throw new Error(
        '`map.absolute` option is not available in this PostCSS build'
      )
    }
  }

  toUrl(path) {
    let cached = this.memoizedURLs.get(path);
    if (cached) return cached

    if (sep === '\\') {
      path = path.replace(/\\/g, '/');
    }

    let url = encodeURI(path).replace(/[#?]/g, encodeURIComponent);
    this.memoizedURLs.set(path, url);

    return url
  }
}

var mapGenerator = MapGenerator$2;

const SINGLE_QUOTE = "'".charCodeAt(0);
const DOUBLE_QUOTE = '"'.charCodeAt(0);
const BACKSLASH = '\\'.charCodeAt(0);
const SLASH = '/'.charCodeAt(0);
const NEWLINE = '\n'.charCodeAt(0);
const SPACE = ' '.charCodeAt(0);
const FEED = '\f'.charCodeAt(0);
const TAB = '\t'.charCodeAt(0);
const CR = '\r'.charCodeAt(0);
const OPEN_SQUARE = '['.charCodeAt(0);
const CLOSE_SQUARE = ']'.charCodeAt(0);
const OPEN_PARENTHESES = '('.charCodeAt(0);
const CLOSE_PARENTHESES = ')'.charCodeAt(0);
const OPEN_CURLY = '{'.charCodeAt(0);
const CLOSE_CURLY = '}'.charCodeAt(0);
const SEMICOLON = ';'.charCodeAt(0);
const ASTERISK = '*'.charCodeAt(0);
const COLON = ':'.charCodeAt(0);
const AT = '@'.charCodeAt(0);

const RE_AT_END = /[\t\n\f\r "#'()/;[\\\]{}]/g;
const RE_WORD_END = /[\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g;
const RE_BAD_BRACKET = /.[\r\n"'(/\\]/;
const RE_HEX_ESCAPE = /[\da-f]/i;

var tokenize = function tokenizer(input, options = {}) {
  let css = input.css.valueOf();
  let ignore = options.ignoreErrors;

  let code, content, escape, next, quote;
  let currentToken, escaped, escapePos, n, prev;

  let length = css.length;
  let pos = 0;
  let buffer = [];
  let returned = [];

  function position() {
    return pos
  }

  function unclosed(what) {
    throw input.error('Unclosed ' + what, pos)
  }

  function endOfFile() {
    return returned.length === 0 && pos >= length
  }

  function nextToken(opts) {
    if (returned.length) return returned.pop()
    if (pos >= length) return

    let ignoreUnclosed = opts ? opts.ignoreUnclosed : false;

    code = css.charCodeAt(pos);

    switch (code) {
      case NEWLINE:
      case SPACE:
      case TAB:
      case CR:
      case FEED: {
        next = pos;
        do {
          next += 1;
          code = css.charCodeAt(next);
        } while (
          code === SPACE ||
          code === NEWLINE ||
          code === TAB ||
          code === CR ||
          code === FEED
        )

        currentToken = ['space', css.slice(pos, next)];
        pos = next - 1;
        break
      }

      case OPEN_SQUARE:
      case CLOSE_SQUARE:
      case OPEN_CURLY:
      case CLOSE_CURLY:
      case COLON:
      case SEMICOLON:
      case CLOSE_PARENTHESES: {
        let controlChar = String.fromCharCode(code);
        currentToken = [controlChar, controlChar, pos];
        break
      }

      case OPEN_PARENTHESES: {
        prev = buffer.length ? buffer.pop()[1] : '';
        n = css.charCodeAt(pos + 1);
        if (
          prev === 'url' &&
          n !== SINGLE_QUOTE &&
          n !== DOUBLE_QUOTE &&
          n !== SPACE &&
          n !== NEWLINE &&
          n !== TAB &&
          n !== FEED &&
          n !== CR
        ) {
          next = pos;
          do {
            escaped = false;
            next = css.indexOf(')', next + 1);
            if (next === -1) {
              if (ignore || ignoreUnclosed) {
                next = pos;
                break
              } else {
                unclosed('bracket');
              }
            }
            escapePos = next;
            while (css.charCodeAt(escapePos - 1) === BACKSLASH) {
              escapePos -= 1;
              escaped = !escaped;
            }
          } while (escaped)

          currentToken = ['brackets', css.slice(pos, next + 1), pos, next];

          pos = next;
        } else {
          next = css.indexOf(')', pos + 1);
          content = css.slice(pos, next + 1);

          if (next === -1 || RE_BAD_BRACKET.test(content)) {
            currentToken = ['(', '(', pos];
          } else {
            currentToken = ['brackets', content, pos, next];
            pos = next;
          }
        }

        break
      }

      case SINGLE_QUOTE:
      case DOUBLE_QUOTE: {
        quote = code === SINGLE_QUOTE ? "'" : '"';
        next = pos;
        do {
          escaped = false;
          next = css.indexOf(quote, next + 1);
          if (next === -1) {
            if (ignore || ignoreUnclosed) {
              next = pos + 1;
              break
            } else {
              unclosed('string');
            }
          }
          escapePos = next;
          while (css.charCodeAt(escapePos - 1) === BACKSLASH) {
            escapePos -= 1;
            escaped = !escaped;
          }
        } while (escaped)

        currentToken = ['string', css.slice(pos, next + 1), pos, next];
        pos = next;
        break
      }

      case AT: {
        RE_AT_END.lastIndex = pos + 1;
        RE_AT_END.test(css);
        if (RE_AT_END.lastIndex === 0) {
          next = css.length - 1;
        } else {
          next = RE_AT_END.lastIndex - 2;
        }

        currentToken = ['at-word', css.slice(pos, next + 1), pos, next];

        pos = next;
        break
      }

      case BACKSLASH: {
        next = pos;
        escape = true;
        while (css.charCodeAt(next + 1) === BACKSLASH) {
          next += 1;
          escape = !escape;
        }
        code = css.charCodeAt(next + 1);
        if (
          escape &&
          code !== SLASH &&
          code !== SPACE &&
          code !== NEWLINE &&
          code !== TAB &&
          code !== CR &&
          code !== FEED
        ) {
          next += 1;
          if (RE_HEX_ESCAPE.test(css.charAt(next))) {
            while (RE_HEX_ESCAPE.test(css.charAt(next + 1))) {
              next += 1;
            }
            if (css.charCodeAt(next + 1) === SPACE) {
              next += 1;
            }
          }
        }

        currentToken = ['word', css.slice(pos, next + 1), pos, next];

        pos = next;
        break
      }

      default: {
        if (code === SLASH && css.charCodeAt(pos + 1) === ASTERISK) {
          next = css.indexOf('*/', pos + 2) + 1;
          if (next === 0) {
            if (ignore || ignoreUnclosed) {
              next = css.length;
            } else {
              unclosed('comment');
            }
          }

          currentToken = ['comment', css.slice(pos, next + 1), pos, next];
          pos = next;
        } else {
          RE_WORD_END.lastIndex = pos + 1;
          RE_WORD_END.test(css);
          if (RE_WORD_END.lastIndex === 0) {
            next = css.length - 1;
          } else {
            next = RE_WORD_END.lastIndex - 2;
          }

          currentToken = ['word', css.slice(pos, next + 1), pos, next];
          buffer.push(currentToken);
          pos = next;
        }

        break
      }
    }

    pos++;
    return currentToken
  }

  function back(token) {
    returned.push(token);
  }

  return {
    back,
    endOfFile,
    nextToken,
    position
  }
};

let AtRule$1 = atRule;
let Comment$1 = comment;
let Declaration$1 = declaration;
let Root$3 = root;
let Rule$1 = rule;
let tokenizer = tokenize;

const SAFE_COMMENT_NEIGHBOR = {
  empty: true,
  space: true
};

function findLastWithPosition(tokens) {
  for (let i = tokens.length - 1; i >= 0; i--) {
    let token = tokens[i];
    let pos = token[3] || token[2];
    if (pos) return pos
  }
}

class Parser$1 {
  constructor(input) {
    this.input = input;

    this.root = new Root$3();
    this.current = this.root;
    this.spaces = '';
    this.semicolon = false;

    this.createTokenizer();
    this.root.source = { input, start: { column: 1, line: 1, offset: 0 } };
  }

  atrule(token) {
    let node = new AtRule$1();
    node.name = token[1].slice(1);
    if (node.name === '') {
      this.unnamedAtrule(node, token);
    }
    this.init(node, token[2]);

    let type;
    let prev;
    let shift;
    let last = false;
    let open = false;
    let params = [];
    let brackets = [];

    while (!this.tokenizer.endOfFile()) {
      token = this.tokenizer.nextToken();
      type = token[0];

      if (type === '(' || type === '[') {
        brackets.push(type === '(' ? ')' : ']');
      } else if (type === '{' && brackets.length > 0) {
        brackets.push('}');
      } else if (type === brackets[brackets.length - 1]) {
        brackets.pop();
      }

      if (brackets.length === 0) {
        if (type === ';') {
          node.source.end = this.getPosition(token[2]);
          node.source.end.offset++;
          this.semicolon = true;
          break
        } else if (type === '{') {
          open = true;
          break
        } else if (type === '}') {
          if (params.length > 0) {
            shift = params.length - 1;
            prev = params[shift];
            while (prev && prev[0] === 'space') {
              prev = params[--shift];
            }
            if (prev) {
              node.source.end = this.getPosition(prev[3] || prev[2]);
              node.source.end.offset++;
            }
          }
          this.end(token);
          break
        } else {
          params.push(token);
        }
      } else {
        params.push(token);
      }

      if (this.tokenizer.endOfFile()) {
        last = true;
        break
      }
    }

    node.raws.between = this.spacesAndCommentsFromEnd(params);
    if (params.length) {
      node.raws.afterName = this.spacesAndCommentsFromStart(params);
      this.raw(node, 'params', params);
      if (last) {
        token = params[params.length - 1];
        node.source.end = this.getPosition(token[3] || token[2]);
        node.source.end.offset++;
        this.spaces = node.raws.between;
        node.raws.between = '';
      }
    } else {
      node.raws.afterName = '';
      node.params = '';
    }

    if (open) {
      node.nodes = [];
      this.current = node;
    }
  }

  checkMissedSemicolon(tokens) {
    let colon = this.colon(tokens);
    if (colon === false) return

    let founded = 0;
    let token;
    for (let j = colon - 1; j >= 0; j--) {
      token = tokens[j];
      if (token[0] !== 'space') {
        founded += 1;
        if (founded === 2) break
      }
    }
    // If the token is a word, e.g. `!important`, `red` or any other valid property's value.
    // Then we need to return the colon after that word token. [3] is the "end" colon of that word.
    // And because we need it after that one we do +1 to get the next one.
    throw this.input.error(
      'Missed semicolon',
      token[0] === 'word' ? token[3] + 1 : token[2]
    )
  }

  colon(tokens) {
    let brackets = 0;
    let prev, token, type;
    for (let [i, element] of tokens.entries()) {
      token = element;
      type = token[0];

      if (type === '(') {
        brackets += 1;
      }
      if (type === ')') {
        brackets -= 1;
      }
      if (brackets === 0 && type === ':') {
        if (!prev) {
          this.doubleColon(token);
        } else if (prev[0] === 'word' && prev[1] === 'progid') {
          continue
        } else {
          return i
        }
      }

      prev = token;
    }
    return false
  }

  comment(token) {
    let node = new Comment$1();
    this.init(node, token[2]);
    node.source.end = this.getPosition(token[3] || token[2]);
    node.source.end.offset++;

    let text = token[1].slice(2, -2);
    if (/^\s*$/.test(text)) {
      node.text = '';
      node.raws.left = text;
      node.raws.right = '';
    } else {
      let match = text.match(/^(\s*)([^]*\S)(\s*)$/);
      node.text = match[2];
      node.raws.left = match[1];
      node.raws.right = match[3];
    }
  }

  createTokenizer() {
    this.tokenizer = tokenizer(this.input);
  }

  decl(tokens, customProperty) {
    let node = new Declaration$1();
    this.init(node, tokens[0][2]);

    let last = tokens[tokens.length - 1];
    if (last[0] === ';') {
      this.semicolon = true;
      tokens.pop();
    }

    node.source.end = this.getPosition(
      last[3] || last[2] || findLastWithPosition(tokens)
    );
    node.source.end.offset++;

    while (tokens[0][0] !== 'word') {
      if (tokens.length === 1) this.unknownWord(tokens);
      node.raws.before += tokens.shift()[1];
    }
    node.source.start = this.getPosition(tokens[0][2]);

    node.prop = '';
    while (tokens.length) {
      let type = tokens[0][0];
      if (type === ':' || type === 'space' || type === 'comment') {
        break
      }
      node.prop += tokens.shift()[1];
    }

    node.raws.between = '';

    let token;
    while (tokens.length) {
      token = tokens.shift();

      if (token[0] === ':') {
        node.raws.between += token[1];
        break
      } else {
        if (token[0] === 'word' && /\w/.test(token[1])) {
          this.unknownWord([token]);
        }
        node.raws.between += token[1];
      }
    }

    if (node.prop[0] === '_' || node.prop[0] === '*') {
      node.raws.before += node.prop[0];
      node.prop = node.prop.slice(1);
    }

    let firstSpaces = [];
    let next;
    while (tokens.length) {
      next = tokens[0][0];
      if (next !== 'space' && next !== 'comment') break
      firstSpaces.push(tokens.shift());
    }

    this.precheckMissedSemicolon(tokens);

    for (let i = tokens.length - 1; i >= 0; i--) {
      token = tokens[i];
      if (token[1].toLowerCase() === '!important') {
        node.important = true;
        let string = this.stringFrom(tokens, i);
        string = this.spacesFromEnd(tokens) + string;
        if (string !== ' !important') node.raws.important = string;
        break
      } else if (token[1].toLowerCase() === 'important') {
        let cache = tokens.slice(0);
        let str = '';
        for (let j = i; j > 0; j--) {
          let type = cache[j][0];
          if (str.trim().startsWith('!') && type !== 'space') {
            break
          }
          str = cache.pop()[1] + str;
        }
        if (str.trim().startsWith('!')) {
          node.important = true;
          node.raws.important = str;
          tokens = cache;
        }
      }

      if (token[0] !== 'space' && token[0] !== 'comment') {
        break
      }
    }

    let hasWord = tokens.some(i => i[0] !== 'space' && i[0] !== 'comment');

    if (hasWord) {
      node.raws.between += firstSpaces.map(i => i[1]).join('');
      firstSpaces = [];
    }
    this.raw(node, 'value', firstSpaces.concat(tokens), customProperty);

    if (node.value.includes(':') && !customProperty) {
      this.checkMissedSemicolon(tokens);
    }
  }

  doubleColon(token) {
    throw this.input.error(
      'Double colon',
      { offset: token[2] },
      { offset: token[2] + token[1].length }
    )
  }

  emptyRule(token) {
    let node = new Rule$1();
    this.init(node, token[2]);
    node.selector = '';
    node.raws.between = '';
    this.current = node;
  }

  end(token) {
    if (this.current.nodes && this.current.nodes.length) {
      this.current.raws.semicolon = this.semicolon;
    }
    this.semicolon = false;

    this.current.raws.after = (this.current.raws.after || '') + this.spaces;
    this.spaces = '';

    if (this.current.parent) {
      this.current.source.end = this.getPosition(token[2]);
      this.current.source.end.offset++;
      this.current = this.current.parent;
    } else {
      this.unexpectedClose(token);
    }
  }

  endFile() {
    if (this.current.parent) this.unclosedBlock();
    if (this.current.nodes && this.current.nodes.length) {
      this.current.raws.semicolon = this.semicolon;
    }
    this.current.raws.after = (this.current.raws.after || '') + this.spaces;
    this.root.source.end = this.getPosition(this.tokenizer.position());
  }

  freeSemicolon(token) {
    this.spaces += token[1];
    if (this.current.nodes) {
      let prev = this.current.nodes[this.current.nodes.length - 1];
      if (prev && prev.type === 'rule' && !prev.raws.ownSemicolon) {
        prev.raws.ownSemicolon = this.spaces;
        this.spaces = '';
        prev.source.end = this.getPosition(token[2]);
        prev.source.end.offset += prev.raws.ownSemicolon.length;
      }
    }
  }

  // Helpers

  getPosition(offset) {
    let pos = this.input.fromOffset(offset);
    return {
      column: pos.col,
      line: pos.line,
      offset
    }
  }

  init(node, offset) {
    this.current.push(node);
    node.source = {
      input: this.input,
      start: this.getPosition(offset)
    };
    node.raws.before = this.spaces;
    this.spaces = '';
    if (node.type !== 'comment') this.semicolon = false;
  }

  other(start) {
    let end = false;
    let type = null;
    let colon = false;
    let bracket = null;
    let brackets = [];
    let customProperty = start[1].startsWith('--');

    let tokens = [];
    let token = start;
    while (token) {
      type = token[0];
      tokens.push(token);

      if (type === '(' || type === '[') {
        if (!bracket) bracket = token;
        brackets.push(type === '(' ? ')' : ']');
      } else if (customProperty && colon && type === '{') {
        if (!bracket) bracket = token;
        brackets.push('}');
      } else if (brackets.length === 0) {
        if (type === ';') {
          if (colon) {
            this.decl(tokens, customProperty);
            return
          } else {
            break
          }
        } else if (type === '{') {
          this.rule(tokens);
          return
        } else if (type === '}') {
          this.tokenizer.back(tokens.pop());
          end = true;
          break
        } else if (type === ':') {
          colon = true;
        }
      } else if (type === brackets[brackets.length - 1]) {
        brackets.pop();
        if (brackets.length === 0) bracket = null;
      }

      token = this.tokenizer.nextToken();
    }

    if (this.tokenizer.endOfFile()) end = true;
    if (brackets.length > 0) this.unclosedBracket(bracket);

    if (end && colon) {
      if (!customProperty) {
        while (tokens.length) {
          token = tokens[tokens.length - 1][0];
          if (token !== 'space' && token !== 'comment') break
          this.tokenizer.back(tokens.pop());
        }
      }
      this.decl(tokens, customProperty);
    } else {
      this.unknownWord(tokens);
    }
  }

  parse() {
    let token;
    while (!this.tokenizer.endOfFile()) {
      token = this.tokenizer.nextToken();

      switch (token[0]) {
        case 'space':
          this.spaces += token[1];
          break

        case ';':
          this.freeSemicolon(token);
          break

        case '}':
          this.end(token);
          break

        case 'comment':
          this.comment(token);
          break

        case 'at-word':
          this.atrule(token);
          break

        case '{':
          this.emptyRule(token);
          break

        default:
          this.other(token);
          break
      }
    }
    this.endFile();
  }

  precheckMissedSemicolon(/* tokens */) {
    // Hook for Safe Parser
  }

  raw(node, prop, tokens, customProperty) {
    let token, type;
    let length = tokens.length;
    let value = '';
    let clean = true;
    let next, prev;

    for (let i = 0; i < length; i += 1) {
      token = tokens[i];
      type = token[0];
      if (type === 'space' && i === length - 1 && !customProperty) {
        clean = false;
      } else if (type === 'comment') {
        prev = tokens[i - 1] ? tokens[i - 1][0] : 'empty';
        next = tokens[i + 1] ? tokens[i + 1][0] : 'empty';
        if (!SAFE_COMMENT_NEIGHBOR[prev] && !SAFE_COMMENT_NEIGHBOR[next]) {
          if (value.slice(-1) === ',') {
            clean = false;
          } else {
            value += token[1];
          }
        } else {
          clean = false;
        }
      } else {
        value += token[1];
      }
    }
    if (!clean) {
      let raw = tokens.reduce((all, i) => all + i[1], '');
      node.raws[prop] = { raw, value };
    }
    node[prop] = value;
  }

  rule(tokens) {
    tokens.pop();

    let node = new Rule$1();
    this.init(node, tokens[0][2]);

    node.raws.between = this.spacesAndCommentsFromEnd(tokens);
    this.raw(node, 'selector', tokens);
    this.current = node;
  }

  spacesAndCommentsFromEnd(tokens) {
    let lastTokenType;
    let spaces = '';
    while (tokens.length) {
      lastTokenType = tokens[tokens.length - 1][0];
      if (lastTokenType !== 'space' && lastTokenType !== 'comment') break
      spaces = tokens.pop()[1] + spaces;
    }
    return spaces
  }

  // Errors

  spacesAndCommentsFromStart(tokens) {
    let next;
    let spaces = '';
    while (tokens.length) {
      next = tokens[0][0];
      if (next !== 'space' && next !== 'comment') break
      spaces += tokens.shift()[1];
    }
    return spaces
  }

  spacesFromEnd(tokens) {
    let lastTokenType;
    let spaces = '';
    while (tokens.length) {
      lastTokenType = tokens[tokens.length - 1][0];
      if (lastTokenType !== 'space') break
      spaces = tokens.pop()[1] + spaces;
    }
    return spaces
  }

  stringFrom(tokens, from) {
    let result = '';
    for (let i = from; i < tokens.length; i++) {
      result += tokens[i][1];
    }
    tokens.splice(from, tokens.length - from);
    return result
  }

  unclosedBlock() {
    let pos = this.current.source.start;
    throw this.input.error('Unclosed block', pos.line, pos.column)
  }

  unclosedBracket(bracket) {
    throw this.input.error(
      'Unclosed bracket',
      { offset: bracket[2] },
      { offset: bracket[2] + 1 }
    )
  }

  unexpectedClose(token) {
    throw this.input.error(
      'Unexpected }',
      { offset: token[2] },
      { offset: token[2] + 1 }
    )
  }

  unknownWord(tokens) {
    throw this.input.error(
      'Unknown word ' + tokens[0][1],
      { offset: tokens[0][2] },
      { offset: tokens[0][2] + tokens[0][1].length }
    )
  }

  unnamedAtrule(node, token) {
    throw this.input.error(
      'At-rule without name',
      { offset: token[2] },
      { offset: token[2] + token[1].length }
    )
  }
}

var parser = Parser$1;

let Container$2 = container;
let Input$1 = input;
let Parser = parser;

function parse$3(css, opts) {
  let input = new Input$1(css, opts);
  let parser = new Parser(input);
  try {
    parser.parse();
  } catch (e) {
    throw e
  }

  return parser.root
}

var parse_1 = parse$3;
parse$3.default = parse$3;

Container$2.registerParse(parse$3);

class Warning$2 {
  constructor(text, opts = {}) {
    this.type = 'warning';
    this.text = text;

    if (opts.node && opts.node.source) {
      let range = opts.node.rangeBy(opts);
      this.line = range.start.line;
      this.column = range.start.column;
      this.endLine = range.end.line;
      this.endColumn = range.end.column;
    }

    for (let opt in opts) this[opt] = opts[opt];
  }

  toString() {
    if (this.node) {
      return this.node.error(this.text, {
        index: this.index,
        plugin: this.plugin,
        word: this.word
      }).message
    }

    if (this.plugin) {
      return this.plugin + ': ' + this.text
    }

    return this.text
  }
}

var warning = Warning$2;
Warning$2.default = Warning$2;

let Warning$1 = warning;

class Result$3 {
  get content() {
    return this.css
  }

  constructor(processor, root, opts) {
    this.processor = processor;
    this.messages = [];
    this.root = root;
    this.opts = opts;
    this.css = undefined;
    this.map = undefined;
  }

  toString() {
    return this.css
  }

  warn(text, opts = {}) {
    if (!opts.plugin) {
      if (this.lastPlugin && this.lastPlugin.postcssPlugin) {
        opts.plugin = this.lastPlugin.postcssPlugin;
      }
    }

    let warning = new Warning$1(text, opts);
    this.messages.push(warning);

    return warning
  }

  warnings() {
    return this.messages.filter(i => i.type === 'warning')
  }
}

var result = Result$3;
Result$3.default = Result$3;

let Container$1 = container;
let Document$2 = document;
let MapGenerator$1 = mapGenerator;
let parse$2 = parse_1;
let Result$2 = result;
let Root$2 = root;
let stringify$2 = stringify_1;
let { isClean, my } = symbols;

const TYPE_TO_CLASS_NAME = {
  atrule: 'AtRule',
  comment: 'Comment',
  decl: 'Declaration',
  document: 'Document',
  root: 'Root',
  rule: 'Rule'
};

const PLUGIN_PROPS = {
  AtRule: true,
  AtRuleExit: true,
  Comment: true,
  CommentExit: true,
  Declaration: true,
  DeclarationExit: true,
  Document: true,
  DocumentExit: true,
  Once: true,
  OnceExit: true,
  postcssPlugin: true,
  prepare: true,
  Root: true,
  RootExit: true,
  Rule: true,
  RuleExit: true
};

const NOT_VISITORS = {
  Once: true,
  postcssPlugin: true,
  prepare: true
};

const CHILDREN = 0;

function isPromise(obj) {
  return typeof obj === 'object' && typeof obj.then === 'function'
}

function getEvents(node) {
  let key = false;
  let type = TYPE_TO_CLASS_NAME[node.type];
  if (node.type === 'decl') {
    key = node.prop.toLowerCase();
  } else if (node.type === 'atrule') {
    key = node.name.toLowerCase();
  }

  if (key && node.append) {
    return [
      type,
      type + '-' + key,
      CHILDREN,
      type + 'Exit',
      type + 'Exit-' + key
    ]
  } else if (key) {
    return [type, type + '-' + key, type + 'Exit', type + 'Exit-' + key]
  } else if (node.append) {
    return [type, CHILDREN, type + 'Exit']
  } else {
    return [type, type + 'Exit']
  }
}

function toStack(node) {
  let events;
  if (node.type === 'document') {
    events = ['Document', CHILDREN, 'DocumentExit'];
  } else if (node.type === 'root') {
    events = ['Root', CHILDREN, 'RootExit'];
  } else {
    events = getEvents(node);
  }

  return {
    eventIndex: 0,
    events,
    iterator: 0,
    node,
    visitorIndex: 0,
    visitors: []
  }
}

function cleanMarks(node) {
  node[isClean] = false;
  if (node.nodes) node.nodes.forEach(i => cleanMarks(i));
  return node
}

let postcss$1 = {};

class LazyResult$2 {
  get content() {
    return this.stringify().content
  }

  get css() {
    return this.stringify().css
  }

  get map() {
    return this.stringify().map
  }

  get messages() {
    return this.sync().messages
  }

  get opts() {
    return this.result.opts
  }

  get processor() {
    return this.result.processor
  }

  get root() {
    return this.sync().root
  }

  get [Symbol.toStringTag]() {
    return 'LazyResult'
  }

  constructor(processor, css, opts) {
    this.stringified = false;
    this.processed = false;

    let root;
    if (
      typeof css === 'object' &&
      css !== null &&
      (css.type === 'root' || css.type === 'document')
    ) {
      root = cleanMarks(css);
    } else if (css instanceof LazyResult$2 || css instanceof Result$2) {
      root = cleanMarks(css.root);
      if (css.map) {
        if (typeof opts.map === 'undefined') opts.map = {};
        if (!opts.map.inline) opts.map.inline = false;
        opts.map.prev = css.map;
      }
    } else {
      let parser = parse$2;
      if (opts.syntax) parser = opts.syntax.parse;
      if (opts.parser) parser = opts.parser;
      if (parser.parse) parser = parser.parse;

      try {
        root = parser(css, opts);
      } catch (error) {
        this.processed = true;
        this.error = error;
      }

      if (root && !root[my]) {
        /* c8 ignore next 2 */
        Container$1.rebuild(root);
      }
    }

    this.result = new Result$2(processor, root, opts);
    this.helpers = { ...postcss$1, postcss: postcss$1, result: this.result };
    this.plugins = this.processor.plugins.map(plugin => {
      if (typeof plugin === 'object' && plugin.prepare) {
        return { ...plugin, ...plugin.prepare(this.result) }
      } else {
        return plugin
      }
    });
  }

  async() {
    if (this.error) return Promise.reject(this.error)
    if (this.processed) return Promise.resolve(this.result)
    if (!this.processing) {
      this.processing = this.runAsync();
    }
    return this.processing
  }

  catch(onRejected) {
    return this.async().catch(onRejected)
  }

  finally(onFinally) {
    return this.async().then(onFinally, onFinally)
  }

  getAsyncError() {
    throw new Error('Use process(css).then(cb) to work with async plugins')
  }

  handleError(error, node) {
    let plugin = this.result.lastPlugin;
    try {
      if (node) node.addToError(error);
      this.error = error;
      if (error.name === 'CssSyntaxError' && !error.plugin) {
        error.plugin = plugin.postcssPlugin;
        error.setMessage();
      }
    } catch (err) {
      /* c8 ignore next 3 */
      // eslint-disable-next-line no-console
      if (console && console.error) console.error(err);
    }
    return error
  }

  prepareVisitors() {
    this.listeners = {};
    let add = (plugin, type, cb) => {
      if (!this.listeners[type]) this.listeners[type] = [];
      this.listeners[type].push([plugin, cb]);
    };
    for (let plugin of this.plugins) {
      if (typeof plugin === 'object') {
        for (let event in plugin) {
          if (!PLUGIN_PROPS[event] && /^[A-Z]/.test(event)) {
            throw new Error(
              `Unknown event ${event} in ${plugin.postcssPlugin}. ` +
                `Try to update PostCSS (${this.processor.version} now).`
            )
          }
          if (!NOT_VISITORS[event]) {
            if (typeof plugin[event] === 'object') {
              for (let filter in plugin[event]) {
                if (filter === '*') {
                  add(plugin, event, plugin[event][filter]);
                } else {
                  add(
                    plugin,
                    event + '-' + filter.toLowerCase(),
                    plugin[event][filter]
                  );
                }
              }
            } else if (typeof plugin[event] === 'function') {
              add(plugin, event, plugin[event]);
            }
          }
        }
      }
    }
    this.hasListener = Object.keys(this.listeners).length > 0;
  }

  async runAsync() {
    this.plugin = 0;
    for (let i = 0; i < this.plugins.length; i++) {
      let plugin = this.plugins[i];
      let promise = this.runOnRoot(plugin);
      if (isPromise(promise)) {
        try {
          await promise;
        } catch (error) {
          throw this.handleError(error)
        }
      }
    }

    this.prepareVisitors();
    if (this.hasListener) {
      let root = this.result.root;
      while (!root[isClean]) {
        root[isClean] = true;
        let stack = [toStack(root)];
        while (stack.length > 0) {
          let promise = this.visitTick(stack);
          if (isPromise(promise)) {
            try {
              await promise;
            } catch (e) {
              let node = stack[stack.length - 1].node;
              throw this.handleError(e, node)
            }
          }
        }
      }

      if (this.listeners.OnceExit) {
        for (let [plugin, visitor] of this.listeners.OnceExit) {
          this.result.lastPlugin = plugin;
          try {
            if (root.type === 'document') {
              let roots = root.nodes.map(subRoot =>
                visitor(subRoot, this.helpers)
              );

              await Promise.all(roots);
            } else {
              await visitor(root, this.helpers);
            }
          } catch (e) {
            throw this.handleError(e)
          }
        }
      }
    }

    this.processed = true;
    return this.stringify()
  }

  runOnRoot(plugin) {
    this.result.lastPlugin = plugin;
    try {
      if (typeof plugin === 'object' && plugin.Once) {
        if (this.result.root.type === 'document') {
          let roots = this.result.root.nodes.map(root =>
            plugin.Once(root, this.helpers)
          );

          if (isPromise(roots[0])) {
            return Promise.all(roots)
          }

          return roots
        }

        return plugin.Once(this.result.root, this.helpers)
      } else if (typeof plugin === 'function') {
        return plugin(this.result.root, this.result)
      }
    } catch (error) {
      throw this.handleError(error)
    }
  }

  stringify() {
    if (this.error) throw this.error
    if (this.stringified) return this.result
    this.stringified = true;

    this.sync();

    let opts = this.result.opts;
    let str = stringify$2;
    if (opts.syntax) str = opts.syntax.stringify;
    if (opts.stringifier) str = opts.stringifier;
    if (str.stringify) str = str.stringify;

    let map = new MapGenerator$1(str, this.result.root, this.result.opts);
    let data = map.generate();
    this.result.css = data[0];
    this.result.map = data[1];

    return this.result
  }

  sync() {
    if (this.error) throw this.error
    if (this.processed) return this.result
    this.processed = true;

    if (this.processing) {
      throw this.getAsyncError()
    }

    for (let plugin of this.plugins) {
      let promise = this.runOnRoot(plugin);
      if (isPromise(promise)) {
        throw this.getAsyncError()
      }
    }

    this.prepareVisitors();
    if (this.hasListener) {
      let root = this.result.root;
      while (!root[isClean]) {
        root[isClean] = true;
        this.walkSync(root);
      }
      if (this.listeners.OnceExit) {
        if (root.type === 'document') {
          for (let subRoot of root.nodes) {
            this.visitSync(this.listeners.OnceExit, subRoot);
          }
        } else {
          this.visitSync(this.listeners.OnceExit, root);
        }
      }
    }

    return this.result
  }

  then(onFulfilled, onRejected) {
    return this.async().then(onFulfilled, onRejected)
  }

  toString() {
    return this.css
  }

  visitSync(visitors, node) {
    for (let [plugin, visitor] of visitors) {
      this.result.lastPlugin = plugin;
      let promise;
      try {
        promise = visitor(node, this.helpers);
      } catch (e) {
        throw this.handleError(e, node.proxyOf)
      }
      if (node.type !== 'root' && node.type !== 'document' && !node.parent) {
        return true
      }
      if (isPromise(promise)) {
        throw this.getAsyncError()
      }
    }
  }

  visitTick(stack) {
    let visit = stack[stack.length - 1];
    let { node, visitors } = visit;

    if (node.type !== 'root' && node.type !== 'document' && !node.parent) {
      stack.pop();
      return
    }

    if (visitors.length > 0 && visit.visitorIndex < visitors.length) {
      let [plugin, visitor] = visitors[visit.visitorIndex];
      visit.visitorIndex += 1;
      if (visit.visitorIndex === visitors.length) {
        visit.visitors = [];
        visit.visitorIndex = 0;
      }
      this.result.lastPlugin = plugin;
      try {
        return visitor(node.toProxy(), this.helpers)
      } catch (e) {
        throw this.handleError(e, node)
      }
    }

    if (visit.iterator !== 0) {
      let iterator = visit.iterator;
      let child;
      while ((child = node.nodes[node.indexes[iterator]])) {
        node.indexes[iterator] += 1;
        if (!child[isClean]) {
          child[isClean] = true;
          stack.push(toStack(child));
          return
        }
      }
      visit.iterator = 0;
      delete node.indexes[iterator];
    }

    let events = visit.events;
    while (visit.eventIndex < events.length) {
      let event = events[visit.eventIndex];
      visit.eventIndex += 1;
      if (event === CHILDREN) {
        if (node.nodes && node.nodes.length) {
          node[isClean] = true;
          visit.iterator = node.getIterator();
        }
        return
      } else if (this.listeners[event]) {
        visit.visitors = this.listeners[event];
        return
      }
    }
    stack.pop();
  }

  walkSync(node) {
    node[isClean] = true;
    let events = getEvents(node);
    for (let event of events) {
      if (event === CHILDREN) {
        if (node.nodes) {
          node.each(child => {
            if (!child[isClean]) this.walkSync(child);
          });
        }
      } else {
        let visitors = this.listeners[event];
        if (visitors) {
          if (this.visitSync(visitors, node.toProxy())) return
        }
      }
    }
  }

  warnings() {
    return this.sync().warnings()
  }
}

LazyResult$2.registerPostcss = dependant => {
  postcss$1 = dependant;
};

var lazyResult = LazyResult$2;
LazyResult$2.default = LazyResult$2;

Root$2.registerLazyResult(LazyResult$2);
Document$2.registerLazyResult(LazyResult$2);

let MapGenerator = mapGenerator;
let parse$1 = parse_1;
const Result$1 = result;
let stringify$1 = stringify_1;

class NoWorkResult$1 {
  get content() {
    return this.result.css
  }

  get css() {
    return this.result.css
  }

  get map() {
    return this.result.map
  }

  get messages() {
    return []
  }

  get opts() {
    return this.result.opts
  }

  get processor() {
    return this.result.processor
  }

  get root() {
    if (this._root) {
      return this._root
    }

    let root;
    let parser = parse$1;

    try {
      root = parser(this._css, this._opts);
    } catch (error) {
      this.error = error;
    }

    if (this.error) {
      throw this.error
    } else {
      this._root = root;
      return root
    }
  }

  get [Symbol.toStringTag]() {
    return 'NoWorkResult'
  }

  constructor(processor, css, opts) {
    css = css.toString();
    this.stringified = false;

    this._processor = processor;
    this._css = css;
    this._opts = opts;
    this._map = undefined;
    let root;

    let str = stringify$1;
    this.result = new Result$1(this._processor, root, this._opts);
    this.result.css = css;

    let self = this;
    Object.defineProperty(this.result, 'root', {
      get() {
        return self.root
      }
    });

    let map = new MapGenerator(str, root, this._opts, css);
    if (map.isMap()) {
      let [generatedCSS, generatedMap] = map.generate();
      if (generatedCSS) {
        this.result.css = generatedCSS;
      }
      if (generatedMap) {
        this.result.map = generatedMap;
      }
    } else {
      map.clearAnnotation();
      this.result.css = map.css;
    }
  }

  async() {
    if (this.error) return Promise.reject(this.error)
    return Promise.resolve(this.result)
  }

  catch(onRejected) {
    return this.async().catch(onRejected)
  }

  finally(onFinally) {
    return this.async().then(onFinally, onFinally)
  }

  sync() {
    if (this.error) throw this.error
    return this.result
  }

  then(onFulfilled, onRejected) {

    return this.async().then(onFulfilled, onRejected)
  }

  toString() {
    return this._css
  }

  warnings() {
    return []
  }
}

var noWorkResult = NoWorkResult$1;
NoWorkResult$1.default = NoWorkResult$1;

let Document$1 = document;
let LazyResult$1 = lazyResult;
let NoWorkResult = noWorkResult;
let Root$1 = root;

class Processor$1 {
  constructor(plugins = []) {
    this.version = '8.5.3';
    this.plugins = this.normalize(plugins);
  }

  normalize(plugins) {
    let normalized = [];
    for (let i of plugins) {
      if (i.postcss === true) {
        i = i();
      } else if (i.postcss) {
        i = i.postcss;
      }

      if (typeof i === 'object' && Array.isArray(i.plugins)) {
        normalized = normalized.concat(i.plugins);
      } else if (typeof i === 'object' && i.postcssPlugin) {
        normalized.push(i);
      } else if (typeof i === 'function') {
        normalized.push(i);
      } else if (typeof i === 'object' && (i.parse || i.stringify)) ; else {
        throw new Error(i + ' is not a PostCSS plugin')
      }
    }
    return normalized
  }

  process(css, opts = {}) {
    if (
      !this.plugins.length &&
      !opts.parser &&
      !opts.stringifier &&
      !opts.syntax
    ) {
      return new NoWorkResult(this, css, opts)
    } else {
      return new LazyResult$1(this, css, opts)
    }
  }

  use(plugin) {
    this.plugins = this.plugins.concat(this.normalize([plugin]));
    return this
  }
}

var processor = Processor$1;
Processor$1.default = Processor$1;

Root$1.registerProcessor(Processor$1);
Document$1.registerProcessor(Processor$1);

let AtRule = atRule;
let Comment = comment;
let Container = container;
let CssSyntaxError = cssSyntaxError;
let Declaration = declaration;
let Document = document;
let fromJSON = fromJSON_1;
let Input = input;
let LazyResult = lazyResult;
let list = list_1;
let Node = node_1;
let parse = parse_1;
let Processor = processor;
let Result = result;
let Root = root;
let Rule = rule;
let stringify = stringify_1;
let Warning = warning;

function postcss(...plugins) {
  if (plugins.length === 1 && Array.isArray(plugins[0])) {
    plugins = plugins[0];
  }
  return new Processor(plugins)
}

postcss.plugin = function plugin(name, initializer) {
  let warningPrinted = false;
  function creator(...args) {
    // eslint-disable-next-line no-console
    if (console && console.warn && !warningPrinted) {
      warningPrinted = true;
      // eslint-disable-next-line no-console
      console.warn(
        name +
          ': postcss.plugin was deprecated. Migration guide:\n' +
          'https://evilmartians.com/chronicles/postcss-8-plugin-migration'
      );
      if (process.env.LANG && process.env.LANG.startsWith('cn')) {
        /* c8 ignore next 7 */
        // eslint-disable-next-line no-console
        console.warn(
          name +
            ': 里面 postcss.plugin 被弃用. 迁移指南:\n' +
            'https://www.w3ctech.com/topic/2226'
        );
      }
    }
    let transformer = initializer(...args);
    transformer.postcssPlugin = name;
    transformer.postcssVersion = new Processor().version;
    return transformer
  }

  let cache;
  Object.defineProperty(creator, 'postcss', {
    get() {
      if (!cache) cache = creator();
      return cache
    }
  });

  creator.process = function (css, processOpts, pluginOpts) {
    return postcss([creator(pluginOpts)]).process(css, processOpts)
  };

  return creator
};

postcss.stringify = stringify;
postcss.parse = parse;
postcss.fromJSON = fromJSON;
postcss.list = list;

postcss.comment = defaults => new Comment(defaults);
postcss.atRule = defaults => new AtRule(defaults);
postcss.decl = defaults => new Declaration(defaults);
postcss.rule = defaults => new Rule(defaults);
postcss.root = defaults => new Root(defaults);
postcss.document = defaults => new Document(defaults);

postcss.CssSyntaxError = CssSyntaxError;
postcss.Declaration = Declaration;
postcss.Container = Container;
postcss.Processor = Processor;
postcss.Document = Document;
postcss.Comment = Comment;
postcss.Warning = Warning;
postcss.AtRule = AtRule;
postcss.Result = Result;
postcss.Input = Input;
postcss.Rule = Rule;
postcss.Root = Root;
postcss.Node = Node;

LazyResult.registerPostcss(postcss);

var postcss_1 = postcss;
postcss.default = postcss;

const htmlparser = require$$0$1;
const escapeStringRegexp = escapeStringRegexp$1;
const { isPlainObject } = require$$2$1;
const deepmerge = cjs;
const parseSrcset = parseSrcset$1.exports;
const { parse: postcssParse } = postcss_1;
// Tags that can conceivably represent stand-alone media.
const mediaTags = [
  'img', 'audio', 'video', 'picture', 'svg',
  'object', 'map', 'iframe', 'embed'
];
// Tags that are inherently vulnerable to being used in XSS attacks.
const vulnerableTags = [ 'script', 'style' ];

function each(obj, cb) {
  if (obj) {
    Object.keys(obj).forEach(function (key) {
      cb(obj[key], key);
    });
  }
}

// Avoid false positives with .__proto__, .hasOwnProperty, etc.
function has(obj, key) {
  return ({}).hasOwnProperty.call(obj, key);
}

// Returns those elements of `a` for which `cb(a)` returns truthy
function filter(a, cb) {
  const n = [];
  each(a, function(v) {
    if (cb(v)) {
      n.push(v);
    }
  });
  return n;
}

function isEmptyObject(obj) {
  for (const key in obj) {
    if (has(obj, key)) {
      return false;
    }
  }
  return true;
}

function stringifySrcset(parsedSrcset) {
  return parsedSrcset.map(function(part) {
    if (!part.url) {
      throw new Error('URL missing');
    }

    return (
      part.url +
      (part.w ? ` ${part.w}w` : '') +
      (part.h ? ` ${part.h}h` : '') +
      (part.d ? ` ${part.d}x` : '')
    );
  }).join(', ');
}

var sanitizeHtml_1 = sanitizeHtml;

// A valid attribute name.
// We use a tolerant definition based on the set of strings defined by
// html.spec.whatwg.org/multipage/parsing.html#before-attribute-name-state
// and html.spec.whatwg.org/multipage/parsing.html#attribute-name-state .
// The characters accepted are ones which can be appended to the attribute
// name buffer without triggering a parse error:
//   * unexpected-equals-sign-before-attribute-name
//   * unexpected-null-character
//   * unexpected-character-in-attribute-name
// We exclude the empty string because it's impossible to get to the after
// attribute name state with an empty attribute name buffer.
const VALID_HTML_ATTRIBUTE_NAME = /^[^\0\t\n\f\r /<=>]+$/;

// Ignore the _recursing flag; it's there for recursive
// invocation as a guard against this exploit:
// https://github.com/fb55/htmlparser2/issues/105

function sanitizeHtml(html, options, _recursing) {
  if (html == null) {
    return '';
  }
  if (typeof html === 'number') {
    html = html.toString();
  }

  let result = '';
  // Used for hot swapping the result variable with an empty string in order to "capture" the text written to it.
  let tempResult = '';

  function Frame(tag, attribs) {
    const that = this;
    this.tag = tag;
    this.attribs = attribs || {};
    this.tagPosition = result.length;
    this.text = ''; // Node inner text
    this.mediaChildren = [];

    this.updateParentNodeText = function() {
      if (stack.length) {
        const parentFrame = stack[stack.length - 1];
        parentFrame.text += that.text;
      }
    };

    this.updateParentNodeMediaChildren = function() {
      if (stack.length && mediaTags.includes(this.tag)) {
        const parentFrame = stack[stack.length - 1];
        parentFrame.mediaChildren.push(this.tag);
      }
    };
  }

  options = Object.assign({}, sanitizeHtml.defaults, options);
  options.parser = Object.assign({}, htmlParserDefaults, options.parser);

  const tagAllowed = function (name) {
    return options.allowedTags === false || (options.allowedTags || []).indexOf(name) > -1;
  };

  // vulnerableTags
  vulnerableTags.forEach(function (tag) {
    if (tagAllowed(tag) && !options.allowVulnerableTags) {
      console.warn(`\n\n⚠️ Your \`allowedTags\` option includes, \`${tag}\`, which is inherently\nvulnerable to XSS attacks. Please remove it from \`allowedTags\`.\nOr, to disable this warning, add the \`allowVulnerableTags\` option\nand ensure you are accounting for this risk.\n\n`);
    }
  });

  // Tags that contain something other than HTML, or where discarding
  // the text when the tag is disallowed makes sense for other reasons.
  // If we are not allowing these tags, we should drop their content too.
  // For other tags you would drop the tag but keep its content.
  const nonTextTagsArray = options.nonTextTags || [
    'script',
    'style',
    'textarea',
    'option'
  ];
  let allowedAttributesMap;
  let allowedAttributesGlobMap;
  if (options.allowedAttributes) {
    allowedAttributesMap = {};
    allowedAttributesGlobMap = {};
    each(options.allowedAttributes, function(attributes, tag) {
      allowedAttributesMap[tag] = [];
      const globRegex = [];
      attributes.forEach(function(obj) {
        if (typeof obj === 'string' && obj.indexOf('*') >= 0) {
          globRegex.push(escapeStringRegexp(obj).replace(/\\\*/g, '.*'));
        } else {
          allowedAttributesMap[tag].push(obj);
        }
      });
      if (globRegex.length) {
        allowedAttributesGlobMap[tag] = new RegExp('^(' + globRegex.join('|') + ')$');
      }
    });
  }
  const allowedClassesMap = {};
  const allowedClassesGlobMap = {};
  const allowedClassesRegexMap = {};
  each(options.allowedClasses, function(classes, tag) {
    // Implicitly allows the class attribute
    if (allowedAttributesMap) {
      if (!has(allowedAttributesMap, tag)) {
        allowedAttributesMap[tag] = [];
      }
      allowedAttributesMap[tag].push('class');
    }

    allowedClassesMap[tag] = classes;

    if (Array.isArray(classes)) {
      const globRegex = [];
      allowedClassesMap[tag] = [];
      allowedClassesRegexMap[tag] = [];
      classes.forEach(function(obj) {
        if (typeof obj === 'string' && obj.indexOf('*') >= 0) {
          globRegex.push(escapeStringRegexp(obj).replace(/\\\*/g, '.*'));
        } else if (obj instanceof RegExp) {
          allowedClassesRegexMap[tag].push(obj);
        } else {
          allowedClassesMap[tag].push(obj);
        }
      });
      if (globRegex.length) {
        allowedClassesGlobMap[tag] = new RegExp('^(' + globRegex.join('|') + ')$');
      }
    }
  });

  const transformTagsMap = {};
  let transformTagsAll;
  each(options.transformTags, function(transform, tag) {
    let transFun;
    if (typeof transform === 'function') {
      transFun = transform;
    } else if (typeof transform === 'string') {
      transFun = sanitizeHtml.simpleTransform(transform);
    }
    if (tag === '*') {
      transformTagsAll = transFun;
    } else {
      transformTagsMap[tag] = transFun;
    }
  });

  let depth;
  let stack;
  let skipMap;
  let transformMap;
  let skipText;
  let skipTextDepth;
  let addedText = false;

  initializeState();

  const parser = new htmlparser.Parser({
    onopentag: function(name, attribs) {
      // If `enforceHtmlBoundary` is `true` and this has found the opening
      // `html` tag, reset the state.
      if (options.enforceHtmlBoundary && name === 'html') {
        initializeState();
      }

      if (skipText) {
        skipTextDepth++;
        return;
      }
      const frame = new Frame(name, attribs);
      stack.push(frame);

      let skip = false;
      const hasText = !!frame.text;
      let transformedTag;
      if (has(transformTagsMap, name)) {
        transformedTag = transformTagsMap[name](name, attribs);

        frame.attribs = attribs = transformedTag.attribs;

        if (transformedTag.text !== undefined) {
          frame.innerText = transformedTag.text;
        }

        if (name !== transformedTag.tagName) {
          frame.name = name = transformedTag.tagName;
          transformMap[depth] = transformedTag.tagName;
        }
      }
      if (transformTagsAll) {
        transformedTag = transformTagsAll(name, attribs);

        frame.attribs = attribs = transformedTag.attribs;
        if (name !== transformedTag.tagName) {
          frame.name = name = transformedTag.tagName;
          transformMap[depth] = transformedTag.tagName;
        }
      }

      if (!tagAllowed(name) || (options.disallowedTagsMode === 'recursiveEscape' && !isEmptyObject(skipMap)) || (options.nestingLimit != null && depth >= options.nestingLimit)) {
        skip = true;
        skipMap[depth] = true;
        if (options.disallowedTagsMode === 'discard' || options.disallowedTagsMode === 'completelyDiscard') {
          if (nonTextTagsArray.indexOf(name) !== -1) {
            skipText = true;
            skipTextDepth = 1;
          }
        }
        skipMap[depth] = true;
      }
      depth++;
      if (skip) {
        if (options.disallowedTagsMode === 'discard' || options.disallowedTagsMode === 'completelyDiscard') {
          // We want the contents but not this tag
          return;
        }
        tempResult = result;
        result = '';
      }
      result += '<' + name;

      if (name === 'script') {
        if (options.allowedScriptHostnames || options.allowedScriptDomains) {
          frame.innerText = '';
        }
      }

      if (!allowedAttributesMap || has(allowedAttributesMap, name) || allowedAttributesMap['*']) {
        each(attribs, function(value, a) {
          if (!VALID_HTML_ATTRIBUTE_NAME.test(a)) {
            // This prevents part of an attribute name in the output from being
            // interpreted as the end of an attribute, or end of a tag.
            delete frame.attribs[a];
            return;
          }
          // If the value is empty, check if the attribute is in the allowedEmptyAttributes array.
          // If it is not in the allowedEmptyAttributes array, and it is a known non-boolean attribute, delete it
          // List taken from https://html.spec.whatwg.org/multipage/indices.html#attributes-3
          if (value === '' && (!options.allowedEmptyAttributes.includes(a)) &&
            (options.nonBooleanAttributes.includes(a) || options.nonBooleanAttributes.includes('*'))) {
            delete frame.attribs[a];
            return;
          }
          // check allowedAttributesMap for the element and attribute and modify the value
          // as necessary if there are specific values defined.
          let passedAllowedAttributesMapCheck = false;
          if (!allowedAttributesMap ||
            (has(allowedAttributesMap, name) && allowedAttributesMap[name].indexOf(a) !== -1) ||
            (allowedAttributesMap['*'] && allowedAttributesMap['*'].indexOf(a) !== -1) ||
            (has(allowedAttributesGlobMap, name) && allowedAttributesGlobMap[name].test(a)) ||
            (allowedAttributesGlobMap['*'] && allowedAttributesGlobMap['*'].test(a))) {
            passedAllowedAttributesMapCheck = true;
          } else if (allowedAttributesMap && allowedAttributesMap[name]) {
            for (const o of allowedAttributesMap[name]) {
              if (isPlainObject(o) && o.name && (o.name === a)) {
                passedAllowedAttributesMapCheck = true;
                let newValue = '';
                if (o.multiple === true) {
                  // verify the values that are allowed
                  const splitStrArray = value.split(' ');
                  for (const s of splitStrArray) {
                    if (o.values.indexOf(s) !== -1) {
                      if (newValue === '') {
                        newValue = s;
                      } else {
                        newValue += ' ' + s;
                      }
                    }
                  }
                } else if (o.values.indexOf(value) >= 0) {
                  // verified an allowed value matches the entire attribute value
                  newValue = value;
                }
                value = newValue;
              }
            }
          }
          if (passedAllowedAttributesMapCheck) {
            if (options.allowedSchemesAppliedToAttributes.indexOf(a) !== -1) {
              if (naughtyHref(name, value)) {
                delete frame.attribs[a];
                return;
              }
            }

            if (name === 'script' && a === 'src') {

              let allowed = true;

              try {
                const parsed = parseUrl(value);

                if (options.allowedScriptHostnames || options.allowedScriptDomains) {
                  const allowedHostname = (options.allowedScriptHostnames || []).find(function (hostname) {
                    return hostname === parsed.url.hostname;
                  });
                  const allowedDomain = (options.allowedScriptDomains || []).find(function(domain) {
                    return parsed.url.hostname === domain || parsed.url.hostname.endsWith(`.${domain}`);
                  });
                  allowed = allowedHostname || allowedDomain;
                }
              } catch (e) {
                allowed = false;
              }

              if (!allowed) {
                delete frame.attribs[a];
                return;
              }
            }

            if (name === 'iframe' && a === 'src') {
              let allowed = true;
              try {
                const parsed = parseUrl(value);

                if (parsed.isRelativeUrl) {
                  // default value of allowIframeRelativeUrls is true
                  // unless allowedIframeHostnames or allowedIframeDomains specified
                  allowed = has(options, 'allowIframeRelativeUrls')
                    ? options.allowIframeRelativeUrls
                    : (!options.allowedIframeHostnames && !options.allowedIframeDomains);
                } else if (options.allowedIframeHostnames || options.allowedIframeDomains) {
                  const allowedHostname = (options.allowedIframeHostnames || []).find(function (hostname) {
                    return hostname === parsed.url.hostname;
                  });
                  const allowedDomain = (options.allowedIframeDomains || []).find(function(domain) {
                    return parsed.url.hostname === domain || parsed.url.hostname.endsWith(`.${domain}`);
                  });
                  allowed = allowedHostname || allowedDomain;
                }
              } catch (e) {
                // Unparseable iframe src
                allowed = false;
              }
              if (!allowed) {
                delete frame.attribs[a];
                return;
              }
            }
            if (a === 'srcset') {
              try {
                let parsed = parseSrcset(value);
                parsed.forEach(function(value) {
                  if (naughtyHref('srcset', value.url)) {
                    value.evil = true;
                  }
                });
                parsed = filter(parsed, function(v) {
                  return !v.evil;
                });
                if (!parsed.length) {
                  delete frame.attribs[a];
                  return;
                } else {
                  value = stringifySrcset(filter(parsed, function(v) {
                    return !v.evil;
                  }));
                  frame.attribs[a] = value;
                }
              } catch (e) {
                // Unparseable srcset
                delete frame.attribs[a];
                return;
              }
            }
            if (a === 'class') {
              const allowedSpecificClasses = allowedClassesMap[name];
              const allowedWildcardClasses = allowedClassesMap['*'];
              const allowedSpecificClassesGlob = allowedClassesGlobMap[name];
              const allowedSpecificClassesRegex = allowedClassesRegexMap[name];
              const allowedWildcardClassesGlob = allowedClassesGlobMap['*'];
              const allowedClassesGlobs = [
                allowedSpecificClassesGlob,
                allowedWildcardClassesGlob
              ]
                .concat(allowedSpecificClassesRegex)
                .filter(function (t) {
                  return t;
                });
              if (allowedSpecificClasses && allowedWildcardClasses) {
                value = filterClasses(value, deepmerge(allowedSpecificClasses, allowedWildcardClasses), allowedClassesGlobs);
              } else {
                value = filterClasses(value, allowedSpecificClasses || allowedWildcardClasses, allowedClassesGlobs);
              }
              if (!value.length) {
                delete frame.attribs[a];
                return;
              }
            }
            if (a === 'style') {
              if (options.parseStyleAttributes) {
                try {
                  const abstractSyntaxTree = postcssParse(name + ' {' + value + '}', { map: false });
                  const filteredAST = filterCss(abstractSyntaxTree, options.allowedStyles);

                  value = stringifyStyleAttributes(filteredAST);

                  if (value.length === 0) {
                    delete frame.attribs[a];
                    return;
                  }
                } catch (e) {
                  if (typeof window !== 'undefined') {
                    console.warn('Failed to parse "' + name + ' {' + value + '}' + '", If you\'re running this in a browser, we recommend to disable style parsing: options.parseStyleAttributes: false, since this only works in a node environment due to a postcss dependency, More info: https://github.com/apostrophecms/sanitize-html/issues/547');
                  }
                  delete frame.attribs[a];
                  return;
                }
              } else if (options.allowedStyles) {
                throw new Error('allowedStyles option cannot be used together with parseStyleAttributes: false.');
              }
            }
            result += ' ' + a;
            if (value && value.length) {
              result += '="' + escapeHtml(value, true) + '"';
            } else if (options.allowedEmptyAttributes.includes(a)) {
              result += '=""';
            }
          } else {
            delete frame.attribs[a];
          }
        });
      }
      if (options.selfClosing.indexOf(name) !== -1) {
        result += ' />';
      } else {
        result += '>';
        if (frame.innerText && !hasText && !options.textFilter) {
          result += escapeHtml(frame.innerText);
          addedText = true;
        }
      }
      if (skip) {
        result = tempResult + escapeHtml(result);
        tempResult = '';
      }
    },
    ontext: function(text) {
      if (skipText) {
        return;
      }
      const lastFrame = stack[stack.length - 1];
      let tag;

      if (lastFrame) {
        tag = lastFrame.tag;
        // If inner text was set by transform function then let's use it
        text = lastFrame.innerText !== undefined ? lastFrame.innerText : text;
      }

      if (options.disallowedTagsMode === 'completelyDiscard' && !tagAllowed(tag)) {
        text = '';
      } else if ((options.disallowedTagsMode === 'discard' || options.disallowedTagsMode === 'completelyDiscard') && ((tag === 'script') || (tag === 'style'))) {
        // htmlparser2 gives us these as-is. Escaping them ruins the content. Allowing
        // script tags is, by definition, game over for XSS protection, so if that's
        // your concern, don't allow them. The same is essentially true for style tags
        // which have their own collection of XSS vectors.
        result += text;
      } else {
        const escaped = escapeHtml(text, false);
        if (options.textFilter && !addedText) {
          result += options.textFilter(escaped, tag);
        } else if (!addedText) {
          result += escaped;
        }
      }
      if (stack.length) {
        const frame = stack[stack.length - 1];
        frame.text += text;
      }
    },
    onclosetag: function(name, isImplied) {

      if (skipText) {
        skipTextDepth--;
        if (!skipTextDepth) {
          skipText = false;
        } else {
          return;
        }
      }

      const frame = stack.pop();
      if (!frame) {
        // Do not crash on bad markup
        return;
      }

      if (frame.tag !== name) {
        // Another case of bad markup.
        // Push to stack, so that it will be used in future closing tags.
        stack.push(frame);
        return;
      }

      skipText = options.enforceHtmlBoundary ? name === 'html' : false;
      depth--;
      const skip = skipMap[depth];
      if (skip) {
        delete skipMap[depth];
        if (options.disallowedTagsMode === 'discard' || options.disallowedTagsMode === 'completelyDiscard') {
          frame.updateParentNodeText();
          return;
        }
        tempResult = result;
        result = '';
      }

      if (transformMap[depth]) {
        name = transformMap[depth];
        delete transformMap[depth];
      }

      if (options.exclusiveFilter && options.exclusiveFilter(frame)) {
        result = result.substr(0, frame.tagPosition);
        return;
      }

      frame.updateParentNodeMediaChildren();
      frame.updateParentNodeText();

      if (
        // Already output />
        options.selfClosing.indexOf(name) !== -1 ||
        // Escaped tag, closing tag is implied
        (isImplied && !tagAllowed(name) && [ 'escape', 'recursiveEscape' ].indexOf(options.disallowedTagsMode) >= 0)
      ) {
        if (skip) {
          result = tempResult;
          tempResult = '';
        }
        return;
      }

      result += '</' + name + '>';
      if (skip) {
        result = tempResult + escapeHtml(result);
        tempResult = '';
      }
      addedText = false;
    }
  }, options.parser);
  parser.write(html);
  parser.end();

  return result;

  function initializeState() {
    result = '';
    depth = 0;
    stack = [];
    skipMap = {};
    transformMap = {};
    skipText = false;
    skipTextDepth = 0;
  }

  function escapeHtml(s, quote) {
    if (typeof (s) !== 'string') {
      s = s + '';
    }
    if (options.parser.decodeEntities) {
      s = s.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;');
      if (quote) {
        s = s.replace(/"/g, '&quot;');
      }
    }
    // TODO: this is inadequate because it will pass `&0;`. This approach
    // will not work, each & must be considered with regard to whether it
    // is followed by a 100% syntactically valid entity or not, and escaped
    // if it is not. If this bothers you, don't set parser.decodeEntities
    // to false. (The default is true.)
    s = s.replace(/&(?![a-zA-Z0-9#]{1,20};)/g, '&amp;') // Match ampersands not part of existing HTML entity
      .replace(/</g, '&lt;')
      .replace(/>/g, '&gt;');
    if (quote) {
      s = s.replace(/"/g, '&quot;');
    }
    return s;
  }

  function naughtyHref(name, href) {
    // Browsers ignore character codes of 32 (space) and below in a surprising
    // number of situations. Start reading here:
    // https://www.owasp.org/index.php/XSS_Filter_Evasion_Cheat_Sheet#Embedded_tab
    // eslint-disable-next-line no-control-regex
    href = href.replace(/[\x00-\x20]+/g, '');
    // Clobber any comments in URLs, which the browser might
    // interpret inside an XML data island, allowing
    // a javascript: URL to be snuck through
    while (true) {
      const firstIndex = href.indexOf('<!--');
      if (firstIndex === -1) {
        break;
      }
      const lastIndex = href.indexOf('-->', firstIndex + 4);
      if (lastIndex === -1) {
        break;
      }
      href = href.substring(0, firstIndex) + href.substring(lastIndex + 3);
    }
    // Case insensitive so we don't get faked out by JAVASCRIPT #1
    // Allow more characters after the first so we don't get faked
    // out by certain schemes browsers accept
    const matches = href.match(/^([a-zA-Z][a-zA-Z0-9.\-+]*):/);
    if (!matches) {
      // Protocol-relative URL starting with any combination of '/' and '\'
      if (href.match(/^[/\\]{2}/)) {
        return !options.allowProtocolRelative;
      }

      // No scheme
      return false;
    }
    const scheme = matches[1].toLowerCase();

    if (has(options.allowedSchemesByTag, name)) {
      return options.allowedSchemesByTag[name].indexOf(scheme) === -1;
    }

    return !options.allowedSchemes || options.allowedSchemes.indexOf(scheme) === -1;
  }

  function parseUrl(value) {
    value = value.replace(/^(\w+:)?\s*[\\/]\s*[\\/]/, '$1//');
    if (value.startsWith('relative:')) {
      // An attempt to exploit our workaround for base URLs being
      // mandatory for relative URL validation in the WHATWG
      // URL parser, reject it
      throw new Error('relative: exploit attempt');
    }
    // naughtyHref is in charge of whether protocol relative URLs
    // are cool. Here we are concerned just with allowed hostnames and
    // whether to allow relative URLs.
    //
    // Build a placeholder "base URL" against which any reasonable
    // relative URL may be parsed successfully
    let base = 'relative://relative-site';
    for (let i = 0; (i < 100); i++) {
      base += `/${i}`;
    }

    const parsed = new URL(value, base);

    const isRelativeUrl = parsed && parsed.hostname === 'relative-site' && parsed.protocol === 'relative:';
    return {
      isRelativeUrl,
      url: parsed
    };
  }
  /**
   * Filters user input css properties by allowlisted regex attributes.
   * Modifies the abstractSyntaxTree object.
   *
   * @param {object} abstractSyntaxTree  - Object representation of CSS attributes.
   * @property {array[Declaration]} abstractSyntaxTree.nodes[0] - Each object cointains prop and value key, i.e { prop: 'color', value: 'red' }.
   * @param {object} allowedStyles       - Keys are properties (i.e color), value is list of permitted regex rules (i.e /green/i).
   * @return {object}                    - The modified tree.
   */
  function filterCss(abstractSyntaxTree, allowedStyles) {
    if (!allowedStyles) {
      return abstractSyntaxTree;
    }

    const astRules = abstractSyntaxTree.nodes[0];
    let selectedRule;

    // Merge global and tag-specific styles into new AST.
    if (allowedStyles[astRules.selector] && allowedStyles['*']) {
      selectedRule = deepmerge(
        allowedStyles[astRules.selector],
        allowedStyles['*']
      );
    } else {
      selectedRule = allowedStyles[astRules.selector] || allowedStyles['*'];
    }

    if (selectedRule) {
      abstractSyntaxTree.nodes[0].nodes = astRules.nodes.reduce(filterDeclarations(selectedRule), []);
    }

    return abstractSyntaxTree;
  }

  /**
   * Extracts the style attributes from an AbstractSyntaxTree and formats those
   * values in the inline style attribute format.
   *
   * @param  {AbstractSyntaxTree} filteredAST
   * @return {string}             - Example: "color:yellow;text-align:center !important;font-family:helvetica;"
   */
  function stringifyStyleAttributes(filteredAST) {
    return filteredAST.nodes[0].nodes
      .reduce(function(extractedAttributes, attrObject) {
        extractedAttributes.push(
          `${attrObject.prop}:${attrObject.value}${attrObject.important ? ' !important' : ''}`
        );
        return extractedAttributes;
      }, [])
      .join(';');
  }

  /**
    * Filters the existing attributes for the given property. Discards any attributes
    * which don't match the allowlist.
    *
    * @param  {object} selectedRule             - Example: { color: red, font-family: helvetica }
    * @param  {array} allowedDeclarationsList   - List of declarations which pass the allowlist.
    * @param  {object} attributeObject          - Object representing the current css property.
    * @property {string} attributeObject.type   - Typically 'declaration'.
    * @property {string} attributeObject.prop   - The CSS property, i.e 'color'.
    * @property {string} attributeObject.value  - The corresponding value to the css property, i.e 'red'.
    * @return {function}                        - When used in Array.reduce, will return an array of Declaration objects
    */
  function filterDeclarations(selectedRule) {
    return function (allowedDeclarationsList, attributeObject) {
      // If this property is allowlisted...
      if (has(selectedRule, attributeObject.prop)) {
        const matchesRegex = selectedRule[attributeObject.prop].some(function(regularExpression) {
          return regularExpression.test(attributeObject.value);
        });

        if (matchesRegex) {
          allowedDeclarationsList.push(attributeObject);
        }
      }
      return allowedDeclarationsList;
    };
  }

  function filterClasses(classes, allowed, allowedGlobs) {
    if (!allowed) {
      // The class attribute is allowed without filtering on this tag
      return classes;
    }
    classes = classes.split(/\s+/);
    return classes.filter(function(clss) {
      return allowed.indexOf(clss) !== -1 || allowedGlobs.some(function(glob) {
        return glob.test(clss);
      });
    }).join(' ');
  }
}

// Defaults are accessible to you so that you can use them as a starting point
// programmatically if you wish

const htmlParserDefaults = {
  decodeEntities: true
};
sanitizeHtml.defaults = {
  allowedTags: [
    // Sections derived from MDN element categories and limited to the more
    // benign categories.
    // https://developer.mozilla.org/en-US/docs/Web/HTML/Element
    // Content sectioning
    'address', 'article', 'aside', 'footer', 'header',
    'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'hgroup',
    'main', 'nav', 'section',
    // Text content
    'blockquote', 'dd', 'div', 'dl', 'dt', 'figcaption', 'figure',
    'hr', 'li', 'main', 'ol', 'p', 'pre', 'ul',
    // Inline text semantics
    'a', 'abbr', 'b', 'bdi', 'bdo', 'br', 'cite', 'code', 'data', 'dfn',
    'em', 'i', 'kbd', 'mark', 'q',
    'rb', 'rp', 'rt', 'rtc', 'ruby',
    's', 'samp', 'small', 'span', 'strong', 'sub', 'sup', 'time', 'u', 'var', 'wbr',
    // Table content
    'caption', 'col', 'colgroup', 'table', 'tbody', 'td', 'tfoot', 'th',
    'thead', 'tr'
  ],
  // Tags that cannot be boolean
  nonBooleanAttributes: [
    'abbr', 'accept', 'accept-charset', 'accesskey', 'action',
    'allow', 'alt', 'as', 'autocapitalize', 'autocomplete',
    'blocking', 'charset', 'cite', 'class', 'color', 'cols',
    'colspan', 'content', 'contenteditable', 'coords', 'crossorigin',
    'data', 'datetime', 'decoding', 'dir', 'dirname', 'download',
    'draggable', 'enctype', 'enterkeyhint', 'fetchpriority', 'for',
    'form', 'formaction', 'formenctype', 'formmethod', 'formtarget',
    'headers', 'height', 'hidden', 'high', 'href', 'hreflang',
    'http-equiv', 'id', 'imagesizes', 'imagesrcset', 'inputmode',
    'integrity', 'is', 'itemid', 'itemprop', 'itemref', 'itemtype',
    'kind', 'label', 'lang', 'list', 'loading', 'low', 'max',
    'maxlength', 'media', 'method', 'min', 'minlength', 'name',
    'nonce', 'optimum', 'pattern', 'ping', 'placeholder', 'popover',
    'popovertarget', 'popovertargetaction', 'poster', 'preload',
    'referrerpolicy', 'rel', 'rows', 'rowspan', 'sandbox', 'scope',
    'shape', 'size', 'sizes', 'slot', 'span', 'spellcheck', 'src',
    'srcdoc', 'srclang', 'srcset', 'start', 'step', 'style',
    'tabindex', 'target', 'title', 'translate', 'type', 'usemap',
    'value', 'width', 'wrap',
    // Event handlers
    'onauxclick', 'onafterprint', 'onbeforematch', 'onbeforeprint',
    'onbeforeunload', 'onbeforetoggle', 'onblur', 'oncancel',
    'oncanplay', 'oncanplaythrough', 'onchange', 'onclick', 'onclose',
    'oncontextlost', 'oncontextmenu', 'oncontextrestored', 'oncopy',
    'oncuechange', 'oncut', 'ondblclick', 'ondrag', 'ondragend',
    'ondragenter', 'ondragleave', 'ondragover', 'ondragstart',
    'ondrop', 'ondurationchange', 'onemptied', 'onended',
    'onerror', 'onfocus', 'onformdata', 'onhashchange', 'oninput',
    'oninvalid', 'onkeydown', 'onkeypress', 'onkeyup',
    'onlanguagechange', 'onload', 'onloadeddata', 'onloadedmetadata',
    'onloadstart', 'onmessage', 'onmessageerror', 'onmousedown',
    'onmouseenter', 'onmouseleave', 'onmousemove', 'onmouseout',
    'onmouseover', 'onmouseup', 'onoffline', 'ononline', 'onpagehide',
    'onpageshow', 'onpaste', 'onpause', 'onplay', 'onplaying',
    'onpopstate', 'onprogress', 'onratechange', 'onreset', 'onresize',
    'onrejectionhandled', 'onscroll', 'onscrollend',
    'onsecuritypolicyviolation', 'onseeked', 'onseeking', 'onselect',
    'onslotchange', 'onstalled', 'onstorage', 'onsubmit', 'onsuspend',
    'ontimeupdate', 'ontoggle', 'onunhandledrejection', 'onunload',
    'onvolumechange', 'onwaiting', 'onwheel'
  ],
  disallowedTagsMode: 'discard',
  allowedAttributes: {
    a: [ 'href', 'name', 'target' ],
    // We don't currently allow img itself by default, but
    // these attributes would make sense if we did.
    img: [ 'src', 'srcset', 'alt', 'title', 'width', 'height', 'loading' ]
  },
  allowedEmptyAttributes: [
    'alt'
  ],
  // Lots of these won't come up by default because we don't allow them
  selfClosing: [ 'img', 'br', 'hr', 'area', 'base', 'basefont', 'input', 'link', 'meta' ],
  // URL schemes we permit
  allowedSchemes: [ 'http', 'https', 'ftp', 'mailto', 'tel' ],
  allowedSchemesByTag: {},
  allowedSchemesAppliedToAttributes: [ 'href', 'src', 'cite' ],
  allowProtocolRelative: true,
  enforceHtmlBoundary: false,
  parseStyleAttributes: true
};

sanitizeHtml.simpleTransform = function(newTagName, newAttribs, merge) {
  merge = (merge === undefined) ? true : merge;
  newAttribs = newAttribs || {};

  return function(tagName, attribs) {
    let attrib;
    if (merge) {
      for (attrib in newAttribs) {
        attribs[attrib] = newAttribs[attrib];
      }
    } else {
      attribs = newAttribs;
    }

    return {
      tagName: newTagName,
      attribs: attribs
    };
  };
};

const sanitizeHtml$1 = sanitizeHtml_1;

var utc$1 = {exports: {}};

(function (module, exports) {
!function(t,i){module.exports=i();}(commonjsGlobal,(function(){var t="minute",i=/[+-]\d\d(?::?\d\d)?/g,e=/([+-]|\d\d)/g;return function(s,f,n){var u=f.prototype;n.utc=function(t){var i={date:t,utc:!0,args:arguments};return new f(i)},u.utc=function(i){var e=n(this.toDate(),{locale:this.$L,utc:!0});return i?e.add(this.utcOffset(),t):e},u.local=function(){return n(this.toDate(),{locale:this.$L,utc:!1})};var o=u.parse;u.parse=function(t){t.utc&&(this.$u=!0),this.$utils().u(t.$offset)||(this.$offset=t.$offset),o.call(this,t);};var r=u.init;u.init=function(){if(this.$u){var t=this.$d;this.$y=t.getUTCFullYear(),this.$M=t.getUTCMonth(),this.$D=t.getUTCDate(),this.$W=t.getUTCDay(),this.$H=t.getUTCHours(),this.$m=t.getUTCMinutes(),this.$s=t.getUTCSeconds(),this.$ms=t.getUTCMilliseconds();}else r.call(this);};var a=u.utcOffset;u.utcOffset=function(s,f){var n=this.$utils().u;if(n(s))return this.$u?0:n(this.$offset)?a.call(this):this.$offset;if("string"==typeof s&&(s=function(t){void 0===t&&(t="");var s=t.match(i);if(!s)return null;var f=(""+s[0]).match(e)||["-",0,0],n=f[0],u=60*+f[1]+ +f[2];return 0===u?0:"+"===n?u:-u}(s),null===s))return this;var u=Math.abs(s)<=16?60*s:s,o=this;if(f)return o.$offset=u,o.$u=0===s,o;if(0!==s){var r=this.$u?this.toDate().getTimezoneOffset():-1*this.utcOffset();(o=this.local().add(u+r,t)).$offset=u,o.$x.$localOffset=r;}else o=this.utc();return o};var h=u.format;u.format=function(t){var i=t||(this.$u?"YYYY-MM-DDTHH:mm:ss[Z]":"");return h.call(this,i)},u.valueOf=function(){var t=this.$utils().u(this.$offset)?0:this.$offset+(this.$x.$localOffset||this.$d.getTimezoneOffset());return this.$d.valueOf()-6e4*t},u.isUTC=function(){return !!this.$u},u.toISOString=function(){return this.toDate().toISOString()},u.toString=function(){return this.toDate().toUTCString()};var l=u.toDate;u.toDate=function(t){return "s"===t&&this.$offset?n(this.format("YYYY-MM-DD HH:mm:ss:SSS")).toDate():l.call(this)};var c=u.diff;u.diff=function(t,i,e){if(t&&this.$u===t.$u)return c.call(this,t,i,e);var s=this.local(),f=n(t).local();return c.call(s,f,i,e)};}}));
}(utc$1));

const utc = utc$1.exports;

var timezone$1 = {exports: {}};

(function (module, exports) {
!function(t,e){module.exports=e();}(commonjsGlobal,(function(){var t={year:0,month:1,day:2,hour:3,minute:4,second:5},e={};return function(n,i,o){var r,a=function(t,n,i){void 0===i&&(i={});var o=new Date(t),r=function(t,n){void 0===n&&(n={});var i=n.timeZoneName||"short",o=t+"|"+i,r=e[o];return r||(r=new Intl.DateTimeFormat("en-US",{hour12:!1,timeZone:t,year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",timeZoneName:i}),e[o]=r),r}(n,i);return r.formatToParts(o)},u=function(e,n){for(var i=a(e,n),r=[],u=0;u<i.length;u+=1){var f=i[u],s=f.type,m=f.value,c=t[s];c>=0&&(r[c]=parseInt(m,10));}var d=r[3],l=24===d?0:d,v=r[0]+"-"+r[1]+"-"+r[2]+" "+l+":"+r[4]+":"+r[5]+":000",h=+e;return (o.utc(v).valueOf()-(h-=h%1e3))/6e4},f=i.prototype;f.tz=function(t,e){void 0===t&&(t=r);var n=this.utcOffset(),i=this.toDate(),a=i.toLocaleString("en-US",{timeZone:t}),u=Math.round((i-new Date(a))/1e3/60),f=o(a).$set("millisecond",this.$ms).utcOffset(15*-Math.round(i.getTimezoneOffset()/15)-u,!0);if(e){var s=f.utcOffset();f=f.add(n-s,"minute");}return f.$x.$timezone=t,f},f.offsetName=function(t){var e=this.$x.$timezone||o.tz.guess(),n=a(this.valueOf(),e,{timeZoneName:t}).find((function(t){return "timezonename"===t.type.toLowerCase()}));return n&&n.value};var s=f.startOf;f.startOf=function(t,e){if(!this.$x||!this.$x.$timezone)return s.call(this,t,e);var n=o(this.format("YYYY-MM-DD HH:mm:ss:SSS"));return s.call(n,t,e).tz(this.$x.$timezone,!0)},o.tz=function(t,e,n){var i=n&&e,a=n||e||r,f=u(+o(),a);if("string"!=typeof t)return o(t).tz(a);var s=function(t,e,n){var i=t-60*e*1e3,o=u(i,n);if(e===o)return [i,e];var r=u(i-=60*(o-e)*1e3,n);return o===r?[i,o]:[t-60*Math.min(o,r)*1e3,Math.max(o,r)]}(o.utc(t,i).valueOf(),f,a),m=s[0],c=s[1],d=o(m).utcOffset(c);return d.$x.$timezone=a,d},o.tz.guess=function(){return Intl.DateTimeFormat().resolvedOptions().timeZone},o.tz.setDefault=function(t){r=t;};}}));
}(timezone$1));

const timezone = timezone$1.exports;

var fr = {exports: {}};

(function (module, exports) {
!function(e,n){module.exports=n(dayjs_min.exports);}(commonjsGlobal,(function(e){function n(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var t=n(e),i={name:"fr",weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),weekStart:1,yearStart:4,formats:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},ordinal:function(e){return ""+e+(1===e?"er":"")}};return t.default.locale(i,null,!0),i}));
}(fr));

var es = {exports: {}};

(function (module, exports) {
!function(e,o){module.exports=o(dayjs_min.exports);}(commonjsGlobal,(function(e){function o(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var s=o(e),d={name:"es",monthsShort:"ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),weekStart:1,formats:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},ordinal:function(e){return e+"º"}};return s.default.locale(d,null,!0),d}));
}(es));

var de = {exports: {}};

(function (module, exports) {
!function(e,n){module.exports=n(dayjs_min.exports);}(commonjsGlobal,(function(e){function n(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var t=n(e),a={s:"ein paar Sekunden",m:["eine Minute","einer Minute"],mm:"%d Minuten",h:["eine Stunde","einer Stunde"],hh:"%d Stunden",d:["ein Tag","einem Tag"],dd:["%d Tage","%d Tagen"],M:["ein Monat","einem Monat"],MM:["%d Monate","%d Monaten"],y:["ein Jahr","einem Jahr"],yy:["%d Jahre","%d Jahren"]};function i(e,n,t){var i=a[t];return Array.isArray(i)&&(i=i[n?0:1]),i.replace("%d",e)}var r={name:"de",weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So._Mo._Di._Mi._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),months:"Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sept._Okt._Nov._Dez.".split("_"),ordinal:function(e){return e+"."},weekStart:1,yearStart:4,formats:{LTS:"HH:mm:ss",LT:"HH:mm",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},relativeTime:{future:"in %s",past:"vor %s",s:i,m:i,mm:i,h:i,hh:i,d:i,dd:i,M:i,MM:i,y:i,yy:i}};return t.default.locale(r,null,!0),r}));
}(de));

var nl = {exports: {}};

(function (module, exports) {
!function(e,a){module.exports=a(dayjs_min.exports);}(commonjsGlobal,(function(e){function a(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var d=a(e),n={name:"nl",weekdays:"zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag".split("_"),weekdaysShort:"zo._ma._di._wo._do._vr._za.".split("_"),weekdaysMin:"zo_ma_di_wo_do_vr_za".split("_"),months:"januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december".split("_"),monthsShort:"jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec".split("_"),ordinal:function(e){return "["+e+(1===e||8===e||e>=20?"ste":"de")+"]"},weekStart:1,yearStart:4,formats:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},relativeTime:{future:"over %s",past:"%s geleden",s:"een paar seconden",m:"een minuut",mm:"%d minuten",h:"een uur",hh:"%d uur",d:"een dag",dd:"%d dagen",M:"een maand",MM:"%d maanden",y:"een jaar",yy:"%d jaar"}};return d.default.locale(n,null,!0),n}));
}(nl));

var sv = {exports: {}};

(function (module, exports) {
!function(e,t){module.exports=t(dayjs_min.exports);}(commonjsGlobal,(function(e){function t(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var a=t(e),d={name:"sv",weekdays:"söndag_måndag_tisdag_onsdag_torsdag_fredag_lördag".split("_"),weekdaysShort:"sön_mån_tis_ons_tor_fre_lör".split("_"),weekdaysMin:"sö_må_ti_on_to_fr_lö".split("_"),months:"januari_februari_mars_april_maj_juni_juli_augusti_september_oktober_november_december".split("_"),monthsShort:"jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec".split("_"),weekStart:1,yearStart:4,ordinal:function(e){var t=e%10;return "["+e+(1===t||2===t?"a":"e")+"]"},formats:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [kl.] HH:mm",LLLL:"dddd D MMMM YYYY [kl.] HH:mm",lll:"D MMM YYYY HH:mm",llll:"ddd D MMM YYYY HH:mm"},relativeTime:{future:"om %s",past:"för %s sedan",s:"några sekunder",m:"en minut",mm:"%d minuter",h:"en timme",hh:"%d timmar",d:"en dag",dd:"%d dagar",M:"en månad",MM:"%d månader",y:"ett år",yy:"%d år"}};return a.default.locale(d,null,!0),d}));
}(sv));

var ja = {exports: {}};

(function (module, exports) {
!function(e,_){module.exports=_(dayjs_min.exports);}(commonjsGlobal,(function(e){function _(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var t=_(e),d={name:"ja",weekdays:"日曜日_月曜日_火曜日_水曜日_木曜日_金曜日_土曜日".split("_"),weekdaysShort:"日_月_火_水_木_金_土".split("_"),weekdaysMin:"日_月_火_水_木_金_土".split("_"),months:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),ordinal:function(e){return e+"日"},formats:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日 dddd HH:mm",l:"YYYY/MM/DD",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日(ddd) HH:mm"},meridiem:function(e){return e<12?"午前":"午後"},relativeTime:{future:"%s後",past:"%s前",s:"数秒",m:"1分",mm:"%d分",h:"1時間",hh:"%d時間",d:"1日",dd:"%d日",M:"1ヶ月",MM:"%dヶ月",y:"1年",yy:"%d年"}};return t.default.locale(d,null,!0),d}));
}(ja));

var zhCn = {exports: {}};

(function (module, exports) {
!function(e,_){module.exports=_(dayjs_min.exports);}(commonjsGlobal,(function(e){function _(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var t=_(e),d={name:"zh-cn",weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"周日_周一_周二_周三_周四_周五_周六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),ordinal:function(e,_){return "W"===_?e+"周":e+"日"},weekStart:1,yearStart:4,formats:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日Ah点mm分",LLLL:"YYYY年M月D日ddddAh点mm分",l:"YYYY/M/D",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},relativeTime:{future:"%s内",past:"%s前",s:"几秒",m:"1 分钟",mm:"%d 分钟",h:"1 小时",hh:"%d 小时",d:"1 天",dd:"%d 天",M:"1 个月",MM:"%d 个月",y:"1 年",yy:"%d 年"},meridiem:function(e,_){var t=100*e+_;return t<600?"凌晨":t<900?"早上":t<1100?"上午":t<1300?"中午":t<1800?"下午":"晚上"}};return t.default.locale(d,null,!0),d}));
}(zhCn));

var ko = {exports: {}};

(function (module, exports) {
!function(e,_){module.exports=_(dayjs_min.exports);}(commonjsGlobal,(function(e){function _(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var d=_(e),t={name:"ko",weekdays:"일요일_월요일_화요일_수요일_목요일_금요일_토요일".split("_"),weekdaysShort:"일_월_화_수_목_금_토".split("_"),weekdaysMin:"일_월_화_수_목_금_토".split("_"),months:"1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월".split("_"),monthsShort:"1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월".split("_"),ordinal:function(e){return e},formats:{LT:"A h:mm",LTS:"A h:mm:ss",L:"YYYY.MM.DD.",LL:"YYYY년 MMMM D일",LLL:"YYYY년 MMMM D일 A h:mm",LLLL:"YYYY년 MMMM D일 dddd A h:mm",l:"YYYY.MM.DD.",ll:"YYYY년 MMMM D일",lll:"YYYY년 MMMM D일 A h:mm",llll:"YYYY년 MMMM D일 dddd A h:mm"},meridiem:function(e){return e<12?"오전":"오후"},relativeTime:{future:"%s 후",past:"%s 전",s:"몇 초",m:"1분",mm:"%d분",h:"한 시간",hh:"%d시간",d:"하루",dd:"%d일",M:"한 달",MM:"%d달",y:"일 년",yy:"%d년"}};return d.default.locale(t,null,!0),t}));
}(ko));

dayjs.extend(utc);
dayjs.extend(timezone);
const sanitizeOptions = {
    textFilter: function (text) {
        return text.replace(/&amp;/g, '&');
    },
};
function getTimezoneOffset(timezone) {
    return dayjs().tz(timezone).format('Z');
}
function sanitize(text) {
    return sanitizeHtml$1(text, sanitizeOptions);
}
function debug(...args) {
    if (window && window.localStorage && window.localStorage.getItem('debug')) {
        console.groupCollapsed(...args);
        const error = new Error();
        error.name = 'Debug';
        console.debug(error.stack);
        console.groupEnd();
    }
}
function error(...args) {
    console.error(...args);
}
function uniqueID() {
    return Math.random().toString(36).substr(2, 9);
}
function formatEventName(propKey) {
    return propKey.toString().replace(/^on/, '');
}
function getLastDayOfMonth(date) {
    return new Date(date.getFullYear(), date.getMonth() + 1, 0);
}
function getFirstDayOfMonth(date) {
    return new Date(date.getFullYear(), date.getMonth(), 1);
}
function isSameDay(date1, date2) {
    return date1.getFullYear() === date2.getFullYear() && date1.getMonth() === date2.getMonth() && date1.getDate() === date2.getDate();
}
function isSameDayTimezone(timeslot, comparisonDate, timezoneStr) {
    const timeslotInTimezone = dayjs(timeslot).tz(timezoneStr);
    const comparisonDateInTimezone = dayjs(comparisonDate);
    return (timeslotInTimezone.year() === comparisonDateInTimezone.year() &&
        timeslotInTimezone.month() === comparisonDateInTimezone.month() &&
        timeslotInTimezone.date() === comparisonDateInTimezone.date());
}
function formatBookedEventDate(date, timezoneStr, language = 'en-US') {
    return dayjs(date).tz(timezoneStr).locale(language).format('dddd, MMMM D, YYYY');
}
function isSameMonth(date1, date2) {
    return date1.getFullYear() === date2.getFullYear() && date1.getMonth() === date2.getMonth();
}
const validateTimeFormatInput = text => {
    if (text === '') {
        return true;
    }
    const regexPattern = /^(0[0-9]|1[0-2]|^[0-9])(:[0-5][0-9][ap]m?|:[0-5][0-9]|:[0-5]|:)?$/i;
    return regexPattern.test(text);
};
const validateExactTimeFormat = input => {
    const regex = /^(0[1-9]|1[0-2]):([0-5][0-9])(am|pm)$/i;
    return regex.test(input);
};
function roundToNearest15Minutes(time = null) {
    let currentTime = dayjs();
    if (time) {
        currentTime = time;
    }
    const minuteRemainder = currentTime.minute() % 15;
    let roundedTime;
    if (minuteRemainder !== 0) {
        roundedTime = currentTime.add(15 - minuteRemainder, 'minute');
    }
    else {
        roundedTime = currentTime;
    }
    return roundedTime;
}
function autocompleteTimeFormat(input) {
    const currentTime = dayjs();
    let completedTime = '';
    const [inputHour, inputMinuteWithAmPm] = input.split(':');
    if (inputHour.length === 1) {
        completedTime += '0' + inputHour;
    }
    else if (inputHour.length === 2) {
        completedTime += inputHour;
    }
    completedTime += ':';
    if (inputMinuteWithAmPm === undefined || inputMinuteWithAmPm == '') {
        completedTime += '00';
    }
    else {
        if (inputMinuteWithAmPm.length === 1) {
            completedTime += inputMinuteWithAmPm + '0';
        }
        else {
            completedTime += inputMinuteWithAmPm;
        }
    }
    const amPmIndicator = completedTime.slice(-1);
    if (amPmIndicator === 'a') {
        completedTime += 'm';
    }
    if (amPmIndicator === 'p') {
        completedTime += 'm';
    }
    if (completedTime.slice(-1) !== 'm') {
        if (completedTime.split(':')[0] == '00') {
            completedTime += 'am';
        }
        else {
            completedTime += currentTime.format('a');
        }
    }
    return completedTime;
}
function convertTo12HourFormat(timeStr) {
    const [hoursInitial, minutes] = timeStr.split(':').map(num => parseInt(num, 10));
    let hours = hoursInitial;
    const ampm = hours >= 12 ? 'pm' : 'am';
    hours = hours % 12;
    hours = hours ? hours : 12;
    const formattedHours = hours.toString().padStart(2, '0');
    const formattedMinutes = minutes.toString().padStart(2, '0');
    return `${formattedHours}:${formattedMinutes}${ampm}`;
}
function convertTo24HourFormat(timeStr) {
    const [time, modifier] = timeStr.split(/(am|pm)/i);
    const [hoursInitial, minutes] = time.split(':').map(num => parseInt(num, 10));
    let hours = hoursInitial;
    if (modifier.toLowerCase() === 'pm' && hours < 12) {
        hours += 12;
    }
    else if (modifier.toLowerCase() === 'am' && hours === 12) {
        hours = 0;
    }
    return `${hours.toString().padStart(2, '0')}:${minutes.toString().padStart(2, '0')}`;
}
function timeToMinutes(time) {
    const [hours, minutesPart] = time.match(/(\d+):(\d+)(am|pm)/).slice(1);
    let minutes = parseInt(hours, 10) * 60 + parseInt(minutesPart, 10);
    if (time.includes('pm') && parseInt(hours, 10) < 12)
        minutes += 12 * 60;
    if (time.includes('am') && parseInt(hours, 10) === 12)
        minutes -= 12 * 60;
    return minutes;
}
function minutesToTime(minutes) {
    const h = Math.floor(minutes / 60);
    const m = minutes % 60;
    return `${h}:${m < 10 ? '0' : ''}${m}`;
}
function getBrowser() {
    const ua = navigator.userAgent;
    const isChrome = /Chrome/.test(ua) && /Google Inc/.test(navigator.vendor);
    const isSafari = /Safari/.test(ua) && /Apple Computer/.test(navigator.vendor);
    const isFirefox = /Firefox/.test(ua);
    const isIE = /Trident/.test(ua);
    const isEdgeLegacy = /Edge/.test(ua);
    const isEdgeChromium = isChrome && /Edg/.test(ua);
    if (isEdgeChromium)
        return 'Edge (Chromium)';
    if (isChrome)
        return 'Chrome';
    if (isSafari)
        return 'Safari';
    if (isFirefox)
        return 'Firefox';
    if (isIE)
        return 'Internet Explorer';
    if (isEdgeLegacy)
        return 'Edge (Legacy)';
    return 'Unknown';
}
function dataResponse(data, error = null) {
    if (error) {
        return [null, error];
    }
    return [data, null];
}
function parsePreviewLink(link, config) {
    const replacements = {
        'config.id': config?.id,
        'id': config?.id,
        'slug': config?.slug,
    };
    Object.keys(replacements).forEach(key => {
        if (replacements[key]) {
            link = link.replace(`{${key}}`, replacements[key]);
        }
    });
    return link;
}
function isNonPrintableKey(event) {
    if (event.keyCode < 48 ||
        (event.keyCode > 90 && event.keyCode < 96) ||
        (event.keyCode > 111 && event.keyCode < 186) ||
        event.keyCode > 222 ||
        event.keyCode === 32 ||
        event.keyCode === 91 ||
        event.keyCode === 92 ||
        event.keyCode === 93 ||
        (event.keyCode >= 112 && event.keyCode <= 123) ||
        (event.keyCode >= 37 && event.keyCode <= 40)) {
        return true;
    }
    if (event.ctrlKey || event.altKey || event.metaKey) {
        return true;
    }
    const shiftSpecialChars = [
        48,
        49,
        50,
        51,
        52,
        53,
        54,
        55,
        56,
        57,
        186,
        187,
        188,
        189,
        190,
        191,
        192,
        219,
        220,
        221,
        222,
    ];
    if (event.shiftKey && shiftSpecialChars.includes(event.keyCode)) {
        return false;
    }
    return false;
}
function addDaysToCurrentDate(startDate, days) {
    const currentDate = new Date(startDate);
    currentDate.setDate(currentDate.getDate() + days);
    currentDate.setHours(23);
    currentDate.setMinutes(59);
    currentDate.setSeconds(0);
    currentDate.setMilliseconds(0);
    return currentDate;
}
function isObject(item) {
    return item && typeof item === 'object' && !Array.isArray(item);
}
function mergeDeep(target, source) {
    if (Array.isArray(target) && Array.isArray(source) && target !== source) {
        if (target.some(item => item.is_organizer) && source.some(item => item.is_organizer)) {
            target = target.map(participant => ({ ...participant, is_organizer: false }));
        }
        else if (!source.some(item => item.is_organizer)) {
            let foundOrganizer = false;
            target = target.map(participant => {
                if (!foundOrganizer) {
                    foundOrganizer = true;
                    return { ...participant, is_organizer: true };
                }
                return participant;
            });
        }
        return target
            .map((item, index) => {
            return source[index] ? mergeDeep(item, source[index]) : item;
        })
            .concat(source.slice(target.length));
    }
    else if (isObject(target) && isObject(source)) {
        const output = Object.assign({}, target);
        Object.keys(source).forEach(key => {
            if (isObject(source[key])) {
                if (!(key in target)) {
                    output[key] = source[key];
                }
                else {
                    output[key] = mergeDeep(target[key], source[key]);
                }
            }
            else {
                output[key] = source[key];
            }
        });
        return output;
    }
    return source;
}
function convertMinutesToHoursAndMinutes(minutes) {
    if (minutes < 60) {
        return `${minutes} ${t('time.minutes')}`;
    }
    const hours = Math.floor(minutes / 60);
    const remainingMinutes = minutes % 60;
    const hoursText = t(`time.${hours > 1 ? 'hours' : 'hour'}`);
    const minutesText = remainingMinutes ? `${remainingMinutes} ${t(`time.${remainingMinutes > 1 ? 'minutes' : 'minute'}`)}` : '';
    return `${hours} ${hoursText} ${minutesText}`;
}
function checkForMissingSlots(slots, host) {
    slots.forEach(slot => {
        const slotElement = host.shadowRoot?.querySelector(`slot[name="${slot}"]`);
        const slotNodes = slotElement?.assignedNodes();
        if (slotNodes && slotNodes.length === 0) {
            console.warn(`${host.nodeName} No content provided for slot="${slot}".`);
        }
    });
}
function compactStringToUUIDs(compactString) {
    const buffer = Buffer.from(compactString, 'base64');
    const uuidBytes1 = buffer.slice(0, 16);
    const uuidBytes2 = buffer.slice(16, 32);
    const salt = buffer.slice(32);
    function bufferToUUID(buffer) {
        const hex = buffer.toString('hex');
        return `${hex.slice(0, 8)}-${hex.slice(8, 12)}-${hex.slice(12, 16)}-${hex.slice(16, 20)}-${hex.slice(20)}`;
    }
    const uuid1 = bufferToUUID(uuidBytes1);
    const uuid2 = bufferToUUID(uuidBytes2);
    const b64EncodedSalt = salt.toString('base64').replace(/\+/g, '-').replace(/\//g, '_').replace(/=+$/, '');
    return [uuid1, uuid2, b64EncodedSalt];
}
const t = key => {
    return instance.t(key);
};
const capitalizeFirstLetter = (str) => {
    if (typeof str !== 'string')
        return '';
    return str.charAt(0).toUpperCase() + str.slice(1);
};
const translateMonth = (month) => {
    return t(`months.${month}`);
};
const isValidUrl = (url) => {
    try {
        new URL(url);
        return true;
    }
    catch (e) {
        return false;
    }
};
const isValidImage = (url) => {
    return new Promise((resolve, reject) => {
        if (url === '')
            return resolve(true);
        const img = new Image();
        img.src = url;
        img.onerror = () => {
            reject(false);
        };
        img.onload = () => {
            resolve(true);
        };
    });
};
function generateRRule(selectedDate, option, endDate, customOptions, timezoneStr = 'UTC') {
    const daysOfWeek = {
        0: RRule.SU,
        1: RRule.MO,
        2: RRule.TU,
        3: RRule.WE,
        4: RRule.TH,
        5: RRule.FR,
        6: RRule.SA,
    };
    const selectedDay = dayjs.tz(selectedDate, timezoneStr).toDate();
    const dayOfWeek = daysOfWeek[selectedDay.getDay()];
    const date = selectedDay.getDate();
    const occurrenceInMonth = Math.ceil(date / 7);
    const untilDate = endDate ? dayjs.tz(endDate, timezoneStr).toDate() : undefined;
    switch (option) {
        case 'none': {
            return null;
        }
        case 'daily': {
            return new RRule({
                freq: RRule.DAILY,
                until: untilDate,
            }).toString();
        }
        case 'weekly': {
            return new RRule({
                freq: RRule.WEEKLY,
                byweekday: dayOfWeek,
                until: untilDate,
            }).toString();
        }
        case 'monthly': {
            return new RRule({
                freq: RRule.MONTHLY,
                byweekday: [dayOfWeek.nth(occurrenceInMonth)],
                until: untilDate,
            }).toString();
        }
        case 'yearly': {
            return new RRule({
                freq: RRule.YEARLY,
                dtstart: selectedDay,
                until: untilDate,
            }).toString();
        }
        case 'custom': {
            if (!customOptions) {
                throw new Error('Custom options must be provided for custom recurrence.');
            }
            const byweekday = customOptions.frequency === 'weekly'
                ? customOptions.daysOfWeek?.map(day => RRule[day])
                : customOptions.frequency === 'monthly' && !customOptions.monthlySameDate
                    ? [dayOfWeek.nth(occurrenceInMonth)]
                    : undefined;
            const bymonthday = customOptions.frequency === 'monthly' && customOptions.monthlySameDate ? dayjs.tz(selectedDate, timezoneStr).date() : undefined;
            return new RRule({
                freq: {
                    daily: RRule.DAILY,
                    weekly: RRule.WEEKLY,
                    monthly: RRule.MONTHLY,
                    yearly: RRule.YEARLY,
                }[customOptions.frequency || 'daily'],
                interval: customOptions.interval || 1,
                byweekday,
                bymonthday,
                until: customOptions.end?.type === 'on' ? dayjs.tz(customOptions.end.date, timezoneStr).toDate() : undefined,
                count: customOptions.end?.type === 'after' ? customOptions.end.count : undefined,
            }).toString();
        }
        default: {
            throw new Error(`Invalid option: ${option}`);
        }
    }
}
function getCalendarRange(currentDate, viewType) {
    const current = dayjs(currentDate).startOf('day');
    let startTime;
    let endTime;
    switch (viewType) {
        case 'week': {
            startTime = current.startOf('week');
            endTime = current.endOf('week');
            break;
        }
        case 'month': {
            startTime = current.startOf('month').startOf('week');
            endTime = current.endOf('month').endOf('week');
            break;
        }
        case 'day': {
            startTime = current.startOf('day');
            endTime = current.endOf('day');
            break;
        }
        default: {
            throw new Error('Invalid viewType. Use "week", "month", or "day".');
        }
    }
    return {
        startTime: startTime.unix(),
        endTime: endTime.unix(),
    };
}

export { translateMonth as A, Buffer as B, getTimezoneOffset as C, isSameDayTimezone as D, timeToMinutes as E, convertTo12HourFormat as F, convertTo24HourFormat as G, minutesToTime as H, isValidUrl as I, checkForMissingSlots as J, generateRRule as K, isValidImage as L, getBrowser as M, isNonPrintableKey as N, autocompleteTimeFormat as O, validateTimeFormatInput as P, roundToNearest15Minutes as Q, validateExactTimeFormat as R, dayjs as a, debug as b, commonjsGlobal as c, dataResponse as d, uniqueID as e, formatEventName as f, getCalendarRange as g, global$1 as h, instance as i, addDaysToCurrentDate as j, compactStringToUUIDs as k, capitalizeFirstLetter as l, mergeDeep as m, parsePreviewLink as n, error as o, process as p, formatBookedEventDate as q, sanitize as r, sanitizeHtml$1 as s, timezone as t, utc as u, isSameMonth as v, getLastDayOfMonth as w, getFirstDayOfMonth as x, isSameDay as y, convertMinutesToHoursAndMinutes as z };

//# sourceMappingURL=utils-b7f9cbcc.js.map